Crate browser_protocol

Crate browser_protocol 

Modules

accessibility
animation
audits
Audits domain allows investigation of page violations and possible improvements.
autofill
Defines commands and events for Autofill.
backgroundservice
Defines events for background web platform features.
bluetoothemulation
This domain allows configuring virtual Bluetooth devices to test the web-bluetooth API.
browser
The Browser domain defines methods and events for browser managing.
cachestorage
cast
A domain for interacting with Cast, Presentation API, and Remote Playback API functionalities.
crashreportcontext
This domain exposes the current state of the CrashReportContext API.
css
This domain exposes CSS read/write operations. All CSS objects (stylesheets, rules, and styles) have an associated ‘id’ used in subsequent operations on the related object. Each object type has a specific ‘id’ structure, and those are not interchangeable between objects of different kinds. CSS objects can be loaded using the ‘get*ForNode()’ calls (which accept a DOM node id). A client can also keep track of stylesheets via the ‘styleSheetAdded’/‘styleSheetRemoved’ events and subsequently load the required stylesheet contents using the ‘getStyleSheet[Text]()’ methods.
debugger
deviceaccess
deviceorientation
dom
This domain exposes DOM read/write operations. Each DOM Node is represented with its mirror object that has an ‘id’. This ‘id’ can be used to get additional information on the Node, resolve it into the JavaScript object wrapper, etc. It is important that client receives DOM events only for the nodes that are known to the client. Backend keeps track of the nodes that were sent to the client and never sends the same node twice. It is client’s responsibility to collect information about the nodes that were sent to the client. Note that ‘iframe’ owner elements will return corresponding document elements as their child nodes.
domdebugger
DOM debugging allows setting breakpoints on particular DOM operations and events. JavaScript execution will stop on these operations as if there was a regular breakpoint set.
domsnapshot
This domain facilitates obtaining document snapshots with DOM, layout, and style information.
domstorage
Query and modify DOM storage.
emulation
This domain emulates different environments for the page.
eventbreakpoints
EventBreakpoints permits setting JavaScript breakpoints on operations and events occurring in native code invoked from JavaScript. Once breakpoint is hit, it is reported through Debugger domain, similarly to regular breakpoints being hit.
extensions
Defines commands and events for browser extensions.
fedcm
This domain allows interacting with the FedCM dialog.
fetch
A domain for letting clients substitute browser’s network layer with client code.
filesystem
headlessexperimental
This domain provides experimental commands only supported in headless mode.
heap_profiler
indexeddb
input
inspector
io
Input/Output operations for streams produced by DevTools.
layertree
log
Provides access to log entries.
media
This domain allows detailed inspection of media elements.
memory
network
Network domain allows tracking network activities of the page. It exposes information about http, file, data and other requests and responses, their headers, bodies, timing, etc.
overlay
This domain provides various functionality related to drawing atop the inspected page.
page
Actions and events related to the inspected page belong to the page domain.
performance
performancetimeline
Reporting of performance timeline events, as specified in https://w3c.github.io/performance-timeline/#dom-performanceobserver.
preload
profiler
pwa
This domain allows interacting with the browser to control PWAs.
runtime
security
serviceworker
smartcardemulation
storage
systeminfo
The SystemInfo domain defines methods and events for querying low-level system information.
target
Supports additional targets discovery and allows to attach to them.
tethering
The Tethering domain defines methods and events for browser port binding.
tracing
webaudio
This domain allows inspection of Web Audio API. https://webaudio.github.io/web-audio-api/
webauthn
This domain allows configuring virtual authenticators to test the WebAuthn API.