Module accessibility

Module accessibility 

Structs

AXNode
A node in the accessibility tree.
AXNodeBuilder
AXProperty
AXPropertyBuilder
AXRelatedNode
AXRelatedNodeBuilder
AXValue
A single computed AX property.
AXValueBuilder
AXValueSource
A single source for a computed AX property.
AXValueSourceBuilder
DisableParams
EnableParams
GetAXNodeAndAncestorsParams
Fetches a node and all ancestors up to and including the root. Requires ‘enable()’ to have been called previously.
GetAXNodeAndAncestorsParamsBuilder
GetAXNodeAndAncestorsReturns
Fetches a node and all ancestors up to and including the root. Requires ‘enable()’ to have been called previously.
GetAXNodeAndAncestorsReturnsBuilder
GetChildAXNodesParams
Fetches a particular accessibility node by AXNodeId. Requires ‘enable()’ to have been called previously.
GetChildAXNodesParamsBuilder
GetChildAXNodesReturns
Fetches a particular accessibility node by AXNodeId. Requires ‘enable()’ to have been called previously.
GetChildAXNodesReturnsBuilder
GetFullAXTreeParams
Fetches the entire accessibility tree for the root Document
GetFullAXTreeParamsBuilder
GetFullAXTreeReturns
Fetches the entire accessibility tree for the root Document
GetFullAXTreeReturnsBuilder
GetPartialAXTreeParams
Fetches the accessibility node and partial accessibility tree for this DOM node, if it exists.
GetPartialAXTreeParamsBuilder
GetPartialAXTreeReturns
Fetches the accessibility node and partial accessibility tree for this DOM node, if it exists.
GetPartialAXTreeReturnsBuilder
GetRootAXNodeParams
Fetches the root node. Requires ‘enable()’ to have been called previously.
GetRootAXNodeParamsBuilder
GetRootAXNodeReturns
Fetches the root node. Requires ‘enable()’ to have been called previously.
GetRootAXNodeReturnsBuilder
QueryAXTreeParams
Query a DOM node’s accessibility subtree for accessible name and role. This command computes the name and role for all nodes in the subtree, including those that are ignored for accessibility, and returns those that match the specified name and role. If no DOM node is specified, or the DOM node does not exist, the command returns an error. If neither ‘accessibleName’ or ‘role’ is specified, it returns all the accessibility nodes in the subtree.
QueryAXTreeParamsBuilder
QueryAXTreeReturns
Query a DOM node’s accessibility subtree for accessible name and role. This command computes the name and role for all nodes in the subtree, including those that are ignored for accessibility, and returns those that match the specified name and role. If no DOM node is specified, or the DOM node does not exist, the command returns an error. If neither ‘accessibleName’ or ‘role’ is specified, it returns all the accessibility nodes in the subtree.
QueryAXTreeReturnsBuilder

Enums

AXPropertyName
Values of AXProperty name:
AXValueNativeSourceType
Enum of possible native property sources (as a subtype of a particular AXValueSourceType).
AXValueSourceType
Enum of possible property sources.
AXValueType
Enum of possible property types.

Type Aliases

AXNodeId
Unique accessibility node identifier.