pub struct AXValue<'a> { /* private fields */ }Expand description
A single computed AX property.
Implementations
Sourceimpl<'a> AXValue<'a>
impl<'a> AXValue<'a>
Sourcepub fn builder(type_: impl Into<AXValueType>) -> AXValueBuilder<'a>
pub fn builder(type_: impl Into<AXValueType>) -> AXValueBuilder<'a>
Creates a builder for this type with the required parameters:
type_: The type of this value.
Sourcepub fn type_(&self) -> &AXValueType
pub fn type_(&self) -> &AXValueType
The type of this value.
One or more related nodes, if applicable.
Sourcepub fn sources(&self) -> Option<&[AXValueSource<'a>]>
pub fn sources(&self) -> Option<&[AXValueSource<'a>]>
The sources which contributed to the computation of this property.