pub struct AXValueSource {
pub type_: AXValueSourceType,
pub value: Option<AXValue>,
pub attribute: Option<String>,
pub attributeValue: Option<AXValue>,
pub superseded: Option<bool>,
pub nativeSource: Option<AXValueNativeSourceType>,
pub nativeSourceValue: Option<AXValue>,
pub invalid: Option<bool>,
pub invalidReason: Option<String>,
}Expand description
A single source for a computed AX property.
Fields
type_: AXValueSourceTypeWhat type of source this is.
value: Option<AXValue>The value of this property source.
attribute: Option<String>The name of the relevant attribute, if any.
attributeValue: Option<AXValue>The value of the relevant attribute, if any.
superseded: Option<bool>Whether this source is superseded by a higher priority source.
nativeSource: Option<AXValueNativeSourceType>The native markup source for this value, e.g. a ‘
nativeSourceValue: Option<AXValue>The value, such as a node or node list, of the native source.
invalid: Option<bool>Whether the value for this property is invalid.
invalidReason: Option<String>Reason for the value being invalid, if it is.