AXValueSourceBuilder

Struct AXValueSourceBuilder 

pub struct AXValueSourceBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> AXValueSourceBuilder<'a>

pub fn value(self, value: AXValue<'a>) -> Self

The value of this property source.

pub fn attribute(self, attribute: impl Into<Cow<'a, str>>) -> Self

The name of the relevant attribute, if any.

pub fn attribute_value(self, attribute_value: AXValue<'a>) -> Self

The value of the relevant attribute, if any.

pub fn superseded(self, superseded: bool) -> Self

Whether this source is superseded by a higher priority source.

pub fn native_source( self, native_source: impl Into<AXValueNativeSourceType>, ) -> Self

The native markup source for this value, e.g. a ‘<label>’ element.

pub fn native_source_value(self, native_source_value: AXValue<'a>) -> Self

The value, such as a node or node list, of the native source.

pub fn invalid(self, invalid: bool) -> Self

Whether the value for this property is invalid.

pub fn invalid_reason(self, invalid_reason: impl Into<Cow<'a, str>>) -> Self

Reason for the value being invalid, if it is.

pub fn build(self) -> AXValueSource<'a>