pub struct GetPartialAXTreeParams {
pub nodeId: Option<NodeId>,
pub backendNodeId: Option<BackendNodeId>,
pub objectId: Option<RemoteObjectId>,
pub fetchRelatives: Option<bool>,
}Expand description
Fetches the accessibility node and partial accessibility tree for this DOM node, if it exists.
Fields
nodeId: Option<NodeId>Identifier of the node to get the partial accessibility tree for.
backendNodeId: Option<BackendNodeId>Identifier of the backend node to get the partial accessibility tree for.
objectId: Option<RemoteObjectId>JavaScript object id of the node wrapper to get the partial accessibility tree for.
fetchRelatives: Option<bool>Whether to fetch this node’s ancestors, siblings and children. Defaults to true.
Implementations