pub struct GetPartialAXTreeParamsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> GetPartialAXTreeParamsBuilder<'a>
impl<'a> GetPartialAXTreeParamsBuilder<'a>
Sourcepub fn node_id(self, node_id: NodeId) -> Self
pub fn node_id(self, node_id: NodeId) -> Self
Identifier of the node to get the partial accessibility tree for.
Sourcepub fn backend_node_id(self, backend_node_id: BackendNodeId) -> Self
pub fn backend_node_id(self, backend_node_id: BackendNodeId) -> Self
Identifier of the backend node to get the partial accessibility tree for.
Sourcepub fn object_id(self, object_id: RemoteObjectId<'a>) -> Self
pub fn object_id(self, object_id: RemoteObjectId<'a>) -> Self
JavaScript object id of the node wrapper to get the partial accessibility tree for.
Sourcepub fn fetch_relatives(self, fetch_relatives: bool) -> Self
pub fn fetch_relatives(self, fetch_relatives: bool) -> Self
Whether to fetch this node’s ancestors, siblings and children. Defaults to true.
pub fn build(self) -> GetPartialAXTreeParams<'a>