pub struct QueryAXTreeParams<'a> { /* private fields */ }Expand description
Query a DOM node’s accessibility subtree for accessible name and role. This command computes the name and role for all nodes in the subtree, including those that are ignored for accessibility, and returns those that match the specified name and role. If no DOM node is specified, or the DOM node does not exist, the command returns an error. If neither ‘accessibleName’ or ‘role’ is specified, it returns all the accessibility nodes in the subtree.
Implementations
Sourceimpl<'a> QueryAXTreeParams<'a>
impl<'a> QueryAXTreeParams<'a>
Sourcepub fn builder() -> QueryAXTreeParamsBuilder<'a>
pub fn builder() -> QueryAXTreeParamsBuilder<'a>
Creates a builder for this type.
Sourcepub fn backend_node_id(&self) -> Option<&BackendNodeId>
pub fn backend_node_id(&self) -> Option<&BackendNodeId>
Identifier of the backend node for the root to query.
Sourcepub fn object_id(&self) -> Option<&RemoteObjectId<'a>>
pub fn object_id(&self) -> Option<&RemoteObjectId<'a>>
JavaScript object id of the node wrapper for the root to query.
Sourcepub fn accessible_name(&self) -> Option<&str>
pub fn accessible_name(&self) -> Option<&str>
Find nodes with this computed name.