Module animation

Module animation 

Structs

Animation
Animation instance.
AnimationEffect
AnimationEffect instance
DisableParams
EnableParams
GetCurrentTimeParams
Returns the current time of the an animation.
GetCurrentTimeReturns
Returns the current time of the an animation.
GetPlaybackRateParams
GetPlaybackRateReturns
Gets the playback rate of the document timeline.
KeyframeStyle
Keyframe Style
KeyframesRule
Keyframes Rule
ReleaseAnimationsParams
Releases a set of animations to no longer be manipulated.
ResolveAnimationParams
Gets the remote object of the Animation.
ResolveAnimationReturns
Gets the remote object of the Animation.
SeekAnimationsParams
Seek a set of animations to a particular time within each animation.
SetPausedParams
Sets the paused state of a set of animations.
SetPlaybackRateParams
Sets the playback rate of the document timeline.
SetTimingParams
Sets the timing of an animation node.
ViewOrScrollTimeline
Timeline instance