pub struct ViewOrScrollTimeline { /* private fields */ }Expand description
Timeline instance
Implementations
Sourceimpl ViewOrScrollTimeline
impl ViewOrScrollTimeline
Sourcepub fn builder(axis: ScrollOrientation) -> ViewOrScrollTimelineBuilder
pub fn builder(axis: ScrollOrientation) -> ViewOrScrollTimelineBuilder
Creates a builder for this type with the required parameters:
axis: Orientation of the scroll
Sourcepub fn source_node_id(&self) -> Option<&BackendNodeId>
pub fn source_node_id(&self) -> Option<&BackendNodeId>
Scroll container node
Sourcepub fn start_offset(&self) -> Option<f64>
pub fn start_offset(&self) -> Option<f64>
Represents the starting scroll position of the timeline as a length offset in pixels from scroll origin.
Sourcepub fn end_offset(&self) -> Option<f64>
pub fn end_offset(&self) -> Option<f64>
Represents the ending scroll position of the timeline as a length offset in pixels from scroll origin.
Sourcepub fn subject_node_id(&self) -> Option<&BackendNodeId>
pub fn subject_node_id(&self) -> Option<&BackendNodeId>
The element whose principal box’s visibility in the scrollport defined the progress of the timeline. Does not exist for animations with ScrollTimeline
Sourcepub fn axis(&self) -> &ScrollOrientation
pub fn axis(&self) -> &ScrollOrientation
Orientation of the scroll