pub struct ViewOrScrollTimelineBuilder { /* private fields */ }Implementations
Sourceimpl ViewOrScrollTimelineBuilder
impl ViewOrScrollTimelineBuilder
Sourcepub fn source_node_id(self, source_node_id: BackendNodeId) -> Self
pub fn source_node_id(self, source_node_id: BackendNodeId) -> Self
Scroll container node
Sourcepub fn start_offset(self, start_offset: f64) -> Self
pub fn start_offset(self, start_offset: f64) -> Self
Represents the starting scroll position of the timeline as a length offset in pixels from scroll origin.
Sourcepub fn end_offset(self, end_offset: f64) -> Self
pub fn end_offset(self, end_offset: f64) -> Self
Represents the ending scroll position of the timeline as a length offset in pixels from scroll origin.
Sourcepub fn subject_node_id(self, subject_node_id: BackendNodeId) -> Self
pub fn subject_node_id(self, subject_node_id: BackendNodeId) -> Self
The element whose principal box’s visibility in the scrollport defined the progress of the timeline. Does not exist for animations with ScrollTimeline
pub fn build(self) -> ViewOrScrollTimeline