Module audits

Module audits 

Audits domain allows investigation of page violations and possible improvements.

Structs

AffectedCookie
Information about a cookie that is affected by an inspector issue.
AffectedFrame
Information about the frame affected by an inspector issue.
AffectedRequest
Information about a request that is affected by an inspector issue.
AttributionReportingIssueDetails
Details for issues around “Attribution Reporting API” usage. Explainer: https://github.com/WICG/attribution-reporting-api
BlockedByResponseIssueDetails
Details for a request that has been blocked with the BLOCKED_BY_RESPONSE code. Currently only used for COEP/COOP, but may be extended to include some CSP errors in the future.
BounceTrackingIssueDetails
This issue warns about sites in the redirect chain of a finished navigation that may be flagged as trackers and have their state cleared if they don’t receive a user interaction. Note that in this context ‘site’ means eTLD+1. For example, if the URL ‘https://example.test:80/bounce’ was in the redirect chain, the site reported would be ‘example.test’.
CheckFormsIssuesParams
CheckFormsIssuesReturns
Runs the form issues check for the target page. Found issues are reported using Audits.issueAdded event.
ClientHintIssueDetails
This issue tracks client hints related issues. It’s used to deprecate old features, encourage the use of new ones, and provide general guidance.
ConnectionAllowlistIssueDetails
ContentSecurityPolicyIssueDetails
CookieDeprecationMetadataIssueDetails
This issue warns about third-party sites that are accessing cookies on the current page, and have been permitted due to having a global metadata grant. Note that in this context ‘site’ means eTLD+1. For example, if the URL ‘https://example.test:80/web_page’ was accessing cookies, the site reported would be ‘example.test’.
CookieIssueDetails
This information is currently necessary, as the front-end has a difficult time finding a specific cookie. With this, we can convey specific error information without the cookie.
CookieIssueInsight
Information about the suggested solution to a cookie issue.
CorsIssueDetails
Details for a CORS related issue, e.g. a warning or error related to CORS RFC1918 enforcement.
DeprecationIssueDetails
This issue tracks information needed to print a deprecation message. https://source.chromium.org/chromium/chromium/src/+/main:third_party/blink/renderer/core/frame/third_party/blink/renderer/core/frame/deprecation/README.md
DisableParams
ElementAccessibilityIssueDetails
This issue warns about errors in the select or summary element content model.
EnableParams
FailedRequestInfo
FederatedAuthRequestIssueDetails
FederatedAuthUserInfoRequestIssueDetails
GenericIssueDetails
Depending on the concrete errorType, different properties are set.
GetEncodedResponseParams
Returns the response body and size if it were re-encoded with the specified settings. Only applies to images.
GetEncodedResponseReturns
Returns the response body and size if it were re-encoded with the specified settings. Only applies to images.
HeavyAdIssueDetails
InspectorIssue
An inspector issue reported from the back-end.
InspectorIssueDetails
This struct holds a list of optional fields with additional information specific to the kind of issue. When adding a new issue code, please also add a new optional field to this type.
MixedContentIssueDetails
NavigatorUserAgentIssueDetails
PartitioningBlobURLIssueDetails
PerformanceIssueDetails
Details for a performance issue.
PermissionElementIssueDetails
This issue warns about improper usage of the element.
PropertyRuleIssueDetails
This issue warns about errors in property rules that lead to property registrations being ignored.
QuirksModeIssueDetails
Details for issues about documents in Quirks Mode or Limited Quirks Mode that affects page layouting.
SRIMessageSignatureIssueDetails
SelectivePermissionsInterventionIssueDetails
The issue warns about blocked calls to privacy sensitive APIs via the Selective Permissions Intervention.
SharedArrayBufferIssueDetails
Details for a issue arising from an SAB being instantiated in, or transferred to a context that is not cross-origin isolated.
SharedDictionaryIssueDetails
SourceCodeLocation
StylesheetLoadingIssueDetails
This issue warns when a referenced stylesheet couldn’t be loaded.
UnencodedDigestIssueDetails
UserReidentificationIssueDetails
This issue warns about uses of APIs that may be considered misuse to re-identify users.

Enums

AttributionReportingIssueType
BlockedByResponseReason
Enum indicating the reason a response has been blocked. These reasons are refinements of the net error BLOCKED_BY_RESPONSE.
ClientHintIssueReason
ConnectionAllowlistError
ContentSecurityPolicyViolationType
CookieExclusionReason
CookieOperation
CookieWarningReason
ElementAccessibilityIssueReason
FederatedAuthRequestIssueReason
Represents the failure reason when a federated authentication reason fails. Should be updated alongside RequestIdTokenStatus in third_party/blink/public/mojom/devtools/inspector_issue.mojom to include all cases except for success.
FederatedAuthUserInfoRequestIssueReason
Represents the failure reason when a getUserInfo() call fails. Should be updated alongside FederatedAuthUserInfoRequestResult in third_party/blink/public/mojom/devtools/inspector_issue.mojom.
GenericIssueErrorType
HeavyAdReason
HeavyAdResolutionStatus
InsightType
Represents the category of insight that a cookie issue falls under.
InspectorIssueCode
A unique identifier for the type of issue. Each type may use one of the optional fields in InspectorIssueDetails to convey more specific information about the kind of issue.
MixedContentResolutionStatus
MixedContentResourceType
PartitioningBlobURLInfo
PerformanceIssueType
PermissionElementIssueType
PropertyRuleIssueReason
SRIMessageSignatureError
SharedArrayBufferIssueType
SharedDictionaryError
StyleSheetLoadingIssueReason
UnencodedDigestError
UserReidentificationIssueType

Type Aliases

IssueId
A unique id for a DevTools inspector issue. Allows other entities (e.g. exceptions, CDP message, console messages, etc.) to reference an issue.