pub struct BlockedByResponseIssueDetails {
pub request: AffectedRequest,
pub parentFrame: Option<AffectedFrame>,
pub blockedFrame: Option<AffectedFrame>,
pub reason: BlockedByResponseReason,
}Expand description
Details for a request that has been blocked with the BLOCKED_BY_RESPONSE code. Currently only used for COEP/COOP, but may be extended to include some CSP errors in the future.
Fields
request: AffectedRequestparentFrame: Option<AffectedFrame>blockedFrame: Option<AffectedFrame>reason: BlockedByResponseReasonTrait Implementations
Sourceimpl Clone for BlockedByResponseIssueDetails
impl Clone for BlockedByResponseIssueDetails
Sourcefn clone(&self) -> BlockedByResponseIssueDetails
fn clone(&self) -> BlockedByResponseIssueDetails
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for BlockedByResponseIssueDetails
impl Default for BlockedByResponseIssueDetails
Sourcefn default() -> BlockedByResponseIssueDetails
fn default() -> BlockedByResponseIssueDetails
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for BlockedByResponseIssueDetails
impl<'de> Deserialize<'de> for BlockedByResponseIssueDetails
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more