CookieIssueDetailsBuilder

Struct CookieIssueDetailsBuilder 

pub struct CookieIssueDetailsBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> CookieIssueDetailsBuilder<'a>

pub fn cookie(self, cookie: AffectedCookie<'a>) -> Self

If AffectedCookie is not set then rawCookieLine contains the raw Set-Cookie header string. This hints at a problem where the cookie line is syntactically or semantically malformed in a way that no valid cookie could be created.

pub fn rawCookieLine(self, rawCookieLine: impl Into<Cow<'a, str>>) -> Self

pub fn siteForCookies(self, siteForCookies: impl Into<Cow<'a, str>>) -> Self

pub fn cookieUrl(self, cookieUrl: impl Into<Cow<'a, str>>) -> Self

pub fn request(self, request: AffectedRequest<'a>) -> Self

pub fn insight(self, insight: CookieIssueInsight<'a>) -> Self

The recommended solution to the issue.

pub fn build(self) -> CookieIssueDetails<'a>