InspectorIssueDetails

Struct InspectorIssueDetails 

pub struct InspectorIssueDetails<'a> { /* private fields */ }
This struct holds a list of optional fields with additional information specific to the kind of issue. When adding a new issue code, please also add a new optional field to this type.

Implementations

Source

impl<'a> InspectorIssueDetails<'a>

pub fn builder() -> InspectorIssueDetailsBuilder<'a>

Creates a builder for this type.

pub fn cookie_issue_details(&self) -> Option<&CookieIssueDetails<'a>>

pub fn mixed_content_issue_details( &self, ) -> Option<&MixedContentIssueDetails<'a>>

pub fn blocked_by_response_issue_details( &self, ) -> Option<&BlockedByResponseIssueDetails<'a>>

pub fn heavy_ad_issue_details(&self) -> Option<&HeavyAdIssueDetails<'a>>

pub fn content_security_policy_issue_details( &self, ) -> Option<&ContentSecurityPolicyIssueDetails<'a>>

pub fn shared_array_buffer_issue_details( &self, ) -> Option<&SharedArrayBufferIssueDetails<'a>>

pub fn cors_issue_details(&self) -> Option<&CorsIssueDetails<'a>>

pub fn attribution_reporting_issue_details( &self, ) -> Option<&AttributionReportingIssueDetails<'a>>

pub fn quirks_mode_issue_details(&self) -> Option<&QuirksModeIssueDetails<'a>>

pub fn partitioning_blob_url_issue_details( &self, ) -> Option<&PartitioningBlobURLIssueDetails<'a>>

pub fn navigator_user_agent_issue_details( &self, ) -> Option<&NavigatorUserAgentIssueDetails<'a>>

pub fn generic_issue_details(&self) -> Option<&GenericIssueDetails<'a>>

pub fn deprecation_issue_details(&self) -> Option<&DeprecationIssueDetails<'a>>

pub fn client_hint_issue_details(&self) -> Option<&ClientHintIssueDetails<'a>>

pub fn federated_auth_request_issue_details( &self, ) -> Option<&FederatedAuthRequestIssueDetails>

pub fn bounce_tracking_issue_details( &self, ) -> Option<&BounceTrackingIssueDetails<'a>>

pub fn cookie_deprecation_metadata_issue_details( &self, ) -> Option<&CookieDeprecationMetadataIssueDetails<'a>>

pub fn stylesheet_loading_issue_details( &self, ) -> Option<&StylesheetLoadingIssueDetails<'a>>

pub fn property_rule_issue_details( &self, ) -> Option<&PropertyRuleIssueDetails<'a>>

pub fn federated_auth_user_info_request_issue_details( &self, ) -> Option<&FederatedAuthUserInfoRequestIssueDetails>

pub fn shared_dictionary_issue_details( &self, ) -> Option<&SharedDictionaryIssueDetails<'a>>

pub fn element_accessibility_issue_details( &self, ) -> Option<&ElementAccessibilityIssueDetails>

pub fn sri_message_signature_issue_details( &self, ) -> Option<&SRIMessageSignatureIssueDetails<'a>>

pub fn unencoded_digest_issue_details( &self, ) -> Option<&UnencodedDigestIssueDetails<'a>>

pub fn connection_allowlist_issue_details( &self, ) -> Option<&ConnectionAllowlistIssueDetails<'a>>

pub fn user_reidentification_issue_details( &self, ) -> Option<&UserReidentificationIssueDetails<'a>>

pub fn permission_element_issue_details( &self, ) -> Option<&PermissionElementIssueDetails<'a>>

pub fn performance_issue_details(&self) -> Option<&PerformanceIssueDetails<'a>>

pub fn selective_permissions_intervention_issue_details( &self, ) -> Option<&SelectivePermissionsInterventionIssueDetails<'a>>