MixedContentIssueDetailsBuilder

Struct MixedContentIssueDetailsBuilder 

pub struct MixedContentIssueDetailsBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> MixedContentIssueDetailsBuilder<'a>

pub fn resource_type( self, resource_type: impl Into<MixedContentResourceType>, ) -> Self

The type of resource causing the mixed content issue (css, js, iframe, form,…). Marked as optional because it is mapped to from blink::mojom::RequestContextType, which will be replaced by network::mojom::RequestDestination

pub fn request(self, request: AffectedRequest<'a>) -> Self

The mixed content request. Does not always exist (e.g. for unsafe form submission urls).

pub fn frame(self, frame: AffectedFrame<'a>) -> Self

Optional because not every mixed content issue is necessarily linked to a frame.

pub fn build(self) -> MixedContentIssueDetails<'a>