PermissionElementIssueDetails

Struct PermissionElementIssueDetails 

pub struct PermissionElementIssueDetails {
    pub issueType: PermissionElementIssueType,
    pub type_: Option<String>,
    pub nodeId: Option<BackendNodeId>,
    pub isWarning: Option<bool>,
    pub permissionName: Option<String>,
    pub occluderNodeInfo: Option<String>,
    pub occluderParentNodeInfo: Option<String>,
    pub disableReason: Option<String>,
}
This issue warns about improper usage of the element.

Fields

issueType: PermissionElementIssueTypetype_: Option<String>

The value of the type attribute.

nodeId: Option<BackendNodeId>

The node ID of the element.

isWarning: Option<bool>

True if the issue is a warning, false if it is an error.

permissionName: Option<String>

Fields for message construction: Used for messages that reference a specific permission name

occluderNodeInfo: Option<String>

Used for messages about occlusion

occluderParentNodeInfo: Option<String>

Used for messages about occluder’s parent

disableReason: Option<String>

Used for messages about activation disabled reason