PermissionElementIssueDetailsBuilder

Struct PermissionElementIssueDetailsBuilder 

pub struct PermissionElementIssueDetailsBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> PermissionElementIssueDetailsBuilder<'a>

pub fn type_(self, type_: impl Into<Cow<'a, str>>) -> Self

The value of the type attribute.

pub fn node_id(self, node_id: BackendNodeId) -> Self

The node ID of the <permission> element.

pub fn is_warning(self, is_warning: bool) -> Self

True if the issue is a warning, false if it is an error.

pub fn permission_name(self, permission_name: impl Into<Cow<'a, str>>) -> Self

Fields for message construction: Used for messages that reference a specific permission name

pub fn occluder_node_info( self, occluder_node_info: impl Into<Cow<'a, str>>, ) -> Self

Used for messages about occlusion

pub fn occluder_parent_node_info( self, occluder_parent_node_info: impl Into<Cow<'a, str>>, ) -> Self

Used for messages about occluder’s parent

pub fn disable_reason(self, disable_reason: impl Into<Cow<'a, str>>) -> Self

Used for messages about activation disabled reason

pub fn build(self) -> PermissionElementIssueDetails<'a>