pub struct PropertyRuleIssueDetails<'a> { /* private fields */ }Expand description
This issue warns about errors in property rules that lead to property registrations being ignored.
Implementations
Sourceimpl<'a> PropertyRuleIssueDetails<'a>
impl<'a> PropertyRuleIssueDetails<'a>
Sourcepub fn builder(
source_code_location: SourceCodeLocation<'a>,
property_rule_issue_reason: impl Into<PropertyRuleIssueReason>,
) -> PropertyRuleIssueDetailsBuilder<'a>
pub fn builder( source_code_location: SourceCodeLocation<'a>, property_rule_issue_reason: impl Into<PropertyRuleIssueReason>, ) -> PropertyRuleIssueDetailsBuilder<'a>
Creates a builder for this type with the required parameters:
source_code_location: Source code position of the property rule.property_rule_issue_reason: Reason why the property rule was discarded.
Sourcepub fn source_code_location(&self) -> &SourceCodeLocation<'a>
pub fn source_code_location(&self) -> &SourceCodeLocation<'a>
Source code position of the property rule.
Sourcepub fn property_rule_issue_reason(&self) -> &PropertyRuleIssueReason
pub fn property_rule_issue_reason(&self) -> &PropertyRuleIssueReason
Reason why the property rule was discarded.
Sourcepub fn property_value(&self) -> Option<&str>
pub fn property_value(&self) -> Option<&str>
The value of the property rule property that failed to parse