Module autofill

Module autofill 

Defines commands and events for Autofill.

Structs

Address
AddressField
AddressFields
A list of address fields.
AddressUI
Defines how an address can be displayed like in chrome://settings/addresses. Address UI is a two dimensional array, each inner array is an “address information line”, and when rendered in a UI surface should be displayed as such. The following address UI for instance: [[{name: “GIVE_NAME”, value: “Jon”}, {name: “FAMILY_NAME”, value: “Doe”}], [{name: “CITY”, value: “Munich”}, {name: “ZIP”, value: “81456”}]] should allow the receiver to render: Jon Doe Munich 81456
CreditCard
FilledField
SetAddressesParams
Set addresses so that developers can verify their forms implementation.
TriggerParams
Trigger autofill on a form identified by the fieldId. If the field and related form cannot be autofilled, returns an error.

Enums

FillingStrategy
Specified whether a filled field was done so by using the html autocomplete attribute or autofill heuristics.