pub struct AddressUI<'a> { /* private fields */ }Expand description
Defines how an address can be displayed like in chrome://settings/addresses. Address UI is a two dimensional array, each inner array is an “address information line”, and when rendered in a UI surface should be displayed as such. The following address UI for instance: [[{name: “GIVE_NAME”, value: “Jon”}, {name: “FAMILY_NAME”, value: “Doe”}], [{name: “CITY”, value: “Munich”}, {name: “ZIP”, value: “81456”}]] should allow the receiver to render: Jon Doe Munich 81456
Implementations
Sourceimpl<'a> AddressUI<'a>
impl<'a> AddressUI<'a>
pub fn builder(addressFields: Vec<AddressFields<'a>>) -> AddressUIBuilder<'a>
pub fn addressFields(&self) -> &[AddressFields<'a>]