pub struct TriggerParams {
pub fieldId: BackendNodeId,
pub frameId: Option<FrameId>,
pub card: Option<CreditCard>,
pub address: Option<Address>,
}Expand description
Trigger autofill on a form identified by the fieldId. If the field and related form cannot be autofilled, returns an error.
Fields
fieldId: BackendNodeIdIdentifies a field that serves as an anchor for autofill.
frameId: Option<FrameId>Identifies the frame that field belongs to.
card: Option<CreditCard>Credit card information to fill out the form. Credit card data is not saved. Mutually exclusive with ‘address’.
address: Option<Address>Address to fill out the form. Address data is not saved. Mutually exclusive with ‘card’.
Implementations