Module backgroundservice

Module backgroundservice 

Defines events for background web platform features.

Structs

BackgroundServiceEvent
BackgroundServiceEventBuilder
ClearEventsParams
Clears all stored data for the service.
ClearEventsParamsBuilder
EventMetadata
A key-value pair for additional event information to pass along.
EventMetadataBuilder
SetRecordingParams
Set the recording state for the service.
SetRecordingParamsBuilder
StartObservingParams
Enables event updates for the service.
StartObservingParamsBuilder
StopObservingParams
Disables event updates for the service.
StopObservingParamsBuilder

Enums

ServiceName
The Background Service that will be associated with the commands/events. Every Background Service operates independently, but they share the same API.