Module bluetoothemulation

Module bluetoothemulation 

This domain allows configuring virtual Bluetooth devices to test the web-bluetooth API.

Structs

AddCharacteristicParams
Adds a characteristic with |characteristicUuid| and |properties| to the service represented by |serviceId|.
AddCharacteristicParamsBuilder
AddCharacteristicReturns
Adds a characteristic with |characteristicUuid| and |properties| to the service represented by |serviceId|.
AddCharacteristicReturnsBuilder
AddDescriptorParams
Adds a descriptor with |descriptorUuid| to the characteristic respresented by |characteristicId|.
AddDescriptorParamsBuilder
AddDescriptorReturns
Adds a descriptor with |descriptorUuid| to the characteristic respresented by |characteristicId|.
AddDescriptorReturnsBuilder
AddServiceParams
Adds a service with |serviceUuid| to the peripheral with |address|.
AddServiceParamsBuilder
AddServiceReturns
Adds a service with |serviceUuid| to the peripheral with |address|.
AddServiceReturnsBuilder
CharacteristicProperties
Describes the properties of a characteristic. This follows Bluetooth Core Specification BT 4.2 Vol 3 Part G 3.3.1. Characteristic Properties.
CharacteristicPropertiesBuilder
DisableParams
EnableParams
Enable the BluetoothEmulation domain.
EnableParamsBuilder
ManufacturerData
Stores the manufacturer data
ManufacturerDataBuilder
RemoveCharacteristicParams
Removes the characteristic respresented by |characteristicId| from the simulated central.
RemoveCharacteristicParamsBuilder
RemoveDescriptorParams
Removes the descriptor with |descriptorId| from the simulated central.
RemoveDescriptorParamsBuilder
RemoveServiceParams
Removes the service respresented by |serviceId| from the simulated central.
RemoveServiceParamsBuilder
ScanEntry
Stores the advertisement packet information that is sent by a Bluetooth device.
ScanEntryBuilder
ScanRecord
Stores the byte data of the advertisement packet sent by a Bluetooth device.
ScanRecordBuilder
SetSimulatedCentralStateParams
Set the state of the simulated central.
SetSimulatedCentralStateParamsBuilder
SimulateAdvertisementParams
Simulates an advertisement packet described in |entry| being received by the central.
SimulateAdvertisementParamsBuilder
SimulateCharacteristicOperationResponseParams
Simulates the response from the characteristic with |characteristicId| for a characteristic operation of |type|. The |code| value follows the Error Codes from Bluetooth Core Specification Vol 3 Part F 3.4.1.1 Error Response. The |data| is expected to exist when simulating a successful read operation response.
SimulateCharacteristicOperationResponseParamsBuilder
SimulateDescriptorOperationResponseParams
Simulates the response from the descriptor with |descriptorId| for a descriptor operation of |type|. The |code| value follows the Error Codes from Bluetooth Core Specification Vol 3 Part F 3.4.1.1 Error Response. The |data| is expected to exist when simulating a successful read operation response.
SimulateDescriptorOperationResponseParamsBuilder
SimulateGATTDisconnectionParams
Simulates a GATT disconnection from the peripheral with |address|.
SimulateGATTDisconnectionParamsBuilder
SimulateGATTOperationResponseParams
Simulates the response code from the peripheral with |address| for a GATT operation of |type|. The |code| value follows the HCI Error Codes from Bluetooth Core Specification Vol 2 Part D 1.3 List Of Error Codes.
SimulateGATTOperationResponseParamsBuilder
SimulatePreconnectedPeripheralParams
Simulates a peripheral with |address|, |name| and |knownServiceUuids| that has already been connected to the system.
SimulatePreconnectedPeripheralParamsBuilder

Enums

CentralState
Indicates the various states of Central.
CharacteristicOperationType
Indicates the various types of characteristic operation.
CharacteristicWriteType
Indicates the various types of characteristic write.
DescriptorOperationType
Indicates the various types of descriptor operation.
GATTOperationType
Indicates the various types of GATT event.