pub struct ScanRecord<'a> { /* private fields */ }Expand description
Stores the byte data of the advertisement packet sent by a Bluetooth device.
Implementations
Sourceimpl<'a> ScanRecord<'a>
impl<'a> ScanRecord<'a>
Sourcepub fn builder() -> ScanRecordBuilder<'a>
pub fn builder() -> ScanRecordBuilder<'a>
Creates a builder for this type.
pub fn name(&self) -> Option<&str>
pub fn uuids(&self) -> Option<&[Cow<'a, str>]>
Sourcepub fn appearance(&self) -> Option<i64>
pub fn appearance(&self) -> Option<i64>
Stores the external appearance description of the device.
Sourcepub fn manufacturer_data(&self) -> Option<&[ManufacturerData<'a>]>
pub fn manufacturer_data(&self) -> Option<&[ManufacturerData<'a>]>
Key is the company identifier and the value is an array of bytes of manufacturer specific data.