pub struct ScanRecordBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ScanRecordBuilder<'a>
impl<'a> ScanRecordBuilder<'a>
pub fn name(self, name: impl Into<Cow<'a, str>>) -> Self
pub fn uuids(self, uuids: Vec<Cow<'a, str>>) -> Self
Sourcepub fn appearance(self, appearance: i64) -> Self
pub fn appearance(self, appearance: i64) -> Self
Stores the external appearance description of the device.
Sourcepub fn txPower(self, txPower: i64) -> Self
pub fn txPower(self, txPower: i64) -> Self
Stores the transmission power of a broadcasting device.
Sourcepub fn manufacturerData(
self,
manufacturerData: Vec<ManufacturerData<'a>>,
) -> Self
pub fn manufacturerData( self, manufacturerData: Vec<ManufacturerData<'a>>, ) -> Self
Key is the company identifier and the value is an array of bytes of manufacturer specific data.
pub fn build(self) -> ScanRecord<'a>