pub struct SimulateCharacteristicOperationResponseParams<'a> { /* private fields */ }Expand description
Simulates the response from the characteristic with |characteristicId| for a characteristic operation of |type|. The |code| value follows the Error Codes from Bluetooth Core Specification Vol 3 Part F 3.4.1.1 Error Response. The |data| is expected to exist when simulating a successful read operation response.
Implementations
Sourceimpl<'a> SimulateCharacteristicOperationResponseParams<'a>
impl<'a> SimulateCharacteristicOperationResponseParams<'a>
Sourcepub fn builder(
characteristic_id: impl Into<Cow<'a, str>>,
type_: impl Into<CharacteristicOperationType>,
code: i64,
) -> SimulateCharacteristicOperationResponseParamsBuilder<'a>
pub fn builder( characteristic_id: impl Into<Cow<'a, str>>, type_: impl Into<CharacteristicOperationType>, code: i64, ) -> SimulateCharacteristicOperationResponseParamsBuilder<'a>
Creates a builder for this type with the required parameters:
characteristic_id:type_:code:
pub fn characteristic_id(&self) -> &str
pub fn type_(&self) -> &CharacteristicOperationType
pub fn code(&self) -> i64
pub fn data(&self) -> Option<&str>