pub struct SimulateDescriptorOperationResponseParams<'a> { /* private fields */ }Expand description
Simulates the response from the descriptor with |descriptorId| for a descriptor operation of |type|. The |code| value follows the Error Codes from Bluetooth Core Specification Vol 3 Part F 3.4.1.1 Error Response. The |data| is expected to exist when simulating a successful read operation response.
Implementations
Sourceimpl<'a> SimulateDescriptorOperationResponseParams<'a>
impl<'a> SimulateDescriptorOperationResponseParams<'a>
Sourcepub fn builder(
descriptor_id: impl Into<Cow<'a, str>>,
type_: impl Into<DescriptorOperationType>,
code: i64,
) -> SimulateDescriptorOperationResponseParamsBuilder<'a>
pub fn builder( descriptor_id: impl Into<Cow<'a, str>>, type_: impl Into<DescriptorOperationType>, code: i64, ) -> SimulateDescriptorOperationResponseParamsBuilder<'a>
Creates a builder for this type with the required parameters:
descriptor_id:type_:code:
pub fn descriptor_id(&self) -> &str
pub fn type_(&self) -> &DescriptorOperationType
pub fn code(&self) -> i64
pub fn data(&self) -> Option<&str>