Module browser

Module browser 

The Browser domain defines methods and events for browser managing.

Structs

AddPrivacySandboxCoordinatorKeyConfigParams
Configures encryption keys used with a given privacy sandbox API to talk to a trusted coordinator. Since this is intended for test automation only, coordinatorOrigin must be a .test domain. No existing coordinator configuration for the origin may exist.
AddPrivacySandboxCoordinatorKeyConfigParamsBuilder
AddPrivacySandboxEnrollmentOverrideParams
Allows a site to use privacy sandbox features that require enrollment without the site actually being enrolled. Only supported on page targets.
AddPrivacySandboxEnrollmentOverrideParamsBuilder
Bounds
Browser window bounds information
BoundsBuilder
Bucket
Chrome histogram bucket.
BucketBuilder
CancelDownloadParams
Cancel a download if in progress
CancelDownloadParamsBuilder
CloseParams
CrashGpuProcessParams
CrashParams
ExecuteBrowserCommandParams
Invoke custom browser commands used by telemetry.
ExecuteBrowserCommandParamsBuilder
GetBrowserCommandLineParams
GetBrowserCommandLineReturns
Returns the command line switches for the browser process if, and only if –enable-automation is on the commandline.
GetBrowserCommandLineReturnsBuilder
GetHistogramParams
Get a Chrome histogram by name.
GetHistogramParamsBuilder
GetHistogramReturns
Get a Chrome histogram by name.
GetHistogramReturnsBuilder
GetHistogramsParams
Get Chrome histograms.
GetHistogramsParamsBuilder
GetHistogramsReturns
Get Chrome histograms.
GetHistogramsReturnsBuilder
GetVersionParams
GetVersionReturns
Returns version information.
GetVersionReturnsBuilder
GetWindowBoundsParams
Get position and size of the browser window.
GetWindowBoundsParamsBuilder
GetWindowBoundsReturns
Get position and size of the browser window.
GetWindowBoundsReturnsBuilder
GetWindowForTargetParams
Get the browser window that contains the devtools target.
GetWindowForTargetParamsBuilder
GetWindowForTargetReturns
Get the browser window that contains the devtools target.
GetWindowForTargetReturnsBuilder
GrantPermissionsParams
Grant specific permissions to the given origin and reject all others. Deprecated. Use setPermission instead.
GrantPermissionsParamsBuilder
Histogram
Chrome histogram.
HistogramBuilder
PermissionDescriptor
Definition of PermissionDescriptor defined in the Permissions API: https://w3c.github.io/permissions/#dom-permissiondescriptor.
PermissionDescriptorBuilder
ResetPermissionsParams
Reset all permission management for all origins.
ResetPermissionsParamsBuilder
SetContentsSizeParams
Set size of the browser contents resizing browser window as necessary.
SetContentsSizeParamsBuilder
SetDockTileParams
Set dock tile details, platform-specific.
SetDockTileParamsBuilder
SetDownloadBehaviorParams
Set the behavior when downloading a file.
SetDownloadBehaviorParamsBuilder
SetPermissionParams
Set permission settings for given embedding and embedded origins.
SetPermissionParamsBuilder
SetWindowBoundsParams
Set position and/or size of the browser window.
SetWindowBoundsParamsBuilder

Enums

BrowserCommandId
Browser command ids used by executeBrowserCommand.
PermissionSetting
PermissionType
PrivacySandboxAPI
WindowState
The state of the browser window.

Type Aliases

BrowserContextID
WindowID