BoundsBuilder

Struct BoundsBuilder 

pub struct BoundsBuilder { /* private fields */ }

Implementations

Source

impl BoundsBuilder

pub fn left(self, left: i64) -> Self

The offset from the left edge of the screen to the window in pixels.

pub fn top(self, top: i64) -> Self

The offset from the top edge of the screen to the window in pixels.

pub fn width(self, width: u64) -> Self

The window width in pixels.

pub fn height(self, height: i64) -> Self

The window height in pixels.

pub fn window_state(self, window_state: impl Into<WindowState>) -> Self

The window state. Default to normal.

pub fn build(self) -> Bounds