pub struct GrantPermissionsParams {
pub permissions: Vec<PermissionType>,
pub origin: Option<String>,
pub browserContextId: Option<BrowserContextID>,
}Expand description
Grant specific permissions to the given origin and reject all others. Deprecated. Use setPermission instead.
Fields
permissions: Vec<PermissionType>origin: Option<String>Origin the permission applies to, all origins if not specified.
browserContextId: Option<BrowserContextID>BrowserContext to override permissions. When omitted, default browser context is used.