pub struct SetDownloadBehaviorParams {
pub behavior: String,
pub browserContextId: Option<BrowserContextID>,
pub downloadPath: Option<String>,
pub eventsEnabled: Option<bool>,
}Expand description
Set the behavior when downloading a file.
Fields
behavior: StringWhether to allow all or deny all download requests, or use default Chrome behavior if available (otherwise deny). |allowAndName| allows download and names files according to their download guids.
browserContextId: Option<BrowserContextID>BrowserContext to set download behavior. When omitted, default browser context is used.
downloadPath: Option<String>The default path to save downloaded files to. This is required if behavior is set to ‘allow’ or ‘allowAndName’.
eventsEnabled: Option<bool>Whether to emit download events (defaults to false).