pub struct SetPermissionParams<'a> { /* private fields */ }Expand description
Set permission settings for given embedding and embedded origins.
Implementations
Sourceimpl<'a> SetPermissionParams<'a>
impl<'a> SetPermissionParams<'a>
Sourcepub fn builder(
permission: PermissionDescriptor<'a>,
setting: impl Into<PermissionSetting>,
) -> SetPermissionParamsBuilder<'a>
pub fn builder( permission: PermissionDescriptor<'a>, setting: impl Into<PermissionSetting>, ) -> SetPermissionParamsBuilder<'a>
Creates a builder for this type with the required parameters:
permission: Descriptor of permission to override.setting: Setting of the permission.
Sourcepub fn permission(&self) -> &PermissionDescriptor<'a>
pub fn permission(&self) -> &PermissionDescriptor<'a>
Descriptor of permission to override.
Sourcepub fn setting(&self) -> &PermissionSetting
pub fn setting(&self) -> &PermissionSetting
Setting of the permission.
Sourcepub fn origin(&self) -> Option<&str>
pub fn origin(&self) -> Option<&str>
Embedding origin the permission applies to, all origins if not specified.
Sourcepub fn embedded_origin(&self) -> Option<&str>
pub fn embedded_origin(&self) -> Option<&str>
Embedded origin the permission applies to. It is ignored unless the embedding origin is present and valid. If the embedding origin is provided but the embedded origin isn’t, the embedding origin is used as the embedded origin.
Sourcepub fn browser_context_id(&self) -> Option<&BrowserContextID<'a>>
pub fn browser_context_id(&self) -> Option<&BrowserContextID<'a>>
Context to override. When omitted, default browser context is used.