pub struct SetPermissionParamsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> SetPermissionParamsBuilder<'a>
impl<'a> SetPermissionParamsBuilder<'a>
Sourcepub fn origin(self, origin: impl Into<Cow<'a, str>>) -> Self
pub fn origin(self, origin: impl Into<Cow<'a, str>>) -> Self
Embedding origin the permission applies to, all origins if not specified.
Sourcepub fn embedded_origin(self, embedded_origin: impl Into<Cow<'a, str>>) -> Self
pub fn embedded_origin(self, embedded_origin: impl Into<Cow<'a, str>>) -> Self
Embedded origin the permission applies to. It is ignored unless the embedding origin is present and valid. If the embedding origin is provided but the embedded origin isn’t, the embedding origin is used as the embedded origin.
Sourcepub fn browser_context_id(
self,
browser_context_id: impl Into<BrowserContextID<'a>>,
) -> Self
pub fn browser_context_id( self, browser_context_id: impl Into<BrowserContextID<'a>>, ) -> Self
Context to override. When omitted, default browser context is used.
pub fn build(self) -> SetPermissionParams<'a>