A domain for interacting with Cast, Presentation API, and Remote Playback API functionalities.
Structs
- Disable
Params - Enable
Params - Starts observing for sinks that can be used for tab mirroring, and if set, sinks compatible with |presentationUrl| as well. When sinks are found, a |sinksUpdated| event is fired. Also starts observing for issue messages. When an issue is added or removed, an |issueUpdated| event is fired.
- Enable
Params Builder - SetSink
ToUse Params - Sets a sink to be used when the web page requests the browser to choose a sink via Presentation API, Remote Playback API, or Cast SDK.
- SetSink
ToUse Params Builder - Sink
- Sink
Builder - Start
Desktop Mirroring Params - Starts mirroring the desktop to the sink.
- Start
Desktop Mirroring Params Builder - Start
TabMirroring Params - Starts mirroring the tab to the sink.
- Start
TabMirroring Params Builder - Stop
Casting Params - Stops the active Cast session on the sink.
- Stop
Casting Params Builder