pub struct EnableParams<'a> { /* private fields */ }Expand description
Starts observing for sinks that can be used for tab mirroring, and if set, sinks compatible with |presentationUrl| as well. When sinks are found, a |sinksUpdated| event is fired. Also starts observing for issue messages. When an issue is added or removed, an |issueUpdated| event is fired.
Implementations
Sourceimpl<'a> EnableParams<'a>
impl<'a> EnableParams<'a>
Sourcepub fn builder() -> EnableParamsBuilder<'a>
pub fn builder() -> EnableParamsBuilder<'a>
Creates a builder for this type.
pub fn presentation_url(&self) -> Option<&str>