pub enum CSSRuleType {
MediaRule,
SupportsRule,
ContainerRule,
LayerRule,
ScopeRule,
StyleRule,
StartingStyleRule,
NavigationRule,
}Expand description
Enum indicating the type of a CSS rule, used to represent the order of a style rule’s ancestors. This list only contains rule types that are collected during the ancestor rule collection.
Variants