AddRuleParams

Struct AddRuleParams 

pub struct AddRuleParams<'a> { /* private fields */ }
Inserts a new rule with the given ‘ruleText’ in a stylesheet with given ‘styleSheetId’, at the position specified by ‘location’.

Implementations

Source

impl<'a> AddRuleParams<'a>

pub fn builder( style_sheet_id: StyleSheetId<'a>, rule_text: impl Into<Cow<'a, str>>, location: SourceRange, ) -> AddRuleParamsBuilder<'a>

Creates a builder for this type with the required parameters:

  • style_sheet_id: The css style sheet identifier where a new rule should be inserted.
  • rule_text: The text of a new rule.
  • location: Text position of a new rule in the target style sheet.
pub fn style_sheet_id(&self) -> &StyleSheetId<'a>

The css style sheet identifier where a new rule should be inserted.

pub fn rule_text(&self) -> &str

The text of a new rule.

pub fn location(&self) -> &SourceRange

Text position of a new rule in the target style sheet.

pub fn node_for_property_syntax_validation(&self) -> Option<&NodeId>

NodeId for the DOM node in whose context custom property declarations for registered properties should be validated. If omitted, declarations in the new rule text can only be validated statically, which may produce incorrect results if the declaration contains a var() for example.

Source

impl<'a> AddRuleParams<'a>

pub const METHOD: &'static str = "CSS.addRule"