pub struct CSSContainerQuery<'a> { /* private fields */ }Expand description
CSS container query rule descriptor.
Implementations
Sourceimpl<'a> CSSContainerQuery<'a>
impl<'a> CSSContainerQuery<'a>
Sourcepub fn builder(
text: impl Into<Cow<'a, str>>,
condition_text: impl Into<Cow<'a, str>>,
) -> CSSContainerQueryBuilder<'a>
pub fn builder( text: impl Into<Cow<'a, str>>, condition_text: impl Into<Cow<'a, str>>, ) -> CSSContainerQueryBuilder<'a>
Creates a builder for this type with the required parameters:
text: Container query text. Contains the query part without the container name for a single query. Deprecated in favor of conditionText which contains the full prelude after @container.condition_text: CSSContainerRule.conditionText
Sourcepub fn text(&self) -> &str
pub fn text(&self) -> &str
Container query text. Contains the query part without the container name for a single query. Deprecated in favor of conditionText which contains the full prelude after @container.
Sourcepub fn range(&self) -> Option<&SourceRange>
pub fn range(&self) -> Option<&SourceRange>
The associated rule header range in the enclosing stylesheet (if available).
Sourcepub fn style_sheet_id(&self) -> Option<&StyleSheetId<'a>>
pub fn style_sheet_id(&self) -> Option<&StyleSheetId<'a>>
Identifier of the stylesheet containing this object (if exists).
Sourcepub fn physical_axes(&self) -> Option<&PhysicalAxes>
pub fn physical_axes(&self) -> Option<&PhysicalAxes>
Optional physical axes queried for the container.
Sourcepub fn logical_axes(&self) -> Option<&LogicalAxes>
pub fn logical_axes(&self) -> Option<&LogicalAxes>
Optional logical axes queried for the container.
Sourcepub fn queries_scroll_state(&self) -> Option<bool>
pub fn queries_scroll_state(&self) -> Option<bool>
true if the query contains scroll-state() queries.
Sourcepub fn queries_anchored(&self) -> Option<bool>
pub fn queries_anchored(&self) -> Option<bool>
true if the query contains anchored() queries.
Sourcepub fn condition_text(&self) -> &str
pub fn condition_text(&self) -> &str
CSSContainerRule.conditionText