CSSFunctionRule

Struct CSSFunctionRule 

pub struct CSSFunctionRule<'a> { /* private fields */ }
CSS function at-rule representation.

Implementations

Source

impl<'a> CSSFunctionRule<'a>

pub fn builder( name: ProtocolValue<'a>, origin: impl Into<StyleSheetOrigin>, parameters: Vec<CSSFunctionParameter<'a>>, children: Vec<CSSFunctionNode<'a>>, ) -> CSSFunctionRuleBuilder<'a>

Creates a builder for this type with the required parameters:

  • name: Name of the function.
  • origin: Parent stylesheet’s origin.
  • parameters: List of parameters.
  • children: Function body.
pub fn name(&self) -> &ProtocolValue<'a>

Name of the function.

pub fn style_sheet_id(&self) -> Option<&StyleSheetId<'a>>

The css style sheet identifier (absent for user agent stylesheet and user-specified stylesheet rules) this rule came from.

pub fn origin(&self) -> &StyleSheetOrigin

Parent stylesheet’s origin.

pub fn parameters(&self) -> &[CSSFunctionParameter<'a>]

List of parameters.

pub fn children(&self) -> &[CSSFunctionNode<'a>]

Function body.

pub fn origin_tree_scope_node_id(&self) -> Option<&BackendNodeId>

The BackendNodeId of the DOM node that constitutes the origin tree scope of this rule.