pub struct CSSLayer<'a> { /* private fields */ }Expand description
CSS Layer at-rule descriptor.
Implementations
Sourceimpl<'a> CSSLayer<'a>
impl<'a> CSSLayer<'a>
Sourcepub fn builder(text: impl Into<Cow<'a, str>>) -> CSSLayerBuilder<'a>
pub fn builder(text: impl Into<Cow<'a, str>>) -> CSSLayerBuilder<'a>
Creates a builder for this type with the required parameters:
text: Layer name.
Sourcepub fn range(&self) -> Option<&SourceRange>
pub fn range(&self) -> Option<&SourceRange>
The associated rule header range in the enclosing stylesheet (if available).
Sourcepub fn style_sheet_id(&self) -> Option<&StyleSheetId<'a>>
pub fn style_sheet_id(&self) -> Option<&StyleSheetId<'a>>
Identifier of the stylesheet containing this object (if exists).