pub struct CSSNavigation<'a> { /* private fields */ }Expand description
CSS Navigation at-rule descriptor.
Implementations
Sourcepub fn builder(text: impl Into<Cow<'a, str>>) -> CSSNavigationBuilder<'a>
pub fn builder(text: impl Into<Cow<'a, str>>) -> CSSNavigationBuilder<'a>
Creates a builder for this type with the required parameters:
text: Navigation rule text.
Sourcepub fn range(&self) -> Option<&SourceRange>
pub fn range(&self) -> Option<&SourceRange>
The associated rule header range in the enclosing stylesheet (if available).
Sourcepub fn style_sheet_id(&self) -> Option<&StyleSheetId<'a>>
pub fn style_sheet_id(&self) -> Option<&StyleSheetId<'a>>
Identifier of the stylesheet containing this object (if exists).