pub struct CSSProperty<'a> { /* private fields */ }Expand description
CSS property declaration data.
Implementations
Sourceimpl<'a> CSSProperty<'a>
impl<'a> CSSProperty<'a>
Sourcepub fn builder(
name: impl Into<Cow<'a, str>>,
value: impl Into<Cow<'a, str>>,
) -> CSSPropertyBuilder<'a>
pub fn builder( name: impl Into<Cow<'a, str>>, value: impl Into<Cow<'a, str>>, ) -> CSSPropertyBuilder<'a>
Creates a builder for this type with the required parameters:
name: The property name.value: The property value.
Sourcepub fn important(&self) -> Option<bool>
pub fn important(&self) -> Option<bool>
Whether the property has “!important” annotation (implies ‘false’ if absent).
Sourcepub fn implicit(&self) -> Option<bool>
pub fn implicit(&self) -> Option<bool>
Whether the property is implicit (implies ‘false’ if absent).
Sourcepub fn parsed_ok(&self) -> Option<bool>
pub fn parsed_ok(&self) -> Option<bool>
Whether the property is understood by the browser (implies ‘true’ if absent).
Sourcepub fn disabled(&self) -> Option<bool>
pub fn disabled(&self) -> Option<bool>
Whether the property is disabled by the user (present for source-based properties only).
Sourcepub fn range(&self) -> Option<&SourceRange>
pub fn range(&self) -> Option<&SourceRange>
The entire property range in the enclosing style declaration (if available).
Sourcepub fn longhand_properties(&self) -> Option<&[Box<CSSProperty<'a>>]>
pub fn longhand_properties(&self) -> Option<&[Box<CSSProperty<'a>>]>
Parsed longhand components of this property if it is a shorthand. This field will be empty if the given property is not a shorthand.