CSSPropertyBuilder

Struct CSSPropertyBuilder 

pub struct CSSPropertyBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> CSSPropertyBuilder<'a>

pub fn important(self, important: bool) -> Self

Whether the property has “!important” annotation (implies ‘false’ if absent).

pub fn implicit(self, implicit: bool) -> Self

Whether the property is implicit (implies ‘false’ if absent).

pub fn text(self, text: impl Into<Cow<'a, str>>) -> Self

The full property text as specified in the style.

pub fn parsed_ok(self, parsed_ok: bool) -> Self

Whether the property is understood by the browser (implies ‘true’ if absent).

pub fn disabled(self, disabled: bool) -> Self

Whether the property is disabled by the user (present for source-based properties only).

pub fn range(self, range: SourceRange) -> Self

The entire property range in the enclosing style declaration (if available).

pub fn longhand_properties( self, longhand_properties: Vec<Box<CSSProperty<'a>>>, ) -> Self

Parsed longhand components of this property if it is a shorthand. This field will be empty if the given property is not a shorthand.

pub fn build(self) -> CSSProperty<'a>