pub struct CSSStyle<'a> { /* private fields */ }Expand description
CSS style representation.
Implementations
Sourceimpl<'a> CSSStyle<'a>
impl<'a> CSSStyle<'a>
Sourcepub fn builder(
css_properties: Vec<CSSProperty<'a>>,
shorthand_entries: Vec<ShorthandEntry<'a>>,
) -> CSSStyleBuilder<'a>
pub fn builder( css_properties: Vec<CSSProperty<'a>>, shorthand_entries: Vec<ShorthandEntry<'a>>, ) -> CSSStyleBuilder<'a>
Creates a builder for this type with the required parameters:
css_properties: CSS properties in the style.shorthand_entries: Computed values for all shorthands found in the style.
Sourcepub fn style_sheet_id(&self) -> Option<&StyleSheetId<'a>>
pub fn style_sheet_id(&self) -> Option<&StyleSheetId<'a>>
The css style sheet identifier (absent for user agent stylesheet and user-specified stylesheet rules) this rule came from.
Sourcepub fn css_properties(&self) -> &[CSSProperty<'a>]
pub fn css_properties(&self) -> &[CSSProperty<'a>]
CSS properties in the style.
Sourcepub fn shorthand_entries(&self) -> &[ShorthandEntry<'a>]
pub fn shorthand_entries(&self) -> &[ShorthandEntry<'a>]
Computed values for all shorthands found in the style.
Sourcepub fn range(&self) -> Option<&SourceRange>
pub fn range(&self) -> Option<&SourceRange>
Style declaration range in the enclosing stylesheet (if available).