pub struct CSSStyleSheetHeaderBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> CSSStyleSheetHeaderBuilder<'a>
impl<'a> CSSStyleSheetHeaderBuilder<'a>
Sourcepub fn source_map_url(self, source_map_url: impl Into<Cow<'a, str>>) -> Self
pub fn source_map_url(self, source_map_url: impl Into<Cow<'a, str>>) -> Self
URL of source map associated with the stylesheet (if any).
Sourcepub fn owner_node(self, owner_node: BackendNodeId) -> Self
pub fn owner_node(self, owner_node: BackendNodeId) -> Self
The backend id for the owner node of the stylesheet.
Sourcepub fn has_source_url(self, has_source_url: bool) -> Self
pub fn has_source_url(self, has_source_url: bool) -> Self
Whether the sourceURL field value comes from the sourceURL comment.
Sourcepub fn loading_failed(self, loading_failed: bool) -> Self
pub fn loading_failed(self, loading_failed: bool) -> Self
If the style sheet was loaded from a network resource, this indicates when the resource failed to load
pub fn build(self) -> CSSStyleSheetHeader<'a>