pub struct ComputedStyleExtraFields {
pub isAppearanceBase: bool,
}Fields
isAppearanceBase: boolReturns whether or not this node is being rendered with base appearance, which happens when it has its appearance property set to base/base-select or it is in the subtree of an element being rendered with base appearance.