pub struct GetLayersForNodeParams {
pub nodeId: NodeId,
}Expand description
Returns all layers parsed by the rendering engine for the tree scope of a node. Given a DOM element identified by nodeId, getLayersForNode returns the root layer for the nearest ancestor document or shadow root. The layer root contains the full layer tree for the tree scope and their ordering.
Fields
nodeId: NodeIdTrait Implementations
Sourceimpl Clone for GetLayersForNodeParams
impl Clone for GetLayersForNodeParams
Sourcefn clone(&self) -> GetLayersForNodeParams
fn clone(&self) -> GetLayersForNodeParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetLayersForNodeParams
impl Debug for GetLayersForNodeParams
Sourceimpl Default for GetLayersForNodeParams
impl Default for GetLayersForNodeParams
Sourcefn default() -> GetLayersForNodeParams
fn default() -> GetLayersForNodeParams
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for GetLayersForNodeParams
impl<'de> Deserialize<'de> for GetLayersForNodeParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more