GetLayersForNodeReturns

Struct GetLayersForNodeReturns 

pub struct GetLayersForNodeReturns<'a> { /* private fields */ }
Returns all layers parsed by the rendering engine for the tree scope of a node. Given a DOM element identified by nodeId, getLayersForNode returns the root layer for the nearest ancestor document or shadow root. The layer root contains the full layer tree for the tree scope and their ordering.

Implementations

Source

impl<'a> GetLayersForNodeReturns<'a>

pub fn builder( root_layer: CSSLayerData<'a>, ) -> GetLayersForNodeReturnsBuilder<'a>

Creates a builder for this type with the required parameters:

  • root_layer:
pub fn root_layer(&self) -> &CSSLayerData<'a>