pub struct GetLocationForSelectorReturns { /* private fields */ }Expand description
Given a CSS selector text and a style sheet ID, getLocationForSelector returns an array of locations of the CSS selector in the style sheet.
Implementations
Sourceimpl GetLocationForSelectorReturns
impl GetLocationForSelectorReturns
Sourcepub fn builder(ranges: Vec<SourceRange>) -> GetLocationForSelectorReturnsBuilder
pub fn builder(ranges: Vec<SourceRange>) -> GetLocationForSelectorReturnsBuilder
Creates a builder for this type with the required parameters:
ranges:
pub fn ranges(&self) -> &[SourceRange]