pub struct InheritedAnimatedStyleEntry<'a> { /* private fields */ }Expand description
Inherited CSS style collection for animated styles from ancestor node.
Implementations
Sourceimpl<'a> InheritedAnimatedStyleEntry<'a>
impl<'a> InheritedAnimatedStyleEntry<'a>
Sourcepub fn builder() -> InheritedAnimatedStyleEntryBuilder<'a>
pub fn builder() -> InheritedAnimatedStyleEntryBuilder<'a>
Creates a builder for this type.
Sourcepub fn animation_styles(&self) -> Option<&[CSSAnimationStyle<'a>]>
pub fn animation_styles(&self) -> Option<&[CSSAnimationStyle<'a>]>
Styles coming from the animations of the ancestor, if any, in the style inheritance chain.
Sourcepub fn transitions_style(&self) -> Option<&CSSStyle<'a>>
pub fn transitions_style(&self) -> Option<&CSSStyle<'a>>
The style coming from the transitions of the ancestor, if any, in the style inheritance chain.