pub struct InheritedPseudoElementMatches {
pub pseudoElements: Vec<PseudoElementMatches>,
}Expand description
Inherited pseudo element matches from pseudos of an ancestor node.
Fields
pseudoElements: Vec<PseudoElementMatches>Matches of pseudo styles from the pseudos of an ancestor node.