pub struct InheritedStyleEntry<'a> { /* private fields */ }Expand description
Inherited CSS rule collection from ancestor node.
Implementations
Sourceimpl<'a> InheritedStyleEntry<'a>
impl<'a> InheritedStyleEntry<'a>
Sourcepub fn builder(
matched_css_rules: Vec<RuleMatch<'a>>,
) -> InheritedStyleEntryBuilder<'a>
pub fn builder( matched_css_rules: Vec<RuleMatch<'a>>, ) -> InheritedStyleEntryBuilder<'a>
Creates a builder for this type with the required parameters:
matched_css_rules: Matches of CSS rules matching the ancestor node in the style inheritance chain.
Sourcepub fn inline_style(&self) -> Option<&CSSStyle<'a>>
pub fn inline_style(&self) -> Option<&CSSStyle<'a>>
The ancestor node’s inline style, if any, in the style inheritance chain.
Sourcepub fn matched_css_rules(&self) -> &[RuleMatch<'a>]
pub fn matched_css_rules(&self) -> &[RuleMatch<'a>]
Matches of CSS rules matching the ancestor node in the style inheritance chain.