pub struct PlatformFontUsage<'a> { /* private fields */ }Expand description
Information about amount of glyphs that were rendered with given font.
Implementations
Sourceimpl<'a> PlatformFontUsage<'a>
impl<'a> PlatformFontUsage<'a>
Sourcepub fn builder(
family_name: impl Into<Cow<'a, str>>,
post_script_name: impl Into<Cow<'a, str>>,
is_custom_font: bool,
glyph_count: f64,
) -> PlatformFontUsageBuilder<'a>
pub fn builder( family_name: impl Into<Cow<'a, str>>, post_script_name: impl Into<Cow<'a, str>>, is_custom_font: bool, glyph_count: f64, ) -> PlatformFontUsageBuilder<'a>
Creates a builder for this type with the required parameters:
family_name: Font’s family name reported by platform.post_script_name: Font’s PostScript name reported by platform.is_custom_font: Indicates if the font was downloaded or resolved locally.glyph_count: Amount of glyphs that were rendered with this font.
Sourcepub fn family_name(&self) -> &str
pub fn family_name(&self) -> &str
Font’s family name reported by platform.
Sourcepub fn post_script_name(&self) -> &str
pub fn post_script_name(&self) -> &str
Font’s PostScript name reported by platform.
Sourcepub fn is_custom_font(&self) -> bool
pub fn is_custom_font(&self) -> bool
Indicates if the font was downloaded or resolved locally.
Sourcepub fn glyph_count(&self) -> f64
pub fn glyph_count(&self) -> f64
Amount of glyphs that were rendered with this font.