ResolveValuesParams

Struct ResolveValuesParams 

pub struct ResolveValuesParams<'a> { /* private fields */ }
Resolve the specified values in the context of the provided element. For example, a value of ‘1em’ is evaluated according to the computed ‘font-size’ of the element and a value ‘calc(1px + 2px)’ will be resolved to ‘3px’. If the ‘propertyName’ was specified the ‘values’ are resolved as if they were property’s declaration. If a value cannot be parsed according to the provided property syntax, the value is parsed using combined syntax as if null ‘propertyName’ was provided. If the value cannot be resolved even then, return the provided value without any changes. Note: this function currently does not resolve CSS random() function, it returns unmodified random() function parts.’

Implementations

Source

impl<'a> ResolveValuesParams<'a>

pub fn builder( values: Vec<Cow<'a, str>>, node_id: NodeId, ) -> ResolveValuesParamsBuilder<'a>

Creates a builder for this type with the required parameters:

  • values: Cascade-dependent keywords (revert/revert-layer) do not work.
  • node_id: Id of the node in whose context the expression is evaluated
pub fn values(&self) -> &[Cow<'a, str>]

Cascade-dependent keywords (revert/revert-layer) do not work.

pub fn node_id(&self) -> &NodeId

Id of the node in whose context the expression is evaluated

pub fn property_name(&self) -> Option<&str>

Only longhands and custom property names are accepted.

pub fn pseudo_type(&self) -> Option<&PseudoType>

Pseudo element type, only works for pseudo elements that generate elements in the tree, such as ::before and ::after.

pub fn pseudo_identifier(&self) -> Option<&str>

Pseudo element custom ident.

Source

impl<'a> ResolveValuesParams<'a>

pub const METHOD: &'static str = "CSS.resolveValues"