ResolveValuesParamsBuilder

Struct ResolveValuesParamsBuilder 

pub struct ResolveValuesParamsBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> ResolveValuesParamsBuilder<'a>

pub fn property_name(self, property_name: impl Into<Cow<'a, str>>) -> Self

Only longhands and custom property names are accepted.

pub fn pseudo_type(self, pseudo_type: PseudoType) -> Self

Pseudo element type, only works for pseudo elements that generate elements in the tree, such as ::before and ::after.

pub fn pseudo_identifier( self, pseudo_identifier: impl Into<Cow<'a, str>>, ) -> Self

Pseudo element custom ident.

pub fn build(self) -> ResolveValuesParams<'a>