pub struct RuleUsage<'a> { /* private fields */ }Expand description
CSS coverage information.
Implementations
Sourceimpl<'a> RuleUsage<'a>
impl<'a> RuleUsage<'a>
Sourcepub fn builder(
style_sheet_id: StyleSheetId<'a>,
start_offset: f64,
end_offset: f64,
used: bool,
) -> RuleUsageBuilder<'a>
pub fn builder( style_sheet_id: StyleSheetId<'a>, start_offset: f64, end_offset: f64, used: bool, ) -> RuleUsageBuilder<'a>
Creates a builder for this type with the required parameters:
style_sheet_id: The css style sheet identifier (absent for user agent stylesheet and user-specified stylesheet rules) this rule came from.start_offset: Offset of the start of the rule (including selector) from the beginning of the stylesheet.end_offset: Offset of the end of the rule body from the beginning of the stylesheet.used: Indicates whether the rule was actually used by some element in the page.
Sourcepub fn style_sheet_id(&self) -> &StyleSheetId<'a>
pub fn style_sheet_id(&self) -> &StyleSheetId<'a>
The css style sheet identifier (absent for user agent stylesheet and user-specified stylesheet rules) this rule came from.
Sourcepub fn start_offset(&self) -> f64
pub fn start_offset(&self) -> f64
Offset of the start of the rule (including selector) from the beginning of the stylesheet.
Sourcepub fn end_offset(&self) -> f64
pub fn end_offset(&self) -> f64
Offset of the end of the rule body from the beginning of the stylesheet.