pub struct SetEffectivePropertyValueForNodeParams<'a> { /* private fields */ }Expand description
Find a rule with the given active property for the given node and set the new value for this property
Implementations
Sourceimpl<'a> SetEffectivePropertyValueForNodeParams<'a>
impl<'a> SetEffectivePropertyValueForNodeParams<'a>
Sourcepub fn builder(
node_id: NodeId,
property_name: impl Into<Cow<'a, str>>,
value: impl Into<Cow<'a, str>>,
) -> SetEffectivePropertyValueForNodeParamsBuilder<'a>
pub fn builder( node_id: NodeId, property_name: impl Into<Cow<'a, str>>, value: impl Into<Cow<'a, str>>, ) -> SetEffectivePropertyValueForNodeParamsBuilder<'a>
Creates a builder for this type with the required parameters:
node_id: The element id for which to set property.property_name:value:
pub fn property_name(&self) -> &str
pub fn value(&self) -> &str