pub struct SetStyleTextsParams<'a> { /* private fields */ }Expand description
Applies specified style edits one after another in the given order.
Implementations
Sourceimpl<'a> SetStyleTextsParams<'a>
impl<'a> SetStyleTextsParams<'a>
Sourcepub fn builder(
edits: Vec<StyleDeclarationEdit<'a>>,
) -> SetStyleTextsParamsBuilder<'a>
pub fn builder( edits: Vec<StyleDeclarationEdit<'a>>, ) -> SetStyleTextsParamsBuilder<'a>
Creates a builder for this type with the required parameters:
edits:
pub fn edits(&self) -> &[StyleDeclarationEdit<'a>]
Sourcepub fn node_for_property_syntax_validation(&self) -> Option<&NodeId>
pub fn node_for_property_syntax_validation(&self) -> Option<&NodeId>
NodeId for the DOM node in whose context custom property declarations for registered properties should be validated. If omitted, declarations in the new rule text can only be validated statically, which may produce incorrect results if the declaration contains a var() for example.