pub struct SetStyleTextsParamsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> SetStyleTextsParamsBuilder<'a>
impl<'a> SetStyleTextsParamsBuilder<'a>
Sourcepub fn node_for_property_syntax_validation(
self,
node_for_property_syntax_validation: NodeId,
) -> Self
pub fn node_for_property_syntax_validation( self, node_for_property_syntax_validation: NodeId, ) -> Self
NodeId for the DOM node in whose context custom property declarations for registered properties should be validated. If omitted, declarations in the new rule text can only be validated statically, which may produce incorrect results if the declaration contains a var() for example.
pub fn build(self) -> SetStyleTextsParams<'a>