pub struct StyleDeclarationEdit<'a> { /* private fields */ }Expand description
A descriptor of operation to mutate style declaration text.
Implementations
Sourceimpl<'a> StyleDeclarationEdit<'a>
impl<'a> StyleDeclarationEdit<'a>
Sourcepub fn builder(
style_sheet_id: StyleSheetId<'a>,
range: SourceRange,
text: impl Into<Cow<'a, str>>,
) -> StyleDeclarationEditBuilder<'a>
pub fn builder( style_sheet_id: StyleSheetId<'a>, range: SourceRange, text: impl Into<Cow<'a, str>>, ) -> StyleDeclarationEditBuilder<'a>
Creates a builder for this type with the required parameters:
style_sheet_id: The css style sheet identifier.range: The range of the style text in the enclosing stylesheet.text: New style text.
Sourcepub fn style_sheet_id(&self) -> &StyleSheetId<'a>
pub fn style_sheet_id(&self) -> &StyleSheetId<'a>
The css style sheet identifier.
Sourcepub fn range(&self) -> &SourceRange
pub fn range(&self) -> &SourceRange
The range of the style text in the enclosing stylesheet.