pub struct TrackComputedStyleUpdatesForNodeParams {
pub nodeId: Option<NodeId>,
}Expand description
Starts tracking the given node for the computed style updates and whenever the computed style is updated for node, it queues a ‘computedStyleUpdated’ event with throttling. There can only be 1 node tracked for computed style updates so passing a new node id removes tracking from the previous node. Pass ‘undefined’ to disable tracking.
Fields
nodeId: Option<NodeId>Trait Implementations
Sourceimpl Clone for TrackComputedStyleUpdatesForNodeParams
impl Clone for TrackComputedStyleUpdatesForNodeParams
Sourcefn clone(&self) -> TrackComputedStyleUpdatesForNodeParams
fn clone(&self) -> TrackComputedStyleUpdatesForNodeParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for TrackComputedStyleUpdatesForNodeParams
impl Default for TrackComputedStyleUpdatesForNodeParams
Sourcefn default() -> TrackComputedStyleUpdatesForNodeParams
fn default() -> TrackComputedStyleUpdatesForNodeParams
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for TrackComputedStyleUpdatesForNodeParams
impl<'de> Deserialize<'de> for TrackComputedStyleUpdatesForNodeParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more