This domain exposes DOM read/write operations. Each DOM Node is represented with its mirror object that has an ‘id’. This ‘id’ can be used to get additional information on the Node, resolve it into the JavaScript object wrapper, etc. It is important that client receives DOM events only for the nodes that are known to the client. Backend keeps track of the nodes that were sent to the client and never sends the same node twice. It is client’s responsibility to collect information about the nodes that were sent to the client. Note that ‘iframe’ owner elements will return corresponding document elements as their child nodes.
Structs
- Backend
Node - Backend node with a friendly name.
- BoxModel
- Box model.
- CSSComputed
Style Property - Collect
Class Names From Subtree Params - Collects class names for the node with given id and all of it’s child nodes.
- Collect
Class Names From Subtree Returns - Collects class names for the node with given id and all of it’s child nodes.
- Copy
ToParams - Creates a deep copy of the specified node and places it into the target container before the given anchor.
- Copy
ToReturns - Creates a deep copy of the specified node and places it into the target container before the given anchor.
- Describe
Node Params - Describes node given its id, does not require domain to be enabled. Does not start tracking any objects, can be used for automation.
- Describe
Node Returns - Describes node given its id, does not require domain to be enabled. Does not start tracking any objects, can be used for automation.
- Detached
Element Info - A structure to hold the top-level node of a detached tree and an array of its retained descendants.
- Disable
Params - Discard
Search Results Params - Discards search results from the session with the given id. ‘getSearchResults’ should no longer be called for that search.
- Enable
Params - Enables DOM agent for the given page.
- Focus
Params - Focuses the given element.
- Force
Show Popover Params - When enabling, this API force-opens the popover identified by nodeId and keeps it open until disabled.
- Force
Show Popover Returns - When enabling, this API force-opens the popover identified by nodeId and keeps it open until disabled.
- GetAnchor
Element Params - Returns the target anchor element of the given anchor query according to https://www.w3.org/TR/css-anchor-position-1/#target.
- GetAnchor
Element Returns - Returns the target anchor element of the given anchor query according to https://www.w3.org/TR/css-anchor-position-1/#target.
- GetAttributes
Params - Returns attributes for the specified node.
- GetAttributes
Returns - Returns attributes for the specified node.
- GetBox
Model Params - Returns boxes for the given node.
- GetBox
Model Returns - Returns boxes for the given node.
- GetContainer
ForNode Params - Returns the query container of the given node based on container query conditions: containerName, physical and logical axes, and whether it queries scroll-state or anchored elements. If no axes are provided and queriesScrollState is false, the style container is returned, which is the direct parent or the closest element with a matching container-name.
- GetContainer
ForNode Returns - Returns the query container of the given node based on container query conditions: containerName, physical and logical axes, and whether it queries scroll-state or anchored elements. If no axes are provided and queriesScrollState is false, the style container is returned, which is the direct parent or the closest element with a matching container-name.
- GetContent
Quads Params - Returns quads that describe node position on the page. This method might return multiple quads for inline nodes.
- GetContent
Quads Returns - Returns quads that describe node position on the page. This method might return multiple quads for inline nodes.
- GetDetached
DomNodes Params - GetDetached
DomNodes Returns - Returns list of detached nodes
- GetDocument
Params - Returns the root DOM node (and optionally the subtree) to the caller. Implicitly enables the DOM domain events for the current target.
- GetDocument
Returns - Returns the root DOM node (and optionally the subtree) to the caller. Implicitly enables the DOM domain events for the current target.
- GetElement
ByRelation Params - Returns the NodeId of the matched element according to certain relations.
- GetElement
ByRelation Returns - Returns the NodeId of the matched element according to certain relations.
- GetFile
Info Params - Returns file information for the given File wrapper.
- GetFile
Info Returns - Returns file information for the given File wrapper.
- GetFlattened
Document Params - Returns the root DOM node (and optionally the subtree) to the caller. Deprecated, as it is not designed to work well with the rest of the DOM agent. Use DOMSnapshot.captureSnapshot instead.
- GetFlattened
Document Returns - Returns the root DOM node (and optionally the subtree) to the caller. Deprecated, as it is not designed to work well with the rest of the DOM agent. Use DOMSnapshot.captureSnapshot instead.
- GetFrame
Owner Params - Returns iframe node that owns iframe with the given domain.
- GetFrame
Owner Returns - Returns iframe node that owns iframe with the given domain.
- GetNode
ForLocation Params - Returns node id at given location. Depending on whether DOM domain is enabled, nodeId is either returned or not.
- GetNode
ForLocation Returns - Returns node id at given location. Depending on whether DOM domain is enabled, nodeId is either returned or not.
- GetNode
Stack Traces Params - Gets stack traces associated with a Node. As of now, only provides stack trace for Node creation.
- GetNode
Stack Traces Returns - Gets stack traces associated with a Node. As of now, only provides stack trace for Node creation.
- GetNodes
ForSubtree ByStyle Params - Finds nodes with a given computed style in a subtree.
- GetNodes
ForSubtree ByStyle Returns - Finds nodes with a given computed style in a subtree.
- GetOuterHTML
Params - Returns node’s HTML markup.
- GetOuterHTML
Returns - Returns node’s HTML markup.
- GetQuerying
Descendants ForContainer Params - Returns the descendants of a container query container that have container queries against this container.
- GetQuerying
Descendants ForContainer Returns - Returns the descendants of a container query container that have container queries against this container.
- GetRelayout
Boundary Params - Returns the id of the nearest ancestor that is a relayout boundary.
- GetRelayout
Boundary Returns - Returns the id of the nearest ancestor that is a relayout boundary.
- GetSearch
Results Params - Returns search results from given ‘fromIndex’ to given ‘toIndex’ from the search with the given identifier.
- GetSearch
Results Returns - Returns search results from given ‘fromIndex’ to given ‘toIndex’ from the search with the given identifier.
- GetTop
Layer Elements Params - GetTop
Layer Elements Returns - Returns NodeIds of current top layer elements. Top layer is rendered closest to the user within a viewport, therefore its elements always appear on top of all other content.
- Hide
Highlight Params - Highlight
Node Params - Highlight
Rect Params - Mark
Undoable State Params - Move
ToParams - Moves node into the new container, places it before the given anchor.
- Move
ToReturns - Moves node into the new container, places it before the given anchor.
- Node
- DOM interaction is implemented in terms of mirror objects that represent the actual DOM nodes. DOMNode is a base node mirror type.
- Perform
Search Params - Searches for a given string in the DOM tree. Use ‘getSearchResults’ to access search results or ‘cancelSearch’ to end this search session.
- Perform
Search Returns - Searches for a given string in the DOM tree. Use ‘getSearchResults’ to access search results or ‘cancelSearch’ to end this search session.
- Push
Node ByPath ToFrontend Params - Requests that the node is sent to the caller given its path. // FIXME, use XPath
- Push
Node ByPath ToFrontend Returns - Requests that the node is sent to the caller given its path. // FIXME, use XPath
- Push
Nodes ByBackend IdsTo Frontend Params - Requests that a batch of nodes is sent to the caller given their backend node ids.
- Push
Nodes ByBackend IdsTo Frontend Returns - Requests that a batch of nodes is sent to the caller given their backend node ids.
- Query
Selector AllParams - Executes ‘querySelectorAll’ on a given node.
- Query
Selector AllReturns - Executes ‘querySelectorAll’ on a given node.
- Query
Selector Params - Executes ‘querySelector’ on a given node.
- Query
Selector Returns - Executes ‘querySelector’ on a given node.
- RGBA
- A structure holding an RGBA color.
- Rect
- Rectangle.
- Redo
Params - Remove
Attribute Params - Removes attribute with given name from an element with given id.
- Remove
Node Params - Removes node with given id.
- Request
Child Nodes Params - Requests that children of the node with given id are returned to the caller in form of ‘setChildNodes’ events where not only immediate children are retrieved, but all children down to the specified depth.
- Request
Node Params - Requests that the node is sent to the caller given the JavaScript node object reference. All nodes that form the path from the node to the root are also sent to the client as a series of ‘setChildNodes’ notifications.
- Request
Node Returns - Requests that the node is sent to the caller given the JavaScript node object reference. All nodes that form the path from the node to the root are also sent to the client as a series of ‘setChildNodes’ notifications.
- Resolve
Node Params - Resolves the JavaScript node object for a given NodeId or BackendNodeId.
- Resolve
Node Returns - Resolves the JavaScript node object for a given NodeId or BackendNodeId.
- Scroll
Into View IfNeeded Params - Scrolls the specified rect of the given node into view if not already visible. Note: exactly one between nodeId, backendNodeId and objectId should be passed to identify the node.
- SetAttribute
Value Params - Sets attribute for an element with given id.
- SetAttributes
AsText Params - Sets attributes on element with given id. This method is useful when user edits some existing attribute value and types in several attribute name/value pairs.
- SetFile
Input Files Params - Sets files for the given file input element.
- SetInspected
Node Params - Enables console to refer to the node with given id via $x (see Command Line API for more details $x functions).
- SetNode
Name Params - Sets node name for a node with given id.
- SetNode
Name Returns - Sets node name for a node with given id.
- SetNode
Stack Traces Enabled Params - Sets if stack traces should be captured for Nodes. See ‘Node.getNodeStackTraces’. Default is disabled.
- SetNode
Value Params - Sets node value for a node with given id.
- SetOuterHTML
Params - Sets node HTML markup, returns new node id.
- Shape
Outside Info - CSS Shape Outside details.
- Undo
Params
Enums
- Compatibility
Mode - Document compatibility mode.
- Logical
Axes - ContainerSelector logical axes
- Physical
Axes - ContainerSelector physical axes
- Pseudo
Type - Pseudo element type.
- Scroll
Orientation - Physical scroll orientation
- Shadow
Root Type - Shadow root type.
Type Aliases
- Backend
Node Id - Unique DOM node identifier used to reference a node that may not have been pushed to the front-end.
- NodeId
- Unique DOM node identifier.
- Quad
- An array of quad vertices, x immediately followed by y for each point, points clock-wise.
- Style
Sheet Id - Unique identifier for a CSS stylesheet.