pub struct CopyToParams { /* private fields */ }Expand description
Creates a deep copy of the specified node and places it into the target container before the given anchor.
Implementations
Sourceimpl CopyToParams
impl CopyToParams
pub fn builder(nodeId: NodeId, targetNodeId: NodeId) -> CopyToParamsBuilder
pub fn nodeId(&self) -> &NodeId
pub fn targetNodeId(&self) -> &NodeId
pub fn insertBeforeNodeId(&self) -> Option<&NodeId>