pub struct DescribeNodeReturns {
pub node: Node,
}Expand description
Describes node given its id, does not require domain to be enabled. Does not start tracking any objects, can be used for automation.
Fields
node: NodeNode description.