pub struct ForceShowPopoverParams {
pub nodeId: NodeId,
pub enable: bool,
}Expand description
When enabling, this API force-opens the popover identified by nodeId and keeps it open until disabled.
Fields
nodeId: NodeIdId of the popover HTMLElement
enable: boolIf true, opens the popover and keeps it open. If false, closes the popover if it was previously force-opened.