pub struct GetAnchorElementParams {
pub nodeId: NodeId,
pub anchorSpecifier: Option<String>,
}Expand description
Returns the target anchor element of the given anchor query according to https://www.w3.org/TR/css-anchor-position-1/#target.
Fields
nodeId: NodeIdId of the positioned element from which to find the anchor.
anchorSpecifier: Option<String>An optional anchor specifier, as defined in https://www.w3.org/TR/css-anchor-position-1/#anchor-specifier. If not provided, it will return the implicit anchor element for the given positioned element.