pub struct GetContainerForNodeParams<'a> { /* private fields */ }Expand description
Returns the query container of the given node based on container query conditions: containerName, physical and logical axes, and whether it queries scroll-state or anchored elements. If no axes are provided and queriesScrollState is false, the style container is returned, which is the direct parent or the closest element with a matching container-name.
Implementations
Sourceimpl<'a> GetContainerForNodeParams<'a>
impl<'a> GetContainerForNodeParams<'a>
pub fn builder(nodeId: NodeId) -> GetContainerForNodeParamsBuilder<'a>
pub fn nodeId(&self) -> &NodeId
pub fn containerName(&self) -> Option<&str>
pub fn physicalAxes(&self) -> Option<&PhysicalAxes>
pub fn logicalAxes(&self) -> Option<&LogicalAxes>
pub fn queriesScrollState(&self) -> Option<bool>
pub fn queriesAnchored(&self) -> Option<bool>