pub struct GetContentQuadsParams {
pub nodeId: Option<NodeId>,
pub backendNodeId: Option<BackendNodeId>,
pub objectId: Option<RemoteObjectId>,
}Expand description
Returns quads that describe node position on the page. This method might return multiple quads for inline nodes.
Fields
nodeId: Option<NodeId>Identifier of the node.
backendNodeId: Option<BackendNodeId>Identifier of the backend node.
objectId: Option<RemoteObjectId>JavaScript object id of the node wrapper.