pub struct GetElementByRelationParams {
pub nodeId: NodeId,
pub relation: String,
}Expand description
Returns the NodeId of the matched element according to certain relations.
Fields
nodeId: NodeIdId of the node from which to query the relation.
relation: StringType of relation to get.