pub struct GetFlattenedDocumentParams {
pub depth: Option<i64>,
pub pierce: Option<bool>,
}Expand description
Returns the root DOM node (and optionally the subtree) to the caller. Deprecated, as it is not designed to work well with the rest of the DOM agent. Use DOMSnapshot.captureSnapshot instead.
Fields
depth: Option<i64>The maximum depth at which children should be retrieved, defaults to 1. Use -1 for the entire subtree or provide an integer larger than 0.
pierce: Option<bool>Whether or not iframes and shadow roots should be traversed when returning the subtree (default is false).