pub struct GetFlattenedDocumentParamsBuilder { /* private fields */ }Implementations
Sourceimpl GetFlattenedDocumentParamsBuilder
impl GetFlattenedDocumentParamsBuilder
Sourcepub fn depth(self, depth: i64) -> Self
pub fn depth(self, depth: i64) -> Self
The maximum depth at which children should be retrieved, defaults to 1. Use -1 for the entire subtree or provide an integer larger than 0.
Sourcepub fn pierce(self, pierce: bool) -> Self
pub fn pierce(self, pierce: bool) -> Self
Whether or not iframes and shadow roots should be traversed when returning the subtree (default is false).
pub fn build(self) -> GetFlattenedDocumentParams