pub struct GetFrameOwnerReturns { /* private fields */ }Expand description
Returns iframe node that owns iframe with the given domain.
Implementations
Sourceimpl GetFrameOwnerReturns
impl GetFrameOwnerReturns
Sourcepub fn builder(backend_node_id: BackendNodeId) -> GetFrameOwnerReturnsBuilder
pub fn builder(backend_node_id: BackendNodeId) -> GetFrameOwnerReturnsBuilder
Creates a builder for this type with the required parameters:
backend_node_id: Resulting node.
Sourcepub fn backend_node_id(&self) -> &BackendNodeId
pub fn backend_node_id(&self) -> &BackendNodeId
Resulting node.