pub struct GetNodeStackTracesParams {
pub nodeId: NodeId,
}Expand description
Gets stack traces associated with a Node. As of now, only provides stack trace for Node creation.
Fields
nodeId: NodeIdId of the node to get stack traces for.
Implementations