pub struct GetQueryingDescendantsForContainerParams {
pub nodeId: NodeId,
}Expand description
Returns the descendants of a container query container that have container queries against this container.
Fields
nodeId: NodeIdId of the container node to find querying descendants from.
Implementations