pub struct GetQueryingDescendantsForContainerReturns {
pub nodeIds: Vec<NodeId>,
}Expand description
Returns the descendants of a container query container that have container queries against this container.
Fields
nodeIds: Vec<NodeId>Descendant nodes with container queries against the given container.