pub struct GetSearchResultsParams {
pub searchId: String,
pub fromIndex: u64,
pub toIndex: u64,
}Expand description
Returns search results from given ‘fromIndex’ to given ‘toIndex’ from the search with the given identifier.
Fields
searchId: StringUnique search session identifier.
fromIndex: u64Start index of the search result to be returned.
toIndex: u64End index of the search result to be returned.