pub struct GetTopLayerElementsReturns {
pub nodeIds: Vec<NodeId>,
}Expand description
Returns NodeIds of current top layer elements. Top layer is rendered closest to the user within a viewport, therefore its elements always appear on top of all other content.
Fields
nodeIds: Vec<NodeId>NodeIds of top layer elements