pub struct MoveToParams {
pub nodeId: NodeId,
pub targetNodeId: NodeId,
pub insertBeforeNodeId: Option<NodeId>,
}Expand description
Moves node into the new container, places it before the given anchor.
Fields
nodeId: NodeIdId of the node to move.
targetNodeId: NodeIdId of the element to drop the moved node into.
insertBeforeNodeId: Option<NodeId>Drop node before this one (if absent, the moved node becomes the last child of ‘targetNodeId’).
Implementations