Node

Struct Node 

pub struct Node<'a> { /* private fields */ }
DOM interaction is implemented in terms of mirror objects that represent the actual DOM nodes. DOMNode is a base node mirror type.

Implementations

Source

impl<'a> Node<'a>

pub fn builder( node_id: NodeId, backend_node_id: BackendNodeId, node_type: i64, node_name: impl Into<Cow<'a, str>>, local_name: impl Into<Cow<'a, str>>, node_value: impl Into<Cow<'a, str>>, ) -> NodeBuilder<'a>

Creates a builder for this type with the required parameters:

  • node_id: Node identifier that is passed into the rest of the DOM messages as the nodeId. Backend will only push node with given id once. It is aware of all requested nodes and will only fire DOM events for nodes known to the client.
  • backend_node_id: The BackendNodeId for this node.
  • node_type: Node’s nodeType.
  • node_name: Node’s nodeName.
  • local_name: Node’s localName.
  • node_value: Node’s nodeValue.
pub fn node_id(&self) -> &NodeId

Node identifier that is passed into the rest of the DOM messages as the ‘nodeId’. Backend will only push node with given ‘id’ once. It is aware of all requested nodes and will only fire DOM events for nodes known to the client.

pub fn parent_id(&self) -> Option<&NodeId>

The id of the parent node if any.

pub fn backend_node_id(&self) -> &BackendNodeId

The BackendNodeId for this node.

pub fn node_type(&self) -> i64

‘Node’’s nodeType.

pub fn node_name(&self) -> &str

‘Node’’s nodeName.

pub fn local_name(&self) -> &str

‘Node’’s localName.

pub fn node_value(&self) -> &str

‘Node’’s nodeValue.

pub fn child_node_count(&self) -> Option<u64>

Child count for ‘Container’ nodes.

pub fn children(&self) -> Option<&[Box<Node<'a>>]>

Child nodes of this node when requested with children.

pub fn attributes(&self) -> Option<&[Cow<'a, str>]>

Attributes of the ‘Element’ node in the form of flat array ‘[name1, value1, name2, value2]’.

pub fn document_url(&self) -> Option<&str>

Document URL that ‘Document’ or ‘FrameOwner’ node points to.

pub fn base_url(&self) -> Option<&str>

Base URL that ‘Document’ or ‘FrameOwner’ node uses for URL completion.

pub fn public_id(&self) -> Option<&str>

‘DocumentType’’s publicId.

pub fn system_id(&self) -> Option<&str>

‘DocumentType’’s systemId.

pub fn internal_subset(&self) -> Option<&str>

‘DocumentType’’s internalSubset.

pub fn xml_version(&self) -> Option<&str>

‘Document’’s XML version in case of XML documents.

pub fn name(&self) -> Option<&str>

‘Attr’’s name.

pub fn value(&self) -> Option<&str>

‘Attr’’s value.

pub fn pseudo_type(&self) -> Option<&PseudoType>

Pseudo element type for this node.

pub fn pseudo_identifier(&self) -> Option<&str>

Pseudo element identifier for this node. Only present if there is a valid pseudoType.

pub fn shadow_root_type(&self) -> Option<&ShadowRootType>

Shadow root type.

pub fn frame_id(&self) -> Option<&FrameId<'a>>

Frame ID for frame owner elements.

pub fn content_document(&self) -> Option<&Node<'a>>

Content document for frame owner elements.

pub fn shadow_roots(&self) -> Option<&[Box<Node<'a>>]>

Shadow root list for given element host.

pub fn template_content(&self) -> Option<&Node<'a>>

Content document fragment for template elements.

pub fn pseudo_elements(&self) -> Option<&[Box<Node<'a>>]>

Pseudo elements associated with this node.

pub fn imported_document(&self) -> Option<&Node<'a>>

Deprecated, as the HTML Imports API has been removed (crbug.com/937746). This property used to return the imported document for the HTMLImport links. The property is always undefined now.

pub fn distributed_nodes(&self) -> Option<&[BackendNode<'a>]>

Distributed nodes for given insertion point.

pub fn is_svg(&self) -> Option<bool>

Whether the node is SVG.

pub fn compatibility_mode(&self) -> Option<&CompatibilityMode>

pub fn assigned_slot(&self) -> Option<&BackendNode<'a>>

pub fn is_scrollable(&self) -> Option<bool>

pub fn affected_by_starting_styles(&self) -> Option<bool>

pub fn adopted_style_sheets(&self) -> Option<&[StyleSheetId<'a>]>

pub fn ad_provenance(&self) -> Option<&AdProvenance<'a>>