NodeBuilder

Struct NodeBuilder 

pub struct NodeBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> NodeBuilder<'a>

pub fn parent_id(self, parent_id: NodeId) -> Self

The id of the parent node if any.

pub fn child_node_count(self, child_node_count: u64) -> Self

Child count for ‘Container’ nodes.

pub fn children(self, children: Vec<Box<Node<'a>>>) -> Self

Child nodes of this node when requested with children.

pub fn attributes(self, attributes: Vec<Cow<'a, str>>) -> Self

Attributes of the ‘Element’ node in the form of flat array ‘[name1, value1, name2, value2]’.

pub fn document_url(self, document_url: impl Into<Cow<'a, str>>) -> Self

Document URL that ‘Document’ or ‘FrameOwner’ node points to.

pub fn base_url(self, base_url: impl Into<Cow<'a, str>>) -> Self

Base URL that ‘Document’ or ‘FrameOwner’ node uses for URL completion.

pub fn public_id(self, public_id: impl Into<Cow<'a, str>>) -> Self

‘DocumentType’’s publicId.

pub fn system_id(self, system_id: impl Into<Cow<'a, str>>) -> Self

‘DocumentType’’s systemId.

pub fn internal_subset(self, internal_subset: impl Into<Cow<'a, str>>) -> Self

‘DocumentType’’s internalSubset.

pub fn xml_version(self, xml_version: impl Into<Cow<'a, str>>) -> Self

‘Document’’s XML version in case of XML documents.

pub fn name(self, name: impl Into<Cow<'a, str>>) -> Self

‘Attr’’s name.

pub fn value(self, value: impl Into<Cow<'a, str>>) -> Self

‘Attr’’s value.

pub fn pseudo_type(self, pseudo_type: impl Into<PseudoType>) -> Self

Pseudo element type for this node.

pub fn pseudo_identifier( self, pseudo_identifier: impl Into<Cow<'a, str>>, ) -> Self

Pseudo element identifier for this node. Only present if there is a valid pseudoType.

pub fn shadow_root_type( self, shadow_root_type: impl Into<ShadowRootType>, ) -> Self

Shadow root type.

pub fn frame_id(self, frame_id: FrameId<'a>) -> Self

Frame ID for frame owner elements.

pub fn content_document(self, content_document: Box<Node<'a>>) -> Self

Content document for frame owner elements.

pub fn shadow_roots(self, shadow_roots: Vec<Box<Node<'a>>>) -> Self

Shadow root list for given element host.

pub fn template_content(self, template_content: Box<Node<'a>>) -> Self

Content document fragment for template elements.

pub fn pseudo_elements(self, pseudo_elements: Vec<Box<Node<'a>>>) -> Self

Pseudo elements associated with this node.

pub fn imported_document(self, imported_document: Box<Node<'a>>) -> Self

Deprecated, as the HTML Imports API has been removed (crbug.com/937746). This property used to return the imported document for the HTMLImport links. The property is always undefined now.

pub fn distributed_nodes(self, distributed_nodes: Vec<BackendNode<'a>>) -> Self

Distributed nodes for given insertion point.

pub fn is_svg(self, is_svg: bool) -> Self

Whether the node is SVG.

pub fn compatibility_mode( self, compatibility_mode: impl Into<CompatibilityMode>, ) -> Self

pub fn assigned_slot(self, assigned_slot: BackendNode<'a>) -> Self

pub fn is_scrollable(self, is_scrollable: bool) -> Self

pub fn affected_by_starting_styles( self, affected_by_starting_styles: bool, ) -> Self

pub fn adopted_style_sheets( self, adopted_style_sheets: Vec<StyleSheetId<'a>>, ) -> Self

pub fn ad_provenance(self, ad_provenance: AdProvenance<'a>) -> Self

pub fn build(self) -> Node<'a>