RequestNodeParams

Struct RequestNodeParams 

pub struct RequestNodeParams<'a> { /* private fields */ }
Requests that the node is sent to the caller given the JavaScript node object reference. All nodes that form the path from the node to the root are also sent to the client as a series of ‘setChildNodes’ notifications.

Implementations

Source

impl<'a> RequestNodeParams<'a>

pub fn builder(object_id: RemoteObjectId<'a>) -> RequestNodeParamsBuilder<'a>

Creates a builder for this type with the required parameters:

  • object_id: JavaScript object id to convert into node.
pub fn object_id(&self) -> &RemoteObjectId<'a>

JavaScript object id to convert into node.

Source

impl<'a> RequestNodeParams<'a>

pub const METHOD: &'static str = "DOM.requestNode"