RequestNodeReturns

Struct RequestNodeReturns 

pub struct RequestNodeReturns {
    pub nodeId: NodeId,
}
Requests that the node is sent to the caller given the JavaScript node object reference. All nodes that form the path from the node to the root are also sent to the client as a series of ‘setChildNodes’ notifications.

Fields

nodeId: NodeId

Node id for given object.