pub struct ScrollIntoViewIfNeededParams {
pub nodeId: Option<NodeId>,
pub backendNodeId: Option<BackendNodeId>,
pub objectId: Option<RemoteObjectId>,
pub rect: Option<Rect>,
}Expand description
Scrolls the specified rect of the given node into view if not already visible. Note: exactly one between nodeId, backendNodeId and objectId should be passed to identify the node.
Fields
nodeId: Option<NodeId>Identifier of the node.
backendNodeId: Option<BackendNodeId>Identifier of the backend node.
objectId: Option<RemoteObjectId>JavaScript object id of the node wrapper.
rect: Option<Rect>The rect to be scrolled into view, relative to the node’s border box, in CSS pixels. When omitted, center of the node will be used, similar to Element.scrollIntoView.
Implementations