ScrollIntoViewIfNeededParamsBuilder

Struct ScrollIntoViewIfNeededParamsBuilder 

pub struct ScrollIntoViewIfNeededParamsBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> ScrollIntoViewIfNeededParamsBuilder<'a>

pub fn nodeId(self, nodeId: NodeId) -> Self

Identifier of the node.

pub fn backendNodeId(self, backendNodeId: BackendNodeId) -> Self

Identifier of the backend node.

pub fn objectId(self, objectId: RemoteObjectId<'a>) -> Self

JavaScript object id of the node wrapper.

pub fn rect(self, rect: Rect) -> Self

The rect to be scrolled into view, relative to the node’s border box, in CSS pixels. When omitted, center of the node will be used, similar to Element.scrollIntoView.

pub fn build(self) -> ScrollIntoViewIfNeededParams<'a>