GetEventListenersParams

Struct GetEventListenersParams 

pub struct GetEventListenersParams {
    pub objectId: RemoteObjectId,
    pub depth: Option<i64>,
    pub pierce: Option<bool>,
}
Returns event listeners of the given object.

Fields

objectId: RemoteObjectId

Identifier of the object to return listeners for.

depth: Option<i64>

The maximum depth at which Node children should be retrieved, defaults to 1. Use -1 for the entire subtree or provide an integer larger than 0.

pierce: Option<bool>

Whether or not iframes and shadow roots should be traversed when returning the subtree (default is false). Reports listeners for all contexts if pierce is enabled.