GetEventListenersParamsBuilder

Struct GetEventListenersParamsBuilder 

pub struct GetEventListenersParamsBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> GetEventListenersParamsBuilder<'a>

pub fn depth(self, depth: i64) -> Self

The maximum depth at which Node children should be retrieved, defaults to 1. Use -1 for the entire subtree or provide an integer larger than 0.

pub fn pierce(self, pierce: bool) -> Self

Whether or not iframes and shadow roots should be traversed when returning the subtree (default is false). Reports listeners for all contexts if pierce is enabled.

pub fn build(self) -> GetEventListenersParams<'a>