Module domsnapshot

Module domsnapshot 

This domain facilitates obtaining document snapshots with DOM, layout, and style information.

Structs

CaptureSnapshotParams
Returns a document snapshot, including the full DOM tree of the root node (including iframes, template contents, and imported documents) in a flattened array, as well as layout and white-listed computed style information for the nodes. Shadow DOM in the returned DOM tree is flattened.
CaptureSnapshotParamsBuilder
CaptureSnapshotReturns
Returns a document snapshot, including the full DOM tree of the root node (including iframes, template contents, and imported documents) in a flattened array, as well as layout and white-listed computed style information for the nodes. Shadow DOM in the returned DOM tree is flattened.
CaptureSnapshotReturnsBuilder
ComputedStyle
A subset of the full ComputedStyle as defined by the request whitelist.
ComputedStyleBuilder
DOMNode
A Node in the DOM tree.
DOMNodeBuilder
DisableParams
DocumentSnapshot
Document snapshot.
DocumentSnapshotBuilder
EnableParams
GetSnapshotParams
Returns a document snapshot, including the full DOM tree of the root node (including iframes, template contents, and imported documents) in a flattened array, as well as layout and white-listed computed style information for the nodes. Shadow DOM in the returned DOM tree is flattened.
GetSnapshotParamsBuilder
GetSnapshotReturns
Returns a document snapshot, including the full DOM tree of the root node (including iframes, template contents, and imported documents) in a flattened array, as well as layout and white-listed computed style information for the nodes. Shadow DOM in the returned DOM tree is flattened.
GetSnapshotReturnsBuilder
InlineTextBox
Details of post layout rendered text positions. The exact layout should not be regarded as stable and may change between versions.
InlineTextBoxBuilder
LayoutTreeNode
Details of an element in the DOM tree with a LayoutObject.
LayoutTreeNodeBuilder
LayoutTreeSnapshot
Table of details of an element in the DOM tree with a LayoutObject.
LayoutTreeSnapshotBuilder
NameValue
A name/value pair.
NameValueBuilder
NodeTreeSnapshot
Table containing nodes.
NodeTreeSnapshotBuilder
RareBooleanData
RareBooleanDataBuilder
RareIntegerData
RareIntegerDataBuilder
RareStringData
Data that is only present on rare nodes.
RareStringDataBuilder
TextBoxSnapshot
Table of details of the post layout rendered text positions. The exact layout should not be regarded as stable and may change between versions.
TextBoxSnapshotBuilder

Type Aliases

ArrayOfStrings
Index of the string in the strings table.
Rectangle
StringIndex
Index of the string in the strings table.