pub struct CaptureSnapshotParams {
pub computedStyles: Vec<String>,
pub includePaintOrder: Option<bool>,
pub includeDOMRects: Option<bool>,
pub includeBlendedBackgroundColors: Option<bool>,
pub includeTextColorOpacities: Option<bool>,
}Expand description
Returns a document snapshot, including the full DOM tree of the root node (including iframes, template contents, and imported documents) in a flattened array, as well as layout and white-listed computed style information for the nodes. Shadow DOM in the returned DOM tree is flattened.
Fields
computedStyles: Vec<String>Whitelist of computed styles to return.
includePaintOrder: Option<bool>Whether to include layout object paint orders into the snapshot.
includeDOMRects: Option<bool>Whether to include DOM rectangles (offsetRects, clientRects, scrollRects) into the snapshot
includeBlendedBackgroundColors: Option<bool>Whether to include blended background colors in the snapshot (default: false). Blended background color is achieved by blending background colors of all elements that overlap with the current element.
includeTextColorOpacities: Option<bool>Whether to include text color opacity in the snapshot (default: false). An element might have the opacity property set that affects the text color of the element. The final text color opacity is computed based on the opacity of all overlapping elements.
Implementations