pub struct CaptureSnapshotParamsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> CaptureSnapshotParamsBuilder<'a>
impl<'a> CaptureSnapshotParamsBuilder<'a>
Sourcepub fn include_paint_order(self, include_paint_order: bool) -> Self
pub fn include_paint_order(self, include_paint_order: bool) -> Self
Whether to include layout object paint orders into the snapshot.
Sourcepub fn include_dom_rects(self, include_dom_rects: bool) -> Self
pub fn include_dom_rects(self, include_dom_rects: bool) -> Self
Whether to include DOM rectangles (offsetRects, clientRects, scrollRects) into the snapshot
Sourcepub fn include_blended_background_colors(
self,
include_blended_background_colors: bool,
) -> Self
pub fn include_blended_background_colors( self, include_blended_background_colors: bool, ) -> Self
Whether to include blended background colors in the snapshot (default: false). Blended background color is achieved by blending background colors of all elements that overlap with the current element.
Sourcepub fn include_text_color_opacities(
self,
include_text_color_opacities: bool,
) -> Self
pub fn include_text_color_opacities( self, include_text_color_opacities: bool, ) -> Self
Whether to include text color opacity in the snapshot (default: false). An element might have the opacity property set that affects the text color of the element. The final text color opacity is computed based on the opacity of all overlapping elements.
pub fn build(self) -> CaptureSnapshotParams<'a>