pub struct CaptureSnapshotReturns {
pub documents: Vec<DocumentSnapshot>,
pub strings: Vec<String>,
}Expand description
Returns a document snapshot, including the full DOM tree of the root node (including iframes, template contents, and imported documents) in a flattened array, as well as layout and white-listed computed style information for the nodes. Shadow DOM in the returned DOM tree is flattened.
Fields
documents: Vec<DocumentSnapshot>The nodes in the DOM tree. The DOMNode at index 0 corresponds to the root document.
strings: Vec<String>Shared string table that all string properties refer to with indexes.