DOMNode

Struct DOMNode 

pub struct DOMNode<'a> { /* private fields */ }
A Node in the DOM tree.

Implementations

Source

impl<'a> DOMNode<'a>

pub fn builder( node_type: i64, node_name: impl Into<Cow<'a, str>>, node_value: impl Into<Cow<'a, str>>, backend_node_id: BackendNodeId, ) -> DOMNodeBuilder<'a>

Creates a builder for this type with the required parameters:

  • node_type: Node’s nodeType.
  • node_name: Node’s nodeName.
  • node_value: Node’s nodeValue.
  • backend_node_id: Node’s id, corresponds to DOM.Node.backendNodeId.
pub fn node_type(&self) -> i64

‘Node’’s nodeType.

pub fn node_name(&self) -> &str

‘Node’’s nodeName.

pub fn node_value(&self) -> &str

‘Node’’s nodeValue.

pub fn text_value(&self) -> Option<&str>

Only set for textarea elements, contains the text value.

pub fn input_value(&self) -> Option<&str>

Only set for input elements, contains the input’s associated text value.

pub fn input_checked(&self) -> Option<bool>

Only set for radio and checkbox input elements, indicates if the element has been checked

pub fn option_selected(&self) -> Option<bool>

Only set for option elements, indicates if the element has been selected

pub fn backend_node_id(&self) -> &BackendNodeId

‘Node’’s id, corresponds to DOM.Node.backendNodeId.

pub fn child_node_indexes(&self) -> Option<&[i64]>

The indexes of the node’s child nodes in the ‘domNodes’ array returned by ‘getSnapshot’, if any.

pub fn attributes(&self) -> Option<&[NameValue<'a>]>

Attributes of an ‘Element’ node.

pub fn pseudo_element_indexes(&self) -> Option<&[i64]>

Indexes of pseudo elements associated with this node in the ‘domNodes’ array returned by ‘getSnapshot’, if any.

pub fn layout_node_index(&self) -> Option<u64>

The index of the node’s related layout tree node in the ‘layoutTreeNodes’ array returned by ‘getSnapshot’, if any.

pub fn document_url(&self) -> Option<&str>

Document URL that ‘Document’ or ‘FrameOwner’ node points to.

pub fn base_url(&self) -> Option<&str>

Base URL that ‘Document’ or ‘FrameOwner’ node uses for URL completion.

pub fn content_language(&self) -> Option<&str>

Only set for documents, contains the document’s content language.

pub fn document_encoding(&self) -> Option<&str>

Only set for documents, contains the document’s character set encoding.

pub fn public_id(&self) -> Option<&str>

‘DocumentType’ node’s publicId.

pub fn system_id(&self) -> Option<&str>

‘DocumentType’ node’s systemId.

pub fn frame_id(&self) -> Option<&FrameId<'a>>

Frame ID for frame owner elements and also for the document node.

pub fn content_document_index(&self) -> Option<u64>

The index of a frame owner element’s content document in the ‘domNodes’ array returned by ‘getSnapshot’, if any.

pub fn pseudo_type(&self) -> Option<&PseudoType>

Type of a pseudo element node.

pub fn shadow_root_type(&self) -> Option<&ShadowRootType>

Shadow root type.

pub fn is_clickable(&self) -> Option<bool>

Whether this DOM node responds to mouse clicks. This includes nodes that have had click event listeners attached via JavaScript as well as anchor tags that naturally navigate when clicked.

pub fn event_listeners(&self) -> Option<&[EventListener<'a>]>

Details of the node’s event listeners, if any.

pub fn current_source_url(&self) -> Option<&str>

The selected url for nodes with a srcset attribute.

pub fn origin_url(&self) -> Option<&str>

The url of the script (if any) that generates this node.

pub fn scroll_offset_x(&self) -> Option<f64>

Scroll offsets, set when this node is a Document.

pub fn scroll_offset_y(&self) -> Option<f64>