pub struct DOMNodeBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> DOMNodeBuilder<'a>
impl<'a> DOMNodeBuilder<'a>
Sourcepub fn text_value(self, text_value: impl Into<Cow<'a, str>>) -> Self
pub fn text_value(self, text_value: impl Into<Cow<'a, str>>) -> Self
Only set for textarea elements, contains the text value.
Sourcepub fn input_value(self, input_value: impl Into<Cow<'a, str>>) -> Self
pub fn input_value(self, input_value: impl Into<Cow<'a, str>>) -> Self
Only set for input elements, contains the input’s associated text value.
Sourcepub fn input_checked(self, input_checked: bool) -> Self
pub fn input_checked(self, input_checked: bool) -> Self
Only set for radio and checkbox input elements, indicates if the element has been checked
Sourcepub fn option_selected(self, option_selected: bool) -> Self
pub fn option_selected(self, option_selected: bool) -> Self
Only set for option elements, indicates if the element has been selected
Sourcepub fn child_node_indexes(self, child_node_indexes: Vec<i64>) -> Self
pub fn child_node_indexes(self, child_node_indexes: Vec<i64>) -> Self
The indexes of the node’s child nodes in the ‘domNodes’ array returned by ‘getSnapshot’, if any.
Sourcepub fn attributes(self, attributes: Vec<NameValue<'a>>) -> Self
pub fn attributes(self, attributes: Vec<NameValue<'a>>) -> Self
Attributes of an ‘Element’ node.
Sourcepub fn pseudo_element_indexes(self, pseudo_element_indexes: Vec<i64>) -> Self
pub fn pseudo_element_indexes(self, pseudo_element_indexes: Vec<i64>) -> Self
Indexes of pseudo elements associated with this node in the ‘domNodes’ array returned by ‘getSnapshot’, if any.
Sourcepub fn layout_node_index(self, layout_node_index: u64) -> Self
pub fn layout_node_index(self, layout_node_index: u64) -> Self
The index of the node’s related layout tree node in the ‘layoutTreeNodes’ array returned by ‘getSnapshot’, if any.
Sourcepub fn document_url(self, document_url: impl Into<Cow<'a, str>>) -> Self
pub fn document_url(self, document_url: impl Into<Cow<'a, str>>) -> Self
Document URL that ‘Document’ or ‘FrameOwner’ node points to.
Sourcepub fn base_url(self, base_url: impl Into<Cow<'a, str>>) -> Self
pub fn base_url(self, base_url: impl Into<Cow<'a, str>>) -> Self
Base URL that ‘Document’ or ‘FrameOwner’ node uses for URL completion.
Sourcepub fn content_language(self, content_language: impl Into<Cow<'a, str>>) -> Self
pub fn content_language(self, content_language: impl Into<Cow<'a, str>>) -> Self
Only set for documents, contains the document’s content language.
Sourcepub fn document_encoding(
self,
document_encoding: impl Into<Cow<'a, str>>,
) -> Self
pub fn document_encoding( self, document_encoding: impl Into<Cow<'a, str>>, ) -> Self
Only set for documents, contains the document’s character set encoding.
Sourcepub fn public_id(self, public_id: impl Into<Cow<'a, str>>) -> Self
pub fn public_id(self, public_id: impl Into<Cow<'a, str>>) -> Self
‘DocumentType’ node’s publicId.
Sourcepub fn system_id(self, system_id: impl Into<Cow<'a, str>>) -> Self
pub fn system_id(self, system_id: impl Into<Cow<'a, str>>) -> Self
‘DocumentType’ node’s systemId.
Sourcepub fn frame_id(self, frame_id: FrameId<'a>) -> Self
pub fn frame_id(self, frame_id: FrameId<'a>) -> Self
Frame ID for frame owner elements and also for the document node.
Sourcepub fn content_document_index(self, content_document_index: u64) -> Self
pub fn content_document_index(self, content_document_index: u64) -> Self
The index of a frame owner element’s content document in the ‘domNodes’ array returned by ‘getSnapshot’, if any.
Sourcepub fn pseudo_type(self, pseudo_type: PseudoType) -> Self
pub fn pseudo_type(self, pseudo_type: PseudoType) -> Self
Type of a pseudo element node.
Sourcepub fn shadow_root_type(self, shadow_root_type: ShadowRootType) -> Self
pub fn shadow_root_type(self, shadow_root_type: ShadowRootType) -> Self
Shadow root type.
Sourcepub fn is_clickable(self, is_clickable: bool) -> Self
pub fn is_clickable(self, is_clickable: bool) -> Self
Whether this DOM node responds to mouse clicks. This includes nodes that have had click event listeners attached via JavaScript as well as anchor tags that naturally navigate when clicked.
Sourcepub fn event_listeners(self, event_listeners: Vec<EventListener<'a>>) -> Self
pub fn event_listeners(self, event_listeners: Vec<EventListener<'a>>) -> Self
Details of the node’s event listeners, if any.
Sourcepub fn current_source_url(
self,
current_source_url: impl Into<Cow<'a, str>>,
) -> Self
pub fn current_source_url( self, current_source_url: impl Into<Cow<'a, str>>, ) -> Self
The selected url for nodes with a srcset attribute.
Sourcepub fn origin_url(self, origin_url: impl Into<Cow<'a, str>>) -> Self
pub fn origin_url(self, origin_url: impl Into<Cow<'a, str>>) -> Self
The url of the script (if any) that generates this node.
Sourcepub fn scroll_offset_x(self, scroll_offset_x: f64) -> Self
pub fn scroll_offset_x(self, scroll_offset_x: f64) -> Self
Scroll offsets, set when this node is a Document.