pub struct GetSnapshotParams<'a> { /* private fields */ }Expand description
Returns a document snapshot, including the full DOM tree of the root node (including iframes, template contents, and imported documents) in a flattened array, as well as layout and white-listed computed style information for the nodes. Shadow DOM in the returned DOM tree is flattened.
Implementations
Sourceimpl<'a> GetSnapshotParams<'a>
impl<'a> GetSnapshotParams<'a>
Sourcepub fn builder(
computed_style_whitelist: Vec<Cow<'a, str>>,
) -> GetSnapshotParamsBuilder<'a>
pub fn builder( computed_style_whitelist: Vec<Cow<'a, str>>, ) -> GetSnapshotParamsBuilder<'a>
Creates a builder for this type with the required parameters:
computed_style_whitelist: Whitelist of computed styles to return.
Sourcepub fn computed_style_whitelist(&self) -> &[Cow<'a, str>]
pub fn computed_style_whitelist(&self) -> &[Cow<'a, str>]
Whitelist of computed styles to return.
Sourcepub fn include_event_listeners(&self) -> Option<bool>
pub fn include_event_listeners(&self) -> Option<bool>
Whether or not to retrieve details of DOM listeners (default false).
Sourcepub fn include_paint_order(&self) -> Option<bool>
pub fn include_paint_order(&self) -> Option<bool>
Whether to determine and include the paint order index of LayoutTreeNodes (default false).
Sourcepub fn include_user_agent_shadow_tree(&self) -> Option<bool>
pub fn include_user_agent_shadow_tree(&self) -> Option<bool>
Whether to include UA shadow tree in the snapshot (default false).