pub struct GetSnapshotReturns<'a> { /* private fields */ }Expand description
Returns a document snapshot, including the full DOM tree of the root node (including iframes, template contents, and imported documents) in a flattened array, as well as layout and white-listed computed style information for the nodes. Shadow DOM in the returned DOM tree is flattened.
Implementations
Sourceimpl<'a> GetSnapshotReturns<'a>
impl<'a> GetSnapshotReturns<'a>
Sourcepub fn builder(
dom_nodes: Vec<DOMNode<'a>>,
layout_tree_nodes: Vec<LayoutTreeNode<'a>>,
computed_styles: Vec<ComputedStyle<'a>>,
) -> GetSnapshotReturnsBuilder<'a>
pub fn builder( dom_nodes: Vec<DOMNode<'a>>, layout_tree_nodes: Vec<LayoutTreeNode<'a>>, computed_styles: Vec<ComputedStyle<'a>>, ) -> GetSnapshotReturnsBuilder<'a>
Creates a builder for this type with the required parameters:
dom_nodes: The nodes in the DOM tree. The DOMNode at index 0 corresponds to the root document.layout_tree_nodes: The nodes in the layout tree.computed_styles: Whitelisted ComputedStyle properties for each node in the layout tree.
Sourcepub fn dom_nodes(&self) -> &[DOMNode<'a>]
pub fn dom_nodes(&self) -> &[DOMNode<'a>]
The nodes in the DOM tree. The DOMNode at index 0 corresponds to the root document.
Sourcepub fn layout_tree_nodes(&self) -> &[LayoutTreeNode<'a>]
pub fn layout_tree_nodes(&self) -> &[LayoutTreeNode<'a>]
The nodes in the layout tree.
Sourcepub fn computed_styles(&self) -> &[ComputedStyle<'a>]
pub fn computed_styles(&self) -> &[ComputedStyle<'a>]
Whitelisted ComputedStyle properties for each node in the layout tree.