pub struct InlineTextBox { /* private fields */ }Expand description
Details of post layout rendered text positions. The exact layout should not be regarded as stable and may change between versions.
Implementations
Sourceimpl InlineTextBox
impl InlineTextBox
Sourcepub fn builder(
bounding_box: Rect,
start_character_index: u64,
num_characters: i64,
) -> InlineTextBoxBuilder
pub fn builder( bounding_box: Rect, start_character_index: u64, num_characters: i64, ) -> InlineTextBoxBuilder
Creates a builder for this type with the required parameters:
bounding_box: The bounding box in document coordinates. Note that scroll offset of the document is ignored.start_character_index: The starting index in characters, for this post layout textbox substring. Characters that would be represented as a surrogate pair in UTF-16 have length 2.num_characters: The number of characters in this post layout textbox substring. Characters that would be represented as a surrogate pair in UTF-16 have length 2.
Sourcepub fn bounding_box(&self) -> &Rect
pub fn bounding_box(&self) -> &Rect
The bounding box in document coordinates. Note that scroll offset of the document is ignored.
Sourcepub fn start_character_index(&self) -> u64
pub fn start_character_index(&self) -> u64
The starting index in characters, for this post layout textbox substring. Characters that would be represented as a surrogate pair in UTF-16 have length 2.
Sourcepub fn num_characters(&self) -> i64
pub fn num_characters(&self) -> i64
The number of characters in this post layout textbox substring. Characters that would be represented as a surrogate pair in UTF-16 have length 2.