LayoutTreeNode

Struct LayoutTreeNode 

pub struct LayoutTreeNode<'a> { /* private fields */ }
Details of an element in the DOM tree with a LayoutObject.

Implementations

Source

impl<'a> LayoutTreeNode<'a>

pub fn builder( dom_node_index: u64, bounding_box: Rect, ) -> LayoutTreeNodeBuilder<'a>

Creates a builder for this type with the required parameters:

  • dom_node_index: The index of the related DOM node in the domNodes array returned by getSnapshot.
  • bounding_box: The bounding box in document coordinates. Note that scroll offset of the document is ignored.
pub fn dom_node_index(&self) -> u64

The index of the related DOM node in the ‘domNodes’ array returned by ‘getSnapshot’.

pub fn bounding_box(&self) -> &Rect

The bounding box in document coordinates. Note that scroll offset of the document is ignored.

pub fn layout_text(&self) -> Option<&str>

Contents of the LayoutText, if any.

pub fn inline_text_nodes(&self) -> Option<&[InlineTextBox]>

The post-layout inline text nodes, if any.

pub fn style_index(&self) -> Option<u64>

Index into the ‘computedStyles’ array returned by ‘getSnapshot’.

pub fn paint_order(&self) -> Option<i64>

Global paint order index, which is determined by the stacking order of the nodes. Nodes that are painted together will have the same index. Only provided if includePaintOrder in getSnapshot was true.

pub fn is_stacking_context(&self) -> Option<bool>

Set to true to indicate the element begins a new stacking context.