pub struct LayoutTreeNodeBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> LayoutTreeNodeBuilder<'a>
impl<'a> LayoutTreeNodeBuilder<'a>
Sourcepub fn layout_text(self, layout_text: impl Into<Cow<'a, str>>) -> Self
pub fn layout_text(self, layout_text: impl Into<Cow<'a, str>>) -> Self
Contents of the LayoutText, if any.
Sourcepub fn inline_text_nodes(self, inline_text_nodes: Vec<InlineTextBox>) -> Self
pub fn inline_text_nodes(self, inline_text_nodes: Vec<InlineTextBox>) -> Self
The post-layout inline text nodes, if any.
Sourcepub fn style_index(self, style_index: u64) -> Self
pub fn style_index(self, style_index: u64) -> Self
Index into the ‘computedStyles’ array returned by ‘getSnapshot’.
Sourcepub fn paint_order(self, paint_order: i64) -> Self
pub fn paint_order(self, paint_order: i64) -> Self
Global paint order index, which is determined by the stacking order of the nodes. Nodes that are painted together will have the same index. Only provided if includePaintOrder in getSnapshot was true.
Sourcepub fn is_stacking_context(self, is_stacking_context: bool) -> Self
pub fn is_stacking_context(self, is_stacking_context: bool) -> Self
Set to true to indicate the element begins a new stacking context.
pub fn build(self) -> LayoutTreeNode<'a>