pub struct LayoutTreeSnapshotBuilder { /* private fields */ }Implementations
Sourceimpl LayoutTreeSnapshotBuilder
impl LayoutTreeSnapshotBuilder
Sourcepub fn paint_orders(self, paint_orders: Vec<i64>) -> Self
pub fn paint_orders(self, paint_orders: Vec<i64>) -> Self
Global paint order index, which is determined by the stacking order of the nodes. Nodes that are painted together will have the same index. Only provided if includePaintOrder in captureSnapshot was true.
Sourcepub fn offset_rects(self, offset_rects: Vec<Rectangle>) -> Self
pub fn offset_rects(self, offset_rects: Vec<Rectangle>) -> Self
The offset rect of nodes. Only available when includeDOMRects is set to true
Sourcepub fn scroll_rects(self, scroll_rects: Vec<Rectangle>) -> Self
pub fn scroll_rects(self, scroll_rects: Vec<Rectangle>) -> Self
The scroll rect of nodes. Only available when includeDOMRects is set to true
Sourcepub fn client_rects(self, client_rects: Vec<Rectangle>) -> Self
pub fn client_rects(self, client_rects: Vec<Rectangle>) -> Self
The client rect of nodes. Only available when includeDOMRects is set to true
Sourcepub fn blended_background_colors(
self,
blended_background_colors: Vec<StringIndex>,
) -> Self
pub fn blended_background_colors( self, blended_background_colors: Vec<StringIndex>, ) -> Self
The list of background colors that are blended with colors of overlapping elements.
Sourcepub fn text_color_opacities(self, text_color_opacities: Vec<f64>) -> Self
pub fn text_color_opacities(self, text_color_opacities: Vec<f64>) -> Self
The list of computed text opacities.
pub fn build(self) -> LayoutTreeSnapshot