NodeTreeSnapshotBuilder

Struct NodeTreeSnapshotBuilder 

pub struct NodeTreeSnapshotBuilder { /* private fields */ }

Implementations

Source

impl NodeTreeSnapshotBuilder

pub fn parent_index(self, parent_index: Vec<i64>) -> Self

Parent node index.

pub fn node_type(self, node_type: Vec<i64>) -> Self

‘Node’’s nodeType.

pub fn shadow_root_type(self, shadow_root_type: RareStringData) -> Self

Type of the shadow root the ‘Node’ is in. String values are equal to the ‘ShadowRootType’ enum.

pub fn node_name(self, node_name: Vec<StringIndex>) -> Self

‘Node’’s nodeName.

pub fn node_value(self, node_value: Vec<StringIndex>) -> Self

‘Node’’s nodeValue.

pub fn backend_node_id(self, backend_node_id: Vec<BackendNodeId>) -> Self

‘Node’’s id, corresponds to DOM.Node.backendNodeId.

pub fn attributes(self, attributes: Vec<ArrayOfStrings>) -> Self

Attributes of an ‘Element’ node. Flatten name, value pairs.

pub fn text_value(self, text_value: RareStringData) -> Self

Only set for textarea elements, contains the text value.

pub fn input_value(self, input_value: RareStringData) -> Self

Only set for input elements, contains the input’s associated text value.

pub fn input_checked(self, input_checked: RareBooleanData) -> Self

Only set for radio and checkbox input elements, indicates if the element has been checked

pub fn option_selected(self, option_selected: RareBooleanData) -> Self

Only set for option elements, indicates if the element has been selected

pub fn content_document_index( self, content_document_index: RareIntegerData, ) -> Self

The index of the document in the list of the snapshot documents.

pub fn pseudo_type(self, pseudo_type: RareStringData) -> Self

Type of a pseudo element node.

pub fn pseudo_identifier(self, pseudo_identifier: RareStringData) -> Self

Pseudo element identifier for this node. Only present if there is a valid pseudoType.

pub fn is_clickable(self, is_clickable: RareBooleanData) -> Self

Whether this DOM node responds to mouse clicks. This includes nodes that have had click event listeners attached via JavaScript as well as anchor tags that naturally navigate when clicked.

pub fn current_source_url(self, current_source_url: RareStringData) -> Self

The selected url for nodes with a srcset attribute.

pub fn origin_url(self, origin_url: RareStringData) -> Self

The url of the script (if any) that generates this node.

pub fn build(self) -> NodeTreeSnapshot