pub struct TextBoxSnapshot { /* private fields */ }Expand description
Table of details of the post layout rendered text positions. The exact layout should not be regarded as stable and may change between versions.
Implementations