pub struct AddScreenParams<'a> { /* private fields */ }Expand description
Add a new screen to the device. Only supported in headless mode.
Implementations
Sourceimpl<'a> AddScreenParams<'a>
impl<'a> AddScreenParams<'a>
Sourcepub fn builder(
left: i64,
top: i64,
width: u64,
height: i64,
) -> AddScreenParamsBuilder<'a>
pub fn builder( left: i64, top: i64, width: u64, height: i64, ) -> AddScreenParamsBuilder<'a>
Creates a builder for this type with the required parameters:
left: Offset of the left edge of the screen in pixels.top: Offset of the top edge of the screen in pixels.width: The width of the screen in pixels.height: The height of the screen in pixels.
Sourcepub fn work_area_insets(&self) -> Option<&WorkAreaInsets>
pub fn work_area_insets(&self) -> Option<&WorkAreaInsets>
Specifies the screen’s work area. Default is entire screen.
Sourcepub fn device_pixel_ratio(&self) -> Option<f64>
pub fn device_pixel_ratio(&self) -> Option<f64>
Specifies the screen’s device pixel ratio. Default is 1.
Sourcepub fn rotation(&self) -> Option<i64>
pub fn rotation(&self) -> Option<i64>
Specifies the screen’s rotation angle. Available values are 0, 90, 180 and 270. Default is 0.
Sourcepub fn color_depth(&self) -> Option<i64>
pub fn color_depth(&self) -> Option<i64>
Specifies the screen’s color depth in bits. Default is 24.
Sourcepub fn label(&self) -> Option<&str>
pub fn label(&self) -> Option<&str>
Specifies the descriptive label for the screen. Default is none.
Sourcepub fn is_internal(&self) -> Option<bool>
pub fn is_internal(&self) -> Option<bool>
Indicates whether the screen is internal to the device or external, attached to the device. Default is false.