pub struct DisplayFeature<'a> { /* private fields */ }Implementations
Sourceimpl<'a> DisplayFeature<'a>
impl<'a> DisplayFeature<'a>
Sourcepub fn builder(
orientation: impl Into<Cow<'a, str>>,
offset: i32,
mask_length: u64,
) -> DisplayFeatureBuilder<'a>
pub fn builder( orientation: impl Into<Cow<'a, str>>, offset: i32, mask_length: u64, ) -> DisplayFeatureBuilder<'a>
Creates a builder for this type with the required parameters:
orientation: Orientation of a display feature in relation to screenoffset: The offset from the screen origin in either the x (for vertical orientation) or y (for horizontal orientation) direction.mask_length: A display feature may mask content such that it is not physically displayed - this length along with the offset describes this area. A display feature that only splits content will have a 0 mask_length.
Sourcepub fn orientation(&self) -> &str
pub fn orientation(&self) -> &str
Orientation of a display feature in relation to screen
Sourcepub fn offset(&self) -> i32
pub fn offset(&self) -> i32
The offset from the screen origin in either the x (for vertical orientation) or y (for horizontal orientation) direction.
Sourcepub fn mask_length(&self) -> u64
pub fn mask_length(&self) -> u64
A display feature may mask content such that it is not physically displayed - this length along with the offset describes this area. A display feature that only splits content will have a 0 mask_length.