ScreenInfo

Struct ScreenInfo 

pub struct ScreenInfo<'a> { /* private fields */ }
Screen information similar to the one returned by window.getScreenDetails() method, see https://w3c.github.io/window-management/#screendetailed.

Implementations

Source

impl<'a> ScreenInfo<'a>

pub fn builder( left: i64, top: i64, width: u64, height: i64, avail_left: i64, avail_top: i64, avail_width: u64, avail_height: i64, device_pixel_ratio: f64, orientation: ScreenOrientation<'a>, color_depth: i64, is_extended: bool, is_internal: bool, is_primary: bool, label: impl Into<Cow<'a, str>>, id: impl Into<ScreenId<'a>>, ) -> ScreenInfoBuilder<'a>

Creates a builder for this type with the required parameters:

  • left: Offset of the left edge of the screen.
  • top: Offset of the top edge of the screen.
  • width: Width of the screen.
  • height: Height of the screen.
  • avail_left: Offset of the left edge of the available screen area.
  • avail_top: Offset of the top edge of the available screen area.
  • avail_width: Width of the available screen area.
  • avail_height: Height of the available screen area.
  • device_pixel_ratio: Specifies the screen’s device pixel ratio.
  • orientation: Specifies the screen’s orientation.
  • color_depth: Specifies the screen’s color depth in bits.
  • is_extended: Indicates whether the device has multiple screens.
  • is_internal: Indicates whether the screen is internal to the device or external, attached to the device.
  • is_primary: Indicates whether the screen is set as the the operating system primary screen.
  • label: Specifies the descriptive label for the screen.
  • id: Specifies the unique identifier of the screen.
pub fn left(&self) -> i64

Offset of the left edge of the screen.

pub fn top(&self) -> i64

Offset of the top edge of the screen.

pub fn width(&self) -> u64

Width of the screen.

pub fn height(&self) -> i64

Height of the screen.

pub fn avail_left(&self) -> i64

Offset of the left edge of the available screen area.

pub fn avail_top(&self) -> i64

Offset of the top edge of the available screen area.

pub fn avail_width(&self) -> u64

Width of the available screen area.

pub fn avail_height(&self) -> i64

Height of the available screen area.

pub fn device_pixel_ratio(&self) -> f64

Specifies the screen’s device pixel ratio.

pub fn orientation(&self) -> &ScreenOrientation<'a>

Specifies the screen’s orientation.

pub fn color_depth(&self) -> i64

Specifies the screen’s color depth in bits.

pub fn is_extended(&self) -> bool

Indicates whether the device has multiple screens.

pub fn is_internal(&self) -> bool

Indicates whether the screen is internal to the device or external, attached to the device.

pub fn is_primary(&self) -> bool

Indicates whether the screen is set as the the operating system primary screen.

pub fn label(&self) -> &str

Specifies the descriptive label for the screen.

pub fn id(&self) -> &ScreenId<'a>

Specifies the unique identifier of the screen.