SetDefaultBackgroundColorOverrideParams

Struct SetDefaultBackgroundColorOverrideParams 

pub struct SetDefaultBackgroundColorOverrideParams { /* private fields */ }
Sets or clears an override of the default background color of the frame. This override is used if the content does not specify one.

Implementations

Source

impl SetDefaultBackgroundColorOverrideParams

pub fn builder() -> SetDefaultBackgroundColorOverrideParamsBuilder

Creates a builder for this type.

pub fn color(&self) -> Option<&RGBA>

RGBA of the default background color. If not specified, any existing override will be cleared.

Source

impl SetDefaultBackgroundColorOverrideParams

pub const METHOD: &'static str = "Emulation.setDefaultBackgroundColorOverride"