pub struct SetDeviceMetricsOverrideParams<'a> { /* private fields */ }Expand description
Overrides the values of device screen dimensions (window.screen.width, window.screen.height, window.innerWidth, window.innerHeight, and “device-width”/“device-height”-related CSS media query results).
Implementations
Sourceimpl<'a> SetDeviceMetricsOverrideParams<'a>
impl<'a> SetDeviceMetricsOverrideParams<'a>
Sourcepub fn builder(
width: u64,
height: i64,
device_scale_factor: f64,
mobile: bool,
) -> SetDeviceMetricsOverrideParamsBuilder<'a>
pub fn builder( width: u64, height: i64, device_scale_factor: f64, mobile: bool, ) -> SetDeviceMetricsOverrideParamsBuilder<'a>
Creates a builder for this type with the required parameters:
width: Overriding width value in pixels (minimum 0, maximum 10000000). 0 disables the override.height: Overriding height value in pixels (minimum 0, maximum 10000000). 0 disables the override.device_scale_factor: Overriding device scale factor value. 0 disables the override.mobile: Whether to emulate mobile device. This includes viewport meta tag, overlay scrollbars, text autosizing and more.
Sourcepub fn width(&self) -> u64
pub fn width(&self) -> u64
Overriding width value in pixels (minimum 0, maximum 10000000). 0 disables the override.
Sourcepub fn height(&self) -> i64
pub fn height(&self) -> i64
Overriding height value in pixels (minimum 0, maximum 10000000). 0 disables the override.
Sourcepub fn device_scale_factor(&self) -> f64
pub fn device_scale_factor(&self) -> f64
Overriding device scale factor value. 0 disables the override.
Sourcepub fn mobile(&self) -> bool
pub fn mobile(&self) -> bool
Whether to emulate mobile device. This includes viewport meta tag, overlay scrollbars, text autosizing and more.
Sourcepub fn screen_width(&self) -> Option<u64>
pub fn screen_width(&self) -> Option<u64>
Overriding screen width value in pixels (minimum 0, maximum 10000000).
Sourcepub fn screen_height(&self) -> Option<i64>
pub fn screen_height(&self) -> Option<i64>
Overriding screen height value in pixels (minimum 0, maximum 10000000).
Sourcepub fn position_x(&self) -> Option<i64>
pub fn position_x(&self) -> Option<i64>
Overriding view X position on screen in pixels (minimum 0, maximum 10000000).
Sourcepub fn position_y(&self) -> Option<i64>
pub fn position_y(&self) -> Option<i64>
Overriding view Y position on screen in pixels (minimum 0, maximum 10000000).
Sourcepub fn dont_set_visible_size(&self) -> Option<bool>
pub fn dont_set_visible_size(&self) -> Option<bool>
Do not set visible view size, rely upon explicit setVisibleSize call.
Sourcepub fn screen_orientation(&self) -> Option<&ScreenOrientation<'a>>
pub fn screen_orientation(&self) -> Option<&ScreenOrientation<'a>>
Screen orientation override.
Sourcepub fn viewport(&self) -> Option<&Viewport>
pub fn viewport(&self) -> Option<&Viewport>
If set, the visible area of the page will be overridden to this viewport. This viewport change is not observed by the page, e.g. viewport-relative elements do not change positions.
Sourcepub fn display_feature(&self) -> Option<&DisplayFeature<'a>>
pub fn display_feature(&self) -> Option<&DisplayFeature<'a>>
If set, the display feature of a multi-segment screen. If not set, multi-segment support is turned-off. Deprecated, use Emulation.setDisplayFeaturesOverride.
Sourcepub fn device_posture(&self) -> Option<&DevicePosture<'a>>
pub fn device_posture(&self) -> Option<&DevicePosture<'a>>
If set, the posture of a foldable device. If not set the posture is set to continuous. Deprecated, use Emulation.setDevicePostureOverride.
Sourcepub fn scrollbar_type(&self) -> Option<&str>
pub fn scrollbar_type(&self) -> Option<&str>
Scrollbar type. Default: ‘default’.
Sourcepub fn screen_orientation_lock_emulation(&self) -> Option<bool>
pub fn screen_orientation_lock_emulation(&self) -> Option<bool>
If set to true, enables screen orientation lock emulation, which intercepts screen.orientation.lock() calls from the page and reports orientation changes via screenOrientationLockChanged events. This is useful for emulating mobile device orientation lock behavior in responsive design mode.