pub struct SetPrimaryScreenParams {
pub screenId: ScreenId,
}Expand description
Set primary screen. Only supported in headless mode. Note that this changes the coordinate system origin to the top-left of the new primary screen, updating the bounds and work areas of all existing screens accordingly.
Fields
screenId: ScreenIdImplementations