pub struct SetSmallViewportHeightDifferenceOverrideParams { /* private fields */ }Expand description
Allows overriding the difference between the small and large viewport sizes, which determine the value of the ‘svh’ and ‘lvh’ unit, respectively. Only supported for top-level frames.
Implementations
Sourceimpl SetSmallViewportHeightDifferenceOverrideParams
impl SetSmallViewportHeightDifferenceOverrideParams
pub fn builder( difference: i64, ) -> SetSmallViewportHeightDifferenceOverrideParamsBuilder
pub fn difference(&self) -> i64