SetVirtualTimePolicyParamsBuilder

Struct SetVirtualTimePolicyParamsBuilder 

pub struct SetVirtualTimePolicyParamsBuilder { /* private fields */ }

Implementations

Source

impl SetVirtualTimePolicyParamsBuilder

pub fn budget(self, budget: f64) -> Self

If set, after this many virtual milliseconds have elapsed virtual time will be paused and a virtualTimeBudgetExpired event is sent.

pub fn max_virtual_time_task_starvation_count( self, max_virtual_time_task_starvation_count: u64, ) -> Self

If set this specifies the maximum number of tasks that can be run before virtual is forced forwards to prevent deadlock.

pub fn initial_virtual_time(self, initial_virtual_time: TimeSinceEpoch) -> Self

If set, base::Time::Now will be overridden to initially return this value.

pub fn build(self) -> SetVirtualTimePolicyParams