UpdateScreenParams

Struct UpdateScreenParams 

pub struct UpdateScreenParams {
    pub screenId: ScreenId,
    pub left: Option<i64>,
    pub top: Option<i64>,
    pub width: Option<u64>,
    pub height: Option<i64>,
    pub workAreaInsets: Option<WorkAreaInsets>,
    pub devicePixelRatio: Option<f64>,
    pub rotation: Option<i64>,
    pub colorDepth: Option<i64>,
    pub label: Option<String>,
    pub isInternal: Option<bool>,
}
Updates specified screen parameters. Only supported in headless mode.

Fields

screenId: ScreenId

Target screen identifier.

left: Option<i64>

Offset of the left edge of the screen in pixels.

top: Option<i64>

Offset of the top edge of the screen in pixels.

width: Option<u64>

The width of the screen in pixels.

height: Option<i64>

The height of the screen in pixels.

workAreaInsets: Option<WorkAreaInsets>

Specifies the screen’s work area.

devicePixelRatio: Option<f64>

Specifies the screen’s device pixel ratio.

rotation: Option<i64>

Specifies the screen’s rotation angle. Available values are 0, 90, 180 and 270.

colorDepth: Option<i64>

Specifies the screen’s color depth in bits.

label: Option<String>

Specifies the descriptive label for the screen.

isInternal: Option<bool>

Indicates whether the screen is internal to the device or external, attached to the device. Default is false.

Implementations

Source

impl UpdateScreenParams

pub const METHOD: &'static str = "Emulation.updateScreen"