UpdateScreenParamsBuilder

Struct UpdateScreenParamsBuilder 

pub struct UpdateScreenParamsBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> UpdateScreenParamsBuilder<'a>

pub fn left(self, left: i64) -> Self

Offset of the left edge of the screen in pixels.

pub fn top(self, top: i64) -> Self

Offset of the top edge of the screen in pixels.

pub fn width(self, width: u64) -> Self

The width of the screen in pixels.

pub fn height(self, height: i64) -> Self

The height of the screen in pixels.

pub fn work_area_insets(self, work_area_insets: WorkAreaInsets) -> Self

Specifies the screen’s work area.

pub fn device_pixel_ratio(self, device_pixel_ratio: f64) -> Self

Specifies the screen’s device pixel ratio.

pub fn rotation(self, rotation: i64) -> Self

Specifies the screen’s rotation angle. Available values are 0, 90, 180 and 270.

pub fn color_depth(self, color_depth: i64) -> Self

Specifies the screen’s color depth in bits.

pub fn label(self, label: impl Into<Cow<'a, str>>) -> Self

Specifies the descriptive label for the screen.

pub fn is_internal(self, is_internal: bool) -> Self

Indicates whether the screen is internal to the device or external, attached to the device. Default is false.

pub fn build(self) -> UpdateScreenParams<'a>