pub struct UserAgentMetadata<'a> { /* private fields */ }Expand description
Used to specify User Agent Client Hints to emulate. See https://wicg.github.io/ua-client-hints Missing optional values will be filled in by the target with what it would normally use.
Implementations
Sourceimpl<'a> UserAgentMetadata<'a>
impl<'a> UserAgentMetadata<'a>
Sourcepub fn builder(
platform: impl Into<Cow<'a, str>>,
platform_version: impl Into<Cow<'a, str>>,
architecture: impl Into<Cow<'a, str>>,
model: impl Into<Cow<'a, str>>,
mobile: bool,
) -> UserAgentMetadataBuilder<'a>
pub fn builder( platform: impl Into<Cow<'a, str>>, platform_version: impl Into<Cow<'a, str>>, architecture: impl Into<Cow<'a, str>>, model: impl Into<Cow<'a, str>>, mobile: bool, ) -> UserAgentMetadataBuilder<'a>
Creates a builder for this type with the required parameters:
platform:platform_version:architecture:model:mobile:
Sourcepub fn brands(&self) -> Option<&[UserAgentBrandVersion<'a>]>
pub fn brands(&self) -> Option<&[UserAgentBrandVersion<'a>]>
Brands appearing in Sec-CH-UA.
Sourcepub fn full_version_list(&self) -> Option<&[UserAgentBrandVersion<'a>]>
pub fn full_version_list(&self) -> Option<&[UserAgentBrandVersion<'a>]>
Brands appearing in Sec-CH-UA-Full-Version-List.
pub fn full_version(&self) -> Option<&str>
pub fn platform(&self) -> &str
pub fn platform_version(&self) -> &str
pub fn architecture(&self) -> &str
pub fn model(&self) -> &str
pub fn mobile(&self) -> bool
pub fn bitness(&self) -> Option<&str>
pub fn wow64(&self) -> Option<bool>
Sourcepub fn form_factors(&self) -> Option<&[Cow<'a, str>]>
pub fn form_factors(&self) -> Option<&[Cow<'a, str>]>
Used to specify User Agent form-factor values. See https://wicg.github.io/ua-client-hints/#sec-ch-ua-form-factors