Module eventbreakpoints

Module eventbreakpoints 

EventBreakpoints permits setting JavaScript breakpoints on operations and events occurring in native code invoked from JavaScript. Once breakpoint is hit, it is reported through Debugger domain, similarly to regular breakpoints being hit.

Structs

DisableParams
RemoveInstrumentationBreakpointParams
Removes breakpoint on particular native event.
SetInstrumentationBreakpointParams
Sets breakpoint on particular native event.