Module extensions

Module extensions 

Defines commands and events for browser extensions.

Structs

ClearStorageItemsParams
Clears extension storage in the given ‘storageArea’.
ClearStorageItemsParamsBuilder
ExtensionInfo
Detailed information about an extension.
ExtensionInfoBuilder
GetExtensionsParams
GetExtensionsReturns
Gets a list of all unpacked extensions.
GetExtensionsReturnsBuilder
GetStorageItemsParams
Gets data from extension storage in the given ‘storageArea’. If ‘keys’ is specified, these are used to filter the result.
GetStorageItemsParamsBuilder
GetStorageItemsReturns
Gets data from extension storage in the given ‘storageArea’. If ‘keys’ is specified, these are used to filter the result.
GetStorageItemsReturnsBuilder
LoadUnpackedParams
Installs an unpacked extension from the filesystem similar to –load-extension CLI flags. Returns extension ID once the extension has been installed.
LoadUnpackedParamsBuilder
LoadUnpackedReturns
Installs an unpacked extension from the filesystem similar to –load-extension CLI flags. Returns extension ID once the extension has been installed.
LoadUnpackedReturnsBuilder
RemoveStorageItemsParams
Removes ‘keys’ from extension storage in the given ‘storageArea’.
RemoveStorageItemsParamsBuilder
SetStorageItemsParams
Sets ‘values’ in extension storage in the given ‘storageArea’. The provided ‘values’ will be merged with existing values in the storage area.
SetStorageItemsParamsBuilder
TriggerActionParams
Runs an extension default action.
TriggerActionParamsBuilder
UninstallParams
Uninstalls an unpacked extension (others not supported) from the profile.
UninstallParamsBuilder

Enums

StorageArea
Storage areas.