pub struct GetStorageItemsParams<'a> { /* private fields */ }Expand description
Gets data from extension storage in the given ‘storageArea’. If ‘keys’ is specified, these are used to filter the result.
Implementations
Sourceimpl<'a> GetStorageItemsParams<'a>
impl<'a> GetStorageItemsParams<'a>
Sourcepub fn builder(
id: impl Into<Cow<'a, str>>,
storage_area: impl Into<StorageArea>,
) -> GetStorageItemsParamsBuilder<'a>
pub fn builder( id: impl Into<Cow<'a, str>>, storage_area: impl Into<StorageArea>, ) -> GetStorageItemsParamsBuilder<'a>
Creates a builder for this type with the required parameters:
id: ID of extension.storage_area: StorageArea to retrieve data from.
Sourcepub fn storage_area(&self) -> &StorageArea
pub fn storage_area(&self) -> &StorageArea
StorageArea to retrieve data from.