pub struct GetStorageItemsReturns {
pub data: Map<String, Value>,
}Expand description
Gets data from extension storage in the given ‘storageArea’. If ‘keys’ is specified, these are used to filter the result.
Fields
data: Map<String, Value>Trait Implementations
Sourceimpl Clone for GetStorageItemsReturns
impl Clone for GetStorageItemsReturns
Sourcefn clone(&self) -> GetStorageItemsReturns
fn clone(&self) -> GetStorageItemsReturns
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetStorageItemsReturns
impl Debug for GetStorageItemsReturns
Sourceimpl Default for GetStorageItemsReturns
impl Default for GetStorageItemsReturns
Sourcefn default() -> GetStorageItemsReturns
fn default() -> GetStorageItemsReturns
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for GetStorageItemsReturns
impl<'de> Deserialize<'de> for GetStorageItemsReturns
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more