pub struct LoadUnpackedParams {
pub path: String,
pub enableInIncognito: Option<bool>,
}Expand description
Installs an unpacked extension from the filesystem similar to –load-extension CLI flags. Returns extension ID once the extension has been installed. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging flag is set.
Fields
path: StringAbsolute file path.
enableInIncognito: Option<bool>Enable the extension in incognito