pub struct SetStorageItemsParams<'a> { /* private fields */ }Expand description
Sets ‘values’ in extension storage in the given ‘storageArea’. The provided ‘values’ will be merged with existing values in the storage area.
Implementations
Sourceimpl<'a> SetStorageItemsParams<'a>
impl<'a> SetStorageItemsParams<'a>
Sourcepub fn builder(
id: impl Into<Cow<'a, str>>,
storage_area: impl Into<StorageArea>,
values: Map<String, JsonValue>,
) -> SetStorageItemsParamsBuilder<'a>
pub fn builder( id: impl Into<Cow<'a, str>>, storage_area: impl Into<StorageArea>, values: Map<String, JsonValue>, ) -> SetStorageItemsParamsBuilder<'a>
Creates a builder for this type with the required parameters:
id: ID of extension.storage_area: StorageArea to set data in.values: Values to set.
Sourcepub fn storage_area(&self) -> &StorageArea
pub fn storage_area(&self) -> &StorageArea
StorageArea to set data in.