pub struct EnableParamsBuilder { /* private fields */ }Implementations
Sourceimpl EnableParamsBuilder
impl EnableParamsBuilder
Sourcepub fn disableRejectionDelay(self, disableRejectionDelay: bool) -> Self
pub fn disableRejectionDelay(self, disableRejectionDelay: bool) -> Self
Allows callers to disable the promise rejection delay that would normally happen, if this is unimportant to what’s being tested. (step 4 of https://fedidcg.github.io/FedCM/#browser-api-rp-sign-in)
pub fn build(self) -> EnableParams