A domain for letting clients substitute browser’s network layer with client code.
Structs
- Auth
Challenge - Authorization challenge for HTTP status code 401 or 407.
- Auth
Challenge Builder - Auth
Challenge Response - Response to an AuthChallenge.
- Auth
Challenge Response Builder - Continue
Request Params - Continues the request, optionally modifying some of its parameters.
- Continue
Request Params Builder - Continue
Response Params - Continues loading of the paused response, optionally modifying the response headers. If either responseCode or headers are modified, all of them must be present.
- Continue
Response Params Builder - Continue
With Auth Params - Continues a request supplying authChallengeResponse following authRequired event.
- Continue
With Auth Params Builder - Disable
Params - Enable
Params - Enables issuing of requestPaused events. A request will be paused until client calls one of failRequest, fulfillRequest or continueRequest/continueWithAuth.
- Enable
Params Builder - Fail
Request Params - Causes the request to fail with specified reason.
- Fail
Request Params Builder - Fulfill
Request Params - Provides response to the request.
- Fulfill
Request Params Builder - GetResponse
Body Params - Causes the body of the response to be received from the server and returned as a single string. May only be issued for a request that is paused in the Response stage and is mutually exclusive with takeResponseBodyForInterceptionAsStream. Calling other methods that affect the request or disabling fetch domain before body is received results in an undefined behavior. Note that the response body is not available for redirects. Requests paused in the redirect received state may be differentiated by ‘responseCode’ and presence of ‘location’ response header, see comments to ‘requestPaused’ for details.
- GetResponse
Body Params Builder - GetResponse
Body Returns - Causes the body of the response to be received from the server and returned as a single string. May only be issued for a request that is paused in the Response stage and is mutually exclusive with takeResponseBodyForInterceptionAsStream. Calling other methods that affect the request or disabling fetch domain before body is received results in an undefined behavior. Note that the response body is not available for redirects. Requests paused in the redirect received state may be differentiated by ‘responseCode’ and presence of ‘location’ response header, see comments to ‘requestPaused’ for details.
- GetResponse
Body Returns Builder - Header
Entry - Response HTTP header entry
- Header
Entry Builder - Request
Pattern - Request
Pattern Builder - Take
Response Body AsStream Params - Returns a handle to the stream representing the response body. The request must be paused in the HeadersReceived stage. Note that after this command the request can’t be continued as is – client either needs to cancel it or to provide the response body. The stream only supports sequential read, IO.read will fail if the position is specified. This method is mutually exclusive with getResponseBody. Calling other methods that affect the request or disabling fetch domain before body is received results in an undefined behavior.
- Take
Response Body AsStream Params Builder - Take
Response Body AsStream Returns - Returns a handle to the stream representing the response body. The request must be paused in the HeadersReceived stage. Note that after this command the request can’t be continued as is – client either needs to cancel it or to provide the response body. The stream only supports sequential read, IO.read will fail if the position is specified. This method is mutually exclusive with getResponseBody. Calling other methods that affect the request or disabling fetch domain before body is received results in an undefined behavior.
- Take
Response Body AsStream Returns Builder
Enums
- Request
Stage - Stages of the request to handle. Request will intercept before the request is sent. Response will intercept after the response is received (but before response body is received).
Type Aliases
- Request
Id - Unique request identifier. Note that this does not identify individual HTTP requests that are part of a network request.