AuthChallengeResponse

Struct AuthChallengeResponse 

pub struct AuthChallengeResponse<'a> { /* private fields */ }
Response to an AuthChallenge.

Implementations

Source

impl<'a> AuthChallengeResponse<'a>

pub fn builder( response: impl Into<Cow<'a, str>>, ) -> AuthChallengeResponseBuilder<'a>

Creates a builder for this type with the required parameters:

  • response: The decision on what to do in response to the authorization challenge. Default means deferring to the default behavior of the net stack, which will likely either the Cancel authentication or display a popup dialog box.
pub fn response(&self) -> &str

The decision on what to do in response to the authorization challenge. Default means deferring to the default behavior of the net stack, which will likely either the Cancel authentication or display a popup dialog box.

pub fn username(&self) -> Option<&str>

The username to provide, possibly empty. Should only be set if response is ProvideCredentials.

pub fn password(&self) -> Option<&str>

The password to provide, possibly empty. Should only be set if response is ProvideCredentials.