pub struct ContinueRequestParamsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ContinueRequestParamsBuilder<'a>
impl<'a> ContinueRequestParamsBuilder<'a>
Sourcepub fn url(self, url: impl Into<Cow<'a, str>>) -> Self
pub fn url(self, url: impl Into<Cow<'a, str>>) -> Self
If set, the request url will be modified in a way that’s not observable by page.
Sourcepub fn method(self, method: impl Into<Cow<'a, str>>) -> Self
pub fn method(self, method: impl Into<Cow<'a, str>>) -> Self
If set, the request method is overridden.
Sourcepub fn post_data(self, post_data: impl Into<Cow<'a, str>>) -> Self
pub fn post_data(self, post_data: impl Into<Cow<'a, str>>) -> Self
If set, overrides the post data in the request. (Encoded as a base64 string when passed over JSON)
Sourcepub fn headers(self, headers: Vec<HeaderEntry<'a>>) -> Self
pub fn headers(self, headers: Vec<HeaderEntry<'a>>) -> Self
If set, overrides the request headers. Note that the overrides do not extend to subsequent redirect hops, if a redirect happens. Another override may be applied to a different request produced by a redirect.
Sourcepub fn intercept_response(self, intercept_response: bool) -> Self
pub fn intercept_response(self, intercept_response: bool) -> Self
If set, overrides response interception behavior for this request.
pub fn build(self) -> ContinueRequestParams<'a>