pub struct ContinueResponseParams<'a> { /* private fields */ }Expand description
Continues loading of the paused response, optionally modifying the response headers. If either responseCode or headers are modified, all of them must be present.
Implementations
Sourceimpl<'a> ContinueResponseParams<'a>
impl<'a> ContinueResponseParams<'a>
Sourcepub fn builder(
request_id: impl Into<RequestId<'a>>,
) -> ContinueResponseParamsBuilder<'a>
pub fn builder( request_id: impl Into<RequestId<'a>>, ) -> ContinueResponseParamsBuilder<'a>
Creates a builder for this type with the required parameters:
request_id: An id the client received in requestPaused event.
Sourcepub fn request_id(&self) -> &RequestId<'a>
pub fn request_id(&self) -> &RequestId<'a>
An id the client received in requestPaused event.
Sourcepub fn response_code(&self) -> Option<i64>
pub fn response_code(&self) -> Option<i64>
An HTTP response code. If absent, original response code will be used.
Sourcepub fn response_phrase(&self) -> Option<&str>
pub fn response_phrase(&self) -> Option<&str>
A textual representation of responseCode. If absent, a standard phrase matching responseCode is used.
Sourcepub fn response_headers(&self) -> Option<&[HeaderEntry<'a>]>
pub fn response_headers(&self) -> Option<&[HeaderEntry<'a>]>
Response headers. If absent, original response headers will be used.
Sourcepub fn binary_response_headers(&self) -> Option<&str>
pub fn binary_response_headers(&self) -> Option<&str>
Alternative way of specifying response headers as a \0-separated series of name: value pairs. Prefer the above method unless you need to represent some non-UTF8 values that can’t be transmitted over the protocol as text. (Encoded as a base64 string when passed over JSON)