pub struct ContinueResponseParamsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ContinueResponseParamsBuilder<'a>
impl<'a> ContinueResponseParamsBuilder<'a>
Sourcepub fn response_code(self, response_code: i64) -> Self
pub fn response_code(self, response_code: i64) -> Self
An HTTP response code. If absent, original response code will be used.
Sourcepub fn response_phrase(self, response_phrase: impl Into<Cow<'a, str>>) -> Self
pub fn response_phrase(self, response_phrase: impl Into<Cow<'a, str>>) -> Self
A textual representation of responseCode. If absent, a standard phrase matching responseCode is used.
Sourcepub fn response_headers(self, response_headers: Vec<HeaderEntry<'a>>) -> Self
pub fn response_headers(self, response_headers: Vec<HeaderEntry<'a>>) -> Self
Response headers. If absent, original response headers will be used.
Sourcepub fn binary_response_headers(
self,
binary_response_headers: impl Into<Cow<'a, str>>,
) -> Self
pub fn binary_response_headers( self, binary_response_headers: impl Into<Cow<'a, str>>, ) -> Self
Alternative way of specifying response headers as a \0-separated series of name: value pairs. Prefer the above method unless you need to represent some non-UTF8 values that can’t be transmitted over the protocol as text. (Encoded as a base64 string when passed over JSON)
pub fn build(self) -> ContinueResponseParams<'a>