pub struct EnableParams<'a> { /* private fields */ }Expand description
Enables issuing of requestPaused events. A request will be paused until client calls one of failRequest, fulfillRequest or continueRequest/continueWithAuth.
Implementations
Sourceimpl<'a> EnableParams<'a>
impl<'a> EnableParams<'a>
Sourcepub fn builder() -> EnableParamsBuilder<'a>
pub fn builder() -> EnableParamsBuilder<'a>
Creates a builder for this type.
Sourcepub fn patterns(&self) -> Option<&[RequestPattern<'a>]>
pub fn patterns(&self) -> Option<&[RequestPattern<'a>]>
If specified, only requests matching any of these patterns will produce fetchRequested event and will be paused until clients response. If not set, all requests will be affected.
Sourcepub fn handle_auth_requests(&self) -> Option<bool>
pub fn handle_auth_requests(&self) -> Option<bool>
If true, authRequired events will be issued and requests will be paused expecting a call to continueWithAuth.