EnableParamsBuilder

Struct EnableParamsBuilder 

pub struct EnableParamsBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> EnableParamsBuilder<'a>

pub fn patterns(self, patterns: Vec<RequestPattern<'a>>) -> Self

If specified, only requests matching any of these patterns will produce fetchRequested event and will be paused until clients response. If not set, all requests will be affected.

pub fn handle_auth_requests(self, handle_auth_requests: bool) -> Self

If true, authRequired events will be issued and requests will be paused expecting a call to continueWithAuth.

pub fn build(self) -> EnableParams<'a>