FulfillRequestParams

Struct FulfillRequestParams 

pub struct FulfillRequestParams {
    pub requestId: RequestId,
    pub responseCode: i64,
    pub responseHeaders: Option<Vec<HeaderEntry>>,
    pub binaryResponseHeaders: Option<String>,
    pub body: Option<String>,
    pub responsePhrase: Option<String>,
}
Provides response to the request.

Fields

requestId: RequestId

An id the client received in requestPaused event.

responseCode: i64

An HTTP response code.

responseHeaders: Option<Vec<HeaderEntry>>

Response headers.

binaryResponseHeaders: Option<String>

Alternative way of specifying response headers as a \0-separated series of name: value pairs. Prefer the above method unless you need to represent some non-UTF8 values that can’t be transmitted over the protocol as text. (Encoded as a base64 string when passed over JSON)

body: Option<String>

A response body. If absent, original response body will be used if the request is intercepted at the response stage and empty body will be used if the request is intercepted at the request stage. (Encoded as a base64 string when passed over JSON)

responsePhrase: Option<String>

A textual representation of responseCode. If absent, a standard phrase matching responseCode is used.

Implementations

Source

impl FulfillRequestParams

pub const METHOD: &'static str = "Fetch.fulfillRequest"