FulfillRequestParamsBuilder

Struct FulfillRequestParamsBuilder 

pub struct FulfillRequestParamsBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> FulfillRequestParamsBuilder<'a>

pub fn response_headers(self, response_headers: Vec<HeaderEntry<'a>>) -> Self

Response headers.

pub fn binary_response_headers( self, binary_response_headers: impl Into<Cow<'a, str>>, ) -> Self

Alternative way of specifying response headers as a \0-separated series of name: value pairs. Prefer the above method unless you need to represent some non-UTF8 values that can’t be transmitted over the protocol as text. (Encoded as a base64 string when passed over JSON)

pub fn body(self, body: impl Into<Cow<'a, str>>) -> Self

A response body. If absent, original response body will be used if the request is intercepted at the response stage and empty body will be used if the request is intercepted at the request stage. (Encoded as a base64 string when passed over JSON)

pub fn response_phrase(self, response_phrase: impl Into<Cow<'a, str>>) -> Self

A textual representation of responseCode. If absent, a standard phrase matching responseCode is used.

pub fn build(self) -> FulfillRequestParams<'a>