pub struct TakeResponseBodyAsStreamReturns {
pub stream: StreamHandle,
}Expand description
Returns a handle to the stream representing the response body. The request must be paused in the HeadersReceived stage. Note that after this command the request can’t be continued as is – client either needs to cancel it or to provide the response body. The stream only supports sequential read, IO.read will fail if the position is specified. This method is mutually exclusive with getResponseBody. Calling other methods that affect the request or disabling fetch domain before body is received results in an undefined behavior.
Fields
stream: StreamHandleTrait Implementations
Sourceimpl Clone for TakeResponseBodyAsStreamReturns
impl Clone for TakeResponseBodyAsStreamReturns
Sourcefn clone(&self) -> TakeResponseBodyAsStreamReturns
fn clone(&self) -> TakeResponseBodyAsStreamReturns
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for TakeResponseBodyAsStreamReturns
impl Default for TakeResponseBodyAsStreamReturns
Sourcefn default() -> TakeResponseBodyAsStreamReturns
fn default() -> TakeResponseBodyAsStreamReturns
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for TakeResponseBodyAsStreamReturns
impl<'de> Deserialize<'de> for TakeResponseBodyAsStreamReturns
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more