BeginFrameParamsBuilder

Struct BeginFrameParamsBuilder 

pub struct BeginFrameParamsBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> BeginFrameParamsBuilder<'a>

pub fn frameTimeTicks(self, frameTimeTicks: f64) -> Self

Timestamp of this BeginFrame in Renderer TimeTicks (milliseconds of uptime). If not set, the current time will be used.

pub fn interval(self, interval: f64) -> Self

The interval between BeginFrames that is reported to the compositor, in milliseconds. Defaults to a 60 frames/second interval, i.e. about 16.666 milliseconds.

pub fn noDisplayUpdates(self, noDisplayUpdates: bool) -> Self

Whether updates should not be committed and drawn onto the display. False by default. If true, only side effects of the BeginFrame will be run, such as layout and animations, but any visual updates may not be visible on the display or in screenshots.

pub fn screenshot(self, screenshot: ScreenshotParams<'a>) -> Self

If set, a screenshot of the frame will be captured and returned in the response. Otherwise, no screenshot will be captured. Note that capturing a screenshot can fail, for example, during renderer initialization. In such a case, no screenshot data will be returned.

pub fn build(self) -> BeginFrameParams<'a>