pub struct BeginFrameReturns<'a> { /* private fields */ }Expand description
Sends a BeginFrame to the target and returns when the frame was completed. Optionally captures a screenshot from the resulting frame. Requires that the target was created with enabled BeginFrameControl. Designed for use with –run-all-compositor-stages-before-draw, see also https://goo.gle/chrome-headless-rendering for more background.
Implementations
Sourceimpl<'a> BeginFrameReturns<'a>
impl<'a> BeginFrameReturns<'a>
Sourcepub fn builder(has_damage: bool) -> BeginFrameReturnsBuilder<'a>
pub fn builder(has_damage: bool) -> BeginFrameReturnsBuilder<'a>
Creates a builder for this type with the required parameters:
has_damage: Whether the BeginFrame resulted in damage and, thus, a new frame was committed to the display. Reported for diagnostic uses, may be removed in the future.
Sourcepub fn has_damage(&self) -> bool
pub fn has_damage(&self) -> bool
Whether the BeginFrame resulted in damage and, thus, a new frame was committed to the display. Reported for diagnostic uses, may be removed in the future.
Sourcepub fn screenshot_data(&self) -> Option<&str>
pub fn screenshot_data(&self) -> Option<&str>
Base64-encoded image data of the screenshot, if one was requested and successfully taken. (Encoded as a base64 string when passed over JSON)