RequestDataParams

Struct RequestDataParams 

pub struct RequestDataParams<'a> { /* private fields */ }
Requests data from object store or index.

Implementations

Source

impl<'a> RequestDataParams<'a>

pub fn builder( database_name: impl Into<Cow<'a, str>>, object_store_name: impl Into<Cow<'a, str>>, skip_count: u64, page_size: u64, ) -> RequestDataParamsBuilder<'a>

Creates a builder for this type with the required parameters:

  • database_name: Database name.
  • object_store_name: Object store name.
  • skip_count: Number of records to skip.
  • page_size: Number of records to fetch.
pub fn security_origin(&self) -> Option<&str>

At least and at most one of securityOrigin, storageKey, or storageBucket must be specified. Security origin.

pub fn storage_key(&self) -> Option<&str>

Storage key.

pub fn storage_bucket(&self) -> Option<&StorageBucket<'a>>

Storage bucket. If not specified, it uses the default bucket.

pub fn database_name(&self) -> &str

Database name.

pub fn object_store_name(&self) -> &str

Object store name.

pub fn index_name(&self) -> Option<&str>

Index name. If not specified, it performs an object store data request.

pub fn skip_count(&self) -> u64

Number of records to skip.

pub fn page_size(&self) -> u64

Number of records to fetch.

pub fn key_range(&self) -> Option<&KeyRange<'a>>

Key range.

Source

impl<'a> RequestDataParams<'a>

pub const METHOD: &'static str = "IndexedDB.requestData"