pub struct DispatchDragEventParams<'a> { /* private fields */ }Expand description
Dispatches a drag event into the page.
Implementations
Sourceimpl<'a> DispatchDragEventParams<'a>
impl<'a> DispatchDragEventParams<'a>
Sourcepub fn builder(
type_: impl Into<Cow<'a, str>>,
x: f64,
y: f64,
data: DragData<'a>,
) -> DispatchDragEventParamsBuilder<'a>
pub fn builder( type_: impl Into<Cow<'a, str>>, x: f64, y: f64, data: DragData<'a>, ) -> DispatchDragEventParamsBuilder<'a>
Creates a builder for this type with the required parameters:
type_: Type of the drag event.x: X coordinate of the event relative to the main frame’s viewport in CSS pixels.y: Y coordinate of the event relative to the main frame’s viewport in CSS pixels. 0 refers to the top of the viewport and Y increases as it proceeds towards the bottom of the viewport.data:
Sourcepub fn x(&self) -> f64
pub fn x(&self) -> f64
X coordinate of the event relative to the main frame’s viewport in CSS pixels.
Sourcepub fn y(&self) -> f64
pub fn y(&self) -> f64
Y coordinate of the event relative to the main frame’s viewport in CSS pixels. 0 refers to the top of the viewport and Y increases as it proceeds towards the bottom of the viewport.
pub fn data(&self) -> &DragData<'a>