pub struct DispatchMouseEventParams<'a> { /* private fields */ }Expand description
Dispatches a mouse event to the page.
Implementations
Sourceimpl<'a> DispatchMouseEventParams<'a>
impl<'a> DispatchMouseEventParams<'a>
Sourcepub fn builder(
type_: impl Into<Cow<'a, str>>,
x: f64,
y: f64,
) -> DispatchMouseEventParamsBuilder<'a>
pub fn builder( type_: impl Into<Cow<'a, str>>, x: f64, y: f64, ) -> DispatchMouseEventParamsBuilder<'a>
Creates a builder for this type with the required parameters:
type_: Type of the mouse event.x: X coordinate of the event relative to the main frame’s viewport in CSS pixels.y: Y coordinate of the event relative to the main frame’s viewport in CSS pixels. 0 refers to the top of the viewport and Y increases as it proceeds towards the bottom of the viewport.
Sourcepub fn x(&self) -> f64
pub fn x(&self) -> f64
X coordinate of the event relative to the main frame’s viewport in CSS pixels.
Sourcepub fn y(&self) -> f64
pub fn y(&self) -> f64
Y coordinate of the event relative to the main frame’s viewport in CSS pixels. 0 refers to the top of the viewport and Y increases as it proceeds towards the bottom of the viewport.
Sourcepub fn modifiers(&self) -> Option<i64>
pub fn modifiers(&self) -> Option<i64>
Bit field representing pressed modifier keys. Alt=1, Ctrl=2, Meta/Command=4, Shift=8 (default: 0).
Sourcepub fn timestamp(&self) -> Option<&TimeSinceEpoch>
pub fn timestamp(&self) -> Option<&TimeSinceEpoch>
Time at which the event occurred.
Mouse button (default: “none”).
A number indicating which buttons are pressed on the mouse when a mouse event is triggered. Left=1, Right=2, Middle=4, Back=8, Forward=16, None=0.
Sourcepub fn click_count(&self) -> Option<u64>
pub fn click_count(&self) -> Option<u64>
Number of times the mouse button was clicked (default: 0).
Sourcepub fn force(&self) -> Option<f64>
pub fn force(&self) -> Option<f64>
The normalized pressure, which has a range of [0,1] (default: 0).
Sourcepub fn tangential_pressure(&self) -> Option<f64>
pub fn tangential_pressure(&self) -> Option<f64>
The normalized tangential pressure, which has a range of [-1,1] (default: 0).
Sourcepub fn tilt_x(&self) -> Option<f64>
pub fn tilt_x(&self) -> Option<f64>
The plane angle between the Y-Z plane and the plane containing both the stylus axis and the Y axis, in degrees of the range [-90,90], a positive tiltX is to the right (default: 0).
Sourcepub fn tilt_y(&self) -> Option<f64>
pub fn tilt_y(&self) -> Option<f64>
The plane angle between the X-Z plane and the plane containing both the stylus axis and the X axis, in degrees of the range [-90,90], a positive tiltY is towards the user (default: 0).
Sourcepub fn twist(&self) -> Option<i64>
pub fn twist(&self) -> Option<i64>
The clockwise rotation of a pen stylus around its own major axis, in degrees in the range [0,359] (default: 0).
Sourcepub fn pointer_type(&self) -> Option<&str>
pub fn pointer_type(&self) -> Option<&str>
Pointer type (default: “mouse”).