pub struct DragData<'a> { /* private fields */ }Implementations
Sourceimpl<'a> DragData<'a>
impl<'a> DragData<'a>
Sourcepub fn builder(
items: Vec<DragDataItem<'a>>,
drag_operations_mask: i64,
) -> DragDataBuilder<'a>
pub fn builder( items: Vec<DragDataItem<'a>>, drag_operations_mask: i64, ) -> DragDataBuilder<'a>
Creates a builder for this type with the required parameters:
items:drag_operations_mask: Bit field representing allowed drag operations. Copy = 1, Link = 2, Move = 16
pub fn items(&self) -> &[DragDataItem<'a>]
Sourcepub fn files(&self) -> Option<&[Cow<'a, str>]>
pub fn files(&self) -> Option<&[Cow<'a, str>]>
List of filenames that should be included when dropping
Sourcepub fn drag_operations_mask(&self) -> i64
pub fn drag_operations_mask(&self) -> i64
Bit field representing allowed drag operations. Copy = 1, Link = 2, Move = 16