pub struct EmulateTouchFromMouseEventParams<'a> { /* private fields */ }Expand description
Emulates touch event from the mouse event parameters.
Implementations
Sourceimpl<'a> EmulateTouchFromMouseEventParams<'a>
impl<'a> EmulateTouchFromMouseEventParams<'a>
Sourcepub fn builder(
type_: impl Into<Cow<'a, str>>,
x: i32,
y: i32,
button: impl Into<MouseButton>,
) -> EmulateTouchFromMouseEventParamsBuilder<'a>
pub fn builder( type_: impl Into<Cow<'a, str>>, x: i32, y: i32, button: impl Into<MouseButton>, ) -> EmulateTouchFromMouseEventParamsBuilder<'a>
Creates a builder for this type with the required parameters:
type_: Type of the mouse event.x: X coordinate of the mouse pointer in DIP.y: Y coordinate of the mouse pointer in DIP.button: Mouse button. Only “none”, “left”, “right” are supported.
Mouse button. Only “none”, “left”, “right” are supported.
Sourcepub fn timestamp(&self) -> Option<&TimeSinceEpoch>
pub fn timestamp(&self) -> Option<&TimeSinceEpoch>
Time at which the event occurred (default: current time).
Sourcepub fn modifiers(&self) -> Option<i64>
pub fn modifiers(&self) -> Option<i64>
Bit field representing pressed modifier keys. Alt=1, Ctrl=2, Meta/Command=4, Shift=8 (default: 0).
Sourcepub fn click_count(&self) -> Option<u64>
pub fn click_count(&self) -> Option<u64>
Number of times the mouse button was clicked (default: 0).