ImeSetCompositionParams

Struct ImeSetCompositionParams 

pub struct ImeSetCompositionParams<'a> { /* private fields */ }
This method sets the current candidate text for IME. Use imeCommitComposition to commit the final text. Use imeSetComposition with empty string as text to cancel composition.

Implementations

Source

impl<'a> ImeSetCompositionParams<'a>

pub fn builder( text: impl Into<Cow<'a, str>>, selectionStart: i64, selectionEnd: i64, ) -> ImeSetCompositionParamsBuilder<'a>

pub fn text(&self) -> &str

pub fn selectionStart(&self) -> i64

pub fn selectionEnd(&self) -> i64

pub fn replacementStart(&self) -> Option<i64>

pub fn replacementEnd(&self) -> Option<i64>

Source

impl<'a> ImeSetCompositionParams<'a>

pub const METHOD: &'static str = "Input.imeSetComposition"