SetInterceptDragsParams

Struct SetInterceptDragsParams 

pub struct SetInterceptDragsParams { /* private fields */ }
Prevents default drag and drop behavior and instead emits ‘Input.dragIntercepted’ events. Drag and drop behavior can be directly controlled via ‘Input.dispatchDragEvent’.

Implementations

Source

impl SetInterceptDragsParams

Source

impl SetInterceptDragsParams

pub const METHOD: &'static str = "Input.setInterceptDrags"