pub struct SynthesizePinchGestureParams { /* private fields */ }Expand description
Synthesizes a pinch gesture over a time period by issuing appropriate touch events.
Implementations
Sourceimpl SynthesizePinchGestureParams
impl SynthesizePinchGestureParams
Sourcepub fn builder(
x: f64,
y: f64,
scale_factor: f64,
) -> SynthesizePinchGestureParamsBuilder
pub fn builder( x: f64, y: f64, scale_factor: f64, ) -> SynthesizePinchGestureParamsBuilder
Creates a builder for this type with the required parameters:
x: X coordinate of the start of the gesture in CSS pixels.y: Y coordinate of the start of the gesture in CSS pixels.scale_factor: Relative scale factor after zooming (>1.0 zooms in, <1.0 zooms out).
Sourcepub fn scale_factor(&self) -> f64
pub fn scale_factor(&self) -> f64
Relative scale factor after zooming (>1.0 zooms in, <1.0 zooms out).
Sourcepub fn relative_speed(&self) -> Option<i64>
pub fn relative_speed(&self) -> Option<i64>
Relative pointer speed in pixels per second (default: 800).
Sourcepub fn gesture_source_type(&self) -> Option<&GestureSourceType>
pub fn gesture_source_type(&self) -> Option<&GestureSourceType>
Which type of input events to be generated (default: ‘default’, which queries the platform for the preferred input type).