pub struct SynthesizePinchGestureParamsBuilder { /* private fields */ }Implementations
Sourceimpl SynthesizePinchGestureParamsBuilder
impl SynthesizePinchGestureParamsBuilder
Sourcepub fn relative_speed(self, relative_speed: i64) -> Self
pub fn relative_speed(self, relative_speed: i64) -> Self
Relative pointer speed in pixels per second (default: 800).
Sourcepub fn gesture_source_type(
self,
gesture_source_type: impl Into<GestureSourceType>,
) -> Self
pub fn gesture_source_type( self, gesture_source_type: impl Into<GestureSourceType>, ) -> Self
Which type of input events to be generated (default: ‘default’, which queries the platform for the preferred input type).
pub fn build(self) -> SynthesizePinchGestureParams