pub struct SynthesizeScrollGestureParams<'a> { /* private fields */ }Expand description
Synthesizes a scroll gesture over a time period by issuing appropriate touch events.
Implementations
Sourceimpl<'a> SynthesizeScrollGestureParams<'a>
impl<'a> SynthesizeScrollGestureParams<'a>
Sourcepub fn builder(x: f64, y: f64) -> SynthesizeScrollGestureParamsBuilder<'a>
pub fn builder(x: f64, y: f64) -> SynthesizeScrollGestureParamsBuilder<'a>
Creates a builder for this type with the required parameters:
x: X coordinate of the start of the gesture in CSS pixels.y: Y coordinate of the start of the gesture in CSS pixels.
Sourcepub fn x_distance(&self) -> Option<f64>
pub fn x_distance(&self) -> Option<f64>
The distance to scroll along the X axis (positive to scroll left).
Sourcepub fn y_distance(&self) -> Option<f64>
pub fn y_distance(&self) -> Option<f64>
The distance to scroll along the Y axis (positive to scroll up).
Sourcepub fn x_overscroll(&self) -> Option<f64>
pub fn x_overscroll(&self) -> Option<f64>
The number of additional pixels to scroll back along the X axis, in addition to the given distance.
Sourcepub fn y_overscroll(&self) -> Option<f64>
pub fn y_overscroll(&self) -> Option<f64>
The number of additional pixels to scroll back along the Y axis, in addition to the given distance.
Sourcepub fn prevent_fling(&self) -> Option<bool>
pub fn prevent_fling(&self) -> Option<bool>
Prevent fling (default: true).
Sourcepub fn gesture_source_type(&self) -> Option<&GestureSourceType>
pub fn gesture_source_type(&self) -> Option<&GestureSourceType>
Which type of input events to be generated (default: ‘default’, which queries the platform for the preferred input type).
Sourcepub fn repeat_count(&self) -> Option<u64>
pub fn repeat_count(&self) -> Option<u64>
The number of times to repeat the gesture (default: 0).
Sourcepub fn repeat_delay_ms(&self) -> Option<i64>
pub fn repeat_delay_ms(&self) -> Option<i64>
The number of milliseconds delay between each repeat. (default: 250).
Sourcepub fn interaction_marker_name(&self) -> Option<&str>
pub fn interaction_marker_name(&self) -> Option<&str>
The name of the interaction markers to generate, if not empty (default: “”).