SynthesizeScrollGestureParamsBuilder

Struct SynthesizeScrollGestureParamsBuilder 

pub struct SynthesizeScrollGestureParamsBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> SynthesizeScrollGestureParamsBuilder<'a>

pub fn x_distance(self, x_distance: f64) -> Self

The distance to scroll along the X axis (positive to scroll left).

pub fn y_distance(self, y_distance: f64) -> Self

The distance to scroll along the Y axis (positive to scroll up).

pub fn x_overscroll(self, x_overscroll: f64) -> Self

The number of additional pixels to scroll back along the X axis, in addition to the given distance.

pub fn y_overscroll(self, y_overscroll: f64) -> Self

The number of additional pixels to scroll back along the Y axis, in addition to the given distance.

pub fn prevent_fling(self, prevent_fling: bool) -> Self

Prevent fling (default: true).

pub fn speed(self, speed: i64) -> Self

Swipe speed in pixels per second (default: 800).

pub fn gesture_source_type( self, gesture_source_type: impl Into<GestureSourceType>, ) -> Self

Which type of input events to be generated (default: ‘default’, which queries the platform for the preferred input type).

pub fn repeat_count(self, repeat_count: u64) -> Self

The number of times to repeat the gesture (default: 0).

pub fn repeat_delay_ms(self, repeat_delay_ms: i64) -> Self

The number of milliseconds delay between each repeat. (default: 250).

pub fn interaction_marker_name( self, interaction_marker_name: impl Into<Cow<'a, str>>, ) -> Self

The name of the interaction markers to generate, if not empty (default: “”).

pub fn build(self) -> SynthesizeScrollGestureParams<'a>