pub struct SynthesizeTapGestureParams { /* private fields */ }Expand description
Synthesizes a tap gesture over a time period by issuing appropriate touch events.
Implementations
Sourceimpl SynthesizeTapGestureParams
impl SynthesizeTapGestureParams
Sourcepub fn builder(x: f64, y: f64) -> SynthesizeTapGestureParamsBuilder
pub fn builder(x: f64, y: f64) -> SynthesizeTapGestureParamsBuilder
Creates a builder for this type with the required parameters:
x: X coordinate of the start of the gesture in CSS pixels.y: Y coordinate of the start of the gesture in CSS pixels.
Sourcepub fn duration(&self) -> Option<i64>
pub fn duration(&self) -> Option<i64>
Duration between touchdown and touchup events in ms (default: 50).
Sourcepub fn tap_count(&self) -> Option<u64>
pub fn tap_count(&self) -> Option<u64>
Number of times to perform the tap (e.g. 2 for double tap, default: 1).
Sourcepub fn gesture_source_type(&self) -> Option<&GestureSourceType>
pub fn gesture_source_type(&self) -> Option<&GestureSourceType>
Which type of input events to be generated (default: ‘default’, which queries the platform for the preferred input type).