pub struct TouchPoint { /* private fields */ }Implementations
Sourceimpl TouchPoint
impl TouchPoint
Sourcepub fn builder(x: f64, y: f64) -> TouchPointBuilder
pub fn builder(x: f64, y: f64) -> TouchPointBuilder
Creates a builder for this type with the required parameters:
x: X coordinate of the event relative to the main frame’s viewport in CSS pixels.y: Y coordinate of the event relative to the main frame’s viewport in CSS pixels. 0 refers to the top of the viewport and Y increases as it proceeds towards the bottom of the viewport.
Sourcepub fn x(&self) -> f64
pub fn x(&self) -> f64
X coordinate of the event relative to the main frame’s viewport in CSS pixels.
Sourcepub fn y(&self) -> f64
pub fn y(&self) -> f64
Y coordinate of the event relative to the main frame’s viewport in CSS pixels. 0 refers to the top of the viewport and Y increases as it proceeds towards the bottom of the viewport.
Sourcepub fn rotation_angle(&self) -> Option<f64>
pub fn rotation_angle(&self) -> Option<f64>
Rotation angle (default: 0.0).
Sourcepub fn tangential_pressure(&self) -> Option<f64>
pub fn tangential_pressure(&self) -> Option<f64>
The normalized tangential pressure, which has a range of [-1,1] (default: 0).
Sourcepub fn tilt_x(&self) -> Option<f64>
pub fn tilt_x(&self) -> Option<f64>
The plane angle between the Y-Z plane and the plane containing both the stylus axis and the Y axis, in degrees of the range [-90,90], a positive tiltX is to the right (default: 0)
Sourcepub fn tilt_y(&self) -> Option<f64>
pub fn tilt_y(&self) -> Option<f64>
The plane angle between the X-Z plane and the plane containing both the stylus axis and the X axis, in degrees of the range [-90,90], a positive tiltY is towards the user (default: 0).