Module io

Module io 

Input/Output operations for streams produced by DevTools.

Structs

CloseParams
Close the stream, discard any temporary backing storage.
CloseParamsBuilder
ReadParams
Read a chunk of the stream
ReadParamsBuilder
ReadReturns
Read a chunk of the stream
ReadReturnsBuilder
ResolveBlobParams
Return UUID of Blob object specified by a remote object id.
ResolveBlobParamsBuilder
ResolveBlobReturns
Return UUID of Blob object specified by a remote object id.
ResolveBlobReturnsBuilder

Type Aliases

StreamHandle
This is either obtained from another method or specified as ‘blob:’ where ‘’ is an UUID of a Blob.