pub struct ReadParams {
pub handle: StreamHandle,
pub offset: Option<i32>,
pub size: Option<u64>,
}Expand description
Read a chunk of the stream
Fields
handle: StreamHandleHandle of the stream to read.
offset: Option<i32>Seek to the specified offset before reading (if not specified, proceed with offset following the last read). Some types of streams may only support sequential reads.
size: Option<u64>Maximum number of bytes to read (left upon the agent discretion if not specified).