ReadParamsBuilder

Struct ReadParamsBuilder 

pub struct ReadParamsBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> ReadParamsBuilder<'a>

pub fn offset(self, offset: i32) -> Self

Seek to the specified offset before reading (if not specified, proceed with offset following the last read). Some types of streams may only support sequential reads.

pub fn size(self, size: u64) -> Self

Maximum number of bytes to read (left upon the agent discretion if not specified).

pub fn build(self) -> ReadParams<'a>