Module layertree

Module layertree 

Structs

CompositingReasonsParams
Provides the reasons why the given layer was composited.
CompositingReasonsParamsBuilder
CompositingReasonsReturns
Provides the reasons why the given layer was composited.
CompositingReasonsReturnsBuilder
DisableParams
EnableParams
Layer
Information about a compositing layer.
LayerBuilder
LoadSnapshotParams
Returns the snapshot identifier.
LoadSnapshotParamsBuilder
LoadSnapshotReturns
Returns the snapshot identifier.
LoadSnapshotReturnsBuilder
MakeSnapshotParams
Returns the layer snapshot identifier.
MakeSnapshotParamsBuilder
MakeSnapshotReturns
Returns the layer snapshot identifier.
MakeSnapshotReturnsBuilder
PictureTile
Serialized fragment of layer picture along with its offset within the layer.
PictureTileBuilder
ProfileSnapshotParams
ProfileSnapshotParamsBuilder
ProfileSnapshotReturns
ProfileSnapshotReturnsBuilder
ReleaseSnapshotParams
Releases layer snapshot captured by the back-end.
ReleaseSnapshotParamsBuilder
ReplaySnapshotParams
Replays the layer snapshot and returns the resulting bitmap.
ReplaySnapshotParamsBuilder
ReplaySnapshotReturns
Replays the layer snapshot and returns the resulting bitmap.
ReplaySnapshotReturnsBuilder
ScrollRect
Rectangle where scrolling happens on the main thread.
ScrollRectBuilder
SnapshotCommandLogParams
Replays the layer snapshot and returns canvas log.
SnapshotCommandLogParamsBuilder
SnapshotCommandLogReturns
Replays the layer snapshot and returns canvas log.
SnapshotCommandLogReturnsBuilder
StickyPositionConstraint
Sticky position constraints.
StickyPositionConstraintBuilder

Type Aliases

LayerId
Unique Layer identifier.
PaintProfile
Array of timings, one per paint step.
SnapshotId
Unique snapshot identifier.