pub struct LayerBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> LayerBuilder<'a>
impl<'a> LayerBuilder<'a>
Sourcepub fn parent_layer_id(self, parent_layer_id: impl Into<LayerId<'a>>) -> Self
pub fn parent_layer_id(self, parent_layer_id: impl Into<LayerId<'a>>) -> Self
The id of parent (not present for root).
Sourcepub fn backend_node_id(self, backend_node_id: BackendNodeId) -> Self
pub fn backend_node_id(self, backend_node_id: BackendNodeId) -> Self
The backend id for the node associated with this layer.
Sourcepub fn transform(self, transform: Vec<f64>) -> Self
pub fn transform(self, transform: Vec<f64>) -> Self
Transformation matrix for layer, default is identity matrix
Sourcepub fn anchor_x(self, anchor_x: f64) -> Self
pub fn anchor_x(self, anchor_x: f64) -> Self
Transform anchor point X, absent if no transform specified
Sourcepub fn anchor_y(self, anchor_y: f64) -> Self
pub fn anchor_y(self, anchor_y: f64) -> Self
Transform anchor point Y, absent if no transform specified
Sourcepub fn anchor_z(self, anchor_z: f64) -> Self
pub fn anchor_z(self, anchor_z: f64) -> Self
Transform anchor point Z, absent if no transform specified
Sourcepub fn scroll_rects(self, scroll_rects: Vec<ScrollRect<'a>>) -> Self
pub fn scroll_rects(self, scroll_rects: Vec<ScrollRect<'a>>) -> Self
Rectangles scrolling on main thread only.
Sourcepub fn sticky_position_constraint(
self,
sticky_position_constraint: StickyPositionConstraint<'a>,
) -> Self
pub fn sticky_position_constraint( self, sticky_position_constraint: StickyPositionConstraint<'a>, ) -> Self
Sticky position constraint information
pub fn build(self) -> Layer<'a>