pub struct ProfileSnapshotParams {
pub snapshotId: SnapshotId,
pub minRepeatCount: Option<u64>,
pub minDuration: Option<f64>,
pub clipRect: Option<Rect>,
}Fields
snapshotId: SnapshotIdThe id of the layer snapshot.
minRepeatCount: Option<u64>The maximum number of times to replay the snapshot (1, if not specified).
minDuration: Option<f64>The minimum duration (in seconds) to replay the snapshot.
clipRect: Option<Rect>The clip rectangle to apply when replaying the snapshot.