ProfileSnapshotParamsBuilder

Struct ProfileSnapshotParamsBuilder 

pub struct ProfileSnapshotParamsBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> ProfileSnapshotParamsBuilder<'a>

pub fn minRepeatCount(self, minRepeatCount: u64) -> Self

The maximum number of times to replay the snapshot (1, if not specified).

pub fn minDuration(self, minDuration: f64) -> Self

The minimum duration (in seconds) to replay the snapshot.

pub fn clipRect(self, clipRect: Rect) -> Self

The clip rectangle to apply when replaying the snapshot.

pub fn build(self) -> ProfileSnapshotParams<'a>