pub struct StickyPositionConstraint<'a> { /* private fields */ }Expand description
Sticky position constraints.
Implementations
Sourceimpl<'a> StickyPositionConstraint<'a>
impl<'a> StickyPositionConstraint<'a>
Sourcepub fn builder(
sticky_box_rect: Rect,
containing_block_rect: Rect,
) -> StickyPositionConstraintBuilder<'a>
pub fn builder( sticky_box_rect: Rect, containing_block_rect: Rect, ) -> StickyPositionConstraintBuilder<'a>
Creates a builder for this type with the required parameters:
sticky_box_rect: Layout rectangle of the sticky element before being shiftedcontaining_block_rect: Layout rectangle of the containing block of the sticky element
Sourcepub fn sticky_box_rect(&self) -> &Rect
pub fn sticky_box_rect(&self) -> &Rect
Layout rectangle of the sticky element before being shifted
Sourcepub fn containing_block_rect(&self) -> &Rect
pub fn containing_block_rect(&self) -> &Rect
Layout rectangle of the containing block of the sticky element
Sourcepub fn nearest_layer_shifting_sticky_box(&self) -> Option<&LayerId<'a>>
pub fn nearest_layer_shifting_sticky_box(&self) -> Option<&LayerId<'a>>
The nearest sticky layer that shifts the sticky box
Sourcepub fn nearest_layer_shifting_containing_block(&self) -> Option<&LayerId<'a>>
pub fn nearest_layer_shifting_containing_block(&self) -> Option<&LayerId<'a>>
The nearest sticky layer that shifts the containing block