pub struct StickyPositionConstraintBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> StickyPositionConstraintBuilder<'a>
impl<'a> StickyPositionConstraintBuilder<'a>
Sourcepub fn nearest_layer_shifting_sticky_box(
self,
nearest_layer_shifting_sticky_box: impl Into<LayerId<'a>>,
) -> Self
pub fn nearest_layer_shifting_sticky_box( self, nearest_layer_shifting_sticky_box: impl Into<LayerId<'a>>, ) -> Self
The nearest sticky layer that shifts the sticky box
Sourcepub fn nearest_layer_shifting_containing_block(
self,
nearest_layer_shifting_containing_block: impl Into<LayerId<'a>>,
) -> Self
pub fn nearest_layer_shifting_containing_block( self, nearest_layer_shifting_containing_block: impl Into<LayerId<'a>>, ) -> Self
The nearest sticky layer that shifts the containing block
pub fn build(self) -> StickyPositionConstraint<'a>