pub struct LogEntry<'a> { /* private fields */ }Expand description
Log entry.
Implementations
Sourceimpl<'a> LogEntry<'a>
impl<'a> LogEntry<'a>
Sourcepub fn builder(
source: impl Into<Cow<'a, str>>,
level: impl Into<Cow<'a, str>>,
text: impl Into<Cow<'a, str>>,
timestamp: Timestamp,
) -> LogEntryBuilder<'a>
pub fn builder( source: impl Into<Cow<'a, str>>, level: impl Into<Cow<'a, str>>, text: impl Into<Cow<'a, str>>, timestamp: Timestamp, ) -> LogEntryBuilder<'a>
Creates a builder for this type with the required parameters:
source: Log entry source.level: Log entry severity.text: Logged text.timestamp: Timestamp when this entry was added.
pub fn category(&self) -> Option<&str>
Sourcepub fn line_number(&self) -> Option<i64>
pub fn line_number(&self) -> Option<i64>
Line number in the resource.
Sourcepub fn stack_trace(&self) -> Option<&StackTrace>
pub fn stack_trace(&self) -> Option<&StackTrace>
JavaScript stack trace.
Sourcepub fn network_request_id(&self) -> Option<&RequestId<'a>>
pub fn network_request_id(&self) -> Option<&RequestId<'a>>
Identifier of the network request associated with this entry.
Sourcepub fn args(&self) -> Option<&[RemoteObject]>
pub fn args(&self) -> Option<&[RemoteObject]>
Call arguments.