pub struct PlayerError<'a> { /* private fields */ }Expand description
Corresponds to kMediaError
Implementations
Sourceimpl<'a> PlayerError<'a>
impl<'a> PlayerError<'a>
Sourcepub fn builder(
error_type: impl Into<Cow<'a, str>>,
code: i64,
stack: Vec<PlayerErrorSourceLocation<'a>>,
cause: Vec<Box<PlayerError<'a>>>,
data: Map<String, JsonValue>,
) -> PlayerErrorBuilder<'a>
pub fn builder( error_type: impl Into<Cow<'a, str>>, code: i64, stack: Vec<PlayerErrorSourceLocation<'a>>, cause: Vec<Box<PlayerError<'a>>>, data: Map<String, JsonValue>, ) -> PlayerErrorBuilder<'a>
Creates a builder for this type with the required parameters:
error_type:code: Code is the numeric enum entry for a specific set of error codes, such as PipelineStatusCodes in media/base/pipeline_status.hstack: A trace of where this error was caused / where it passed through.cause: Errors potentially have a root cause error, ie, a DecoderError might be caused by an WindowsErrordata: Extra data attached to an error, such as an HRESULT, Video Codec, etc.
pub fn error_type(&self) -> &str
Sourcepub fn code(&self) -> i64
pub fn code(&self) -> i64
Code is the numeric enum entry for a specific set of error codes, such as PipelineStatusCodes in media/base/pipeline_status.h
Sourcepub fn stack(&self) -> &[PlayerErrorSourceLocation<'a>]
pub fn stack(&self) -> &[PlayerErrorSourceLocation<'a>]
A trace of where this error was caused / where it passed through.
Sourcepub fn cause(&self) -> &[Box<PlayerError<'a>>]
pub fn cause(&self) -> &[Box<PlayerError<'a>>]
Errors potentially have a root cause error, ie, a DecoderError might be caused by an WindowsError