pub struct PlayerMessage<'a> { /* private fields */ }Expand description
Have one type per entry in MediaLogRecord::Type Corresponds to kMessage
Implementations
Sourceimpl<'a> PlayerMessage<'a>
impl<'a> PlayerMessage<'a>
Sourcepub fn builder(
level: impl Into<Cow<'a, str>>,
message: impl Into<Cow<'a, str>>,
) -> PlayerMessageBuilder<'a>
pub fn builder( level: impl Into<Cow<'a, str>>, message: impl Into<Cow<'a, str>>, ) -> PlayerMessageBuilder<'a>
Creates a builder for this type with the required parameters:
level: Keep in sync with MediaLogMessageLevel We are currently keeping the message level ‘error’ separate from the PlayerError type because right now they represent different things, this one being a DVLOG(ERROR) style log message that gets printed based on what log level is selected in the UI, and the other is a representation of a media::PipelineStatus object. Soon however we’re going to be moving away from using PipelineStatus for errors and introducing a new error type which should hopefully let us integrate the error log level into the PlayerError type.message:
Sourcepub fn level(&self) -> &str
pub fn level(&self) -> &str
Keep in sync with MediaLogMessageLevel We are currently keeping the message level ‘error’ separate from the PlayerError type because right now they represent different things, this one being a DVLOG(ERROR) style log message that gets printed based on what log level is selected in the UI, and the other is a representation of a media::PipelineStatus object. Soon however we’re going to be moving away from using PipelineStatus for errors and introducing a new error type which should hopefully let us integrate the error log level into the PlayerError type.
pub fn message(&self) -> &str