Module memory

Module memory 

Structs

DOMCounter
DOM object counter data.
ForciblyPurgeJavaScriptMemoryParams
GetAllTimeSamplingProfileParams
GetAllTimeSamplingProfileReturns
Retrieve native memory allocations profile collected since renderer process startup.
GetBrowserSamplingProfileParams
GetBrowserSamplingProfileReturns
Retrieve native memory allocations profile collected since browser process startup.
GetDOMCountersForLeakDetectionParams
GetDOMCountersForLeakDetectionReturns
Retruns DOM object counters after preparing renderer for leak detection.
GetDOMCountersParams
GetDOMCountersReturns
Retruns current DOM object counters.
GetSamplingProfileParams
GetSamplingProfileReturns
Retrieve native memory allocations profile collected since last ‘startSampling’ call.
Module
Executable module information
PrepareForLeakDetectionParams
SamplingProfile
Array of heap profile samples.
SamplingProfileNode
Heap profile sample.
SetPressureNotificationsSuppressedParams
Enable/disable suppressing memory pressure notifications in all processes.
SimulatePressureNotificationParams
Simulate a memory pressure notification in all processes.
StartSamplingParams
Start collecting native memory profile.
StopSamplingParams

Enums

PressureLevel
Memory pressure level.