pub struct Module<'a> { /* private fields */ }Expand description
Executable module information
Implementations
Sourceimpl<'a> Module<'a>
impl<'a> Module<'a>
Sourcepub fn builder(
name: impl Into<Cow<'a, str>>,
uuid: impl Into<Cow<'a, str>>,
base_address: impl Into<Cow<'a, str>>,
size: f64,
) -> ModuleBuilder<'a>
pub fn builder( name: impl Into<Cow<'a, str>>, uuid: impl Into<Cow<'a, str>>, base_address: impl Into<Cow<'a, str>>, size: f64, ) -> ModuleBuilder<'a>
Creates a builder for this type with the required parameters:
name: Name of the module.uuid: UUID of the module.base_address: Base address where the module is loaded into memory. Encoded as a decimal or hexadecimal (0x prefixed) string.size: Size of the module in bytes.
Sourcepub fn base_address(&self) -> &str
pub fn base_address(&self) -> &str
Base address where the module is loaded into memory. Encoded as a decimal or hexadecimal (0x prefixed) string.