Network domain allows tracking network activities of the page. It exposes information about http, file, data and other requests and responses, their headers, bodies, timing, etc.
Structs
- AdAncestry
- Encapsulates the script ancestry and the root script filter list rule that caused the resource or element to be labeled as an ad.
- AdAncestry
Builder - AdProvenance
- Represents the provenance of an ad resource or element. Only one of ‘filterlistRule’ or ‘adScriptAncestry’ can be set. If ‘filterlistRule’ is provided, the resource URL directly matches a filter list rule. If ‘adScriptAncestry’ is provided, an ad script initiated the resource fetch or appended the element to the DOM. If neither is provided, the entity is known to be an ad, but provenance tracking information is unavailable.
- AdProvenance
Builder - AdScript
Identifier - Identifies the script on the stack that caused a resource or element to be labeled as an ad. For resources, this indicates the context that triggered the fetch. For elements, this indicates the context that caused the element to be appended to the DOM.
- AdScript
Identifier Builder - Associated
Cookie - A cookie associated with the request which may or may not be sent with it. Includes the cookies itself and reasons for blocking or exemption.
- Associated
Cookie Builder - Auth
Challenge - Authorization challenge for HTTP status code 401 or 407.
- Auth
Challenge Builder - Auth
Challenge Response - Response to an AuthChallenge.
- Auth
Challenge Response Builder - Block
Pattern - Block
Pattern Builder - Blocked
SetCookie With Reason - A cookie which was not stored from a response with the corresponding reason.
- Blocked
SetCookie With Reason Builder - Cached
Resource - Information about the cached resource.
- Cached
Resource Builder - CanClear
Browser Cache Params - CanClear
Browser Cache Returns - Tells whether clearing browser cache is supported.
- CanClear
Browser Cache Returns Builder - CanClear
Browser Cookies Params - CanClear
Browser Cookies Returns - Tells whether clearing browser cookies is supported.
- CanClear
Browser Cookies Returns Builder - CanEmulate
Network Conditions Params - CanEmulate
Network Conditions Returns - Tells whether emulation of network conditions is supported.
- CanEmulate
Network Conditions Returns Builder - Challenge
Event Details - Session event details specific to challenges.
- Challenge
Event Details Builder - Clear
Accepted Encodings Override Params - Clear
Browser Cache Params - Clear
Browser Cookies Params - Client
Security State - Client
Security State Builder - Configure
Durable Messages Params - Configures storing response bodies outside of renderer, so that these survive a cross-process navigation. If maxTotalBufferSize is not set, durable messages are disabled.
- Configure
Durable Messages Params Builder - Connect
Timing - Connect
Timing Builder - Content
Security Policy Status - Content
Security Policy Status Builder - Continue
Intercepted Request Params - Response to Network.requestIntercepted which either modifies the request to continue with any modifications, or blocks it, or completes it with the provided response bytes. If a network fetch occurs as a result which encounters a redirect an additional Network.requestIntercepted event will be sent with the same InterceptionId. Deprecated, use Fetch.continueRequest, Fetch.fulfillRequest and Fetch.failRequest instead.
- Continue
Intercepted Request Params Builder - Cookie
- Cookie object
- Cookie
Builder - Cookie
Param - Cookie parameter object
- Cookie
Param Builder - Cookie
Partition Key - cookiePartitionKey object The representation of the components of the key that are created by the cookiePartitionKey class contained in net/cookies/cookie_partition_key.h.
- Cookie
Partition KeyBuilder - Cors
Error Status - Cors
Error Status Builder - Creation
Event Details - Session event details specific to creation.
- Creation
Event Details Builder - Cross
Origin Embedder Policy Status - Cross
Origin Embedder Policy Status Builder - Cross
Origin Opener Policy Status - Cross
Origin Opener Policy Status Builder - Delete
Cookies Params - Deletes browser cookies with matching name and url or domain/path/partitionKey pair.
- Delete
Cookies Params Builder - Delete
Device Bound Session Params - Deletes a device bound session.
- Delete
Device Bound Session Params Builder - Device
Bound Session - A device bound session.
- Device
Bound Session Builder - Device
Bound Session Cookie Craving - A device bound session’s cookie craving.
- Device
Bound Session Cookie Craving Builder - Device
Bound Session Failed Request - Details about a failed device bound session network request.
- Device
Bound Session Failed Request Builder - Device
Bound Session Inclusion Rules - A device bound session’s inclusion rules.
- Device
Bound Session Inclusion Rules Builder - Device
Bound Session Key - Unique identifier for a device bound session.
- Device
Bound Session KeyBuilder - Device
Bound Session UrlRule - A device bound session’s inclusion URL rule.
- Device
Bound Session UrlRule Builder - Device
Bound Session With Usage - How a device bound session was used during a request.
- Device
Bound Session With Usage Builder - DirectTCP
Socket Options - DirectTCP
Socket Options Builder - DirectUDP
Message - DirectUDP
Message Builder - DirectUDP
Socket Options - DirectUDP
Socket Options Builder - Disable
Params - Emulate
Network Conditions ByRule Params - Activates emulation of network conditions for individual requests using URL match patterns. Unlike the deprecated Network.emulateNetworkConditions this method does not affect ‘navigator’ state. Use Network.overrideNetworkState to explicitly modify ‘navigator’ behavior.
- Emulate
Network Conditions ByRule Params Builder - Emulate
Network Conditions ByRule Returns - Activates emulation of network conditions for individual requests using URL match patterns. Unlike the deprecated Network.emulateNetworkConditions this method does not affect ‘navigator’ state. Use Network.overrideNetworkState to explicitly modify ‘navigator’ behavior.
- Emulate
Network Conditions ByRule Returns Builder - Emulate
Network Conditions Params - Activates emulation of network conditions. This command is deprecated in favor of the emulateNetworkConditionsByRule and overrideNetworkState commands, which can be used together to the same effect.
- Emulate
Network Conditions Params Builder - Enable
Device Bound Sessions Params - Sets up tracking device bound sessions and fetching of initial set of sessions.
- Enable
Device Bound Sessions Params Builder - Enable
Params - Enables network tracking, network events will now be delivered to the client.
- Enable
Params Builder - Enable
Reporting ApiParams - Enables tracking for the Reporting API, events generated by the Reporting API will now be delivered to the client. Enabling triggers ‘reportingApiReportAdded’ for all existing reports.
- Enable
Reporting ApiParams Builder - Exempted
SetCookie With Reason - A cookie should have been blocked by 3PCD but is exempted and stored from a response with the corresponding reason. A cookie could only have at most one exemption reason.
- Exempted
SetCookie With Reason Builder - Fetch
Schemeful Site Params - Fetches the schemeful site for a specific origin.
- Fetch
Schemeful Site Params Builder - Fetch
Schemeful Site Returns - Fetches the schemeful site for a specific origin.
- Fetch
Schemeful Site Returns Builder - GetAll
Cookies Params - GetAll
Cookies Returns - Returns all browser cookies. Depending on the backend support, will return detailed cookie information in the ‘cookies’ field. Deprecated. Use Storage.getCookies instead.
- GetAll
Cookies Returns Builder - GetCertificate
Params - Returns the DER-encoded certificate.
- GetCertificate
Params Builder - GetCertificate
Returns - Returns the DER-encoded certificate.
- GetCertificate
Returns Builder - GetCookies
Params - Returns all browser cookies for the current URL. Depending on the backend support, will return detailed cookie information in the ‘cookies’ field.
- GetCookies
Params Builder - GetCookies
Returns - Returns all browser cookies for the current URL. Depending on the backend support, will return detailed cookie information in the ‘cookies’ field.
- GetCookies
Returns Builder - GetRequest
Post Data Params - Returns post data sent with the request. Returns an error when no data was sent with the request.
- GetRequest
Post Data Params Builder - GetRequest
Post Data Returns - Returns post data sent with the request. Returns an error when no data was sent with the request.
- GetRequest
Post Data Returns Builder - GetResponse
Body ForInterception Params - Returns content served for the given currently intercepted request.
- GetResponse
Body ForInterception Params Builder - GetResponse
Body ForInterception Returns - Returns content served for the given currently intercepted request.
- GetResponse
Body ForInterception Returns Builder - GetResponse
Body Params - Returns content served for the given request.
- GetResponse
Body Params Builder - GetResponse
Body Returns - Returns content served for the given request.
- GetResponse
Body Returns Builder - GetSecurity
Isolation Status Params - Returns information about the COEP/COOP isolation status.
- GetSecurity
Isolation Status Params Builder - GetSecurity
Isolation Status Returns - Returns information about the COEP/COOP isolation status.
- GetSecurity
Isolation Status Returns Builder - Initiator
- Information about the request initiator.
- Initiator
Builder - Load
Network Resource Options - An options object that may be extended later to better support CORS, CORB and streaming.
- Load
Network Resource Options Builder - Load
Network Resource Page Result - An object providing the result of a network resource load.
- Load
Network Resource Page Result Builder - Load
Network Resource Params - Fetches the resource and returns the content.
- Load
Network Resource Params Builder - Load
Network Resource Returns - Fetches the resource and returns the content.
- Load
Network Resource Returns Builder - Network
Conditions - Network
Conditions Builder - Override
Network State Params - Override the state of navigator.onLine and navigator.connection.
- Override
Network State Params Builder - Post
Data Entry - Post data entry for HTTP request
- Post
Data Entry Builder - Refresh
Event Details - Session event details specific to refresh.
- Refresh
Event Details Builder - ReplayXHR
Params - This method sends a new XMLHttpRequest which is identical to the original one. The following parameters should be identical: method, url, async, request body, extra headers, withCredentials attribute, user, password.
- ReplayXHR
Params Builder - Reporting
ApiEndpoint - Reporting
ApiEndpoint Builder - Reporting
ApiReport - An object representing a report generated by the Reporting API.
- Reporting
ApiReport Builder - Request
- HTTP request data.
- Request
Builder - Request
Pattern - Request pattern for interception.
- Request
Pattern Builder - Resource
Timing - Timing information for the request.
- Resource
Timing Builder - Response
- HTTP response data.
- Response
Builder - Search
InResponse Body Params - Searches for given string in response content.
- Search
InResponse Body Params Builder - Search
InResponse Body Returns - Searches for given string in response content.
- Search
InResponse Body Returns Builder - Security
Details - Security details about a request.
- Security
Details Builder - Security
Isolation Status - Security
Isolation Status Builder - Service
Worker Router Info - Service
Worker Router Info Builder - SetAccepted
Encodings Params - Sets a list of content encodings that will be accepted. Empty list means no encoding is accepted.
- SetAccepted
Encodings Params Builder - SetAttach
Debug Stack Params - Specifies whether to attach a page script stack id in requests
- SetAttach
Debug Stack Params Builder - SetBlockedUR
LsParams - Blocks URLs from loading.
- SetBlockedUR
LsParams Builder - SetBypass
Service Worker Params - Toggles ignoring of service worker for each request.
- SetBypass
Service Worker Params Builder - SetCache
Disabled Params - Toggles ignoring cache for each request. If ‘true’, cache will not be used.
- SetCache
Disabled Params Builder - SetCookie
Controls Params - Sets Controls for third-party cookie access Page reload is required before the new cookie behavior will be observed
- SetCookie
Controls Params Builder - SetCookie
Params - Sets a cookie with the given cookie data; may overwrite equivalent cookies if they exist.
- SetCookie
Params Builder - SetCookie
Returns - Sets a cookie with the given cookie data; may overwrite equivalent cookies if they exist.
- SetCookie
Returns Builder - SetCookies
Params - Sets given cookies.
- SetCookies
Params Builder - SetExtraHTTP
Headers Params - Specifies whether to always send extra HTTP headers with the requests from this page.
- SetExtraHTTP
Headers Params Builder - SetRequest
Interception Params - Sets the requests to intercept that match the provided patterns and optionally resource types. Deprecated, please use Fetch.enable instead.
- SetRequest
Interception Params Builder - SetUser
Agent Override Params - Allows overriding user agent with the given string.
- SetUser
Agent Override Params Builder - Signed
Certificate Timestamp - Details of a signed certificate timestamp (SCT).
- Signed
Certificate Timestamp Builder - Signed
Exchange Error - Information about a signed exchange response.
- Signed
Exchange Error Builder - Signed
Exchange Header - Information about a signed exchange header. https://wicg.github.io/webpackage/draft-yasskin-httpbis-origin-signed-exchanges-impl.html#cbor-representation
- Signed
Exchange Header Builder - Signed
Exchange Info - Information about a signed exchange response.
- Signed
Exchange Info Builder - Signed
Exchange Signature - Information about a signed exchange signature. https://wicg.github.io/webpackage/draft-yasskin-httpbis-origin-signed-exchanges-impl.html#rfc.section.3.1
- Signed
Exchange Signature Builder - Stream
Resource Content Params - Enables streaming of the response for the given requestId. If enabled, the dataReceived event contains the data that was received during streaming.
- Stream
Resource Content Params Builder - Stream
Resource Content Returns - Enables streaming of the response for the given requestId. If enabled, the dataReceived event contains the data that was received during streaming.
- Stream
Resource Content Returns Builder - Take
Response Body ForInterception AsStream Params - Returns a handle to the stream representing the response body. Note that after this command, the intercepted request can’t be continued as is – you either need to cancel it or to provide the response body. The stream only supports sequential read, IO.read will fail if the position is specified.
- Take
Response Body ForInterception AsStream Params Builder - Take
Response Body ForInterception AsStream Returns - Returns a handle to the stream representing the response body. Note that after this command, the intercepted request can’t be continued as is – you either need to cancel it or to provide the response body. The stream only supports sequential read, IO.read will fail if the position is specified.
- Take
Response Body ForInterception AsStream Returns Builder - Termination
Event Details - Session event details specific to termination.
- Termination
Event Details Builder - Trust
Token Params - Determines what type of Trust Token operation is executed and depending on the type, some additional parameters. The values are specified in third_party/blink/renderer/core/fetch/trust_token.idl.
- Trust
Token Params Builder - WebSocket
Frame - WebSocket message data. This represents an entire WebSocket message, not just a fragmented frame as the name suggests.
- WebSocket
Frame Builder - WebSocket
Request - WebSocket request data.
- WebSocket
Request Builder - WebSocket
Response - WebSocket response data.
- WebSocket
Response Builder
Enums
- Alternate
Protocol Usage - The reason why Chrome uses a specific transport protocol for HTTP semantics.
- Blocked
Reason - The reason why request was blocked.
- Certificate
Transparency Compliance - Whether the request complied with Certificate Transparency policy.
- Connection
Type - The underlying connection technology that the browser is supposedly using.
- Content
Encoding - List of content encodings supported by the backend.
- Content
Security Policy Source - Cookie
Blocked Reason - Types of reasons why a cookie may not be sent with a request.
- Cookie
Exemption Reason - Types of reasons why a cookie should have been blocked by 3PCD but is exempted for the request.
- Cookie
Priority - Represents the cookie’s ‘Priority’ status: https://tools.ietf.org/html/draft-west-cookie-priority-00
- Cookie
Same Site - Represents the cookie’s ‘SameSite’ status: https://tools.ietf.org/html/draft-west-first-party-cookies
- Cookie
Source Scheme - Represents the source scheme of the origin that originally set the cookie. A value of “Unset” allows protocol clients to emulate legacy cookie scope for the scheme. This is a temporary ability and it will be removed in the future.
- Cors
Error - The reason why request was blocked.
- Cross
Origin Embedder Policy Value - Cross
Origin Opener Policy Value - Device
Bound Session Fetch Result - A fetch result for a device bound session creation or refresh.
- Direct
Socket DnsQuery Type - Error
Reason - Network level fetch failure reason.
- IPAddress
Space - Interception
Stage - Stages of the interception to begin intercepting. Request will intercept before the request is sent. Response will intercept after the response is received.
- Local
Network Access Request Policy - Render
Blocking Behavior - The render-blocking behavior of a resource request.
- Report
Status - The status of a Reporting API report.
- Resource
Priority - Loading priority of a resource request.
- Resource
Type - Resource type as it was perceived by the rendering engine.
- Service
Worker Response Source - Source of serviceworker response.
- Service
Worker Router Source - Source of service worker router.
- SetCookie
Blocked Reason - Types of reasons why a cookie may not be stored from a response.
- Signed
Exchange Error Field - Field type for a signed exchange related error.
- Trust
Token Operation Type
Type Aliases
- Device
Bound Session Event Id - A unique identifier for a device bound session event.
- Headers
- Request / response headers as keys / values of JSON object.
- Interception
Id - Unique intercepted request identifier.
- Loader
Id - Unique loader identifier.
- Monotonic
Time - Monotonically increasing time in seconds since an arbitrary point in the past.
- Report
Id - Request
Id - Unique network request identifier. Note that this does not identify individual HTTP requests that are part of a network request.
- Time
Since Epoch - UTC time in seconds, counted from January 1, 1970.