pub struct AdAncestry<'a> { /* private fields */ }Expand description
Encapsulates the script ancestry and the root script filter list rule that caused the resource or element to be labeled as an ad.
Implementations
Sourceimpl<'a> AdAncestry<'a>
impl<'a> AdAncestry<'a>
Sourcepub fn builder(
ancestry_chain: Vec<AdScriptIdentifier<'a>>,
) -> AdAncestryBuilder<'a>
pub fn builder( ancestry_chain: Vec<AdScriptIdentifier<'a>>, ) -> AdAncestryBuilder<'a>
Creates a builder for this type with the required parameters:
ancestry_chain: A chain ofAdScriptIdentifiers representing the ancestry of an ad script that led to the creation of a resource or element. The chain is ordered from the script itself (lowest level) up to its root ancestor that was flagged by a filter list.
Sourcepub fn ancestry_chain(&self) -> &[AdScriptIdentifier<'a>]
pub fn ancestry_chain(&self) -> &[AdScriptIdentifier<'a>]
A chain of ’AdScriptIdentifier’s representing the ancestry of an ad script that led to the creation of a resource or element. The chain is ordered from the script itself (lowest level) up to its root ancestor that was flagged by a filter list.
Sourcepub fn root_script_filterlist_rule(&self) -> Option<&str>
pub fn root_script_filterlist_rule(&self) -> Option<&str>
The filter list rule that caused the root (last) script in ‘ancestryChain’ to be tagged as an ad.