AdProvenance

Struct AdProvenance 

pub struct AdProvenance<'a> { /* private fields */ }
Represents the provenance of an ad resource or element. Only one of ‘filterlistRule’ or ‘adScriptAncestry’ can be set. If ‘filterlistRule’ is provided, the resource URL directly matches a filter list rule. If ‘adScriptAncestry’ is provided, an ad script initiated the resource fetch or appended the element to the DOM. If neither is provided, the entity is known to be an ad, but provenance tracking information is unavailable.

Implementations

Source

impl<'a> AdProvenance<'a>

pub fn builder() -> AdProvenanceBuilder<'a>

Creates a builder for this type.

pub fn filterlist_rule(&self) -> Option<&str>

The filterlist rule that matched, if any.

pub fn ad_script_ancestry(&self) -> Option<&AdAncestry<'a>>

The script ancestry that created the ad, if any.