pub struct AssociatedCookie {
pub cookie: Cookie,
pub blockedReasons: Vec<CookieBlockedReason>,
pub exemptionReason: Option<CookieExemptionReason>,
}Expand description
A cookie associated with the request which may or may not be sent with it. Includes the cookies itself and reasons for blocking or exemption.
Fields
The cookie object representing the cookie which was not sent.
blockedReasons: Vec<CookieBlockedReason>The reason(s) the cookie was blocked. If empty means the cookie is included.
exemptionReason: Option<CookieExemptionReason>The reason the cookie should have been blocked by 3PCD but is exempted. A cookie could only have at most one exemption reason.