pub struct AssociatedCookieBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> AssociatedCookieBuilder<'a>
impl<'a> AssociatedCookieBuilder<'a>
Sourcepub fn exemption_reason(
self,
exemption_reason: impl Into<CookieExemptionReason>,
) -> Self
pub fn exemption_reason( self, exemption_reason: impl Into<CookieExemptionReason>, ) -> Self
The reason the cookie should have been blocked by 3PCD but is exempted. A cookie could only have at most one exemption reason.
pub fn build(self) -> AssociatedCookie<'a>