pub struct AuthChallengeResponse<'a> { /* private fields */ }Expand description
Response to an AuthChallenge.
Implementations
Sourceimpl<'a> AuthChallengeResponse<'a>
impl<'a> AuthChallengeResponse<'a>
Sourcepub fn builder(
response: impl Into<Cow<'a, str>>,
) -> AuthChallengeResponseBuilder<'a>
pub fn builder( response: impl Into<Cow<'a, str>>, ) -> AuthChallengeResponseBuilder<'a>
Creates a builder for this type with the required parameters:
response: The decision on what to do in response to the authorization challenge. Default means deferring to the default behavior of the net stack, which will likely either the Cancel authentication or display a popup dialog box.
Sourcepub fn response(&self) -> &str
pub fn response(&self) -> &str
The decision on what to do in response to the authorization challenge. Default means deferring to the default behavior of the net stack, which will likely either the Cancel authentication or display a popup dialog box.