BlockedSetCookieWithReason

Struct BlockedSetCookieWithReason 

pub struct BlockedSetCookieWithReason<'a> { /* private fields */ }
A cookie which was not stored from a response with the corresponding reason.

Implementations

Source

impl<'a> BlockedSetCookieWithReason<'a>

pub fn builder( blocked_reasons: Vec<SetCookieBlockedReason>, cookie_line: impl Into<Cow<'a, str>>, ) -> BlockedSetCookieWithReasonBuilder<'a>

Creates a builder for this type with the required parameters:

  • blocked_reasons: The reason(s) this cookie was blocked.
  • cookie_line: The string representing this individual cookie as it would appear in the header. This is not the entire “cookie” or “set-cookie” header which could have multiple cookies.
pub fn blocked_reasons(&self) -> &[SetCookieBlockedReason]

The reason(s) this cookie was blocked.

pub fn cookie_line(&self) -> &str

The string representing this individual cookie as it would appear in the header. This is not the entire “cookie” or “set-cookie” header which could have multiple cookies.

pub fn cookie(&self) -> Option<&Cookie<'a>>

The cookie object which represents the cookie which was not stored. It is optional because sometimes complete cookie information is not available, such as in the case of parsing errors.