BlockedSetCookieWithReasonBuilder

Struct BlockedSetCookieWithReasonBuilder 

pub struct BlockedSetCookieWithReasonBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> BlockedSetCookieWithReasonBuilder<'a>

pub fn cookie(self, cookie: Cookie<'a>) -> Self

The cookie object which represents the cookie which was not stored. It is optional because sometimes complete cookie information is not available, such as in the case of parsing errors.

pub fn build(self) -> BlockedSetCookieWithReason<'a>