ContinueInterceptedRequestParams

Struct ContinueInterceptedRequestParams 

pub struct ContinueInterceptedRequestParams<'a> { /* private fields */ }
Response to Network.requestIntercepted which either modifies the request to continue with any modifications, or blocks it, or completes it with the provided response bytes. If a network fetch occurs as a result which encounters a redirect an additional Network.requestIntercepted event will be sent with the same InterceptionId. Deprecated, use Fetch.continueRequest, Fetch.fulfillRequest and Fetch.failRequest instead.

Implementations

Source

impl<'a> ContinueInterceptedRequestParams<'a>

pub fn builder( interception_id: impl Into<InterceptionId<'a>>, ) -> ContinueInterceptedRequestParamsBuilder<'a>

Creates a builder for this type with the required parameters:

  • interception_id:
pub fn interception_id(&self) -> &InterceptionId<'a>

pub fn error_reason(&self) -> Option<&ErrorReason>

If set this causes the request to fail with the given reason. Passing ‘Aborted’ for requests marked with ‘isNavigationRequest’ also cancels the navigation. Must not be set in response to an authChallenge.

pub fn raw_response(&self) -> Option<&str>

If set the requests completes using with the provided base64 encoded raw response, including HTTP status line and headers etc… Must not be set in response to an authChallenge. (Encoded as a base64 string when passed over JSON)

pub fn url(&self) -> Option<&str>

If set the request url will be modified in a way that’s not observable by page. Must not be set in response to an authChallenge.

pub fn method(&self) -> Option<&str>

If set this allows the request method to be overridden. Must not be set in response to an authChallenge.

pub fn post_data(&self) -> Option<&str>

If set this allows postData to be set. Must not be set in response to an authChallenge.

pub fn headers(&self) -> Option<&Headers>

If set this allows the request headers to be changed. Must not be set in response to an authChallenge.

pub fn auth_challenge_response(&self) -> Option<&AuthChallengeResponse<'a>>

Response to a requestIntercepted with an authChallenge. Must not be set otherwise.

Source

impl<'a> ContinueInterceptedRequestParams<'a>

pub const METHOD: &'static str = "Network.continueInterceptedRequest"