pub struct ContinueInterceptedRequestParamsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ContinueInterceptedRequestParamsBuilder<'a>
impl<'a> ContinueInterceptedRequestParamsBuilder<'a>
Sourcepub fn error_reason(self, error_reason: impl Into<ErrorReason>) -> Self
pub fn error_reason(self, error_reason: impl Into<ErrorReason>) -> Self
If set this causes the request to fail with the given reason. Passing ‘Aborted’ for requests marked with ‘isNavigationRequest’ also cancels the navigation. Must not be set in response to an authChallenge.
Sourcepub fn raw_response(self, raw_response: impl Into<Cow<'a, str>>) -> Self
pub fn raw_response(self, raw_response: impl Into<Cow<'a, str>>) -> Self
If set the requests completes using with the provided base64 encoded raw response, including HTTP status line and headers etc… Must not be set in response to an authChallenge. (Encoded as a base64 string when passed over JSON)
Sourcepub fn url(self, url: impl Into<Cow<'a, str>>) -> Self
pub fn url(self, url: impl Into<Cow<'a, str>>) -> Self
If set the request url will be modified in a way that’s not observable by page. Must not be set in response to an authChallenge.
Sourcepub fn method(self, method: impl Into<Cow<'a, str>>) -> Self
pub fn method(self, method: impl Into<Cow<'a, str>>) -> Self
If set this allows the request method to be overridden. Must not be set in response to an authChallenge.
Sourcepub fn post_data(self, post_data: impl Into<Cow<'a, str>>) -> Self
pub fn post_data(self, post_data: impl Into<Cow<'a, str>>) -> Self
If set this allows postData to be set. Must not be set in response to an authChallenge.
Sourcepub fn headers(self, headers: Headers) -> Self
pub fn headers(self, headers: Headers) -> Self
If set this allows the request headers to be changed. Must not be set in response to an authChallenge.
Sourcepub fn auth_challenge_response(
self,
auth_challenge_response: AuthChallengeResponse<'a>,
) -> Self
pub fn auth_challenge_response( self, auth_challenge_response: AuthChallengeResponse<'a>, ) -> Self
Response to a requestIntercepted with an authChallenge. Must not be set otherwise.