CookieParamBuilder

Struct CookieParamBuilder 

pub struct CookieParamBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> CookieParamBuilder<'a>

pub fn url(self, url: impl Into<Cow<'a, str>>) -> Self

The request-URI to associate with the setting of the cookie. This value can affect the default domain, path, source port, and source scheme values of the created cookie.

pub fn domain(self, domain: impl Into<Cow<'a, str>>) -> Self

Cookie domain.

pub fn path(self, path: impl Into<Cow<'a, str>>) -> Self

Cookie path.

pub fn secure(self, secure: bool) -> Self

True if cookie is secure.

pub fn httpOnly(self, httpOnly: bool) -> Self

True if cookie is http-only.

pub fn sameSite(self, sameSite: CookieSameSite) -> Self

Cookie SameSite type.

pub fn expires(self, expires: TimeSinceEpoch) -> Self

Cookie expiration date, session cookie if not set

pub fn priority(self, priority: CookiePriority) -> Self

Cookie Priority.

pub fn sourceScheme(self, sourceScheme: CookieSourceScheme) -> Self

Cookie source scheme type.

pub fn sourcePort(self, sourcePort: i64) -> Self

Cookie source port. Valid values are {-1, [1, 65535]}, -1 indicates an unspecified port. An unspecified port value allows protocol clients to emulate legacy cookie scope for the port. This is a temporary ability and it will be removed in the future.

pub fn partitionKey(self, partitionKey: CookiePartitionKey<'a>) -> Self

Cookie partition key. If not set, the cookie will be set as not partitioned.

pub fn build(self) -> CookieParam<'a>