pub struct CookiePartitionKey<'a> { /* private fields */ }Expand description
cookiePartitionKey object The representation of the components of the key that are created by the cookiePartitionKey class contained in net/cookies/cookie_partition_key.h.
Implementations
Sourceimpl<'a> CookiePartitionKey<'a>
impl<'a> CookiePartitionKey<'a>
Sourcepub fn builder(
top_level_site: impl Into<Cow<'a, str>>,
has_cross_site_ancestor: bool,
) -> CookiePartitionKeyBuilder<'a>
pub fn builder( top_level_site: impl Into<Cow<'a, str>>, has_cross_site_ancestor: bool, ) -> CookiePartitionKeyBuilder<'a>
Creates a builder for this type with the required parameters:
top_level_site: The site of the top-level URL the browser was visiting at the start of the request to the endpoint that set the cookie.has_cross_site_ancestor: Indicates if the cookie has any ancestors that are cross-site to the topLevelSite.
Sourcepub fn top_level_site(&self) -> &str
pub fn top_level_site(&self) -> &str
The site of the top-level URL the browser was visiting at the start of the request to the endpoint that set the cookie.
Sourcepub fn has_cross_site_ancestor(&self) -> bool
pub fn has_cross_site_ancestor(&self) -> bool
Indicates if the cookie has any ancestors that are cross-site to the topLevelSite.