pub struct CreationEventDetails {
pub fetchResult: DeviceBoundSessionFetchResult,
pub newSession: Option<DeviceBoundSession>,
pub failedRequest: Option<DeviceBoundSessionFailedRequest>,
}Expand description
Session event details specific to creation.
Fields
fetchResult: DeviceBoundSessionFetchResultThe result of the fetch attempt.
newSession: Option<DeviceBoundSession>The session if there was a newly created session. This is populated for all successful creation events.
failedRequest: Option<DeviceBoundSessionFailedRequest>Details about a failed device bound session network request if there was one.