pub struct CreationEventDetailsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> CreationEventDetailsBuilder<'a>
impl<'a> CreationEventDetailsBuilder<'a>
Sourcepub fn newSession(self, newSession: DeviceBoundSession<'a>) -> Self
pub fn newSession(self, newSession: DeviceBoundSession<'a>) -> Self
The session if there was a newly created session. This is populated for all successful creation events.
Sourcepub fn failedRequest(
self,
failedRequest: DeviceBoundSessionFailedRequest<'a>,
) -> Self
pub fn failedRequest( self, failedRequest: DeviceBoundSessionFailedRequest<'a>, ) -> Self
Details about a failed device bound session network request if there was one.
pub fn build(self) -> CreationEventDetails<'a>