pub struct DeleteCookiesParams<'a> { /* private fields */ }Expand description
Deletes browser cookies with matching name and url or domain/path/partitionKey pair.
Implementations
Sourceimpl<'a> DeleteCookiesParams<'a>
impl<'a> DeleteCookiesParams<'a>
Sourcepub fn builder(name: impl Into<Cow<'a, str>>) -> DeleteCookiesParamsBuilder<'a>
pub fn builder(name: impl Into<Cow<'a, str>>) -> DeleteCookiesParamsBuilder<'a>
Creates a builder for this type with the required parameters:
name: Name of the cookies to remove.
Sourcepub fn url(&self) -> Option<&str>
pub fn url(&self) -> Option<&str>
If specified, deletes all the cookies with the given name where domain and path match provided URL.
Sourcepub fn partition_key(&self) -> Option<&CookiePartitionKey<'a>>
pub fn partition_key(&self) -> Option<&CookiePartitionKey<'a>>
If specified, deletes only cookies with the the given name and partitionKey where all partition key attributes match the cookie partition key attribute.