pub struct DeleteCookiesParamsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> DeleteCookiesParamsBuilder<'a>
impl<'a> DeleteCookiesParamsBuilder<'a>
Sourcepub fn url(self, url: impl Into<Cow<'a, str>>) -> Self
pub fn url(self, url: impl Into<Cow<'a, str>>) -> Self
If specified, deletes all the cookies with the given name where domain and path match provided URL.
Sourcepub fn domain(self, domain: impl Into<Cow<'a, str>>) -> Self
pub fn domain(self, domain: impl Into<Cow<'a, str>>) -> Self
If specified, deletes only cookies with the exact domain.
Sourcepub fn path(self, path: impl Into<Cow<'a, str>>) -> Self
pub fn path(self, path: impl Into<Cow<'a, str>>) -> Self
If specified, deletes only cookies with the exact path.
Sourcepub fn partition_key(self, partition_key: CookiePartitionKey<'a>) -> Self
pub fn partition_key(self, partition_key: CookiePartitionKey<'a>) -> Self
If specified, deletes only cookies with the the given name and partitionKey where all partition key attributes match the cookie partition key attribute.
pub fn build(self) -> DeleteCookiesParams<'a>