pub struct DeviceBoundSessionFailedRequestBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> DeviceBoundSessionFailedRequestBuilder<'a>
impl<'a> DeviceBoundSessionFailedRequestBuilder<'a>
Sourcepub fn netError(self, netError: impl Into<Cow<'a, str>>) -> Self
pub fn netError(self, netError: impl Into<Cow<'a, str>>) -> Self
The net error of the response if it was not OK.
Sourcepub fn responseError(self, responseError: i64) -> Self
pub fn responseError(self, responseError: i64) -> Self
The response code if the net error was OK and the response code was not 200.
Sourcepub fn responseErrorBody(
self,
responseErrorBody: impl Into<Cow<'a, str>>,
) -> Self
pub fn responseErrorBody( self, responseErrorBody: impl Into<Cow<'a, str>>, ) -> Self
The body of the response if the net error was OK, the response code was not 200, and the response body was not empty.
pub fn build(self) -> DeviceBoundSessionFailedRequest<'a>