pub struct DeviceBoundSessionInclusionRules<'a> { /* private fields */ }Expand description
A device bound session’s inclusion rules.
Implementations
Sourceimpl<'a> DeviceBoundSessionInclusionRules<'a>
impl<'a> DeviceBoundSessionInclusionRules<'a>
Sourcepub fn builder(
origin: impl Into<Cow<'a, str>>,
include_site: bool,
url_rules: Vec<DeviceBoundSessionUrlRule<'a>>,
) -> DeviceBoundSessionInclusionRulesBuilder<'a>
pub fn builder( origin: impl Into<Cow<'a, str>>, include_site: bool, url_rules: Vec<DeviceBoundSessionUrlRule<'a>>, ) -> DeviceBoundSessionInclusionRulesBuilder<'a>
Creates a builder for this type with the required parameters:
origin: See comments onnet::device_bound_sessions::SessionInclusionRules::origin_.include_site: Whether the whole site is included. See comments onnet::device_bound_sessions::SessionInclusionRules::include_site_for more details; this boolean is true if that value is populated.url_rules: See comments onnet::device_bound_sessions::SessionInclusionRules::url_rules_.
Sourcepub fn origin(&self) -> &str
pub fn origin(&self) -> &str
See comments on ‘net::device_bound_sessions::SessionInclusionRules::origin_’.
Sourcepub fn include_site(&self) -> bool
pub fn include_site(&self) -> bool
Whether the whole site is included. See comments on ‘net::device_bound_sessions::SessionInclusionRules::include_site_’ for more details; this boolean is true if that value is populated.
Sourcepub fn url_rules(&self) -> &[DeviceBoundSessionUrlRule<'a>]
pub fn url_rules(&self) -> &[DeviceBoundSessionUrlRule<'a>]
See comments on ‘net::device_bound_sessions::SessionInclusionRules::url_rules_’.