pub struct DeviceBoundSessionWithUsage<'a> { /* private fields */ }Expand description
How a device bound session was used during a request.
Implementations
Sourceimpl<'a> DeviceBoundSessionWithUsage<'a>
impl<'a> DeviceBoundSessionWithUsage<'a>
Sourcepub fn builder(
session_key: DeviceBoundSessionKey<'a>,
usage: impl Into<Cow<'a, str>>,
) -> DeviceBoundSessionWithUsageBuilder<'a>
pub fn builder( session_key: DeviceBoundSessionKey<'a>, usage: impl Into<Cow<'a, str>>, ) -> DeviceBoundSessionWithUsageBuilder<'a>
Creates a builder for this type with the required parameters:
session_key: The key for the session.usage: How the session was used (or not used).
Sourcepub fn session_key(&self) -> &DeviceBoundSessionKey<'a>
pub fn session_key(&self) -> &DeviceBoundSessionKey<'a>
The key for the session.