EmulateNetworkConditionsByRuleReturns

Struct EmulateNetworkConditionsByRuleReturns 

pub struct EmulateNetworkConditionsByRuleReturns<'a> { /* private fields */ }
Activates emulation of network conditions for individual requests using URL match patterns. Unlike the deprecated Network.emulateNetworkConditions this method does not affect ‘navigator’ state. Use Network.overrideNetworkState to explicitly modify ‘navigator’ behavior.

Implementations

Source

impl<'a> EmulateNetworkConditionsByRuleReturns<'a>

pub fn builder( rule_ids: Vec<Cow<'a, str>>, ) -> EmulateNetworkConditionsByRuleReturnsBuilder<'a>

Creates a builder for this type with the required parameters:

  • rule_ids: An id for each entry in matchedNetworkConditions. The id will be included in the requestWillBeSentExtraInfo for requests affected by a rule.
pub fn rule_ids(&self) -> &[Cow<'a, str>]

An id for each entry in matchedNetworkConditions. The id will be included in the requestWillBeSentExtraInfo for requests affected by a rule.