EmulateNetworkConditionsParams

Struct EmulateNetworkConditionsParams 

pub struct EmulateNetworkConditionsParams { /* private fields */ }
Activates emulation of network conditions. This command is deprecated in favor of the emulateNetworkConditionsByRule and overrideNetworkState commands, which can be used together to the same effect.

Implementations

Source

impl EmulateNetworkConditionsParams

pub fn builder( offline: bool, latency: f64, download_throughput: f64, upload_throughput: f64, ) -> EmulateNetworkConditionsParamsBuilder

Creates a builder for this type with the required parameters:

  • offline: True to emulate internet disconnection.
  • latency: Minimum latency from request sent to response headers received (ms).
  • download_throughput: Maximal aggregated download throughput (bytes/sec). -1 disables download throttling.
  • upload_throughput: Maximal aggregated upload throughput (bytes/sec). -1 disables upload throttling.
pub fn offline(&self) -> bool

True to emulate internet disconnection.

pub fn latency(&self) -> f64

Minimum latency from request sent to response headers received (ms).

pub fn download_throughput(&self) -> f64

Maximal aggregated download throughput (bytes/sec). -1 disables download throttling.

pub fn upload_throughput(&self) -> f64

Maximal aggregated upload throughput (bytes/sec). -1 disables upload throttling.

pub fn connection_type(&self) -> Option<&ConnectionType>

Connection type if known.

pub fn packet_loss(&self) -> Option<f64>

WebRTC packet loss (percent, 0-100). 0 disables packet loss emulation, 100 drops all the packets.

pub fn packet_queue_length(&self) -> Option<u64>

WebRTC packet queue length (packet). 0 removes any queue length limitations.

pub fn packet_reordering(&self) -> Option<bool>

WebRTC packetReordering feature.

Source

impl EmulateNetworkConditionsParams

pub const METHOD: &'static str = "Network.emulateNetworkConditions"