pub struct EnableParams { /* private fields */ }Expand description
Enables network tracking, network events will now be delivered to the client.
Implementations
Sourceimpl EnableParams
impl EnableParams
Sourcepub fn builder() -> EnableParamsBuilder
pub fn builder() -> EnableParamsBuilder
Creates a builder for this type.
Sourcepub fn max_total_buffer_size(&self) -> Option<u64>
pub fn max_total_buffer_size(&self) -> Option<u64>
Buffer size in bytes to use when preserving network payloads (XHRs, etc). This is the maximum number of bytes that will be collected by this DevTools session.
Sourcepub fn max_resource_buffer_size(&self) -> Option<u64>
pub fn max_resource_buffer_size(&self) -> Option<u64>
Per-resource buffer size in bytes to use when preserving network payloads (XHRs, etc).
Sourcepub fn max_post_data_size(&self) -> Option<u64>
pub fn max_post_data_size(&self) -> Option<u64>
Longest post body size (in bytes) that would be included in requestWillBeSent notification
Sourcepub fn report_direct_socket_traffic(&self) -> Option<bool>
pub fn report_direct_socket_traffic(&self) -> Option<bool>
Whether DirectSocket chunk send/receive events should be reported.
Sourcepub fn enable_durable_messages(&self) -> Option<bool>
pub fn enable_durable_messages(&self) -> Option<bool>
Enable storing response bodies outside of renderer, so that these survive a cross-process navigation. Requires maxTotalBufferSize to be set. Currently defaults to false. This field is being deprecated in favor of the dedicated configureDurableMessages command, due to the possibility of deadlocks when awaiting Network.enable before issuing Runtime.runIfWaitingForDebugger.