EnableParamsBuilder

Struct EnableParamsBuilder 

pub struct EnableParamsBuilder { /* private fields */ }

Implementations

Source

impl EnableParamsBuilder

pub fn max_total_buffer_size(self, max_total_buffer_size: u64) -> Self

Buffer size in bytes to use when preserving network payloads (XHRs, etc). This is the maximum number of bytes that will be collected by this DevTools session.

pub fn max_resource_buffer_size(self, max_resource_buffer_size: u64) -> Self

Per-resource buffer size in bytes to use when preserving network payloads (XHRs, etc).

pub fn max_post_data_size(self, max_post_data_size: u64) -> Self

Longest post body size (in bytes) that would be included in requestWillBeSent notification

pub fn report_direct_socket_traffic( self, report_direct_socket_traffic: bool, ) -> Self

Whether DirectSocket chunk send/receive events should be reported.

pub fn enable_durable_messages(self, enable_durable_messages: bool) -> Self

Enable storing response bodies outside of renderer, so that these survive a cross-process navigation. Requires maxTotalBufferSize to be set. Currently defaults to false. This field is being deprecated in favor of the dedicated configureDurableMessages command, due to the possibility of deadlocks when awaiting Network.enable before issuing Runtime.runIfWaitingForDebugger.

pub fn build(self) -> EnableParams