EnableReportingApiParams

Struct EnableReportingApiParams 

pub struct EnableReportingApiParams { /* private fields */ }
Enables tracking for the Reporting API, events generated by the Reporting API will now be delivered to the client. Enabling triggers ‘reportingApiReportAdded’ for all existing reports.

Implementations

Source

impl EnableReportingApiParams

pub fn builder(enable: bool) -> EnableReportingApiParamsBuilder

Creates a builder for this type with the required parameters:

  • enable: Whether to enable or disable events for the Reporting API
pub fn enable(&self) -> bool

Whether to enable or disable events for the Reporting API

Source

impl EnableReportingApiParams

pub const METHOD: &'static str = "Network.enableReportingApi"