pub struct ExemptedSetCookieWithReason<'a> { /* private fields */ }Expand description
A cookie should have been blocked by 3PCD but is exempted and stored from a response with the corresponding reason. A cookie could only have at most one exemption reason.
Implementations
Sourceimpl<'a> ExemptedSetCookieWithReason<'a>
impl<'a> ExemptedSetCookieWithReason<'a>
Sourcepub fn builder(
exemption_reason: impl Into<CookieExemptionReason>,
cookie_line: impl Into<Cow<'a, str>>,
cookie: Cookie<'a>,
) -> ExemptedSetCookieWithReasonBuilder<'a>
pub fn builder( exemption_reason: impl Into<CookieExemptionReason>, cookie_line: impl Into<Cow<'a, str>>, cookie: Cookie<'a>, ) -> ExemptedSetCookieWithReasonBuilder<'a>
Creates a builder for this type with the required parameters:
exemption_reason: The reason the cookie was exempted.cookie_line: The string representing this individual cookie as it would appear in the header.cookie: The cookie object representing the cookie.
Sourcepub fn exemption_reason(&self) -> &CookieExemptionReason
pub fn exemption_reason(&self) -> &CookieExemptionReason
The reason the cookie was exempted.
The string representing this individual cookie as it would appear in the header.
The cookie object representing the cookie.