GetCookiesParams

Struct GetCookiesParams 

pub struct GetCookiesParams<'a> { /* private fields */ }
Returns all browser cookies for the current URL. Depending on the backend support, will return detailed cookie information in the ‘cookies’ field.

Implementations

Source

impl<'a> GetCookiesParams<'a>

pub fn builder() -> GetCookiesParamsBuilder<'a>

Creates a builder for this type.

pub fn urls(&self) -> Option<&[Cow<'a, str>]>

The list of URLs for which applicable cookies will be fetched. If not specified, it’s assumed to be set to the list containing the URLs of the page and all of its subframes.

Source

impl<'a> GetCookiesParams<'a>

pub const METHOD: &'static str = "Network.getCookies"