GetCookiesParamsBuilder

Struct GetCookiesParamsBuilder 

pub struct GetCookiesParamsBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> GetCookiesParamsBuilder<'a>

pub fn urls(self, urls: Vec<Cow<'a, str>>) -> Self

The list of URLs for which applicable cookies will be fetched. If not specified, it’s assumed to be set to the list containing the URLs of the page and all of its subframes.

pub fn build(self) -> GetCookiesParams<'a>