pub struct GetResponseBodyForInterceptionParams {
pub interceptionId: InterceptionId,
}Expand description
Returns content served for the given currently intercepted request.
Fields
interceptionId: InterceptionIdIdentifier for the intercepted request to get body for.