pub struct InitiatorBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> InitiatorBuilder<'a>
impl<'a> InitiatorBuilder<'a>
Sourcepub fn stack(self, stack: StackTrace) -> Self
pub fn stack(self, stack: StackTrace) -> Self
Initiator JavaScript stack trace, set for Script only. Requires the Debugger domain to be enabled.
Sourcepub fn url(self, url: impl Into<Cow<'a, str>>) -> Self
pub fn url(self, url: impl Into<Cow<'a, str>>) -> Self
Initiator URL, set for Parser type or for Script type (when script is importing module) or for SignedExchange type.
Sourcepub fn lineNumber(self, lineNumber: f64) -> Self
pub fn lineNumber(self, lineNumber: f64) -> Self
Initiator line number, set for Parser type or for Script type (when script is importing module) (0-based).
Sourcepub fn columnNumber(self, columnNumber: f64) -> Self
pub fn columnNumber(self, columnNumber: f64) -> Self
Initiator column number, set for Parser type or for Script type (when script is importing module) (0-based).
Sourcepub fn requestId(self, requestId: RequestId<'a>) -> Self
pub fn requestId(self, requestId: RequestId<'a>) -> Self
Set if another request triggered this request (e.g. preflight).
pub fn build(self) -> Initiator<'a>