pub struct OverrideNetworkStateParams { /* private fields */ }Expand description
Override the state of navigator.onLine and navigator.connection.
Implementations
Sourceimpl OverrideNetworkStateParams
impl OverrideNetworkStateParams
Sourcepub fn builder(
offline: bool,
latency: f64,
download_throughput: f64,
upload_throughput: f64,
) -> OverrideNetworkStateParamsBuilder
pub fn builder( offline: bool, latency: f64, download_throughput: f64, upload_throughput: f64, ) -> OverrideNetworkStateParamsBuilder
Creates a builder for this type with the required parameters:
offline: True to emulate internet disconnection.latency: Minimum latency from request sent to response headers received (ms).download_throughput: Maximal aggregated download throughput (bytes/sec). -1 disables download throttling.upload_throughput: Maximal aggregated upload throughput (bytes/sec). -1 disables upload throttling.
Sourcepub fn latency(&self) -> f64
pub fn latency(&self) -> f64
Minimum latency from request sent to response headers received (ms).
Sourcepub fn download_throughput(&self) -> f64
pub fn download_throughput(&self) -> f64
Maximal aggregated download throughput (bytes/sec). -1 disables download throttling.
Sourcepub fn upload_throughput(&self) -> f64
pub fn upload_throughput(&self) -> f64
Maximal aggregated upload throughput (bytes/sec). -1 disables upload throttling.
Sourcepub fn connection_type(&self) -> Option<&ConnectionType>
pub fn connection_type(&self) -> Option<&ConnectionType>
Connection type if known.