pub struct RefreshEventDetails {
pub refreshResult: String,
pub fetchResult: Option<DeviceBoundSessionFetchResult>,
pub newSession: Option<DeviceBoundSession>,
pub wasFullyProactiveRefresh: bool,
pub failedRequest: Option<DeviceBoundSessionFailedRequest>,
}Expand description
Session event details specific to refresh.
Fields
refreshResult: StringThe result of a refresh.
fetchResult: Option<DeviceBoundSessionFetchResult>If there was a fetch attempt, the result of that.
newSession: Option<DeviceBoundSession>The session display if there was a newly created session. This is populated for any refresh event that modifies the session config.
wasFullyProactiveRefresh: boolSee comments on ‘net::device_bound_sessions::RefreshEventResult::was_fully_proactive_refresh’.
failedRequest: Option<DeviceBoundSessionFailedRequest>Details about a failed device bound session network request if there was one.