pub struct RefreshEventDetailsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> RefreshEventDetailsBuilder<'a>
impl<'a> RefreshEventDetailsBuilder<'a>
Sourcepub fn fetch_result(
self,
fetch_result: impl Into<DeviceBoundSessionFetchResult>,
) -> Self
pub fn fetch_result( self, fetch_result: impl Into<DeviceBoundSessionFetchResult>, ) -> Self
If there was a fetch attempt, the result of that.
Sourcepub fn new_session(self, new_session: DeviceBoundSession<'a>) -> Self
pub fn new_session(self, new_session: DeviceBoundSession<'a>) -> Self
The session display if there was a newly created session. This is populated for any refresh event that modifies the session config.
Sourcepub fn failed_request(
self,
failed_request: DeviceBoundSessionFailedRequest<'a>,
) -> Self
pub fn failed_request( self, failed_request: DeviceBoundSessionFailedRequest<'a>, ) -> Self
Details about a failed device bound session network request if there was one.
pub fn build(self) -> RefreshEventDetails<'a>