RequestBuilder

Struct RequestBuilder 

pub struct RequestBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> RequestBuilder<'a>

pub fn url_fragment(self, url_fragment: impl Into<Cow<'a, str>>) -> Self

Fragment of the requested URL starting with hash, if present.

pub fn post_data(self, post_data: impl Into<Cow<'a, str>>) -> Self

HTTP POST request data. Use postDataEntries instead.

pub fn has_post_data(self, has_post_data: bool) -> Self

True when the request has POST data. Note that postData might still be omitted when this flag is true when the data is too long.

pub fn post_data_entries( self, post_data_entries: Vec<PostDataEntry<'a>>, ) -> Self

Request body elements (post data broken into individual entries).

pub fn mixed_content_type(self, mixed_content_type: MixedContentType) -> Self

The mixed content type of the request.

Whether is loaded via link preload.

pub fn trust_token_params( self, trust_token_params: TrustTokenParams<'a>, ) -> Self

Set for requests when the TrustToken API is used. Contains the parameters passed by the developer (e.g. via “fetch”) as understood by the backend.

pub fn is_same_site(self, is_same_site: bool) -> Self

True if this resource request is considered to be the ‘same site’ as the request corresponding to the main frame.

True when the resource request is ad-related.

pub fn build(self) -> Request<'a>