pub struct ResponseBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ResponseBuilder<'a>
impl<'a> ResponseBuilder<'a>
Sourcepub fn headers_text(self, headers_text: impl Into<Cow<'a, str>>) -> Self
pub fn headers_text(self, headers_text: impl Into<Cow<'a, str>>) -> Self
HTTP response headers text. This has been replaced by the headers in Network.responseReceivedExtraInfo.
Sourcepub fn request_headers(self, request_headers: Headers) -> Self
pub fn request_headers(self, request_headers: Headers) -> Self
Refined HTTP request headers that were actually transmitted over the network.
Sourcepub fn request_headers_text(
self,
request_headers_text: impl Into<Cow<'a, str>>,
) -> Self
pub fn request_headers_text( self, request_headers_text: impl Into<Cow<'a, str>>, ) -> Self
HTTP request headers text. This has been replaced by the headers in Network.requestWillBeSentExtraInfo.
Sourcepub fn remote_ip_address(
self,
remote_ip_address: impl Into<Cow<'a, str>>,
) -> Self
pub fn remote_ip_address( self, remote_ip_address: impl Into<Cow<'a, str>>, ) -> Self
Remote IP address.
Sourcepub fn remote_port(self, remote_port: i64) -> Self
pub fn remote_port(self, remote_port: i64) -> Self
Remote port.
Sourcepub fn from_disk_cache(self, from_disk_cache: bool) -> Self
pub fn from_disk_cache(self, from_disk_cache: bool) -> Self
Specifies that the request was served from the disk cache.
Sourcepub fn from_service_worker(self, from_service_worker: bool) -> Self
pub fn from_service_worker(self, from_service_worker: bool) -> Self
Specifies that the request was served from the ServiceWorker.
Sourcepub fn from_prefetch_cache(self, from_prefetch_cache: bool) -> Self
pub fn from_prefetch_cache(self, from_prefetch_cache: bool) -> Self
Specifies that the request was served from the prefetch cache.
Sourcepub fn from_early_hints(self, from_early_hints: bool) -> Self
pub fn from_early_hints(self, from_early_hints: bool) -> Self
Specifies that the request was served from the prefetch cache.
Sourcepub fn service_worker_router_info(
self,
service_worker_router_info: ServiceWorkerRouterInfo,
) -> Self
pub fn service_worker_router_info( self, service_worker_router_info: ServiceWorkerRouterInfo, ) -> Self
Information about how ServiceWorker Static Router API was used. If this field is set with ‘matchedSourceType’ field, a matching rule is found. If this field is set without ‘matchedSource’, no matching rule is found. Otherwise, the API is not used.
Sourcepub fn timing(self, timing: ResourceTiming) -> Self
pub fn timing(self, timing: ResourceTiming) -> Self
Timing information for the given request.
Sourcepub fn service_worker_response_source(
self,
service_worker_response_source: impl Into<ServiceWorkerResponseSource>,
) -> Self
pub fn service_worker_response_source( self, service_worker_response_source: impl Into<ServiceWorkerResponseSource>, ) -> Self
Response source of response from ServiceWorker.
Sourcepub fn response_time(self, response_time: TimeSinceEpoch) -> Self
pub fn response_time(self, response_time: TimeSinceEpoch) -> Self
The time at which the returned response was generated.
Sourcepub fn cache_storage_cache_name(
self,
cache_storage_cache_name: impl Into<Cow<'a, str>>,
) -> Self
pub fn cache_storage_cache_name( self, cache_storage_cache_name: impl Into<Cow<'a, str>>, ) -> Self
Cache Storage Cache Name.
Sourcepub fn protocol(self, protocol: impl Into<Cow<'a, str>>) -> Self
pub fn protocol(self, protocol: impl Into<Cow<'a, str>>) -> Self
Protocol used to fetch this request.
Sourcepub fn alternate_protocol_usage(
self,
alternate_protocol_usage: impl Into<AlternateProtocolUsage>,
) -> Self
pub fn alternate_protocol_usage( self, alternate_protocol_usage: impl Into<AlternateProtocolUsage>, ) -> Self
The reason why Chrome uses a specific transport protocol for HTTP semantics.
Sourcepub fn security_details(self, security_details: SecurityDetails<'a>) -> Self
pub fn security_details(self, security_details: SecurityDetails<'a>) -> Self
Security details for the request.