pub struct SecurityDetails<'a> { /* private fields */ }Expand description
Security details about a request.
Implementations
Sourceimpl<'a> SecurityDetails<'a>
impl<'a> SecurityDetails<'a>
Sourcepub fn builder(
protocol: impl Into<Cow<'a, str>>,
key_exchange: impl Into<Cow<'a, str>>,
cipher: impl Into<Cow<'a, str>>,
certificate_id: CertificateId,
subject_name: impl Into<Cow<'a, str>>,
san_list: Vec<Cow<'a, str>>,
issuer: impl Into<Cow<'a, str>>,
valid_from: TimeSinceEpoch,
valid_to: TimeSinceEpoch,
signed_certificate_timestamp_list: Vec<SignedCertificateTimestamp<'a>>,
certificate_transparency_compliance: impl Into<CertificateTransparencyCompliance>,
encrypted_client_hello: bool,
) -> SecurityDetailsBuilder<'a>
pub fn builder( protocol: impl Into<Cow<'a, str>>, key_exchange: impl Into<Cow<'a, str>>, cipher: impl Into<Cow<'a, str>>, certificate_id: CertificateId, subject_name: impl Into<Cow<'a, str>>, san_list: Vec<Cow<'a, str>>, issuer: impl Into<Cow<'a, str>>, valid_from: TimeSinceEpoch, valid_to: TimeSinceEpoch, signed_certificate_timestamp_list: Vec<SignedCertificateTimestamp<'a>>, certificate_transparency_compliance: impl Into<CertificateTransparencyCompliance>, encrypted_client_hello: bool, ) -> SecurityDetailsBuilder<'a>
Creates a builder for this type with the required parameters:
protocol: Protocol name (e.g. “TLS 1.2” or “QUIC”).key_exchange: Key Exchange used by the connection, or the empty string if not applicable.cipher: Cipher name.certificate_id: Certificate ID value.subject_name: Certificate subject name.san_list: Subject Alternative Name (SAN) DNS names and IP addresses.issuer: Name of the issuing CA.valid_from: Certificate valid from date.valid_to: Certificate valid to (expiration) datesigned_certificate_timestamp_list: List of signed certificate timestamps (SCTs).certificate_transparency_compliance: Whether the request complied with Certificate Transparency policyencrypted_client_hello: Whether the connection used Encrypted ClientHello
Sourcepub fn key_exchange(&self) -> &str
pub fn key_exchange(&self) -> &str
Key Exchange used by the connection, or the empty string if not applicable.
Sourcepub fn key_exchange_group(&self) -> Option<&str>
pub fn key_exchange_group(&self) -> Option<&str>
(EC)DH group used by the connection, if applicable.
Sourcepub fn certificate_id(&self) -> &CertificateId
pub fn certificate_id(&self) -> &CertificateId
Certificate ID value.
Sourcepub fn subject_name(&self) -> &str
pub fn subject_name(&self) -> &str
Certificate subject name.
Sourcepub fn san_list(&self) -> &[Cow<'a, str>]
pub fn san_list(&self) -> &[Cow<'a, str>]
Subject Alternative Name (SAN) DNS names and IP addresses.
Sourcepub fn valid_from(&self) -> &TimeSinceEpoch
pub fn valid_from(&self) -> &TimeSinceEpoch
Certificate valid from date.
Sourcepub fn valid_to(&self) -> &TimeSinceEpoch
pub fn valid_to(&self) -> &TimeSinceEpoch
Certificate valid to (expiration) date
Sourcepub fn signed_certificate_timestamp_list(
&self,
) -> &[SignedCertificateTimestamp<'a>]
pub fn signed_certificate_timestamp_list( &self, ) -> &[SignedCertificateTimestamp<'a>]
List of signed certificate timestamps (SCTs).
Sourcepub fn certificate_transparency_compliance(
&self,
) -> &CertificateTransparencyCompliance
pub fn certificate_transparency_compliance( &self, ) -> &CertificateTransparencyCompliance
Whether the request complied with Certificate Transparency policy
Sourcepub fn server_signature_algorithm(&self) -> Option<i64>
pub fn server_signature_algorithm(&self) -> Option<i64>
The signature algorithm used by the server in the TLS server signature, represented as a TLS SignatureScheme code point. Omitted if not applicable or not known.
Sourcepub fn encrypted_client_hello(&self) -> bool
pub fn encrypted_client_hello(&self) -> bool
Whether the connection used Encrypted ClientHello