pub struct ServiceWorkerRouterInfoBuilder { /* private fields */ }Implementations
Sourceimpl ServiceWorkerRouterInfoBuilder
impl ServiceWorkerRouterInfoBuilder
Sourcepub fn rule_id_matched(self, rule_id_matched: u64) -> Self
pub fn rule_id_matched(self, rule_id_matched: u64) -> Self
ID of the rule matched. If there is a matched rule, this field will be set, otherwiser no value will be set.
Sourcepub fn matched_source_type(
self,
matched_source_type: impl Into<ServiceWorkerRouterSource>,
) -> Self
pub fn matched_source_type( self, matched_source_type: impl Into<ServiceWorkerRouterSource>, ) -> Self
The router source of the matched rule. If there is a matched rule, this field will be set, otherwise no value will be set.
Sourcepub fn actual_source_type(
self,
actual_source_type: impl Into<ServiceWorkerRouterSource>,
) -> Self
pub fn actual_source_type( self, actual_source_type: impl Into<ServiceWorkerRouterSource>, ) -> Self
The actual router source used.
pub fn build(self) -> ServiceWorkerRouterInfo