pub struct SetBlockedURLsParams {
pub urlPatterns: Option<Vec<BlockPattern>>,
pub urls: Option<Vec<String>>,
}Expand description
Blocks URLs from loading.
Fields
urlPatterns: Option<Vec<BlockPattern>>Patterns to match in the order in which they are given. These patterns also take precedence over any wildcard patterns defined in ‘urls’.
urls: Option<Vec<String>>URL patterns to block. Wildcards (‘*’) are allowed.