SetBlockedURLsParamsBuilder

Struct SetBlockedURLsParamsBuilder 

pub struct SetBlockedURLsParamsBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> SetBlockedURLsParamsBuilder<'a>

pub fn url_patterns(self, url_patterns: Vec<BlockPattern<'a>>) -> Self

Patterns to match in the order in which they are given. These patterns also take precedence over any wildcard patterns defined in ‘urls’.

pub fn urls(self, urls: Vec<Cow<'a, str>>) -> Self

URL patterns to block. Wildcards (‘*’) are allowed.

pub fn build(self) -> SetBlockedURLsParams<'a>