SetCookieParams

Struct SetCookieParams 

pub struct SetCookieParams<'a> { /* private fields */ }
Sets a cookie with the given cookie data; may overwrite equivalent cookies if they exist.

Implementations

Source

impl<'a> SetCookieParams<'a>

pub fn builder( name: impl Into<Cow<'a, str>>, value: impl Into<Cow<'a, str>>, ) -> SetCookieParamsBuilder<'a>

Creates a builder for this type with the required parameters:

  • name: Cookie name.
  • value: Cookie value.
pub fn name(&self) -> &str

Cookie name.

pub fn value(&self) -> &str

Cookie value.

pub fn url(&self) -> Option<&str>

The request-URI to associate with the setting of the cookie. This value can affect the default domain, path, source port, and source scheme values of the created cookie.

pub fn domain(&self) -> Option<&str>

Cookie domain.

pub fn path(&self) -> Option<&str>

Cookie path.

pub fn secure(&self) -> Option<bool>

True if cookie is secure.

pub fn http_only(&self) -> Option<bool>

True if cookie is http-only.

pub fn same_site(&self) -> Option<&CookieSameSite>

Cookie SameSite type.

pub fn expires(&self) -> Option<&TimeSinceEpoch>

Cookie expiration date, session cookie if not set

pub fn priority(&self) -> Option<&CookiePriority>

Cookie Priority type.

pub fn source_scheme(&self) -> Option<&CookieSourceScheme>

Cookie source scheme type.

pub fn source_port(&self) -> Option<i64>

Cookie source port. Valid values are {-1, [1, 65535]}, -1 indicates an unspecified port. An unspecified port value allows protocol clients to emulate legacy cookie scope for the port. This is a temporary ability and it will be removed in the future.

pub fn partition_key(&self) -> Option<&CookiePartitionKey<'a>>

Cookie partition key. If not set, the cookie will be set as not partitioned.

Source

impl<'a> SetCookieParams<'a>

pub const METHOD: &'static str = "Network.setCookie"