pub struct SetCookieParamsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> SetCookieParamsBuilder<'a>
impl<'a> SetCookieParamsBuilder<'a>
Sourcepub fn url(self, url: impl Into<Cow<'a, str>>) -> Self
pub fn url(self, url: impl Into<Cow<'a, str>>) -> Self
The request-URI to associate with the setting of the cookie. This value can affect the default domain, path, source port, and source scheme values of the created cookie.
Sourcepub fn same_site(self, same_site: impl Into<CookieSameSite>) -> Self
pub fn same_site(self, same_site: impl Into<CookieSameSite>) -> Self
Cookie SameSite type.
Sourcepub fn expires(self, expires: TimeSinceEpoch) -> Self
pub fn expires(self, expires: TimeSinceEpoch) -> Self
Cookie expiration date, session cookie if not set
Sourcepub fn priority(self, priority: impl Into<CookiePriority>) -> Self
pub fn priority(self, priority: impl Into<CookiePriority>) -> Self
Cookie Priority type.
Sourcepub fn source_scheme(self, source_scheme: impl Into<CookieSourceScheme>) -> Self
pub fn source_scheme(self, source_scheme: impl Into<CookieSourceScheme>) -> Self
Cookie source scheme type.
Sourcepub fn source_port(self, source_port: i64) -> Self
pub fn source_port(self, source_port: i64) -> Self
Cookie source port. Valid values are {-1, [1, 65535]}, -1 indicates an unspecified port. An unspecified port value allows protocol clients to emulate legacy cookie scope for the port. This is a temporary ability and it will be removed in the future.
Sourcepub fn partition_key(self, partition_key: CookiePartitionKey<'a>) -> Self
pub fn partition_key(self, partition_key: CookiePartitionKey<'a>) -> Self
Cookie partition key. If not set, the cookie will be set as not partitioned.
pub fn build(self) -> SetCookieParams<'a>