pub struct SetRequestInterceptionParams {
pub patterns: Vec<RequestPattern>,
}Expand description
Sets the requests to intercept that match the provided patterns and optionally resource types. Deprecated, please use Fetch.enable instead.
Fields
patterns: Vec<RequestPattern>Requests matching any of these patterns will be forwarded and wait for the corresponding continueInterceptedRequest call.
Implementations