pub struct SignedCertificateTimestamp<'a> { /* private fields */ }Expand description
Details of a signed certificate timestamp (SCT).
Implementations
Sourceimpl<'a> SignedCertificateTimestamp<'a>
impl<'a> SignedCertificateTimestamp<'a>
Sourcepub fn builder(
status: impl Into<Cow<'a, str>>,
origin: impl Into<Cow<'a, str>>,
log_description: impl Into<Cow<'a, str>>,
log_id: impl Into<Cow<'a, str>>,
timestamp: f64,
hash_algorithm: impl Into<Cow<'a, str>>,
signature_algorithm: impl Into<Cow<'a, str>>,
signature_data: impl Into<Cow<'a, str>>,
) -> SignedCertificateTimestampBuilder<'a>
pub fn builder( status: impl Into<Cow<'a, str>>, origin: impl Into<Cow<'a, str>>, log_description: impl Into<Cow<'a, str>>, log_id: impl Into<Cow<'a, str>>, timestamp: f64, hash_algorithm: impl Into<Cow<'a, str>>, signature_algorithm: impl Into<Cow<'a, str>>, signature_data: impl Into<Cow<'a, str>>, ) -> SignedCertificateTimestampBuilder<'a>
Creates a builder for this type with the required parameters:
status: Validation status.origin: Origin.log_description: Log name / description.log_id: Log ID.timestamp: Issuance date. Unlike TimeSinceEpoch, this contains the number of milliseconds since January 1, 1970, UTC, not the number of seconds.hash_algorithm: Hash algorithm.signature_algorithm: Signature algorithm.signature_data: Signature data.
Sourcepub fn log_description(&self) -> &str
pub fn log_description(&self) -> &str
Log name / description.
Sourcepub fn timestamp(&self) -> f64
pub fn timestamp(&self) -> f64
Issuance date. Unlike TimeSinceEpoch, this contains the number of milliseconds since January 1, 1970, UTC, not the number of seconds.
Sourcepub fn hash_algorithm(&self) -> &str
pub fn hash_algorithm(&self) -> &str
Hash algorithm.
Sourcepub fn signature_algorithm(&self) -> &str
pub fn signature_algorithm(&self) -> &str
Signature algorithm.
Sourcepub fn signature_data(&self) -> &str
pub fn signature_data(&self) -> &str
Signature data.