pub struct SignedExchangeSignature<'a> { /* private fields */ }Expand description
Information about a signed exchange signature. https://wicg.github.io/webpackage/draft-yasskin-httpbis-origin-signed-exchanges-impl.html#rfc.section.3.1
Implementations
Sourceimpl<'a> SignedExchangeSignature<'a>
impl<'a> SignedExchangeSignature<'a>
Sourcepub fn builder(
label: impl Into<Cow<'a, str>>,
signature: impl Into<Cow<'a, str>>,
integrity: impl Into<Cow<'a, str>>,
validity_url: impl Into<Cow<'a, str>>,
date: i64,
expires: i64,
) -> SignedExchangeSignatureBuilder<'a>
pub fn builder( label: impl Into<Cow<'a, str>>, signature: impl Into<Cow<'a, str>>, integrity: impl Into<Cow<'a, str>>, validity_url: impl Into<Cow<'a, str>>, date: i64, expires: i64, ) -> SignedExchangeSignatureBuilder<'a>
Creates a builder for this type with the required parameters:
label: Signed exchange signature label.signature: The hex string of signed exchange signature.integrity: Signed exchange signature integrity.validity_url: Signed exchange signature validity Url.date: Signed exchange signature date.expires: Signed exchange signature expires.
Sourcepub fn cert_sha256(&self) -> Option<&str>
pub fn cert_sha256(&self) -> Option<&str>
The hex string of signed exchange signature cert sha256.
Sourcepub fn validity_url(&self) -> &str
pub fn validity_url(&self) -> &str
Signed exchange signature validity Url.
Sourcepub fn certificates(&self) -> Option<&[Cow<'a, str>]>
pub fn certificates(&self) -> Option<&[Cow<'a, str>]>
The encoded certificates.