pub struct StreamResourceContentReturns {
pub bufferedData: String,
}Expand description
Enables streaming of the response for the given requestId. If enabled, the dataReceived event contains the data that was received during streaming.
Fields
bufferedData: StringData that has been buffered until streaming is enabled. (Encoded as a base64 string when passed over JSON)