pub struct TakeResponseBodyForInterceptionAsStreamParams<'a> { /* private fields */ }Expand description
Returns a handle to the stream representing the response body. Note that after this command, the intercepted request can’t be continued as is – you either need to cancel it or to provide the response body. The stream only supports sequential read, IO.read will fail if the position is specified.
Implementations
Sourceimpl<'a> TakeResponseBodyForInterceptionAsStreamParams<'a>
impl<'a> TakeResponseBodyForInterceptionAsStreamParams<'a>
pub fn builder( interceptionId: InterceptionId<'a>, ) -> TakeResponseBodyForInterceptionAsStreamParamsBuilder<'a>
pub fn interceptionId(&self) -> &InterceptionId<'a>