pub struct TakeResponseBodyForInterceptionAsStreamReturns {
pub stream: StreamHandle,
}Expand description
Returns a handle to the stream representing the response body. Note that after this command, the intercepted request can’t be continued as is – you either need to cancel it or to provide the response body. The stream only supports sequential read, IO.read will fail if the position is specified.
Fields
stream: StreamHandleTrait Implementations
Sourceimpl Clone for TakeResponseBodyForInterceptionAsStreamReturns
impl Clone for TakeResponseBodyForInterceptionAsStreamReturns
Sourcefn clone(&self) -> TakeResponseBodyForInterceptionAsStreamReturns
fn clone(&self) -> TakeResponseBodyForInterceptionAsStreamReturns
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for TakeResponseBodyForInterceptionAsStreamReturns
impl Default for TakeResponseBodyForInterceptionAsStreamReturns
Sourcefn default() -> TakeResponseBodyForInterceptionAsStreamReturns
fn default() -> TakeResponseBodyForInterceptionAsStreamReturns
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for TakeResponseBodyForInterceptionAsStreamReturns
impl<'de> Deserialize<'de> for TakeResponseBodyForInterceptionAsStreamReturns
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more