pub struct TrustTokenParams<'a> { /* private fields */ }Expand description
Determines what type of Trust Token operation is executed and depending on the type, some additional parameters. The values are specified in third_party/blink/renderer/core/fetch/trust_token.idl.
Implementations
Sourceimpl<'a> TrustTokenParams<'a>
impl<'a> TrustTokenParams<'a>
Sourcepub fn builder(
operation: impl Into<TrustTokenOperationType>,
refresh_policy: impl Into<Cow<'a, str>>,
) -> TrustTokenParamsBuilder<'a>
pub fn builder( operation: impl Into<TrustTokenOperationType>, refresh_policy: impl Into<Cow<'a, str>>, ) -> TrustTokenParamsBuilder<'a>
Creates a builder for this type with the required parameters:
operation:refresh_policy: Only set for “token-redemption” operation and determine whether to request a fresh SRR or use a still valid cached SRR.
pub fn operation(&self) -> &TrustTokenOperationType
Sourcepub fn refresh_policy(&self) -> &str
pub fn refresh_policy(&self) -> &str
Only set for “token-redemption” operation and determine whether to request a fresh SRR or use a still valid cached SRR.