Module overlay

Module overlay 

This domain provides various functionality related to drawing atop the inspected page.

Structs

BoxStyle
Style information for drawing a box.
BoxStyleBuilder
ContainerQueryContainerHighlightConfig
ContainerQueryContainerHighlightConfigBuilder
ContainerQueryHighlightConfig
ContainerQueryHighlightConfigBuilder
DisableParams
EnableParams
FlexContainerHighlightConfig
Configuration data for the highlighting of Flex container elements.
FlexContainerHighlightConfigBuilder
FlexItemHighlightConfig
Configuration data for the highlighting of Flex item elements.
FlexItemHighlightConfigBuilder
FlexNodeHighlightConfig
FlexNodeHighlightConfigBuilder
GetGridHighlightObjectsForTestParams
For Persistent Grid testing.
GetGridHighlightObjectsForTestParamsBuilder
GetGridHighlightObjectsForTestReturns
For Persistent Grid testing.
GetGridHighlightObjectsForTestReturnsBuilder
GetHighlightObjectForTestParams
For testing.
GetHighlightObjectForTestParamsBuilder
GetHighlightObjectForTestReturns
For testing.
GetHighlightObjectForTestReturnsBuilder
GetSourceOrderHighlightObjectForTestParams
For Source Order Viewer testing.
GetSourceOrderHighlightObjectForTestParamsBuilder
GetSourceOrderHighlightObjectForTestReturns
For Source Order Viewer testing.
GetSourceOrderHighlightObjectForTestReturnsBuilder
GridHighlightConfig
Configuration data for the highlighting of Grid elements.
GridHighlightConfigBuilder
GridNodeHighlightConfig
Configurations for Persistent Grid Highlight
GridNodeHighlightConfigBuilder
HideHighlightParams
HighlightConfig
Configuration data for the highlighting of page elements.
HighlightConfigBuilder
HighlightFrameParams
Highlights owner element of the frame with given id. Deprecated: Doesn’t work reliably and cannot be fixed due to process separation (the owner node might be in a different process). Determine the owner node in the client and use highlightNode.
HighlightFrameParamsBuilder
HighlightNodeParams
Highlights DOM node with given id or with the given JavaScript object wrapper. Either nodeId or objectId must be specified.
HighlightNodeParamsBuilder
HighlightQuadParams
Highlights given quad. Coordinates are absolute with respect to the main frame viewport.
HighlightQuadParamsBuilder
HighlightRectParams
Highlights given rectangle. Coordinates are absolute with respect to the main frame viewport. Issue: the method does not handle device pixel ratio (DPR) correctly. The coordinates currently have to be adjusted by the client if DPR is not 1 (see crbug.com/437807128).
HighlightRectParamsBuilder
HighlightSourceOrderParams
Highlights the source order of the children of the DOM node with given id or with the given JavaScript object wrapper. Either nodeId or objectId must be specified.
HighlightSourceOrderParamsBuilder
HingeConfig
Configuration for dual screen hinge
HingeConfigBuilder
InspectedElementAnchorConfig
InspectedElementAnchorConfigBuilder
IsolatedElementHighlightConfig
IsolatedElementHighlightConfigBuilder
IsolationModeHighlightConfig
IsolationModeHighlightConfigBuilder
LineStyle
Style information for drawing a line.
LineStyleBuilder
ScrollSnapContainerHighlightConfig
ScrollSnapContainerHighlightConfigBuilder
ScrollSnapHighlightConfig
ScrollSnapHighlightConfigBuilder
SetInspectModeParams
Enters the ‘inspect’ mode. In this mode, elements that user is hovering over are highlighted. Backend then generates ‘inspectNodeRequested’ event upon element selection.
SetInspectModeParamsBuilder
SetPausedInDebuggerMessageParams
SetPausedInDebuggerMessageParamsBuilder
SetShowAdHighlightsParams
Highlights owner element of all frames detected to be ads.
SetShowAdHighlightsParamsBuilder
SetShowContainerQueryOverlaysParams
SetShowContainerQueryOverlaysParamsBuilder
SetShowDebugBordersParams
Requests that backend shows debug borders on layers
SetShowDebugBordersParamsBuilder
SetShowFPSCounterParams
Requests that backend shows the FPS counter
SetShowFPSCounterParamsBuilder
SetShowFlexOverlaysParams
SetShowFlexOverlaysParamsBuilder
SetShowGridOverlaysParams
Highlight multiple elements with the CSS Grid overlay.
SetShowGridOverlaysParamsBuilder
SetShowHingeParams
Add a dual screen device hinge
SetShowHingeParamsBuilder
SetShowHitTestBordersParams
Deprecated, no longer has any effect.
SetShowHitTestBordersParamsBuilder
SetShowInspectedElementAnchorParams
SetShowInspectedElementAnchorParamsBuilder
SetShowIsolatedElementsParams
Show elements in isolation mode with overlays.
SetShowIsolatedElementsParamsBuilder
SetShowLayoutShiftRegionsParams
Requests that backend shows layout shift regions
SetShowLayoutShiftRegionsParamsBuilder
SetShowPaintRectsParams
Requests that backend shows paint rectangles
SetShowPaintRectsParamsBuilder
SetShowScrollBottleneckRectsParams
Requests that backend shows scroll bottleneck rects
SetShowScrollBottleneckRectsParamsBuilder
SetShowScrollSnapOverlaysParams
SetShowScrollSnapOverlaysParamsBuilder
SetShowViewportSizeOnResizeParams
Paints viewport size upon main frame resize.
SetShowViewportSizeOnResizeParamsBuilder
SetShowWebVitalsParams
Deprecated, no longer has any effect.
SetShowWebVitalsParamsBuilder
SetShowWindowControlsOverlayParams
Show Window Controls Overlay for PWA
SetShowWindowControlsOverlayParamsBuilder
SourceOrderConfig
Configuration data for drawing the source order of an elements children.
SourceOrderConfigBuilder
WindowControlsOverlayConfig
Configuration for Window Controls Overlay
WindowControlsOverlayConfigBuilder

Enums

ColorFormat
ContrastAlgorithm
InspectMode