pub struct FlexContainerHighlightConfig<'a> { /* private fields */ }Expand description
Configuration data for the highlighting of Flex container elements.
Implementations
Sourceimpl<'a> FlexContainerHighlightConfig<'a>
impl<'a> FlexContainerHighlightConfig<'a>
Sourcepub fn builder() -> FlexContainerHighlightConfigBuilder<'a>
pub fn builder() -> FlexContainerHighlightConfigBuilder<'a>
Creates a builder for this type.
Sourcepub fn container_border(&self) -> Option<&LineStyle<'a>>
pub fn container_border(&self) -> Option<&LineStyle<'a>>
The style of the container border
Sourcepub fn line_separator(&self) -> Option<&LineStyle<'a>>
pub fn line_separator(&self) -> Option<&LineStyle<'a>>
The style of the separator between lines
Sourcepub fn item_separator(&self) -> Option<&LineStyle<'a>>
pub fn item_separator(&self) -> Option<&LineStyle<'a>>
The style of the separator between items
Sourcepub fn main_distributed_space(&self) -> Option<&BoxStyle>
pub fn main_distributed_space(&self) -> Option<&BoxStyle>
Style of content-distribution space on the main axis (justify-content).
Sourcepub fn cross_distributed_space(&self) -> Option<&BoxStyle>
pub fn cross_distributed_space(&self) -> Option<&BoxStyle>
Style of content-distribution space on the cross axis (align-content).
Sourcepub fn row_gap_space(&self) -> Option<&BoxStyle>
pub fn row_gap_space(&self) -> Option<&BoxStyle>
Style of empty space caused by row gaps (gap/row-gap).
Sourcepub fn column_gap_space(&self) -> Option<&BoxStyle>
pub fn column_gap_space(&self) -> Option<&BoxStyle>
Style of empty space caused by columns gaps (gap/column-gap).
Sourcepub fn cross_alignment(&self) -> Option<&LineStyle<'a>>
pub fn cross_alignment(&self) -> Option<&LineStyle<'a>>
Style of the self-alignment line (align-items).