FlexContainerHighlightConfigBuilder

Struct FlexContainerHighlightConfigBuilder 

pub struct FlexContainerHighlightConfigBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> FlexContainerHighlightConfigBuilder<'a>

pub fn container_border(self, container_border: LineStyle<'a>) -> Self

The style of the container border

pub fn line_separator(self, line_separator: LineStyle<'a>) -> Self

The style of the separator between lines

pub fn item_separator(self, item_separator: LineStyle<'a>) -> Self

The style of the separator between items

pub fn main_distributed_space(self, main_distributed_space: BoxStyle) -> Self

Style of content-distribution space on the main axis (justify-content).

pub fn cross_distributed_space(self, cross_distributed_space: BoxStyle) -> Self

Style of content-distribution space on the cross axis (align-content).

pub fn row_gap_space(self, row_gap_space: BoxStyle) -> Self

Style of empty space caused by row gaps (gap/row-gap).

pub fn column_gap_space(self, column_gap_space: BoxStyle) -> Self

Style of empty space caused by columns gaps (gap/column-gap).

pub fn cross_alignment(self, cross_alignment: LineStyle<'a>) -> Self

Style of the self-alignment line (align-items).

pub fn build(self) -> FlexContainerHighlightConfig<'a>