pub struct FlexItemHighlightConfig<'a> { /* private fields */ }Expand description
Configuration data for the highlighting of Flex item elements.
Implementations
Sourceimpl<'a> FlexItemHighlightConfig<'a>
impl<'a> FlexItemHighlightConfig<'a>
Sourcepub fn builder() -> FlexItemHighlightConfigBuilder<'a>
pub fn builder() -> FlexItemHighlightConfigBuilder<'a>
Creates a builder for this type.
Sourcepub fn base_size_box(&self) -> Option<&BoxStyle>
pub fn base_size_box(&self) -> Option<&BoxStyle>
Style of the box representing the item’s base size
Sourcepub fn base_size_border(&self) -> Option<&LineStyle<'a>>
pub fn base_size_border(&self) -> Option<&LineStyle<'a>>
Style of the border around the box representing the item’s base size
Sourcepub fn flexibility_arrow(&self) -> Option<&LineStyle<'a>>
pub fn flexibility_arrow(&self) -> Option<&LineStyle<'a>>
Style of the arrow representing if the item grew or shrank