pub struct FlexNodeHighlightConfig<'a> { /* private fields */ }Implementations
Sourceimpl<'a> FlexNodeHighlightConfig<'a>
impl<'a> FlexNodeHighlightConfig<'a>
Sourcepub fn builder(
flex_container_highlight_config: FlexContainerHighlightConfig<'a>,
node_id: NodeId,
) -> FlexNodeHighlightConfigBuilder<'a>
pub fn builder( flex_container_highlight_config: FlexContainerHighlightConfig<'a>, node_id: NodeId, ) -> FlexNodeHighlightConfigBuilder<'a>
Creates a builder for this type with the required parameters:
flex_container_highlight_config: A descriptor for the highlight appearance of flex containers.node_id: Identifier of the node to highlight.
Sourcepub fn flex_container_highlight_config(
&self,
) -> &FlexContainerHighlightConfig<'a>
pub fn flex_container_highlight_config( &self, ) -> &FlexContainerHighlightConfig<'a>
A descriptor for the highlight appearance of flex containers.