pub struct GetHighlightObjectForTestParams { /* private fields */ }Expand description
For testing.
Implementations
Sourceimpl GetHighlightObjectForTestParams
impl GetHighlightObjectForTestParams
Sourcepub fn builder(node_id: NodeId) -> GetHighlightObjectForTestParamsBuilder
pub fn builder(node_id: NodeId) -> GetHighlightObjectForTestParamsBuilder
Creates a builder for this type with the required parameters:
node_id: Id of the node to get highlight object for.
Sourcepub fn include_distance(&self) -> Option<bool>
pub fn include_distance(&self) -> Option<bool>
Whether to include distance info.
Sourcepub fn include_style(&self) -> Option<bool>
pub fn include_style(&self) -> Option<bool>
Whether to include style info.
Sourcepub fn color_format(&self) -> Option<&ColorFormat>
pub fn color_format(&self) -> Option<&ColorFormat>
The color format to get config with (default: hex).
Sourcepub fn show_accessibility_info(&self) -> Option<bool>
pub fn show_accessibility_info(&self) -> Option<bool>
Whether to show accessibility info (default: true).