pub struct HighlightConfig<'a> { /* private fields */ }Expand description
Configuration data for the highlighting of page elements.
Implementations
Sourceimpl<'a> HighlightConfig<'a>
impl<'a> HighlightConfig<'a>
Sourcepub fn builder() -> HighlightConfigBuilder<'a>
pub fn builder() -> HighlightConfigBuilder<'a>
Creates a builder for this type.
Sourcepub fn show_info(&self) -> Option<bool>
pub fn show_info(&self) -> Option<bool>
Whether the node info tooltip should be shown (default: false).
Sourcepub fn show_styles(&self) -> Option<bool>
pub fn show_styles(&self) -> Option<bool>
Whether the node styles in the tooltip (default: false).
Sourcepub fn show_rulers(&self) -> Option<bool>
pub fn show_rulers(&self) -> Option<bool>
Whether the rulers should be shown (default: false).
Sourcepub fn show_accessibility_info(&self) -> Option<bool>
pub fn show_accessibility_info(&self) -> Option<bool>
Whether the a11y info should be shown (default: true).
Sourcepub fn show_extension_lines(&self) -> Option<bool>
pub fn show_extension_lines(&self) -> Option<bool>
Whether the extension lines from node to the rulers should be shown (default: false).
Sourcepub fn content_color(&self) -> Option<&RGBA>
pub fn content_color(&self) -> Option<&RGBA>
The content box highlight fill color (default: transparent).
Sourcepub fn padding_color(&self) -> Option<&RGBA>
pub fn padding_color(&self) -> Option<&RGBA>
The padding highlight fill color (default: transparent).
Sourcepub fn border_color(&self) -> Option<&RGBA>
pub fn border_color(&self) -> Option<&RGBA>
The border highlight fill color (default: transparent).
Sourcepub fn margin_color(&self) -> Option<&RGBA>
pub fn margin_color(&self) -> Option<&RGBA>
The margin highlight fill color (default: transparent).
Sourcepub fn event_target_color(&self) -> Option<&RGBA>
pub fn event_target_color(&self) -> Option<&RGBA>
The event target element highlight fill color (default: transparent).
Sourcepub fn shape_color(&self) -> Option<&RGBA>
pub fn shape_color(&self) -> Option<&RGBA>
The shape outside fill color (default: transparent).
Sourcepub fn shape_margin_color(&self) -> Option<&RGBA>
pub fn shape_margin_color(&self) -> Option<&RGBA>
The shape margin fill color (default: transparent).
Sourcepub fn css_grid_color(&self) -> Option<&RGBA>
pub fn css_grid_color(&self) -> Option<&RGBA>
The grid layout color (default: transparent).
Sourcepub fn color_format(&self) -> Option<&ColorFormat>
pub fn color_format(&self) -> Option<&ColorFormat>
The color format used to format color styles (default: hex).
Sourcepub fn grid_highlight_config(&self) -> Option<&GridHighlightConfig>
pub fn grid_highlight_config(&self) -> Option<&GridHighlightConfig>
The grid layout highlight configuration (default: all transparent).
Sourcepub fn flex_container_highlight_config(
&self,
) -> Option<&FlexContainerHighlightConfig<'a>>
pub fn flex_container_highlight_config( &self, ) -> Option<&FlexContainerHighlightConfig<'a>>
The flex container highlight configuration (default: all transparent).
Sourcepub fn flex_item_highlight_config(&self) -> Option<&FlexItemHighlightConfig<'a>>
pub fn flex_item_highlight_config(&self) -> Option<&FlexItemHighlightConfig<'a>>
The flex item highlight configuration (default: all transparent).
Sourcepub fn contrast_algorithm(&self) -> Option<&ContrastAlgorithm>
pub fn contrast_algorithm(&self) -> Option<&ContrastAlgorithm>
The contrast algorithm to use for the contrast ratio (default: aa).
Sourcepub fn container_query_container_highlight_config(
&self,
) -> Option<&ContainerQueryContainerHighlightConfig<'a>>
pub fn container_query_container_highlight_config( &self, ) -> Option<&ContainerQueryContainerHighlightConfig<'a>>
The container query container highlight configuration (default: all transparent).