HighlightConfigBuilder

Struct HighlightConfigBuilder 

pub struct HighlightConfigBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> HighlightConfigBuilder<'a>

pub fn show_info(self, show_info: bool) -> Self

Whether the node info tooltip should be shown (default: false).

pub fn show_styles(self, show_styles: bool) -> Self

Whether the node styles in the tooltip (default: false).

pub fn show_rulers(self, show_rulers: bool) -> Self

Whether the rulers should be shown (default: false).

pub fn show_accessibility_info(self, show_accessibility_info: bool) -> Self

Whether the a11y info should be shown (default: true).

pub fn show_extension_lines(self, show_extension_lines: bool) -> Self

Whether the extension lines from node to the rulers should be shown (default: false).

pub fn content_color(self, content_color: RGBA) -> Self

The content box highlight fill color (default: transparent).

pub fn padding_color(self, padding_color: RGBA) -> Self

The padding highlight fill color (default: transparent).

pub fn border_color(self, border_color: RGBA) -> Self

The border highlight fill color (default: transparent).

pub fn margin_color(self, margin_color: RGBA) -> Self

The margin highlight fill color (default: transparent).

pub fn event_target_color(self, event_target_color: RGBA) -> Self

The event target element highlight fill color (default: transparent).

pub fn shape_color(self, shape_color: RGBA) -> Self

The shape outside fill color (default: transparent).

pub fn shape_margin_color(self, shape_margin_color: RGBA) -> Self

The shape margin fill color (default: transparent).

pub fn css_grid_color(self, css_grid_color: RGBA) -> Self

The grid layout color (default: transparent).

pub fn color_format(self, color_format: impl Into<ColorFormat>) -> Self

The color format used to format color styles (default: hex).

pub fn grid_highlight_config( self, grid_highlight_config: GridHighlightConfig, ) -> Self

The grid layout highlight configuration (default: all transparent).

pub fn flex_container_highlight_config( self, flex_container_highlight_config: FlexContainerHighlightConfig<'a>, ) -> Self

The flex container highlight configuration (default: all transparent).

pub fn flex_item_highlight_config( self, flex_item_highlight_config: FlexItemHighlightConfig<'a>, ) -> Self

The flex item highlight configuration (default: all transparent).

pub fn contrast_algorithm( self, contrast_algorithm: impl Into<ContrastAlgorithm>, ) -> Self

The contrast algorithm to use for the contrast ratio (default: aa).

pub fn container_query_container_highlight_config( self, container_query_container_highlight_config: ContainerQueryContainerHighlightConfig<'a>, ) -> Self

The container query container highlight configuration (default: all transparent).

pub fn build(self) -> HighlightConfig<'a>