pub struct HighlightFrameParams<'a> { /* private fields */ }Expand description
Highlights owner element of the frame with given id. Deprecated: Doesn’t work reliably and cannot be fixed due to process separation (the owner node might be in a different process). Determine the owner node in the client and use highlightNode.
Implementations
Sourceimpl<'a> HighlightFrameParams<'a>
impl<'a> HighlightFrameParams<'a>
pub fn builder(frameId: FrameId<'a>) -> HighlightFrameParamsBuilder<'a>
pub fn frameId(&self) -> &FrameId<'a>
pub fn contentColor(&self) -> Option<&RGBA>
pub fn contentOutlineColor(&self) -> Option<&RGBA>