pub struct HighlightNodeParams {
pub highlightConfig: HighlightConfig,
pub nodeId: Option<NodeId>,
pub backendNodeId: Option<BackendNodeId>,
pub objectId: Option<RemoteObjectId>,
pub selector: Option<String>,
}Expand description
Highlights DOM node with given id or with the given JavaScript object wrapper. Either nodeId or objectId must be specified.
Fields
highlightConfig: HighlightConfigA descriptor for the highlight appearance.
nodeId: Option<NodeId>Identifier of the node to highlight.
backendNodeId: Option<BackendNodeId>Identifier of the backend node to highlight.
objectId: Option<RemoteObjectId>JavaScript object id of the node to be highlighted.
selector: Option<String>Selectors to highlight relevant nodes.