pub struct HighlightRectParams {
pub x: i32,
pub y: i32,
pub width: u64,
pub height: i64,
pub color: Option<RGBA>,
pub outlineColor: Option<RGBA>,
}Expand description
Highlights given rectangle. Coordinates are absolute with respect to the main frame viewport. Issue: the method does not handle device pixel ratio (DPR) correctly. The coordinates currently have to be adjusted by the client if DPR is not 1 (see crbug.com/437807128).
Fields
x: i32X coordinate
y: i32Y coordinate
width: u64Rectangle width
height: i64Rectangle height
color: Option<RGBA>The highlight fill color (default: transparent).
outlineColor: Option<RGBA>The highlight outline color (default: transparent).
Implementations