pub struct HighlightSourceOrderParams<'a> { /* private fields */ }Expand description
Highlights the source order of the children of the DOM node with given id or with the given JavaScript object wrapper. Either nodeId or objectId must be specified.
Implementations
Sourceimpl<'a> HighlightSourceOrderParams<'a>
impl<'a> HighlightSourceOrderParams<'a>
Sourcepub fn builder(
source_order_config: SourceOrderConfig,
) -> HighlightSourceOrderParamsBuilder<'a>
pub fn builder( source_order_config: SourceOrderConfig, ) -> HighlightSourceOrderParamsBuilder<'a>
Creates a builder for this type with the required parameters:
source_order_config: A descriptor for the appearance of the overlay drawing.
Sourcepub fn source_order_config(&self) -> &SourceOrderConfig
pub fn source_order_config(&self) -> &SourceOrderConfig
A descriptor for the appearance of the overlay drawing.
Sourcepub fn backend_node_id(&self) -> Option<&BackendNodeId>
pub fn backend_node_id(&self) -> Option<&BackendNodeId>
Identifier of the backend node to highlight.
Sourcepub fn object_id(&self) -> Option<&RemoteObjectId<'a>>
pub fn object_id(&self) -> Option<&RemoteObjectId<'a>>
JavaScript object id of the node to be highlighted.