pub struct IsolatedElementHighlightConfig { /* private fields */ }Implementations
Sourceimpl IsolatedElementHighlightConfig
impl IsolatedElementHighlightConfig
Sourcepub fn builder(
isolation_mode_highlight_config: IsolationModeHighlightConfig,
node_id: NodeId,
) -> IsolatedElementHighlightConfigBuilder
pub fn builder( isolation_mode_highlight_config: IsolationModeHighlightConfig, node_id: NodeId, ) -> IsolatedElementHighlightConfigBuilder
Creates a builder for this type with the required parameters:
isolation_mode_highlight_config: A descriptor for the highlight appearance of an element in isolation mode.node_id: Identifier of the isolated element to highlight.
Sourcepub fn isolation_mode_highlight_config(&self) -> &IsolationModeHighlightConfig
pub fn isolation_mode_highlight_config(&self) -> &IsolationModeHighlightConfig
A descriptor for the highlight appearance of an element in isolation mode.