pub struct SetShowContainerQueryOverlaysParams<'a> { /* private fields */ }Implementations
Sourceimpl<'a> SetShowContainerQueryOverlaysParams<'a>
impl<'a> SetShowContainerQueryOverlaysParams<'a>
Sourcepub fn builder(
container_query_highlight_configs: Vec<ContainerQueryHighlightConfig<'a>>,
) -> SetShowContainerQueryOverlaysParamsBuilder<'a>
pub fn builder( container_query_highlight_configs: Vec<ContainerQueryHighlightConfig<'a>>, ) -> SetShowContainerQueryOverlaysParamsBuilder<'a>
Creates a builder for this type with the required parameters:
container_query_highlight_configs: An array of node identifiers and descriptors for the highlight appearance.
Sourcepub fn container_query_highlight_configs(
&self,
) -> &[ContainerQueryHighlightConfig<'a>]
pub fn container_query_highlight_configs( &self, ) -> &[ContainerQueryHighlightConfig<'a>]
An array of node identifiers and descriptors for the highlight appearance.