pub struct SetShowIsolatedElementsParams { /* private fields */ }Expand description
Show elements in isolation mode with overlays.
Implementations
Sourceimpl SetShowIsolatedElementsParams
impl SetShowIsolatedElementsParams
Sourcepub fn builder(
isolated_element_highlight_configs: Vec<IsolatedElementHighlightConfig>,
) -> SetShowIsolatedElementsParamsBuilder
pub fn builder( isolated_element_highlight_configs: Vec<IsolatedElementHighlightConfig>, ) -> SetShowIsolatedElementsParamsBuilder
Creates a builder for this type with the required parameters:
isolated_element_highlight_configs: An array of node identifiers and descriptors for the highlight appearance.
Sourcepub fn isolated_element_highlight_configs(
&self,
) -> &[IsolatedElementHighlightConfig]
pub fn isolated_element_highlight_configs( &self, ) -> &[IsolatedElementHighlightConfig]
An array of node identifiers and descriptors for the highlight appearance.