pub struct SetShowScrollSnapOverlaysParams<'a> { /* private fields */ }Implementations
Sourceimpl<'a> SetShowScrollSnapOverlaysParams<'a>
impl<'a> SetShowScrollSnapOverlaysParams<'a>
Sourcepub fn builder(
scroll_snap_highlight_configs: Vec<ScrollSnapHighlightConfig<'a>>,
) -> SetShowScrollSnapOverlaysParamsBuilder<'a>
pub fn builder( scroll_snap_highlight_configs: Vec<ScrollSnapHighlightConfig<'a>>, ) -> SetShowScrollSnapOverlaysParamsBuilder<'a>
Creates a builder for this type with the required parameters:
scroll_snap_highlight_configs: An array of node identifiers and descriptors for the highlight appearance.
Sourcepub fn scroll_snap_highlight_configs(&self) -> &[ScrollSnapHighlightConfig<'a>]
pub fn scroll_snap_highlight_configs(&self) -> &[ScrollSnapHighlightConfig<'a>]
An array of node identifiers and descriptors for the highlight appearance.