pub struct WindowControlsOverlayConfig<'a> { /* private fields */ }Expand description
Configuration for Window Controls Overlay
Implementations
Sourceimpl<'a> WindowControlsOverlayConfig<'a>
impl<'a> WindowControlsOverlayConfig<'a>
Sourcepub fn builder(
show_css: bool,
selected_platform: impl Into<Cow<'a, str>>,
theme_color: impl Into<Cow<'a, str>>,
) -> WindowControlsOverlayConfigBuilder<'a>
pub fn builder( show_css: bool, selected_platform: impl Into<Cow<'a, str>>, theme_color: impl Into<Cow<'a, str>>, ) -> WindowControlsOverlayConfigBuilder<'a>
Creates a builder for this type with the required parameters:
show_css: Whether the title bar CSS should be shown when emulating the Window Controls Overlay.selected_platform: Selected platforms to show the overlay.theme_color: The theme color defined in app manifest.
Sourcepub fn show_css(&self) -> bool
pub fn show_css(&self) -> bool
Whether the title bar CSS should be shown when emulating the Window Controls Overlay.
Sourcepub fn selected_platform(&self) -> &str
pub fn selected_platform(&self) -> &str
Selected platforms to show the overlay.
Sourcepub fn theme_color(&self) -> &str
pub fn theme_color(&self) -> &str
The theme color defined in app manifest.