Actions and events related to the inspected page belong to the page domain.
Structs
- AdFrame
Status - Indicates whether a frame has been identified as an ad and why.
- AddCompilation
Cache Params - Seeds compilation cache for given url. Compilation cache does not survive cross-process navigation.
- AddScript
ToEvaluate OnLoad Params - Deprecated, please use addScriptToEvaluateOnNewDocument instead.
- AddScript
ToEvaluate OnLoad Returns - Deprecated, please use addScriptToEvaluateOnNewDocument instead.
- AddScript
ToEvaluate OnNew Document Params - Evaluates given script in every frame upon creation (before loading frame’s scripts).
- AddScript
ToEvaluate OnNew Document Returns - Evaluates given script in every frame upon creation (before loading frame’s scripts).
- AppManifest
Error - Error while paring app manifest.
- AppManifest
Parsed Properties - Parsed app manifest properties.
- Back
Forward Cache Blocking Details - Back
Forward Cache NotRestored Explanation - Back
Forward Cache NotRestored Explanation Tree - Bring
ToFront Params - Capture
Screenshot Params - Capture page screenshot.
- Capture
Screenshot Returns - Capture page screenshot.
- Capture
Snapshot Params - Returns a snapshot of the page as a string. For MHTML format, the serialization includes iframes, shadow DOM, external resources, and element-inline styles.
- Capture
Snapshot Returns - Returns a snapshot of the page as a string. For MHTML format, the serialization includes iframes, shadow DOM, external resources, and element-inline styles.
- Clear
Compilation Cache Params - Clear
Device Metrics Override Params - Clear
Device Orientation Override Params - Clear
Geolocation Override Params - Close
Params - Compilation
Cache Params - Per-script compilation cache parameters for ‘Page.produceCompilationCache’
- Crash
Params - Create
Isolated World Params - Creates an isolated world for the given frame.
- Create
Isolated World Returns - Creates an isolated world for the given frame.
- Delete
Cookie Params - Deletes browser cookie with given name, domain and path.
- Disable
Params - Enable
Params - Enables page domain notifications.
- File
Filter - File
Handler - Font
Families - Generic font families collection.
- Font
Sizes - Default font sizes.
- Frame
- Information about the Frame on the page.
- Frame
Resource - Information about the Resource on the page.
- Frame
Resource Tree - Information about the Frame hierarchy along with their cached resources.
- Frame
Tree - Information about the Frame hierarchy.
- Generate
Test Report Params - Generates a report for testing.
- GetAd
Script Ancestry Params - GetAd
Script Ancestry Returns - GetAnnotated
Page Content Params - Get the annotated page content for the main frame. This is an experimental command that is subject to change.
- GetAnnotated
Page Content Returns - Get the annotated page content for the main frame. This is an experimental command that is subject to change.
- GetApp
IdParams - GetApp
IdReturns - Returns the unique (PWA) app id. Only returns values if the feature flag ‘WebAppEnableManifestId’ is enabled
- GetApp
Manifest Params - Gets the processed manifest for this current document. This API always waits for the manifest to be loaded. If manifestId is provided, and it does not match the manifest of the current document, this API errors out. If there is not a loaded page, this API errors out immediately.
- GetApp
Manifest Returns - Gets the processed manifest for this current document. This API always waits for the manifest to be loaded. If manifestId is provided, and it does not match the manifest of the current document, this API errors out. If there is not a loaded page, this API errors out immediately.
- GetFrame
Tree Params - GetFrame
Tree Returns - Returns present frame tree structure.
- GetInstallability
Errors Params - GetInstallability
Errors Returns - GetLayout
Metrics Params - GetLayout
Metrics Returns - Returns metrics relating to the layouting of the page, such as viewport bounds/scale.
- GetManifest
Icons Params - GetManifest
Icons Returns - Deprecated because it’s not guaranteed that the returned icon is in fact the one used for PWA installation.
- GetNavigation
History Params - GetNavigation
History Returns - Returns navigation history for the current page.
- GetOrigin
Trials Params - Get Origin Trials on given frame.
- GetOrigin
Trials Returns - Get Origin Trials on given frame.
- GetPermissions
Policy State Params - Get Permissions Policy state on given frame.
- GetPermissions
Policy State Returns - Get Permissions Policy state on given frame.
- GetResource
Content Params - Returns content of the given resource.
- GetResource
Content Returns - Returns content of the given resource.
- GetResource
Tree Params - GetResource
Tree Returns - Returns present frame / resource tree structure.
- Handle
Java Script Dialog Params - Accepts or dismisses a JavaScript initiated dialog (alert, confirm, prompt, or onbeforeunload).
- Image
Resource - The image definition used in both icon and screenshot.
- Installability
Error - The installability error
- Installability
Error Argument - Launch
Handler - Layout
Viewport - Layout viewport position and dimensions.
- Navigate
Params - Navigates current page to the given URL.
- Navigate
Returns - Navigates current page to the given URL.
- Navigate
ToHistory Entry Params - Navigates current page to the given history entry.
- Navigation
Entry - Navigation history entry.
- Origin
Trial - Origin
Trial Token - Origin
Trial Token With Status - Permissions
Policy Block Locator - Permissions
Policy Feature State - Print
ToPDF Params - Print page as PDF.
- Print
ToPDF Returns - Print page as PDF.
- Produce
Compilation Cache Params - Requests backend to produce compilation cache for the specified scripts. ‘scripts’ are appended to the list of scripts for which the cache would be produced. The list may be reset during page navigation. When script with a matching URL is encountered, the cache is optionally produced upon backend discretion, based on internal heuristics. See also: ‘Page.compilationCacheProduced’.
- Protocol
Handler - Related
Application - Reload
Params - Reloads given page optionally ignoring the cache.
- Remove
Script ToEvaluate OnLoad Params - Deprecated, please use removeScriptToEvaluateOnNewDocument instead.
- Remove
Script ToEvaluate OnNew Document Params - Removes given script from the list.
- Reset
Navigation History Params - Scope
Extension - Screencast
Frame AckParams - Acknowledges that a screencast frame has been received by the frontend.
- Screencast
Frame Metadata - Screencast frame metadata.
- Screenshot
- Script
Font Families - Font families collection for a script.
- Search
InResource Params - Searches for given string in resource content.
- Search
InResource Returns - Searches for given string in resource content.
- Security
Origin Details - Additional information about the frame document’s security origin.
- SetAd
Blocking Enabled Params - Enable Chrome’s experimental ad filter on all sites.
- SetBypassCSP
Params - Enable page Content Security Policy by-passing.
- SetDevice
Metrics Override Params - Overrides the values of device screen dimensions (window.screen.width, window.screen.height, window.innerWidth, window.innerHeight, and “device-width”/“device-height”-related CSS media query results).
- SetDevice
Orientation Override Params - Overrides the Device Orientation.
- SetDocument
Content Params - Sets given markup as the document’s HTML.
- SetDownload
Behavior Params - Set the behavior when downloading a file.
- SetFont
Families Params - Set generic font families.
- SetFont
Sizes Params - Set default font sizes.
- SetGeolocation
Override Params - Overrides the Geolocation Position or Error. Omitting any of the parameters emulates position unavailable.
- SetIntercept
File Chooser Dialog Params - Intercept file chooser requests and transfer control to protocol clients. When file chooser interception is enabled, native file chooser dialog is not shown. Instead, a protocol event ‘Page.fileChooserOpened’ is emitted.
- SetLifecycle
Events Enabled Params - Controls whether page will emit lifecycle events.
- SetPrerendering
Allowed Params - Enable/disable prerendering manually.
- SetRPH
Registration Mode Params - Extensions for Custom Handlers API: https://html.spec.whatwg.org/multipage/system-state.html#rph-automation
- SetSPC
Transaction Mode Params - Sets the Secure Payment Confirmation transaction mode. https://w3c.github.io/secure-payment-confirmation/#sctn-automation-set-spc-transaction-mode
- SetTouch
Emulation Enabled Params - Toggles mouse event-based touch event emulation.
- SetWeb
Lifecycle State Params - Tries to update the web lifecycle state of the page. It will transition the page to the given state according to: https://github.com/WICG/web-lifecycle/
- Share
Target - Shortcut
- Start
Screencast Params - Starts sending each frame using the ‘screencastFrame’ event.
- Stop
Loading Params - Stop
Screencast Params - Viewport
- Viewport for capturing screenshot.
- Visual
Viewport - Visual viewport position, dimensions, and scale.
- Wait
ForDebugger Params - WebApp
Manifest
Enums
- AdFrame
Explanation - AdFrame
Type - Indicates whether a frame has been identified as an ad.
- Back
Forward Cache NotRestored Reason - List of not restored reasons for back-forward cache.
- Back
Forward Cache NotRestored Reason Type - Types of not restored reasons for back-forward cache.
- Client
Navigation Disposition - Client
Navigation Reason - Cross
Origin Isolated Context Type - Indicates whether the frame is cross-origin isolated and why it is the case.
- Dialog
Type - Javascript dialog type.
- GatedAPI
Features - Navigation
Type - The type of a frameNavigated event.
- Origin
Trial Status - Status for an Origin Trial.
- Origin
Trial Token Status - Origin Trial(https://www.chromium.org/blink/origin-trials) support. Status for an Origin Trial token.
- Origin
Trial Usage Restriction - Permissions
Policy Block Reason - Reason for a permissions policy feature to be disabled.
- Permissions
Policy Feature - All Permissions Policy features. This enum should match the one defined in services/network/public/cpp/permissions_policy/permissions_policy_features.json5. LINT.IfChange(PermissionsPolicyFeature)
- Referrer
Policy - The referring-policy used for the navigation.
- Secure
Context Type - Indicates whether the frame is a secure context and why it is the case.
- Transition
Type - Transition type.
Type Aliases
- FrameId
- Unique frame identifier.
- Script
Identifier - Unique script identifier.