pub struct AdFrameStatus { /* private fields */ }Expand description
Indicates whether a frame has been identified as an ad and why.
Implementations
Sourceimpl AdFrameStatus
impl AdFrameStatus
Sourcepub fn builder(ad_frame_type: impl Into<AdFrameType>) -> AdFrameStatusBuilder
pub fn builder(ad_frame_type: impl Into<AdFrameType>) -> AdFrameStatusBuilder
Creates a builder for this type with the required parameters:
ad_frame_type:
pub fn ad_frame_type(&self) -> &AdFrameType
pub fn explanations(&self) -> Option<&[AdFrameExplanation]>