pub struct AddScriptToEvaluateOnNewDocumentParams {
pub source: String,
pub worldName: Option<String>,
pub includeCommandLineAPI: Option<bool>,
pub runImmediately: Option<bool>,
}Expand description
Evaluates given script in every frame upon creation (before loading frame’s scripts).
Fields
source: StringworldName: Option<String>If specified, creates an isolated world with the given name and evaluates given script in it. This world name will be used as the ExecutionContextDescription::name when the corresponding event is emitted.
includeCommandLineAPI: Option<bool>Specifies whether command line API should be available to the script, defaults to false.
runImmediately: Option<bool>If true, runs the script immediately on existing execution contexts or worlds. Default: false.