AddScriptToEvaluateOnNewDocumentParamsBuilder

Struct AddScriptToEvaluateOnNewDocumentParamsBuilder 

pub struct AddScriptToEvaluateOnNewDocumentParamsBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> AddScriptToEvaluateOnNewDocumentParamsBuilder<'a>

pub fn world_name(self, world_name: impl Into<Cow<'a, str>>) -> Self

If specified, creates an isolated world with the given name and evaluates given script in it. This world name will be used as the ExecutionContextDescription::name when the corresponding event is emitted.

pub fn include_command_line_api(self, include_command_line_api: bool) -> Self

Specifies whether command line API should be available to the script, defaults to false.

pub fn run_immediately(self, run_immediately: bool) -> Self

If true, runs the script immediately on existing execution contexts or worlds. Default: false.

pub fn build(self) -> AddScriptToEvaluateOnNewDocumentParams<'a>