pub struct CaptureScreenshotParamsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> CaptureScreenshotParamsBuilder<'a>
impl<'a> CaptureScreenshotParamsBuilder<'a>
Sourcepub fn format(self, format: impl Into<Cow<'a, str>>) -> Self
pub fn format(self, format: impl Into<Cow<'a, str>>) -> Self
Image compression format (defaults to png).
Sourcepub fn quality(self, quality: i64) -> Self
pub fn quality(self, quality: i64) -> Self
Compression quality from range [0..100] (jpeg only).
Sourcepub fn from_surface(self, from_surface: bool) -> Self
pub fn from_surface(self, from_surface: bool) -> Self
Capture the screenshot from the surface, rather than the view. Defaults to true.
Sourcepub fn capture_beyond_viewport(self, capture_beyond_viewport: bool) -> Self
pub fn capture_beyond_viewport(self, capture_beyond_viewport: bool) -> Self
Capture the screenshot beyond the viewport. Defaults to false.
Sourcepub fn optimize_for_speed(self, optimize_for_speed: bool) -> Self
pub fn optimize_for_speed(self, optimize_for_speed: bool) -> Self
Optimize image encoding for speed, not for resulting size (defaults to false)
pub fn build(self) -> CaptureScreenshotParams<'a>