pub struct CompilationCacheParams {
pub url: String,
pub eager: Option<bool>,
}Expand description
Per-script compilation cache parameters for ‘Page.produceCompilationCache’
Fields
url: StringThe URL of the script to produce a compilation cache entry for.
eager: Option<bool>A hint to the backend whether eager compilation is recommended. (the actual compilation mode used is upon backend discretion).