pub struct CreateIsolatedWorldParamsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> CreateIsolatedWorldParamsBuilder<'a>
impl<'a> CreateIsolatedWorldParamsBuilder<'a>
Sourcepub fn worldName(self, worldName: impl Into<Cow<'a, str>>) -> Self
pub fn worldName(self, worldName: impl Into<Cow<'a, str>>) -> Self
An optional name which is reported in the Execution Context.
Sourcepub fn grantUniveralAccess(self, grantUniveralAccess: bool) -> Self
pub fn grantUniveralAccess(self, grantUniveralAccess: bool) -> Self
Whether or not universal access should be granted to the isolated world. This is a powerful option, use with caution.
pub fn build(self) -> CreateIsolatedWorldParams<'a>