pub struct FileHandler {
pub action: String,
pub name: String,
pub icons: Option<Vec<ImageResource>>,
pub accepts: Option<Vec<FileFilter>>,
pub launchType: String,
}Fields
action: Stringname: Stringicons: Option<Vec<ImageResource>>accepts: Option<Vec<FileFilter>>Mimic a map, name is the key, accepts is the value.
launchType: StringWon’t repeat the enums, using string for easy comparison. Same as the other enums below.