pub struct FrameBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> FrameBuilder<'a>
impl<'a> FrameBuilder<'a>
Sourcepub fn url_fragment(self, url_fragment: impl Into<Cow<'a, str>>) -> Self
pub fn url_fragment(self, url_fragment: impl Into<Cow<'a, str>>) -> Self
Frame document’s URL fragment including the ‘#’.
Sourcepub fn security_origin_details(
self,
security_origin_details: SecurityOriginDetails,
) -> Self
pub fn security_origin_details( self, security_origin_details: SecurityOriginDetails, ) -> Self
Additional details about the frame document’s security origin.
Sourcepub fn unreachable_url(self, unreachable_url: impl Into<Cow<'a, str>>) -> Self
pub fn unreachable_url(self, unreachable_url: impl Into<Cow<'a, str>>) -> Self
If the frame failed to load, this contains the URL that could not be loaded. Note that unlike url above, this URL may contain a fragment.
Sourcepub fn ad_frame_status(self, ad_frame_status: AdFrameStatus) -> Self
pub fn ad_frame_status(self, ad_frame_status: AdFrameStatus) -> Self
Indicates whether this frame was tagged as an ad and why.
pub fn build(self) -> Frame<'a>