pub struct GetAdScriptAncestryReturns<'a> { /* private fields */ }Implementations
Sourceimpl<'a> GetAdScriptAncestryReturns<'a>
impl<'a> GetAdScriptAncestryReturns<'a>
Sourcepub fn builder() -> GetAdScriptAncestryReturnsBuilder<'a>
pub fn builder() -> GetAdScriptAncestryReturnsBuilder<'a>
Creates a builder for this type.
Sourcepub fn ad_script_ancestry(&self) -> Option<&AdAncestry<'a>>
pub fn ad_script_ancestry(&self) -> Option<&AdAncestry<'a>>
The ancestry chain of ad script identifiers leading to this frame’s creation, along with the root script’s filterlist rule. The ancestry chain is ordered from the most immediate script (in the frame creation stack) to more distant ancestors (that created the immediately preceding script). Only sent if frame is labelled as an ad and ids are available.