GetAdScriptAncestryReturnsBuilder

Struct GetAdScriptAncestryReturnsBuilder 

pub struct GetAdScriptAncestryReturnsBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> GetAdScriptAncestryReturnsBuilder<'a>

pub fn ad_script_ancestry(self, ad_script_ancestry: AdAncestry<'a>) -> Self

The ancestry chain of ad script identifiers leading to this frame’s creation, along with the root script’s filterlist rule. The ancestry chain is ordered from the most immediate script (in the frame creation stack) to more distant ancestors (that created the immediately preceding script). Only sent if frame is labelled as an ad and ids are available.

pub fn build(self) -> GetAdScriptAncestryReturns<'a>