pub struct GetAnnotatedPageContentParams { /* private fields */ }Expand description
Get the annotated page content for the main frame. This is an experimental command that is subject to change.
Implementations
Sourceimpl GetAnnotatedPageContentParams
impl GetAnnotatedPageContentParams
Sourcepub fn builder() -> GetAnnotatedPageContentParamsBuilder
pub fn builder() -> GetAnnotatedPageContentParamsBuilder
Creates a builder for this type.
Sourcepub fn include_actionable_information(&self) -> Option<bool>
pub fn include_actionable_information(&self) -> Option<bool>
Whether to include actionable information. Defaults to true.