pub struct GetAnnotatedPageContentReturns {
pub content: String,
}Expand description
Get the annotated page content for the main frame. This is an experimental command that is subject to change.
Fields
content: StringThe annotated page content as a base64 encoded protobuf. The format is defined by the ‘AnnotatedPageContent’ message in components/optimization_guide/proto/features/common_quality_data.proto (Encoded as a base64 string when passed over JSON)