GetAppManifestParams

Struct GetAppManifestParams 

pub struct GetAppManifestParams {
    pub manifestId: Option<String>,
}
Gets the processed manifest for this current document. This API always waits for the manifest to be loaded. If manifestId is provided, and it does not match the manifest of the current document, this API errors out. If there is not a loaded page, this API errors out immediately.

Fields

manifestId: Option<String>

Implementations

Source

impl GetAppManifestParams

pub const METHOD: &'static str = "Page.getAppManifest"