GetAppManifestReturns

Struct GetAppManifestReturns 

pub struct GetAppManifestReturns<'a> { /* private fields */ }
Gets the processed manifest for this current document. This API always waits for the manifest to be loaded. If manifestId is provided, and it does not match the manifest of the current document, this API errors out. If there is not a loaded page, this API errors out immediately.

Implementations

Source

impl<'a> GetAppManifestReturns<'a>

pub fn builder( url: impl Into<Cow<'a, str>>, errors: Vec<AppManifestError<'a>>, manifest: WebAppManifest<'a>, ) -> GetAppManifestReturnsBuilder<'a>

pub fn url(&self) -> &str

pub fn errors(&self) -> &[AppManifestError<'a>]

pub fn data(&self) -> Option<&str>

pub fn parsed(&self) -> Option<&AppManifestParsedProperties<'a>>

pub fn manifest(&self) -> &WebAppManifest<'a>