pub struct NavigateParams<'a> { /* private fields */ }Expand description
Navigates current page to the given URL.
Implementations
Sourcepub fn builder(url: impl Into<Cow<'a, str>>) -> NavigateParamsBuilder<'a>
pub fn builder(url: impl Into<Cow<'a, str>>) -> NavigateParamsBuilder<'a>
Creates a builder for this type with the required parameters:
url: URL to navigate the page to.
Sourcepub fn transition_type(&self) -> Option<&TransitionType>
pub fn transition_type(&self) -> Option<&TransitionType>
Intended transition type.
Sourcepub fn frame_id(&self) -> Option<&FrameId<'a>>
pub fn frame_id(&self) -> Option<&FrameId<'a>>
Frame id to navigate, if not specified navigates the top frame.
Sourcepub fn referrer_policy(&self) -> Option<&ReferrerPolicy>
pub fn referrer_policy(&self) -> Option<&ReferrerPolicy>
Referrer-policy used for the navigation.