pub struct NavigateReturns<'a> { /* private fields */ }Expand description
Navigates current page to the given URL.
Implementations
Sourcepub fn builder(frame_id: impl Into<FrameId<'a>>) -> NavigateReturnsBuilder<'a>
pub fn builder(frame_id: impl Into<FrameId<'a>>) -> NavigateReturnsBuilder<'a>
Creates a builder for this type with the required parameters:
frame_id: Frame id that has navigated (or failed to navigate)
Sourcepub fn loader_id(&self) -> Option<&LoaderId<'a>>
pub fn loader_id(&self) -> Option<&LoaderId<'a>>
Loader identifier. This is omitted in case of same-document navigation, as the previously committed loaderId would not change.
Sourcepub fn error_text(&self) -> Option<&str>
pub fn error_text(&self) -> Option<&str>
User friendly error message, present if and only if navigation has failed.
Sourcepub fn is_download(&self) -> Option<bool>
pub fn is_download(&self) -> Option<bool>
Whether the navigation resulted in a download.