pub struct NavigationEntry<'a> { /* private fields */ }Expand description
Navigation history entry.
Implementations
Sourcepub fn builder(
id: u64,
url: impl Into<Cow<'a, str>>,
user_typed_url: impl Into<Cow<'a, str>>,
title: impl Into<Cow<'a, str>>,
transition_type: impl Into<TransitionType>,
) -> NavigationEntryBuilder<'a>
pub fn builder( id: u64, url: impl Into<Cow<'a, str>>, user_typed_url: impl Into<Cow<'a, str>>, title: impl Into<Cow<'a, str>>, transition_type: impl Into<TransitionType>, ) -> NavigationEntryBuilder<'a>
Creates a builder for this type with the required parameters:
id: Unique id of the navigation history entry.url: URL of the navigation history entry.user_typed_url: URL that the user typed in the url bar.title: Title of the navigation history entry.transition_type: Transition type.
Sourcepub fn user_typed_url(&self) -> &str
pub fn user_typed_url(&self) -> &str
URL that the user typed in the url bar.
Sourcepub fn transition_type(&self) -> &TransitionType
pub fn transition_type(&self) -> &TransitionType
Transition type.