pub struct PrintToPDFParamsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> PrintToPDFParamsBuilder<'a>
impl<'a> PrintToPDFParamsBuilder<'a>
Display header and footer. Defaults to false.
Sourcepub fn print_background(self, print_background: bool) -> Self
pub fn print_background(self, print_background: bool) -> Self
Print background graphics. Defaults to false.
Sourcepub fn paper_width(self, paper_width: f64) -> Self
pub fn paper_width(self, paper_width: f64) -> Self
Paper width in inches. Defaults to 8.5 inches.
Sourcepub fn paper_height(self, paper_height: f64) -> Self
pub fn paper_height(self, paper_height: f64) -> Self
Paper height in inches. Defaults to 11 inches.
Sourcepub fn margin_top(self, margin_top: f64) -> Self
pub fn margin_top(self, margin_top: f64) -> Self
Top margin in inches. Defaults to 1cm (~0.4 inches).
Sourcepub fn margin_bottom(self, margin_bottom: f64) -> Self
pub fn margin_bottom(self, margin_bottom: f64) -> Self
Bottom margin in inches. Defaults to 1cm (~0.4 inches).
Sourcepub fn margin_left(self, margin_left: f64) -> Self
pub fn margin_left(self, margin_left: f64) -> Self
Left margin in inches. Defaults to 1cm (~0.4 inches).
Sourcepub fn margin_right(self, margin_right: f64) -> Self
pub fn margin_right(self, margin_right: f64) -> Self
Right margin in inches. Defaults to 1cm (~0.4 inches).
Sourcepub fn page_ranges(self, page_ranges: impl Into<Cow<'a, str>>) -> Self
pub fn page_ranges(self, page_ranges: impl Into<Cow<'a, str>>) -> Self
Paper ranges to print, one based, e.g., ‘1-5, 8, 11-13’. Pages are printed in the document order, not in the order specified, and no more than once. Defaults to empty string, which implies the entire document is printed. The page numbers are quietly capped to actual page count of the document, and ranges beyond the end of the document are ignored. If this results in no pages to print, an error is reported. It is an error to specify a range with start greater than end.
Sourcepub fn header_template(self, header_template: impl Into<Cow<'a, str>>) -> Self
pub fn header_template(self, header_template: impl Into<Cow<'a, str>>) -> Self
HTML template for the print header. Should be valid HTML markup with following classes used to inject printing values into them:
- ‘date’: formatted print date
- ‘title’: document title
- ‘url’: document location
- ‘pageNumber’: current page number
- ‘totalPages’: total pages in the document
For example, ‘<span class=title></span>’ would generate span containing the title.
HTML template for the print footer. Should use the same format as the ‘headerTemplate’.
Sourcepub fn prefer_css_page_size(self, prefer_css_page_size: bool) -> Self
pub fn prefer_css_page_size(self, prefer_css_page_size: bool) -> Self
Whether or not to prefer page size as defined by css. Defaults to false, in which case the content will be scaled to fit the paper size.
Sourcepub fn transfer_mode(self, transfer_mode: impl Into<Cow<'a, str>>) -> Self
pub fn transfer_mode(self, transfer_mode: impl Into<Cow<'a, str>>) -> Self
return as stream
Sourcepub fn generate_tagged_pdf(self, generate_tagged_pdf: bool) -> Self
pub fn generate_tagged_pdf(self, generate_tagged_pdf: bool) -> Self
Whether or not to generate tagged (accessible) PDF. Defaults to embedder choice.
Sourcepub fn generate_document_outline(self, generate_document_outline: bool) -> Self
pub fn generate_document_outline(self, generate_document_outline: bool) -> Self
Whether or not to embed the document outline into the PDF.