ProduceCompilationCacheParams

Struct ProduceCompilationCacheParams 

pub struct ProduceCompilationCacheParams<'a> { /* private fields */ }
Requests backend to produce compilation cache for the specified scripts. ‘scripts’ are appended to the list of scripts for which the cache would be produced. The list may be reset during page navigation. When script with a matching URL is encountered, the cache is optionally produced upon backend discretion, based on internal heuristics. See also: ‘Page.compilationCacheProduced’.

Implementations

Source

impl<'a> ProduceCompilationCacheParams<'a>

Source

impl<'a> ProduceCompilationCacheParams<'a>

pub const METHOD: &'static str = "Page.produceCompilationCache"