pub struct ReloadParamsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ReloadParamsBuilder<'a>
impl<'a> ReloadParamsBuilder<'a>
Sourcepub fn ignore_cache(self, ignore_cache: bool) -> Self
pub fn ignore_cache(self, ignore_cache: bool) -> Self
If true, browser cache is ignored (as if the user pressed Shift+refresh).
Sourcepub fn script_to_evaluate_on_load(
self,
script_to_evaluate_on_load: impl Into<Cow<'a, str>>,
) -> Self
pub fn script_to_evaluate_on_load( self, script_to_evaluate_on_load: impl Into<Cow<'a, str>>, ) -> Self
If set, the script will be injected into all frames of the inspected page after reload. Argument will be ignored if reloading dataURL origin.
Sourcepub fn loader_id(self, loader_id: LoaderId<'a>) -> Self
pub fn loader_id(self, loader_id: LoaderId<'a>) -> Self
If set, an error will be thrown if the target page’s main frame’s loader id does not match the provided id. This prevents accidentally reloading an unintended target in case there’s a racing navigation.
pub fn build(self) -> ReloadParams<'a>