pub struct SetDeviceMetricsOverrideParamsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> SetDeviceMetricsOverrideParamsBuilder<'a>
impl<'a> SetDeviceMetricsOverrideParamsBuilder<'a>
Sourcepub fn screen_width(self, screen_width: u64) -> Self
pub fn screen_width(self, screen_width: u64) -> Self
Overriding screen width value in pixels (minimum 0, maximum 10000000).
Sourcepub fn screen_height(self, screen_height: i64) -> Self
pub fn screen_height(self, screen_height: i64) -> Self
Overriding screen height value in pixels (minimum 0, maximum 10000000).
Sourcepub fn position_x(self, position_x: i64) -> Self
pub fn position_x(self, position_x: i64) -> Self
Overriding view X position on screen in pixels (minimum 0, maximum 10000000).
Sourcepub fn position_y(self, position_y: i64) -> Self
pub fn position_y(self, position_y: i64) -> Self
Overriding view Y position on screen in pixels (minimum 0, maximum 10000000).
Sourcepub fn dont_set_visible_size(self, dont_set_visible_size: bool) -> Self
pub fn dont_set_visible_size(self, dont_set_visible_size: bool) -> Self
Do not set visible view size, rely upon explicit setVisibleSize call.
Sourcepub fn screen_orientation(
self,
screen_orientation: ScreenOrientation<'a>,
) -> Self
pub fn screen_orientation( self, screen_orientation: ScreenOrientation<'a>, ) -> Self
Screen orientation override.
Sourcepub fn viewport(self, viewport: Viewport) -> Self
pub fn viewport(self, viewport: Viewport) -> Self
The viewport dimensions and scale. If not set, the override is cleared.
pub fn build(self) -> SetDeviceMetricsOverrideParams<'a>