pub struct SetInterceptFileChooserDialogParams {
pub enabled: bool,
pub cancel: Option<bool>,
}Expand description
Intercept file chooser requests and transfer control to protocol clients. When file chooser interception is enabled, native file chooser dialog is not shown. Instead, a protocol event ‘Page.fileChooserOpened’ is emitted.
Fields
enabled: boolcancel: Option<bool>If true, cancels the dialog by emitting relevant events (if any) in addition to not showing it if the interception is enabled (default: false).
Implementations