pub struct SetWebLifecycleStateParams {
pub state: String,
}Expand description
Tries to update the web lifecycle state of the page. It will transition the page to the given state according to: https://github.com/WICG/web-lifecycle/
Fields
state: StringTarget lifecycle state