Module performance

Module performance 

Structs

DisableParams
EnableParams
Enable collecting and reporting metrics.
EnableParamsBuilder
GetMetricsParams
GetMetricsReturns
Retrieve current values of run-time metrics.
GetMetricsReturnsBuilder
Metric
Run-time execution metric.
MetricBuilder
SetTimeDomainParams
Sets time domain to use for collecting and reporting duration metrics. Note that this must be called before enabling metrics collection. Calling this method while metrics collection is enabled returns an error.
SetTimeDomainParamsBuilder