SetTimeDomainParams

Struct SetTimeDomainParams 

pub struct SetTimeDomainParams {
    pub timeDomain: String,
}
Sets time domain to use for collecting and reporting duration metrics. Note that this must be called before enabling metrics collection. Calling this method while metrics collection is enabled returns an error.

Fields

timeDomain: String

Time domain

Implementations

Source

impl SetTimeDomainParams

pub const METHOD: &'static str = "Performance.setTimeDomain"