Module performancetimeline

Module performancetimeline 

Reporting of performance timeline events, as specified in https://w3c.github.io/performance-timeline/#dom-performanceobserver.

Structs

EnableParams
Previously buffered events would be reported before method returns. See also: timelineEventAdded
LargestContentfulPaint
See https://github.com/WICG/LargestContentfulPaint and largest_contentful_paint.idl
LayoutShift
See https://wicg.github.io/layout-instability/#sec-layout-shift and layout_shift.idl
LayoutShiftAttribution
TimelineEvent