pub struct EnableParams<'a> { /* private fields */ }Expand description
Previously buffered events would be reported before method returns. See also: timelineEventAdded
Implementations
Sourceimpl<'a> EnableParams<'a>
impl<'a> EnableParams<'a>
Sourcepub fn builder(event_types: Vec<Cow<'a, str>>) -> EnableParamsBuilder<'a>
pub fn builder(event_types: Vec<Cow<'a, str>>) -> EnableParamsBuilder<'a>
Creates a builder for this type with the required parameters:
event_types: The types of event to report, as specified in https://w3c.github.io/performance-timeline/#dom-performanceentry-entrytype The specified filter overrides any previous filters, passing empty filter disables recording. Note that not all types exposed to the web platform are currently supported.
Sourcepub fn event_types(&self) -> &[Cow<'a, str>]
pub fn event_types(&self) -> &[Cow<'a, str>]
The types of event to report, as specified in https://w3c.github.io/performance-timeline/#dom-performanceentry-entrytype The specified filter overrides any previous filters, passing empty filter disables recording. Note that not all types exposed to the web platform are currently supported.