pub struct TimelineEvent {
pub frameId: FrameId,
pub type_: String,
pub name: String,
pub time: TimeSinceEpoch,
pub duration: Option<f64>,
pub lcpDetails: Option<LargestContentfulPaint>,
pub layoutShiftDetails: Option<LayoutShift>,
}Fields
frameId: FrameIdIdentifies the frame that this event is related to. Empty for non-frame targets.
type_: StringThe event type, as specified in https://w3c.github.io/performance-timeline/#dom-performanceentry-entrytype This determines which of the optional “details” fields is present.
name: StringName may be empty depending on the type.
time: TimeSinceEpochTime in seconds since Epoch, monotonically increasing within document lifetime.
duration: Option<f64>Event duration, if applicable.
lcpDetails: Option<LargestContentfulPaint>layoutShiftDetails: Option<LayoutShift>Trait Implementations
Sourceimpl Clone for TimelineEvent
impl Clone for TimelineEvent
Sourcefn clone(&self) -> TimelineEvent
fn clone(&self) -> TimelineEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TimelineEvent
impl Debug for TimelineEvent
Sourceimpl Default for TimelineEvent
impl Default for TimelineEvent
Sourcefn default() -> TimelineEvent
fn default() -> TimelineEvent
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for TimelineEvent
impl<'de> Deserialize<'de> for TimelineEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more