Module preload

Module preload 

Structs

PreloadingAttemptKey
A key that identifies a preloading attempt.
PreloadingAttemptSource
Lists sources for a preloading attempt, specifically the ids of rule sets that had a speculation rule that triggered the attempt, and the BackendNodeIds of <a href> or <area href> elements that triggered the attempt (in the case of attempts triggered by a document rule). It is possible for multiple rule sets and links to trigger a single attempt.
PrerenderMismatchedHeaders
Information of headers to be displayed when the header mismatch occurred.
RuleSet
Corresponds to SpeculationRuleSet

Enums

PrefetchStatus
TODO(https://crbug.com/1384419): revisit the list of PrefetchStatus and filter out the ones that aren’t necessary to the developers.
PreloadingStatus
Preloading status values, see also PreloadingTriggeringOutcome. This status is shared by prefetchStatusUpdated and prerenderStatusUpdated.
PrerenderFinalStatus
List of FinalStatus reasons for Prerender2.
RuleSetErrorType
SpeculationAction
The type of preloading attempted. It corresponds to mojom::SpeculationAction (although PrefetchWithSubresources is omitted as it isn’t being used by clients).
SpeculationTargetHint
Corresponds to mojom::SpeculationTargetHint. See https://github.com/WICG/nav-speculation/blob/main/triggers.md#window-name-targeting-hints

Type Aliases

PreloadPipelineId
Chrome manages different types of preloads together using a concept of preloading pipeline. For example, if a site uses a SpeculationRules for prerender, Chrome first starts a prefetch and then upgrades it to prerender.
RuleSetId
Unique id