pub struct PreloadingAttemptKey<'a> { /* private fields */ }Expand description
A key that identifies a preloading attempt.
The url used is the url specified by the trigger (i.e. the initial URL), and not the final url that is navigated to. For example, prerendering allows same-origin main frame navigations during the attempt, but the attempt is still keyed with the initial URL.
Implementations
Sourceimpl<'a> PreloadingAttemptKey<'a>
impl<'a> PreloadingAttemptKey<'a>
Sourcepub fn builder(
loader_id: LoaderId<'a>,
action: impl Into<SpeculationAction>,
url: impl Into<Cow<'a, str>>,
) -> PreloadingAttemptKeyBuilder<'a>
pub fn builder( loader_id: LoaderId<'a>, action: impl Into<SpeculationAction>, url: impl Into<Cow<'a, str>>, ) -> PreloadingAttemptKeyBuilder<'a>
Creates a builder for this type with the required parameters:
loader_id:action:url:
pub fn loader_id(&self) -> &LoaderId<'a>
pub fn action(&self) -> &SpeculationAction
pub fn url(&self) -> &str
pub fn form_submission(&self) -> Option<bool>
pub fn target_hint(&self) -> Option<&SpeculationTargetHint>