pub struct PreloadingAttemptSource {
pub key: PreloadingAttemptKey,
pub ruleSetIds: Vec<RuleSetId>,
pub nodeIds: Vec<BackendNodeId>,
}Expand description
Lists sources for a preloading attempt, specifically the ids of rule sets that had a speculation rule that triggered the attempt, and the BackendNodeIds of <a href> or <area href> elements that triggered the attempt (in the case of attempts triggered by a document rule). It is possible for multiple rule sets and links to trigger a single attempt.
Fields
key: PreloadingAttemptKeyruleSetIds: Vec<RuleSetId>nodeIds: Vec<BackendNodeId>Trait Implementations
Sourceimpl Clone for PreloadingAttemptSource
impl Clone for PreloadingAttemptSource
Sourcefn clone(&self) -> PreloadingAttemptSource
fn clone(&self) -> PreloadingAttemptSource
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PreloadingAttemptSource
impl Debug for PreloadingAttemptSource
Sourceimpl Default for PreloadingAttemptSource
impl Default for PreloadingAttemptSource
Sourcefn default() -> PreloadingAttemptSource
fn default() -> PreloadingAttemptSource
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PreloadingAttemptSource
impl<'de> Deserialize<'de> for PreloadingAttemptSource
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more