pub type PreloadPipelineId<'a> = Cow<'a, str>;Expand description
Chrome manages different types of preloads together using a concept of preloading pipeline. For example, if a site uses a SpeculationRules for prerender, Chrome first starts a prefetch and then upgrades it to prerender.
CDP events for them are emitted separately but they share ‘PreloadPipelineId’.
Aliased Type
pub enum PreloadPipelineId<'a> {
Borrowed(&'a str),
Owned(String),
}