Module pwa

Module pwa 

This domain allows interacting with the browser to control PWAs.

Structs

ChangeAppUserSettingsParams
Changes user settings of the web app identified by its manifestId. If the app was not installed, this command returns an error. Unset parameters will be ignored; unrecognized values will cause an error.
FileHandler
FileHandlerAccept
The following types are the replica of https://crsrc.org/c/chrome/browser/web_applications/proto/web_app_os_integration_state.proto;drc=9910d3be894c8f142c977ba1023f30a656bc13fc;l=67
GetOsAppStateParams
Returns the following OS state for the given manifest id.
GetOsAppStateReturns
Returns the following OS state for the given manifest id.
InstallParams
Installs the given manifest identity, optionally using the given installUrlOrBundleUrl
LaunchFilesInAppParams
Opens one or more local files from an installed web app identified by its manifestId. The web app needs to have file handlers registered to process the files. The API returns one or more page Target.TargetIDs which can be used to attach to via Target.attachToTarget or similar APIs. If some files in the parameters cannot be handled by the web app, they will be ignored. If none of the files can be handled, this API returns an error. If no files are provided as the parameter, this API also returns an error.
LaunchFilesInAppReturns
Opens one or more local files from an installed web app identified by its manifestId. The web app needs to have file handlers registered to process the files. The API returns one or more page Target.TargetIDs which can be used to attach to via Target.attachToTarget or similar APIs. If some files in the parameters cannot be handled by the web app, they will be ignored. If none of the files can be handled, this API returns an error. If no files are provided as the parameter, this API also returns an error.
LaunchParams
Launches the installed web app, or an url in the same web app instead of the default start url if it is provided. Returns a page Target.TargetID which can be used to attach to via Target.attachToTarget or similar APIs.
LaunchReturns
Launches the installed web app, or an url in the same web app instead of the default start url if it is provided. Returns a page Target.TargetID which can be used to attach to via Target.attachToTarget or similar APIs.
OpenCurrentPageInAppParams
Opens the current page in its web app identified by the manifest id, needs to be called on a page target. This function returns immediately without waiting for the app to finish loading.
UninstallParams
Uninstalls the given manifest_id and closes any opened app windows.

Enums

DisplayMode
If user prefers opening the app in browser or an app window.