pub struct ChangeAppUserSettingsParamsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ChangeAppUserSettingsParamsBuilder<'a>
impl<'a> ChangeAppUserSettingsParamsBuilder<'a>
Sourcepub fn link_capturing(self, link_capturing: bool) -> Self
pub fn link_capturing(self, link_capturing: bool) -> Self
If user allows the links clicked on by the user in the app’s scope, or extended scope if the manifest has scope extensions and the flags ‘DesktopPWAsLinkCapturingWithScopeExtensions’ and ‘WebAppEnableScopeExtensions’ are enabled.
Note, the API does not support resetting the linkCapturing to the initial value, uninstalling and installing the web app again will reset it.
TODO(crbug.com/339453269): Setting this value on ChromeOS is not supported yet.
pub fn display_mode(self, display_mode: impl Into<DisplayMode>) -> Self
pub fn build(self) -> ChangeAppUserSettingsParams<'a>