pub struct GetOsAppStateParams<'a> { /* private fields */ }Expand description
Returns the following OS state for the given manifest id.
Implementations
Sourceimpl<'a> GetOsAppStateParams<'a>
impl<'a> GetOsAppStateParams<'a>
Sourcepub fn builder(
manifest_id: impl Into<Cow<'a, str>>,
) -> GetOsAppStateParamsBuilder<'a>
pub fn builder( manifest_id: impl Into<Cow<'a, str>>, ) -> GetOsAppStateParamsBuilder<'a>
Creates a builder for this type with the required parameters:
manifest_id: The id from the webapp’s manifest file, commonly it’s the url of the site installing the webapp. See https://web.dev/learn/pwa/web-app-manifest.
Sourcepub fn manifest_id(&self) -> &str
pub fn manifest_id(&self) -> &str
The id from the webapp’s manifest file, commonly it’s the url of the site installing the webapp. See https://web.dev/learn/pwa/web-app-manifest.