InstallParams

Struct InstallParams 

pub struct InstallParams<'a> { /* private fields */ }
Installs the given manifest identity, optionally using the given installUrlOrBundleUrl

IWA-specific install description: manifestId corresponds to isolated-app:// + web_package::SignedWebBundleId

File installation mode: The installUrlOrBundleUrl can be either file:// or http(s):// pointing to a signed web bundle (.swbn). In this case SignedWebBundleId must correspond to The .swbn file’s signing key.

Dev proxy installation mode: installUrlOrBundleUrl must be http(s):// that serves dev mode IWA. web_package::SignedWebBundleId must be of type dev proxy.

The advantage of dev proxy mode is that all changes to IWA automatically will be reflected in the running app without reinstallation.

To generate bundle id for proxy mode:

  1. Generate 32 random bytes.
  2. Add a specific suffix at the end following the documentation https://github.com/WICG/isolated-web-apps/blob/main/Scheme.md#suffix
  3. Encode the entire sequence using Base32 without padding.

If Chrome is not in IWA dev mode, the installation will fail, regardless of the state of the allowlist.

Implementations

Source

impl<'a> InstallParams<'a>

pub fn builder(manifest_id: impl Into<Cow<'a, str>>) -> InstallParamsBuilder<'a>

Creates a builder for this type with the required parameters:

  • manifest_id:
pub fn manifest_id(&self) -> &str

pub fn install_url_or_bundle_url(&self) -> Option<&str>

The location of the app or bundle overriding the one derived from the manifestId.

Source

impl<'a> InstallParams<'a>

pub const METHOD: &'static str = "PWA.install"