Module security

Module security 

Structs

CertificateSecurityState
Details about the security state of the page certificate.
CertificateSecurityStateBuilder
DisableParams
EnableParams
HandleCertificateErrorParams
Handles a certificate error that fired a certificateError event.
HandleCertificateErrorParamsBuilder
InsecureContentStatus
Information about insecure content on the page.
InsecureContentStatusBuilder
SafetyTipInfo
SafetyTipInfoBuilder
SecurityStateExplanation
An explanation of an factor contributing to the security state.
SecurityStateExplanationBuilder
SetIgnoreCertificateErrorsParams
Enable/disable whether all certificate errors should be ignored.
SetIgnoreCertificateErrorsParamsBuilder
SetOverrideCertificateErrorsParams
Enable/disable overriding certificate errors. If enabled, all certificate error events need to be handled by the DevTools client and should be answered with ‘handleCertificateError’ commands.
SetOverrideCertificateErrorsParamsBuilder
VisibleSecurityState
Security state information about the page.
VisibleSecurityStateBuilder

Enums

CertificateErrorAction
The action to take when a certificate error occurs. continue will continue processing the request and cancel will cancel the request.
MixedContentType
A description of mixed content (HTTP resources on HTTPS pages), as defined by https://www.w3.org/TR/mixed-content/#categories
SafetyTipStatus
SecurityState
The security level of a page or resource.

Type Aliases

CertificateId
An internal certificate ID value.