pub struct CertificateSecurityState<'a> { /* private fields */ }Expand description
Details about the security state of the page certificate.
Implementations
Sourceimpl<'a> CertificateSecurityState<'a>
impl<'a> CertificateSecurityState<'a>
Sourcepub fn builder(
protocol: impl Into<Cow<'a, str>>,
key_exchange: impl Into<Cow<'a, str>>,
cipher: impl Into<Cow<'a, str>>,
certificate: Vec<Cow<'a, str>>,
subject_name: impl Into<Cow<'a, str>>,
issuer: impl Into<Cow<'a, str>>,
valid_from: TimeSinceEpoch,
valid_to: TimeSinceEpoch,
certificate_has_weak_signature: bool,
certificate_has_sha1_signature: bool,
modern_ssl: bool,
obsolete_ssl_protocol: bool,
obsolete_ssl_key_exchange: bool,
obsolete_ssl_cipher: bool,
obsolete_ssl_signature: bool,
) -> CertificateSecurityStateBuilder<'a>
pub fn builder( protocol: impl Into<Cow<'a, str>>, key_exchange: impl Into<Cow<'a, str>>, cipher: impl Into<Cow<'a, str>>, certificate: Vec<Cow<'a, str>>, subject_name: impl Into<Cow<'a, str>>, issuer: impl Into<Cow<'a, str>>, valid_from: TimeSinceEpoch, valid_to: TimeSinceEpoch, certificate_has_weak_signature: bool, certificate_has_sha1_signature: bool, modern_ssl: bool, obsolete_ssl_protocol: bool, obsolete_ssl_key_exchange: bool, obsolete_ssl_cipher: bool, obsolete_ssl_signature: bool, ) -> CertificateSecurityStateBuilder<'a>
Creates a builder for this type with the required parameters:
protocol: Protocol name (e.g. “TLS 1.2” or “QUIC”).key_exchange: Key Exchange used by the connection, or the empty string if not applicable.cipher: Cipher name.certificate: Page certificate.subject_name: Certificate subject name.issuer: Name of the issuing CA.valid_from: Certificate valid from date.valid_to: Certificate valid to (expiration) datecertificate_has_weak_signature: True if the certificate uses a weak signature algorithm.certificate_has_sha1_signature: True if the certificate has a SHA1 signature in the chain.modern_ssl: True if modern SSLobsolete_ssl_protocol: True if the connection is using an obsolete SSL protocol.obsolete_ssl_key_exchange: True if the connection is using an obsolete SSL key exchange.obsolete_ssl_cipher: True if the connection is using an obsolete SSL cipher.obsolete_ssl_signature: True if the connection is using an obsolete SSL signature.
Sourcepub fn key_exchange(&self) -> &str
pub fn key_exchange(&self) -> &str
Key Exchange used by the connection, or the empty string if not applicable.
Sourcepub fn key_exchange_group(&self) -> Option<&str>
pub fn key_exchange_group(&self) -> Option<&str>
(EC)DH group used by the connection, if applicable.
Sourcepub fn certificate(&self) -> &[Cow<'a, str>]
pub fn certificate(&self) -> &[Cow<'a, str>]
Page certificate.
Sourcepub fn subject_name(&self) -> &str
pub fn subject_name(&self) -> &str
Certificate subject name.
Sourcepub fn valid_from(&self) -> &TimeSinceEpoch
pub fn valid_from(&self) -> &TimeSinceEpoch
Certificate valid from date.
Sourcepub fn valid_to(&self) -> &TimeSinceEpoch
pub fn valid_to(&self) -> &TimeSinceEpoch
Certificate valid to (expiration) date
Sourcepub fn certificate_network_error(&self) -> Option<&str>
pub fn certificate_network_error(&self) -> Option<&str>
The highest priority network error code, if the certificate has an error.
Sourcepub fn certificate_has_weak_signature(&self) -> bool
pub fn certificate_has_weak_signature(&self) -> bool
True if the certificate uses a weak signature algorithm.
Sourcepub fn certificate_has_sha1_signature(&self) -> bool
pub fn certificate_has_sha1_signature(&self) -> bool
True if the certificate has a SHA1 signature in the chain.
Sourcepub fn modern_ssl(&self) -> bool
pub fn modern_ssl(&self) -> bool
True if modern SSL
Sourcepub fn obsolete_ssl_protocol(&self) -> bool
pub fn obsolete_ssl_protocol(&self) -> bool
True if the connection is using an obsolete SSL protocol.
Sourcepub fn obsolete_ssl_key_exchange(&self) -> bool
pub fn obsolete_ssl_key_exchange(&self) -> bool
True if the connection is using an obsolete SSL key exchange.
Sourcepub fn obsolete_ssl_cipher(&self) -> bool
pub fn obsolete_ssl_cipher(&self) -> bool
True if the connection is using an obsolete SSL cipher.
Sourcepub fn obsolete_ssl_signature(&self) -> bool
pub fn obsolete_ssl_signature(&self) -> bool
True if the connection is using an obsolete SSL signature.