SecurityStateExplanation

Struct SecurityStateExplanation 

pub struct SecurityStateExplanation<'a> { /* private fields */ }
An explanation of an factor contributing to the security state.

Implementations

Source

impl<'a> SecurityStateExplanation<'a>

pub fn builder( security_state: impl Into<SecurityState>, title: impl Into<Cow<'a, str>>, summary: impl Into<Cow<'a, str>>, description: impl Into<Cow<'a, str>>, mixed_content_type: impl Into<MixedContentType>, certificate: Vec<Cow<'a, str>>, ) -> SecurityStateExplanationBuilder<'a>

Creates a builder for this type with the required parameters:

  • security_state: Security state representing the severity of the factor being explained.
  • title: Title describing the type of factor.
  • summary: Short phrase describing the type of factor.
  • description: Full text explanation of the factor.
  • mixed_content_type: The type of mixed content described by the explanation.
  • certificate: Page certificate.
pub fn security_state(&self) -> &SecurityState

Security state representing the severity of the factor being explained.

pub fn title(&self) -> &str

Title describing the type of factor.

pub fn summary(&self) -> &str

Short phrase describing the type of factor.

pub fn description(&self) -> &str

Full text explanation of the factor.

pub fn mixed_content_type(&self) -> &MixedContentType

The type of mixed content described by the explanation.

pub fn certificate(&self) -> &[Cow<'a, str>]

Page certificate.

pub fn recommendations(&self) -> Option<&[Cow<'a, str>]>

Recommendations to fix any issues.