VisibleSecurityStateBuilder

Struct VisibleSecurityStateBuilder 

pub struct VisibleSecurityStateBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> VisibleSecurityStateBuilder<'a>

pub fn certificate_security_state( self, certificate_security_state: CertificateSecurityState<'a>, ) -> Self

Security state details about the page certificate.

pub fn safety_tip_info(self, safety_tip_info: SafetyTipInfo<'a>) -> Self

The type of Safety Tip triggered on the page. Note that this field will be set even if the Safety Tip UI was not actually shown.

pub fn build(self) -> VisibleSecurityState<'a>