pub struct ServiceWorkerVersion {
pub versionId: String,
pub registrationId: RegistrationID,
pub scriptURL: String,
pub runningStatus: ServiceWorkerVersionRunningStatus,
pub status: ServiceWorkerVersionStatus,
pub scriptLastModified: Option<f64>,
pub scriptResponseTime: Option<f64>,
pub controlledClients: Option<Vec<TargetID>>,
pub targetId: Option<TargetID>,
pub routerRules: Option<String>,
}Expand description
ServiceWorker version.
Fields
versionId: StringregistrationId: RegistrationIDscriptURL: StringrunningStatus: ServiceWorkerVersionRunningStatusstatus: ServiceWorkerVersionStatusscriptLastModified: Option<f64>The Last-Modified header value of the main script.
scriptResponseTime: Option<f64>The time at which the response headers of the main script were received from the server. For cached script it is the last time the cache entry was validated.
controlledClients: Option<Vec<TargetID>>targetId: Option<TargetID>routerRules: Option<String>Trait Implementations
Sourceimpl Clone for ServiceWorkerVersion
impl Clone for ServiceWorkerVersion
Sourcefn clone(&self) -> ServiceWorkerVersion
fn clone(&self) -> ServiceWorkerVersion
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ServiceWorkerVersion
impl Debug for ServiceWorkerVersion
Sourceimpl Default for ServiceWorkerVersion
impl Default for ServiceWorkerVersion
Sourcefn default() -> ServiceWorkerVersion
fn default() -> ServiceWorkerVersion
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ServiceWorkerVersion
impl<'de> Deserialize<'de> for ServiceWorkerVersion
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more