pub struct ServiceWorkerVersionBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ServiceWorkerVersionBuilder<'a>
impl<'a> ServiceWorkerVersionBuilder<'a>
Sourcepub fn script_last_modified(self, script_last_modified: f64) -> Self
pub fn script_last_modified(self, script_last_modified: f64) -> Self
The Last-Modified header value of the main script.
Sourcepub fn script_response_time(self, script_response_time: f64) -> Self
pub fn script_response_time(self, script_response_time: f64) -> Self
The time at which the response headers of the main script were received from the server. For cached script it is the last time the cache entry was validated.
pub fn controlled_clients(self, controlled_clients: Vec<TargetID<'a>>) -> Self
pub fn target_id(self, target_id: TargetID<'a>) -> Self
pub fn router_rules(self, router_rules: impl Into<Cow<'a, str>>) -> Self
pub fn build(self) -> ServiceWorkerVersion<'a>