Module smartcardemulation

Module smartcardemulation 

Structs

DisableParams
EnableParams
ProtocolSet
Maps to the |SCARD_PROTOCOL_*| flags.
ProtocolSetBuilder
ReaderStateFlags
Maps to the |SCARD_STATE_*| flags.
ReaderStateFlagsBuilder
ReaderStateIn
ReaderStateInBuilder
ReaderStateOut
ReaderStateOutBuilder
ReportBeginTransactionResultParams
Reports the result of a |SCardBeginTransaction| call. On success, this creates a new transaction object.
ReportBeginTransactionResultParamsBuilder
ReportConnectResultParams
Reports the successful result of a |SCardConnect| call.
ReportConnectResultParamsBuilder
ReportDataResultParams
Reports the successful result of a call that sends back data on success. Used for |SCardTransmit|, |SCardControl|, and |SCardGetAttrib|.
ReportDataResultParamsBuilder
ReportErrorParams
Reports an error result for the given request.
ReportErrorParamsBuilder
ReportEstablishContextResultParams
Reports the successful result of a |SCardEstablishContext| call.
ReportEstablishContextResultParamsBuilder
ReportGetStatusChangeResultParams
Reports the successful result of a |SCardGetStatusChange| call.
ReportGetStatusChangeResultParamsBuilder
ReportListReadersResultParams
Reports the successful result of a |SCardListReaders| call.
ReportListReadersResultParamsBuilder
ReportPlainResultParams
Reports the successful result of a call that returns only a result code. Used for: |SCardCancel|, |SCardDisconnect|, |SCardSetAttrib|, |SCardEndTransaction|.
ReportPlainResultParamsBuilder
ReportReleaseContextResultParams
Reports the successful result of a |SCardReleaseContext| call.
ReportReleaseContextResultParamsBuilder
ReportStatusResultParams
Reports the successful result of a |SCardStatus| call.
ReportStatusResultParamsBuilder

Enums

ConnectionState
Maps to |SCARD_*| connection state values.
Disposition
Indicates what the reader should do with the card.
Protocol
Maps to the |SCARD_PROTOCOL_*| values.
ResultCode
Indicates the PC/SC error code.
ShareMode
Maps to the |SCARD_SHARE_*| values.