Module storage

Module storage 

Structs

ClearCookiesParams
Clears cookies.
ClearCookiesParamsBuilder
ClearDataForOriginParams
Clears storage for origin.
ClearDataForOriginParamsBuilder
ClearDataForStorageKeyParams
Clears storage for storage key.
ClearDataForStorageKeyParamsBuilder
ClearSharedStorageEntriesParams
Clears all entries for a given origin’s shared storage.
ClearSharedStorageEntriesParamsBuilder
ClearTrustTokensParams
Removes all Trust Tokens issued by the provided issuerOrigin. Leaves other stored data, including the issuer’s Redemption Records, intact.
ClearTrustTokensParamsBuilder
ClearTrustTokensReturns
Removes all Trust Tokens issued by the provided issuerOrigin. Leaves other stored data, including the issuer’s Redemption Records, intact.
ClearTrustTokensReturnsBuilder
DeleteSharedStorageEntryParams
Deletes entry for ‘key’ (if it exists) for a given origin’s shared storage.
DeleteSharedStorageEntryParamsBuilder
DeleteStorageBucketParams
Deletes the Storage Bucket with the given storage key and bucket name.
DeleteStorageBucketParamsBuilder
GetCookiesParams
Returns all browser cookies.
GetCookiesParamsBuilder
GetCookiesReturns
Returns all browser cookies.
GetCookiesReturnsBuilder
GetInterestGroupDetailsParams
Gets details for a named interest group.
GetInterestGroupDetailsParamsBuilder
GetInterestGroupDetailsReturns
Gets details for a named interest group.
GetInterestGroupDetailsReturnsBuilder
GetRelatedWebsiteSetsParams
GetRelatedWebsiteSetsReturns
Returns the effective Related Website Sets in use by this profile for the browser session. The effective Related Website Sets will not change during a browser session.
GetRelatedWebsiteSetsReturnsBuilder
GetSharedStorageEntriesParams
Gets the entries in an given origin’s shared storage.
GetSharedStorageEntriesParamsBuilder
GetSharedStorageEntriesReturns
Gets the entries in an given origin’s shared storage.
GetSharedStorageEntriesReturnsBuilder
GetSharedStorageMetadataParams
Gets metadata for an origin’s shared storage.
GetSharedStorageMetadataParamsBuilder
GetSharedStorageMetadataReturns
Gets metadata for an origin’s shared storage.
GetSharedStorageMetadataReturnsBuilder
GetStorageKeyForFrameParams
Returns a storage key given a frame id. Deprecated. Please use Storage.getStorageKey instead.
GetStorageKeyForFrameParamsBuilder
GetStorageKeyForFrameReturns
Returns a storage key given a frame id. Deprecated. Please use Storage.getStorageKey instead.
GetStorageKeyForFrameReturnsBuilder
GetStorageKeyParams
Returns storage key for the given frame. If no frame ID is provided, the storage key of the target executing this command is returned.
GetStorageKeyParamsBuilder
GetStorageKeyReturns
Returns storage key for the given frame. If no frame ID is provided, the storage key of the target executing this command is returned.
GetStorageKeyReturnsBuilder
GetTrustTokensParams
GetTrustTokensReturns
Returns the number of stored Trust Tokens per issuer for the current browsing context.
GetTrustTokensReturnsBuilder
GetUsageAndQuotaParams
Returns usage and quota in bytes.
GetUsageAndQuotaParamsBuilder
GetUsageAndQuotaReturns
Returns usage and quota in bytes.
GetUsageAndQuotaReturnsBuilder
OverrideQuotaForOriginParams
Override quota for the specified origin
OverrideQuotaForOriginParamsBuilder
RelatedWebsiteSet
A single Related Website Set object.
RelatedWebsiteSetBuilder
ResetSharedStorageBudgetParams
Resets the budget for ‘ownerOrigin’ by clearing all budget withdrawals.
ResetSharedStorageBudgetParamsBuilder
RunBounceTrackingMitigationsParams
RunBounceTrackingMitigationsReturns
Deletes state for sites identified as potential bounce trackers, immediately.
RunBounceTrackingMitigationsReturnsBuilder
SetCookiesParams
Sets given cookies.
SetCookiesParamsBuilder
SetInterestGroupAuctionTrackingParams
Enables/Disables issuing of interestGroupAuctionEventOccurred and interestGroupAuctionNetworkRequestCreated.
SetInterestGroupAuctionTrackingParamsBuilder
SetInterestGroupTrackingParams
Enables/Disables issuing of interestGroupAccessed events.
SetInterestGroupTrackingParamsBuilder
SetProtectedAudienceKAnonymityParams
SetProtectedAudienceKAnonymityParamsBuilder
SetSharedStorageEntryParams
Sets entry with ‘key’ and ‘value’ for a given origin’s shared storage.
SetSharedStorageEntryParamsBuilder
SetSharedStorageTrackingParams
Enables/disables issuing of sharedStorageAccessed events.
SetSharedStorageTrackingParamsBuilder
SetStorageBucketTrackingParams
Set tracking for a storage key’s buckets.
SetStorageBucketTrackingParamsBuilder
SharedStorageAccessParams
Bundles the parameters for shared storage access events whose presence/absence can vary according to SharedStorageAccessType.
SharedStorageAccessParamsBuilder
SharedStorageEntry
Struct for a single key-value pair in an origin’s shared storage.
SharedStorageEntryBuilder
SharedStorageMetadata
Details for an origin’s shared storage.
SharedStorageMetadataBuilder
SharedStoragePrivateAggregationConfig
Represents a dictionary object passed in as privateAggregationConfig to run or selectURL.
SharedStoragePrivateAggregationConfigBuilder
SharedStorageReportingMetadata
Pair of reporting metadata details for a candidate URL for ‘selectURL()’.
SharedStorageReportingMetadataBuilder
SharedStorageUrlWithMetadata
Bundles a candidate URL with its reporting metadata.
SharedStorageUrlWithMetadataBuilder
StorageBucket
StorageBucketBuilder
StorageBucketInfo
StorageBucketInfoBuilder
TrackCacheStorageForOriginParams
Registers origin to be notified when an update occurs to its cache storage list.
TrackCacheStorageForOriginParamsBuilder
TrackCacheStorageForStorageKeyParams
Registers storage key to be notified when an update occurs to its cache storage list.
TrackCacheStorageForStorageKeyParamsBuilder
TrackIndexedDBForOriginParams
Registers origin to be notified when an update occurs to its IndexedDB.
TrackIndexedDBForOriginParamsBuilder
TrackIndexedDBForStorageKeyParams
Registers storage key to be notified when an update occurs to its IndexedDB.
TrackIndexedDBForStorageKeyParamsBuilder
TrustTokens
Pair of issuer origin and number of available (signed, but not used) Trust Tokens from that issuer.
TrustTokensBuilder
UntrackCacheStorageForOriginParams
Unregisters origin from receiving notifications for cache storage.
UntrackCacheStorageForOriginParamsBuilder
UntrackCacheStorageForStorageKeyParams
Unregisters storage key from receiving notifications for cache storage.
UntrackCacheStorageForStorageKeyParamsBuilder
UntrackIndexedDBForOriginParams
Unregisters origin from receiving notifications for IndexedDB.
UntrackIndexedDBForOriginParamsBuilder
UntrackIndexedDBForStorageKeyParams
Unregisters storage key from receiving notifications for IndexedDB.
UntrackIndexedDBForStorageKeyParamsBuilder
UsageForType
Usage for a storage type.
UsageForTypeBuilder

Enums

InterestGroupAccessType
Enum of interest group access types.
InterestGroupAuctionEventType
Enum of auction events.
InterestGroupAuctionFetchType
Enum of network fetches auctions can do.
SharedStorageAccessMethod
Enum of shared storage access methods.
SharedStorageAccessScope
Enum of shared storage access scopes.
StorageBucketsDurability
StorageType
Enum of possible storage types.

Type Aliases

InterestGroupAuctionId
Protected audience interest group auction identifier.
SerializedStorageKey