pub struct GetRelatedWebsiteSetsReturns {
pub sets: Vec<RelatedWebsiteSet>,
}Expand description
Returns the effective Related Website Sets in use by this profile for the browser session. The effective Related Website Sets will not change during a browser session.
Fields
sets: Vec<RelatedWebsiteSet>Trait Implementations
Sourceimpl Clone for GetRelatedWebsiteSetsReturns
impl Clone for GetRelatedWebsiteSetsReturns
Sourcefn clone(&self) -> GetRelatedWebsiteSetsReturns
fn clone(&self) -> GetRelatedWebsiteSetsReturns
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetRelatedWebsiteSetsReturns
impl Debug for GetRelatedWebsiteSetsReturns
Sourceimpl Default for GetRelatedWebsiteSetsReturns
impl Default for GetRelatedWebsiteSetsReturns
Sourcefn default() -> GetRelatedWebsiteSetsReturns
fn default() -> GetRelatedWebsiteSetsReturns
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for GetRelatedWebsiteSetsReturns
impl<'de> Deserialize<'de> for GetRelatedWebsiteSetsReturns
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more