pub struct GetStorageKeyReturns<'a> { /* private fields */ }Expand description
Returns storage key for the given frame. If no frame ID is provided, the storage key of the target executing this command is returned.
Implementations
Sourceimpl<'a> GetStorageKeyReturns<'a>
impl<'a> GetStorageKeyReturns<'a>
Sourcepub fn builder(
storage_key: impl Into<SerializedStorageKey<'a>>,
) -> GetStorageKeyReturnsBuilder<'a>
pub fn builder( storage_key: impl Into<SerializedStorageKey<'a>>, ) -> GetStorageKeyReturnsBuilder<'a>
Creates a builder for this type with the required parameters:
storage_key:
pub fn storage_key(&self) -> &SerializedStorageKey<'a>