pub struct GetUsageAndQuotaReturns { /* private fields */ }Expand description
Returns usage and quota in bytes.
Implementations
Sourceimpl GetUsageAndQuotaReturns
impl GetUsageAndQuotaReturns
Sourcepub fn builder(
usage: f64,
quota: f64,
override_active: bool,
usage_breakdown: Vec<UsageForType>,
) -> GetUsageAndQuotaReturnsBuilder
pub fn builder( usage: f64, quota: f64, override_active: bool, usage_breakdown: Vec<UsageForType>, ) -> GetUsageAndQuotaReturnsBuilder
Creates a builder for this type with the required parameters:
usage: Storage usage (bytes).quota: Storage quota (bytes).override_active: Whether or not the origin has an active storage quota overrideusage_breakdown: Storage usage per type (bytes).
Sourcepub fn override_active(&self) -> bool
pub fn override_active(&self) -> bool
Whether or not the origin has an active storage quota override
Sourcepub fn usage_breakdown(&self) -> &[UsageForType]
pub fn usage_breakdown(&self) -> &[UsageForType]
Storage usage per type (bytes).