pub struct RelatedWebsiteSet<'a> { /* private fields */ }Expand description
A single Related Website Set object.
Implementations
Sourceimpl<'a> RelatedWebsiteSet<'a>
impl<'a> RelatedWebsiteSet<'a>
Sourcepub fn builder(
primary_sites: Vec<Cow<'a, str>>,
associated_sites: Vec<Cow<'a, str>>,
service_sites: Vec<Cow<'a, str>>,
) -> RelatedWebsiteSetBuilder<'a>
pub fn builder( primary_sites: Vec<Cow<'a, str>>, associated_sites: Vec<Cow<'a, str>>, service_sites: Vec<Cow<'a, str>>, ) -> RelatedWebsiteSetBuilder<'a>
Creates a builder for this type with the required parameters:
primary_sites: The primary site of this set, along with the ccTLDs if there is any.associated_sites: The associated sites of this set, along with the ccTLDs if there is any.service_sites: The service sites of this set, along with the ccTLDs if there is any.
Sourcepub fn primary_sites(&self) -> &[Cow<'a, str>]
pub fn primary_sites(&self) -> &[Cow<'a, str>]
The primary site of this set, along with the ccTLDs if there is any.
Sourcepub fn associated_sites(&self) -> &[Cow<'a, str>]
pub fn associated_sites(&self) -> &[Cow<'a, str>]
The associated sites of this set, along with the ccTLDs if there is any.
Sourcepub fn service_sites(&self) -> &[Cow<'a, str>]
pub fn service_sites(&self) -> &[Cow<'a, str>]
The service sites of this set, along with the ccTLDs if there is any.