pub struct SharedStorageMetadata { /* private fields */ }Expand description
Details for an origin’s shared storage.
Implementations
Sourcepub fn builder(
creation_time: TimeSinceEpoch,
length: u64,
remaining_budget: f64,
bytes_used: i64,
) -> SharedStorageMetadataBuilder
pub fn builder( creation_time: TimeSinceEpoch, length: u64, remaining_budget: f64, bytes_used: i64, ) -> SharedStorageMetadataBuilder
Creates a builder for this type with the required parameters:
creation_time: Time when the origin’s shared storage was last created.length: Number of key-value pairs stored in origin’s shared storage.remaining_budget: Current amount of bits of entropy remaining in the navigation budget.bytes_used: Total number of bytes stored as key-value pairs in origin’s shared storage.
Sourcepub fn creation_time(&self) -> &TimeSinceEpoch
pub fn creation_time(&self) -> &TimeSinceEpoch
Time when the origin’s shared storage was last created.
Sourcepub fn remaining_budget(&self) -> f64
pub fn remaining_budget(&self) -> f64
Current amount of bits of entropy remaining in the navigation budget.
Sourcepub fn bytes_used(&self) -> i64
pub fn bytes_used(&self) -> i64
Total number of bytes stored as key-value pairs in origin’s shared storage.