pub struct SharedStoragePrivateAggregationConfig<'a> { /* private fields */ }Expand description
Represents a dictionary object passed in as privateAggregationConfig to run or selectURL.
Implementations
Sourcepub fn builder(
filtering_id_max_bytes: u64,
) -> SharedStoragePrivateAggregationConfigBuilder<'a>
pub fn builder( filtering_id_max_bytes: u64, ) -> SharedStoragePrivateAggregationConfigBuilder<'a>
Creates a builder for this type with the required parameters:
filtering_id_max_bytes: Configures the maximum size allowed for filtering IDs.
Sourcepub fn aggregation_coordinator_origin(&self) -> Option<&str>
pub fn aggregation_coordinator_origin(&self) -> Option<&str>
The chosen aggregation service deployment.
Sourcepub fn context_id(&self) -> Option<&str>
pub fn context_id(&self) -> Option<&str>
The context ID provided.
Sourcepub fn filtering_id_max_bytes(&self) -> u64
pub fn filtering_id_max_bytes(&self) -> u64
Configures the maximum size allowed for filtering IDs.
Sourcepub fn max_contributions(&self) -> Option<i64>
pub fn max_contributions(&self) -> Option<i64>
The limit on the number of contributions in the final report.