pub struct SharedStorageReportingMetadata<'a> { /* private fields */ }Expand description
Pair of reporting metadata details for a candidate URL for ‘selectURL()’.
Implementations
Sourcepub fn builder(
event_type: impl Into<Cow<'a, str>>,
reporting_url: impl Into<Cow<'a, str>>,
) -> SharedStorageReportingMetadataBuilder<'a>
pub fn builder( event_type: impl Into<Cow<'a, str>>, reporting_url: impl Into<Cow<'a, str>>, ) -> SharedStorageReportingMetadataBuilder<'a>
Creates a builder for this type with the required parameters:
event_type:reporting_url:
pub fn event_type(&self) -> &str
pub fn reporting_url(&self) -> &str