Module systeminfo

Module systeminfo 

The SystemInfo domain defines methods and events for querying low-level system information.

Structs

GPUDevice
Describes a single graphics processor (GPU).
GPUInfo
Provides information about the GPU(s) on the system.
GetFeatureStateParams
Returns information about the feature state.
GetFeatureStateReturns
Returns information about the feature state.
GetInfoParams
GetInfoReturns
Returns information about the system.
GetProcessInfoParams
GetProcessInfoReturns
Returns information about all running processes.
ProcessInfo
Represents process info.
Size
Describes the width and height dimensions of an entity.
VideoDecodeAcceleratorCapability
Describes a supported video decoding profile with its associated minimum and maximum resolutions.
VideoEncodeAcceleratorCapability
Describes a supported video encoding profile with its associated maximum resolution and maximum framerate.

Enums

ImageType
Image format of a given image.
SubsamplingFormat
YUV subsampling type of the pixels of a given image.