pub struct GetInfoReturns<'a> { /* private fields */ }Expand description
Returns information about the system.
Implementations
Sourceimpl<'a> GetInfoReturns<'a>
impl<'a> GetInfoReturns<'a>
Sourcepub fn builder(
gpu: GPUInfo<'a>,
model_name: impl Into<Cow<'a, str>>,
model_version: impl Into<Cow<'a, str>>,
command_line: impl Into<Cow<'a, str>>,
) -> GetInfoReturnsBuilder<'a>
pub fn builder( gpu: GPUInfo<'a>, model_name: impl Into<Cow<'a, str>>, model_version: impl Into<Cow<'a, str>>, command_line: impl Into<Cow<'a, str>>, ) -> GetInfoReturnsBuilder<'a>
Creates a builder for this type with the required parameters:
gpu: Information about the GPUs on the system.model_name: A platform-dependent description of the model of the machine. On Mac OS, this is, for example, ‘MacBookPro’. Will be the empty string if not supported.model_version: A platform-dependent description of the version of the machine. On Mac OS, this is, for example, ‘10.1’. Will be the empty string if not supported.command_line: The command line string used to launch the browser. Will be the empty string if not supported.
Sourcepub fn model_name(&self) -> &str
pub fn model_name(&self) -> &str
A platform-dependent description of the model of the machine. On Mac OS, this is, for example, ‘MacBookPro’. Will be the empty string if not supported.
Sourcepub fn model_version(&self) -> &str
pub fn model_version(&self) -> &str
A platform-dependent description of the version of the machine. On Mac OS, this is, for example, ‘10.1’. Will be the empty string if not supported.
Sourcepub fn command_line(&self) -> &str
pub fn command_line(&self) -> &str
The command line string used to launch the browser. Will be the empty string if not supported.