pub struct VideoDecodeAcceleratorCapability<'a> { /* private fields */ }Expand description
Describes a supported video decoding profile with its associated minimum and maximum resolutions.
Implementations
Sourceimpl<'a> VideoDecodeAcceleratorCapability<'a>
impl<'a> VideoDecodeAcceleratorCapability<'a>
Sourcepub fn builder(
profile: impl Into<Cow<'a, str>>,
max_resolution: Size,
min_resolution: Size,
) -> VideoDecodeAcceleratorCapabilityBuilder<'a>
pub fn builder( profile: impl Into<Cow<'a, str>>, max_resolution: Size, min_resolution: Size, ) -> VideoDecodeAcceleratorCapabilityBuilder<'a>
Creates a builder for this type with the required parameters:
profile: Video codec profile that is supported, e.g. VP9 Profile 2.max_resolution: Maximum video dimensions in pixels supported for this |profile|.min_resolution: Minimum video dimensions in pixels supported for this |profile|.
Sourcepub fn max_resolution(&self) -> &Size
pub fn max_resolution(&self) -> &Size
Maximum video dimensions in pixels supported for this |profile|.
Sourcepub fn min_resolution(&self) -> &Size
pub fn min_resolution(&self) -> &Size
Minimum video dimensions in pixels supported for this |profile|.