pub struct AutoAttachRelatedParams<'a> { /* private fields */ }Expand description
Adds the specified target to the list of targets that will be monitored for any related target creation (such as child frames, child workers and new versions of service worker) and reported through ‘attachedToTarget’. The specified target is also auto-attached. This cancels the effect of any previous ‘setAutoAttach’ and is also cancelled by subsequent ‘setAutoAttach’. Only available at the Browser target.
Implementations
Sourceimpl<'a> AutoAttachRelatedParams<'a>
impl<'a> AutoAttachRelatedParams<'a>
Sourcepub fn builder(
target_id: impl Into<TargetID<'a>>,
wait_for_debugger_on_start: bool,
) -> AutoAttachRelatedParamsBuilder<'a>
pub fn builder( target_id: impl Into<TargetID<'a>>, wait_for_debugger_on_start: bool, ) -> AutoAttachRelatedParamsBuilder<'a>
Creates a builder for this type with the required parameters:
target_id:wait_for_debugger_on_start: Whether to pause new targets when attaching to them. UseRuntime.runIfWaitingForDebuggerto run paused targets.
pub fn target_id(&self) -> &TargetID<'a>
Sourcepub fn wait_for_debugger_on_start(&self) -> bool
pub fn wait_for_debugger_on_start(&self) -> bool
Whether to pause new targets when attaching to them. Use ‘Runtime.runIfWaitingForDebugger’ to run paused targets.
Sourcepub fn filter(&self) -> Option<&TargetFilter<'a>>
pub fn filter(&self) -> Option<&TargetFilter<'a>>
Only targets matching filter will be attached.