pub struct CreateBrowserContextParamsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> CreateBrowserContextParamsBuilder<'a>
impl<'a> CreateBrowserContextParamsBuilder<'a>
Sourcepub fn dispose_on_detach(self, dispose_on_detach: bool) -> Self
pub fn dispose_on_detach(self, dispose_on_detach: bool) -> Self
If specified, disposes this context when debugging session disconnects.
Sourcepub fn proxy_server(self, proxy_server: impl Into<Cow<'a, str>>) -> Self
pub fn proxy_server(self, proxy_server: impl Into<Cow<'a, str>>) -> Self
Proxy server, similar to the one passed to –proxy-server
Sourcepub fn proxy_bypass_list(
self,
proxy_bypass_list: impl Into<Cow<'a, str>>,
) -> Self
pub fn proxy_bypass_list( self, proxy_bypass_list: impl Into<Cow<'a, str>>, ) -> Self
Proxy bypass list, similar to the one passed to –proxy-bypass-list
Sourcepub fn origins_with_universal_network_access(
self,
origins_with_universal_network_access: Vec<Cow<'a, str>>,
) -> Self
pub fn origins_with_universal_network_access( self, origins_with_universal_network_access: Vec<Cow<'a, str>>, ) -> Self
An optional list of origins to grant unlimited cross-origin access to. Parts of the URL other than those constituting origin are ignored.
pub fn build(self) -> CreateBrowserContextParams<'a>