pub struct ExposeDevToolsProtocolParams<'a> { /* private fields */ }Expand description
Inject object to the target’s main frame that provides a communication channel with browser target.
Injected object will be available as ‘window[bindingName]’.
The object has the following API:
- ‘binding.send(json)’ - a method to send messages over the remote debugging protocol
- ‘binding.onmessage = json => handleMessage(json)’ - a callback that will be called for the protocol notifications and command responses.
Implementations
Sourceimpl<'a> ExposeDevToolsProtocolParams<'a>
impl<'a> ExposeDevToolsProtocolParams<'a>
Sourcepub fn builder(
target_id: impl Into<TargetID<'a>>,
) -> ExposeDevToolsProtocolParamsBuilder<'a>
pub fn builder( target_id: impl Into<TargetID<'a>>, ) -> ExposeDevToolsProtocolParamsBuilder<'a>
Creates a builder for this type with the required parameters:
target_id:
pub fn target_id(&self) -> &TargetID<'a>
Sourcepub fn binding_name(&self) -> Option<&str>
pub fn binding_name(&self) -> Option<&str>
Binding name, ‘cdp’ if not specified.
Sourcepub fn inherit_permissions(&self) -> Option<bool>
pub fn inherit_permissions(&self) -> Option<bool>
If true, inherits the current root session’s permissions (default: false).