pub struct GetTargetsParamsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> GetTargetsParamsBuilder<'a>
impl<'a> GetTargetsParamsBuilder<'a>
Sourcepub fn filter(self, filter: TargetFilter<'a>) -> Self
pub fn filter(self, filter: TargetFilter<'a>) -> Self
Only targets matching filter will be reported. If filter is not specified and target discovery is currently enabled, a filter used for target discovery is used for consistency.
pub fn build(self) -> GetTargetsParams<'a>