SetAutoAttachParams

Struct SetAutoAttachParams 

pub struct SetAutoAttachParams<'a> { /* private fields */ }
Controls whether to automatically attach to new targets which are considered to be directly related to this one (for example, iframes or workers). When turned on, attaches to all existing related targets as well. When turned off, automatically detaches from all currently attached targets. This also clears all targets added by ‘autoAttachRelated’ from the list of targets to watch for creation of related targets. You might want to call this recursively for auto-attached targets to attach to all available targets.

Implementations

Source

impl<'a> SetAutoAttachParams<'a>

pub fn builder( auto_attach: bool, wait_for_debugger_on_start: bool, ) -> SetAutoAttachParamsBuilder<'a>

Creates a builder for this type with the required parameters:

  • auto_attach: Whether to auto-attach to related targets.
  • wait_for_debugger_on_start: Whether to pause new targets when attaching to them. Use Runtime.runIfWaitingForDebugger to run paused targets.
pub fn auto_attach(&self) -> bool

Whether to auto-attach to related targets.

pub fn wait_for_debugger_on_start(&self) -> bool

Whether to pause new targets when attaching to them. Use ‘Runtime.runIfWaitingForDebugger’ to run paused targets.

pub fn flatten(&self) -> Option<bool>

Enables “flat” access to the session via specifying sessionId attribute in the commands. We plan to make this the default, deprecate non-flattened mode, and eventually retire it. See crbug.com/991325.

pub fn filter(&self) -> Option<&TargetFilter<'a>>

Only targets matching filter will be attached.

Source

impl<'a> SetAutoAttachParams<'a>

pub const METHOD: &'static str = "Target.setAutoAttach"