Structs
- EndParams
- GetCategories
Params - GetCategories
Returns - Gets supported tracing categories.
- GetTrack
Event Descriptor Params - GetTrack
Event Descriptor Returns - Return a descriptor for all available tracing categories.
- Record
Clock Sync Marker Params - Record a clock sync marker in the trace.
- Request
Memory Dump Params - Request a global memory dump.
- Request
Memory Dump Returns - Request a global memory dump.
- Start
Params - Start trace events collection.
- Trace
Config
Enums
- Memory
Dump Level OfDetail - Details exposed when memory request explicitly declared. Keep consistent with memory_dump_request_args.h and memory_instrumentation.mojom
- Stream
Compression - Compression type to use for traces returned via streams.
- Stream
Format - Data format of a trace. Can be either the legacy JSON format or the protocol buffer format. Note that the JSON format will be deprecated soon.
- Tracing
Backend - Backend type to use for tracing. ‘chrome’ uses the Chrome-integrated tracing service and is supported on all platforms. ‘system’ is only supported on Chrome OS and uses the Perfetto system tracing service. ‘auto’ chooses ‘system’ when the perfettoConfig provided to Tracing.start specifies at least one non-Chrome data source; otherwise uses ‘chrome’.
Type Aliases
- Memory
Dump Config - Configuration for memory dump. Used only when “memory-infra” category is enabled.