pub struct StartParams<'a> { /* private fields */ }Expand description
Start trace events collection.
Implementations
Sourceimpl<'a> StartParams<'a>
impl<'a> StartParams<'a>
Sourcepub fn builder() -> StartParamsBuilder<'a>
pub fn builder() -> StartParamsBuilder<'a>
Creates a builder for this type.
Sourcepub fn categories(&self) -> Option<&str>
pub fn categories(&self) -> Option<&str>
Category/tag filter
Sourcepub fn buffer_usage_reporting_interval(&self) -> Option<f64>
pub fn buffer_usage_reporting_interval(&self) -> Option<f64>
If set, the agent will issue bufferUsage events at this interval, specified in milliseconds
Sourcepub fn transfer_mode(&self) -> Option<&str>
pub fn transfer_mode(&self) -> Option<&str>
Whether to report trace events as series of dataCollected events or to save trace to a stream (defaults to ‘ReportEvents’).
Sourcepub fn stream_format(&self) -> Option<&StreamFormat>
pub fn stream_format(&self) -> Option<&StreamFormat>
Trace data format to use. This only applies when using ‘ReturnAsStream’ transfer mode (defaults to ‘json’).
Sourcepub fn stream_compression(&self) -> Option<&StreamCompression>
pub fn stream_compression(&self) -> Option<&StreamCompression>
Compression format to use. This only applies when using ‘ReturnAsStream’ transfer mode (defaults to ‘none’)
pub fn trace_config(&self) -> Option<&TraceConfig<'a>>
Sourcepub fn perfetto_config(&self) -> Option<&str>
pub fn perfetto_config(&self) -> Option<&str>
Base64-encoded serialized perfetto.protos.TraceConfig protobuf message When specified, the parameters ‘categories’, ‘options’, ‘traceConfig’ are ignored. (Encoded as a base64 string when passed over JSON)
Sourcepub fn tracing_backend(&self) -> Option<&TracingBackend>
pub fn tracing_backend(&self) -> Option<&TracingBackend>
Backend type (defaults to ‘auto’)