pub struct StartParamsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> StartParamsBuilder<'a>
impl<'a> StartParamsBuilder<'a>
Sourcepub fn categories(self, categories: impl Into<Cow<'a, str>>) -> Self
pub fn categories(self, categories: impl Into<Cow<'a, str>>) -> Self
Category/tag filter
Sourcepub fn buffer_usage_reporting_interval(
self,
buffer_usage_reporting_interval: f64,
) -> Self
pub fn buffer_usage_reporting_interval( self, buffer_usage_reporting_interval: f64, ) -> Self
If set, the agent will issue bufferUsage events at this interval, specified in milliseconds
Sourcepub fn transfer_mode(self, transfer_mode: impl Into<Cow<'a, str>>) -> Self
pub fn transfer_mode(self, transfer_mode: impl Into<Cow<'a, str>>) -> Self
Whether to report trace events as series of dataCollected events or to save trace to a stream (defaults to ‘ReportEvents’).
Sourcepub fn stream_format(self, stream_format: impl Into<StreamFormat>) -> Self
pub fn stream_format(self, stream_format: impl Into<StreamFormat>) -> Self
Trace data format to use. This only applies when using ‘ReturnAsStream’ transfer mode (defaults to ‘json’).
Sourcepub fn stream_compression(
self,
stream_compression: impl Into<StreamCompression>,
) -> Self
pub fn stream_compression( self, stream_compression: impl Into<StreamCompression>, ) -> Self
Compression format to use. This only applies when using ‘ReturnAsStream’ transfer mode (defaults to ‘none’)
pub fn trace_config(self, trace_config: TraceConfig<'a>) -> Self
Sourcepub fn perfetto_config(self, perfetto_config: impl Into<Cow<'a, str>>) -> Self
pub fn perfetto_config(self, perfetto_config: impl Into<Cow<'a, str>>) -> Self
Base64-encoded serialized perfetto.protos.TraceConfig protobuf message When specified, the parameters ‘categories’, ‘options’, ‘traceConfig’ are ignored. (Encoded as a base64 string when passed over JSON)
Sourcepub fn tracing_backend(self, tracing_backend: impl Into<TracingBackend>) -> Self
pub fn tracing_backend(self, tracing_backend: impl Into<TracingBackend>) -> Self
Backend type (defaults to ‘auto’)
pub fn build(self) -> StartParams<'a>