BaseAudioContext

Struct BaseAudioContext 

pub struct BaseAudioContext<'a> { /* private fields */ }
Protocol object for BaseAudioContext

Implementations

Source

impl<'a> BaseAudioContext<'a>

pub fn builder( context_id: impl Into<GraphObjectId<'a>>, context_type: impl Into<ContextType>, context_state: impl Into<ContextState>, callback_buffer_size: f64, max_output_channel_count: f64, sample_rate: f64, ) -> BaseAudioContextBuilder<'a>

Creates a builder for this type with the required parameters:

  • context_id:
  • context_type:
  • context_state:
  • callback_buffer_size: Platform-dependent callback buffer size.
  • max_output_channel_count: Number of output channels supported by audio hardware in use.
  • sample_rate: Context sample rate.
pub fn context_id(&self) -> &GraphObjectId<'a>

pub fn context_type(&self) -> &ContextType

pub fn context_state(&self) -> &ContextState

pub fn realtime_data(&self) -> Option<&ContextRealtimeData>

pub fn callback_buffer_size(&self) -> f64

Platform-dependent callback buffer size.

pub fn max_output_channel_count(&self) -> f64

Number of output channels supported by audio hardware in use.

pub fn sample_rate(&self) -> f64

Context sample rate.