pub struct ContextRealtimeData {
pub currentTime: f64,
pub renderCapacity: f64,
pub callbackIntervalMean: f64,
pub callbackIntervalVariance: f64,
}Expand description
Fields in AudioContext that change in real-time.
Fields
currentTime: f64The current context time in second in BaseAudioContext.
renderCapacity: f64The time spent on rendering graph divided by render quantum duration, and multiplied by 100. 100 means the audio renderer reached the full capacity and glitch may occur.
callbackIntervalMean: f64A running mean of callback interval.
callbackIntervalVariance: f64A running variance of callback interval.