This domain allows configuring virtual authenticators to test the WebAuthn API.
Structs
- AddCredential
Params - Adds the credential to the specified authenticator.
- AddCredential
Params Builder - AddVirtual
Authenticator Params - Creates and adds a virtual authenticator.
- AddVirtual
Authenticator Params Builder - AddVirtual
Authenticator Returns - Creates and adds a virtual authenticator.
- AddVirtual
Authenticator Returns Builder - Clear
Credentials Params - Clears all the credentials from the specified device.
- Clear
Credentials Params Builder - Credential
- Credential
Builder - Disable
Params - Enable
Params - Enable the WebAuthn domain and start intercepting credential storage and retrieval with a virtual authenticator.
- Enable
Params Builder - GetCredential
Params - Returns a single credential stored in the given virtual authenticator that matches the credential ID.
- GetCredential
Params Builder - GetCredential
Returns - Returns a single credential stored in the given virtual authenticator that matches the credential ID.
- GetCredential
Returns Builder - GetCredentials
Params - Returns all the credentials stored in the given virtual authenticator.
- GetCredentials
Params Builder - GetCredentials
Returns - Returns all the credentials stored in the given virtual authenticator.
- GetCredentials
Returns Builder - Remove
Credential Params - Removes a credential from the authenticator.
- Remove
Credential Params Builder - Remove
Virtual Authenticator Params - Removes the given authenticator.
- Remove
Virtual Authenticator Params Builder - SetAutomatic
Presence Simulation Params - Sets whether tests of user presence will succeed immediately (if true) or fail to resolve (if false) for an authenticator. The default is true.
- SetAutomatic
Presence Simulation Params Builder - SetCredential
Properties Params - Allows setting credential properties. https://w3c.github.io/webauthn/#sctn-automation-set-credential-properties
- SetCredential
Properties Params Builder - SetResponse
Override Bits Params - Resets parameters isBogusSignature, isBadUV, isBadUP to false if they are not present.
- SetResponse
Override Bits Params Builder - SetUser
Verified Params - Sets whether User Verification succeeds or fails for an authenticator. The default is true.
- SetUser
Verified Params Builder - Virtual
Authenticator Options - Virtual
Authenticator Options Builder