pub struct GetCredentialParams<'a> { /* private fields */ }Expand description
Returns a single credential stored in the given virtual authenticator that matches the credential ID.
Implementations
Sourceimpl<'a> GetCredentialParams<'a>
impl<'a> GetCredentialParams<'a>
Sourcepub fn builder(
authenticator_id: impl Into<AuthenticatorId<'a>>,
credential_id: impl Into<Cow<'a, str>>,
) -> GetCredentialParamsBuilder<'a>
pub fn builder( authenticator_id: impl Into<AuthenticatorId<'a>>, credential_id: impl Into<Cow<'a, str>>, ) -> GetCredentialParamsBuilder<'a>
Creates a builder for this type with the required parameters:
authenticator_id:credential_id:
pub fn authenticator_id(&self) -> &AuthenticatorId<'a>
pub fn credential_id(&self) -> &str