pub struct SetResponseOverrideBitsParams<'a> { /* private fields */ }Expand description
Resets parameters isBogusSignature, isBadUV, isBadUP to false if they are not present.
Implementations
Sourceimpl<'a> SetResponseOverrideBitsParams<'a>
impl<'a> SetResponseOverrideBitsParams<'a>
Sourcepub fn builder(
authenticator_id: impl Into<AuthenticatorId<'a>>,
) -> SetResponseOverrideBitsParamsBuilder<'a>
pub fn builder( authenticator_id: impl Into<AuthenticatorId<'a>>, ) -> SetResponseOverrideBitsParamsBuilder<'a>
Creates a builder for this type with the required parameters:
authenticator_id:
pub fn authenticator_id(&self) -> &AuthenticatorId<'a>
Sourcepub fn is_bogus_signature(&self) -> Option<bool>
pub fn is_bogus_signature(&self) -> Option<bool>
If isBogusSignature is set, overrides the signature in the authenticator response to be zero. Defaults to false.