pub struct VirtualAuthenticatorOptions { /* private fields */ }Implementations
Sourceimpl VirtualAuthenticatorOptions
impl VirtualAuthenticatorOptions
Sourcepub fn builder(
protocol: impl Into<AuthenticatorProtocol>,
transport: impl Into<AuthenticatorTransport>,
) -> VirtualAuthenticatorOptionsBuilder
pub fn builder( protocol: impl Into<AuthenticatorProtocol>, transport: impl Into<AuthenticatorTransport>, ) -> VirtualAuthenticatorOptionsBuilder
Creates a builder for this type with the required parameters:
protocol:transport:
pub fn protocol(&self) -> &AuthenticatorProtocol
Sourcepub fn ctap2_version(&self) -> Option<&Ctap2Version>
pub fn ctap2_version(&self) -> Option<&Ctap2Version>
Defaults to ctap2_0. Ignored if |protocol| == u2f.
pub fn transport(&self) -> &AuthenticatorTransport
Sourcepub fn has_resident_key(&self) -> Option<bool>
pub fn has_resident_key(&self) -> Option<bool>
Defaults to false.
Sourcepub fn has_user_verification(&self) -> Option<bool>
pub fn has_user_verification(&self) -> Option<bool>
Defaults to false.
Sourcepub fn has_large_blob(&self) -> Option<bool>
pub fn has_large_blob(&self) -> Option<bool>
If set to true, the authenticator will support the largeBlob extension. https://w3c.github.io/webauthn#largeBlob Defaults to false.
Sourcepub fn has_cred_blob(&self) -> Option<bool>
pub fn has_cred_blob(&self) -> Option<bool>
If set to true, the authenticator will support the credBlob extension. https://fidoalliance.org/specs/fido-v2.1-rd-20201208/fido-client-to-authenticator-protocol-v2.1-rd-20201208.html#sctn-credBlob-extension Defaults to false.
Sourcepub fn has_min_pin_length(&self) -> Option<bool>
pub fn has_min_pin_length(&self) -> Option<bool>
If set to true, the authenticator will support the minPinLength extension. https://fidoalliance.org/specs/fido-v2.1-ps-20210615/fido-client-to-authenticator-protocol-v2.1-ps-20210615.html#sctn-minpinlength-extension Defaults to false.
Sourcepub fn has_prf(&self) -> Option<bool>
pub fn has_prf(&self) -> Option<bool>
If set to true, the authenticator will support the prf extension. https://w3c.github.io/webauthn/#prf-extension Defaults to false.
Sourcepub fn has_hmac_secret(&self) -> Option<bool>
pub fn has_hmac_secret(&self) -> Option<bool>
If set to true, the authenticator will support the hmac-secret extension. https://fidoalliance.org/specs/fido-v2.1-ps-20210615/fido-client-to-authenticator-protocol-v2.1-ps-20210615.html#sctn-hmac-secret-extension Defaults to false.
Sourcepub fn has_hmac_secret_mc(&self) -> Option<bool>
pub fn has_hmac_secret_mc(&self) -> Option<bool>
If set to true, the authenticator will support the hmac-secret-mc extension. https://fidoalliance.org/specs/fido-v2.2-rd-20241003/fido-client-to-authenticator-protocol-v2.2-rd-20241003.html#sctn-hmac-secret-make-cred-extension Defaults to false.
Sourcepub fn automatic_presence_simulation(&self) -> Option<bool>
pub fn automatic_presence_simulation(&self) -> Option<bool>
If set to true, tests of user presence will succeed immediately. Otherwise, they will not be resolved. Defaults to true.
Sourcepub fn is_user_verified(&self) -> Option<bool>
pub fn is_user_verified(&self) -> Option<bool>
Sets whether User Verification succeeds or fails for an authenticator. Defaults to false.
Sourcepub fn default_backup_eligibility(&self) -> Option<bool>
pub fn default_backup_eligibility(&self) -> Option<bool>
Credentials created by this authenticator will have the backup eligibility (BE) flag set to this value. Defaults to false. https://w3c.github.io/webauthn/#sctn-credential-backup
Sourcepub fn default_backup_state(&self) -> Option<bool>
pub fn default_backup_state(&self) -> Option<bool>
Credentials created by this authenticator will have the backup state (BS) flag set to this value. Defaults to false. https://w3c.github.io/webauthn/#sctn-credential-backup