VirtualAuthenticatorOptionsBuilder

Struct VirtualAuthenticatorOptionsBuilder 

pub struct VirtualAuthenticatorOptionsBuilder { /* private fields */ }

Implementations

Source

impl VirtualAuthenticatorOptionsBuilder

pub fn ctap2_version(self, ctap2_version: impl Into<Ctap2Version>) -> Self

Defaults to ctap2_0. Ignored if |protocol| == u2f.

pub fn has_resident_key(self, has_resident_key: bool) -> Self

Defaults to false.

pub fn has_user_verification(self, has_user_verification: bool) -> Self

Defaults to false.

pub fn has_large_blob(self, has_large_blob: bool) -> Self

If set to true, the authenticator will support the largeBlob extension. https://w3c.github.io/webauthn#largeBlob Defaults to false.

pub fn has_cred_blob(self, has_cred_blob: bool) -> Self

If set to true, the authenticator will support the credBlob extension. https://fidoalliance.org/specs/fido-v2.1-rd-20201208/fido-client-to-authenticator-protocol-v2.1-rd-20201208.html#sctn-credBlob-extension Defaults to false.

pub fn has_min_pin_length(self, has_min_pin_length: bool) -> Self

If set to true, the authenticator will support the minPinLength extension. https://fidoalliance.org/specs/fido-v2.1-ps-20210615/fido-client-to-authenticator-protocol-v2.1-ps-20210615.html#sctn-minpinlength-extension Defaults to false.

pub fn has_prf(self, has_prf: bool) -> Self

If set to true, the authenticator will support the prf extension. https://w3c.github.io/webauthn/#prf-extension Defaults to false.

pub fn has_hmac_secret(self, has_hmac_secret: bool) -> Self

If set to true, the authenticator will support the hmac-secret extension. https://fidoalliance.org/specs/fido-v2.1-ps-20210615/fido-client-to-authenticator-protocol-v2.1-ps-20210615.html#sctn-hmac-secret-extension Defaults to false.

pub fn has_hmac_secret_mc(self, has_hmac_secret_mc: bool) -> Self

pub fn automatic_presence_simulation( self, automatic_presence_simulation: bool, ) -> Self

If set to true, tests of user presence will succeed immediately. Otherwise, they will not be resolved. Defaults to true.

pub fn is_user_verified(self, is_user_verified: bool) -> Self

Sets whether User Verification succeeds or fails for an authenticator. Defaults to false.

pub fn default_backup_eligibility( self, default_backup_eligibility: bool, ) -> Self

Credentials created by this authenticator will have the backup eligibility (BE) flag set to this value. Defaults to false. https://w3c.github.io/webauthn/#sctn-credential-backup

pub fn default_backup_state(self, default_backup_state: bool) -> Self

Credentials created by this authenticator will have the backup state (BS) flag set to this value. Defaults to false. https://w3c.github.io/webauthn/#sctn-credential-backup

pub fn build(self) -> VirtualAuthenticatorOptions