pub struct AXValueSource<'a> { /* private fields */ }Expand description
A single source for a computed AX property.
Implementations
Sourceimpl<'a> AXValueSource<'a>
impl<'a> AXValueSource<'a>
Sourcepub fn builder(type_: impl Into<AXValueSourceType>) -> AXValueSourceBuilder<'a>
pub fn builder(type_: impl Into<AXValueSourceType>) -> AXValueSourceBuilder<'a>
Creates a builder for this type with the required parameters:
type_: What type of source this is.
Sourcepub fn type_(&self) -> &AXValueSourceType
pub fn type_(&self) -> &AXValueSourceType
What type of source this is.
Sourcepub fn attribute_value(&self) -> Option<&AXValue<'a>>
pub fn attribute_value(&self) -> Option<&AXValue<'a>>
The value of the relevant attribute, if any.
Sourcepub fn superseded(&self) -> Option<bool>
pub fn superseded(&self) -> Option<bool>
Whether this source is superseded by a higher priority source.
Sourcepub fn native_source(&self) -> Option<&AXValueNativeSourceType>
pub fn native_source(&self) -> Option<&AXValueNativeSourceType>
The native markup source for this value, e.g. a ‘<label>’ element.
Sourcepub fn native_source_value(&self) -> Option<&AXValue<'a>>
pub fn native_source_value(&self) -> Option<&AXValue<'a>>
The value, such as a node or node list, of the native source.
Sourcepub fn invalid_reason(&self) -> Option<&str>
pub fn invalid_reason(&self) -> Option<&str>
Reason for the value being invalid, if it is.