pub struct AXValueSourceBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> AXValueSourceBuilder<'a>
impl<'a> AXValueSourceBuilder<'a>
Sourcepub fn attribute(self, attribute: impl Into<Cow<'a, str>>) -> Self
pub fn attribute(self, attribute: impl Into<Cow<'a, str>>) -> Self
The name of the relevant attribute, if any.
Sourcepub fn attribute_value(self, attribute_value: AXValue<'a>) -> Self
pub fn attribute_value(self, attribute_value: AXValue<'a>) -> Self
The value of the relevant attribute, if any.
Sourcepub fn superseded(self, superseded: bool) -> Self
pub fn superseded(self, superseded: bool) -> Self
Whether this source is superseded by a higher priority source.
Sourcepub fn native_source(
self,
native_source: impl Into<AXValueNativeSourceType>,
) -> Self
pub fn native_source( self, native_source: impl Into<AXValueNativeSourceType>, ) -> Self
The native markup source for this value, e.g. a ‘<label>’ element.
Sourcepub fn native_source_value(self, native_source_value: AXValue<'a>) -> Self
pub fn native_source_value(self, native_source_value: AXValue<'a>) -> Self
The value, such as a node or node list, of the native source.
Sourcepub fn invalid_reason(self, invalid_reason: impl Into<Cow<'a, str>>) -> Self
pub fn invalid_reason(self, invalid_reason: impl Into<Cow<'a, str>>) -> Self
Reason for the value being invalid, if it is.
pub fn build(self) -> AXValueSource<'a>