pub struct AXValueSourceBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> AXValueSourceBuilder<'a>
impl<'a> AXValueSourceBuilder<'a>
Sourcepub fn attribute(self, attribute: impl Into<Cow<'a, str>>) -> Self
pub fn attribute(self, attribute: impl Into<Cow<'a, str>>) -> Self
The name of the relevant attribute, if any.
Sourcepub fn attributeValue(self, attributeValue: AXValue<'a>) -> Self
pub fn attributeValue(self, attributeValue: AXValue<'a>) -> Self
The value of the relevant attribute, if any.
Sourcepub fn superseded(self, superseded: bool) -> Self
pub fn superseded(self, superseded: bool) -> Self
Whether this source is superseded by a higher priority source.
Sourcepub fn nativeSource(self, nativeSource: AXValueNativeSourceType) -> Self
pub fn nativeSource(self, nativeSource: AXValueNativeSourceType) -> Self
The native markup source for this value, e.g. a ‘
Sourcepub fn nativeSourceValue(self, nativeSourceValue: AXValue<'a>) -> Self
pub fn nativeSourceValue(self, nativeSourceValue: AXValue<'a>) -> Self
The value, such as a node or node list, of the native source.
Sourcepub fn invalidReason(self, invalidReason: impl Into<Cow<'a, str>>) -> Self
pub fn invalidReason(self, invalidReason: impl Into<Cow<'a, str>>) -> Self
Reason for the value being invalid, if it is.
pub fn build(self) -> AXValueSource<'a>