pub struct GetPartialAXTreeParamsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> GetPartialAXTreeParamsBuilder<'a>
impl<'a> GetPartialAXTreeParamsBuilder<'a>
Sourcepub fn nodeId(self, nodeId: NodeId) -> Self
pub fn nodeId(self, nodeId: NodeId) -> Self
Identifier of the node to get the partial accessibility tree for.
Sourcepub fn backendNodeId(self, backendNodeId: BackendNodeId) -> Self
pub fn backendNodeId(self, backendNodeId: BackendNodeId) -> Self
Identifier of the backend node to get the partial accessibility tree for.
Sourcepub fn objectId(self, objectId: RemoteObjectId<'a>) -> Self
pub fn objectId(self, objectId: RemoteObjectId<'a>) -> Self
JavaScript object id of the node wrapper to get the partial accessibility tree for.
Sourcepub fn fetchRelatives(self, fetchRelatives: bool) -> Self
pub fn fetchRelatives(self, fetchRelatives: bool) -> Self
Whether to fetch this node’s ancestors, siblings and children. Defaults to true.
pub fn build(self) -> GetPartialAXTreeParams<'a>