QueryAXTreeParams

Struct QueryAXTreeParams 

pub struct QueryAXTreeParams<'a> { /* private fields */ }
Query a DOM node’s accessibility subtree for accessible name and role. This command computes the name and role for all nodes in the subtree, including those that are ignored for accessibility, and returns those that match the specified name and role. If no DOM node is specified, or the DOM node does not exist, the command returns an error. If neither ‘accessibleName’ or ‘role’ is specified, it returns all the accessibility nodes in the subtree.

Implementations

Source

impl<'a> QueryAXTreeParams<'a>

pub fn builder() -> QueryAXTreeParamsBuilder<'a>

pub fn nodeId(&self) -> Option<&NodeId>

pub fn backendNodeId(&self) -> Option<&BackendNodeId>

pub fn objectId(&self) -> Option<&RemoteObjectId<'a>>

pub fn accessibleName(&self) -> Option<&str>

pub fn role(&self) -> Option<&str>

Source

impl<'a> QueryAXTreeParams<'a>

pub const METHOD: &'static str = "Accessibility.queryAXTree"