Module animation

Module animation 

Structs

Animation
Animation instance.
AnimationBuilder
AnimationEffect
AnimationEffect instance
AnimationEffectBuilder
DisableParams
EnableParams
GetCurrentTimeParams
Returns the current time of the an animation.
GetCurrentTimeParamsBuilder
GetCurrentTimeReturns
Returns the current time of the an animation.
GetCurrentTimeReturnsBuilder
GetPlaybackRateParams
GetPlaybackRateReturns
Gets the playback rate of the document timeline.
GetPlaybackRateReturnsBuilder
KeyframeStyle
Keyframe Style
KeyframeStyleBuilder
KeyframesRule
Keyframes Rule
KeyframesRuleBuilder
ReleaseAnimationsParams
Releases a set of animations to no longer be manipulated.
ReleaseAnimationsParamsBuilder
ResolveAnimationParams
Gets the remote object of the Animation.
ResolveAnimationParamsBuilder
ResolveAnimationReturns
Gets the remote object of the Animation.
ResolveAnimationReturnsBuilder
SeekAnimationsParams
Seek a set of animations to a particular time within each animation.
SeekAnimationsParamsBuilder
SetPausedParams
Sets the paused state of a set of animations.
SetPausedParamsBuilder
SetPlaybackRateParams
Sets the playback rate of the document timeline.
SetPlaybackRateParamsBuilder
SetTimingParams
Sets the timing of an animation node.
SetTimingParamsBuilder
ViewOrScrollTimeline
Timeline instance
ViewOrScrollTimelineBuilder