Structs
- Animation
- Animation instance.
- Animation
Effect - AnimationEffect instance
- GetCurrent
Time Params - Returns the current time of the an animation.
- GetCurrent
Time Returns - Returns the current time of the an animation.
- GetPlayback
Rate Returns - Gets the playback rate of the document timeline.
- Keyframe
Style - Keyframe Style
- Keyframes
Rule - Keyframes Rule
- Release
Animations Params - Releases a set of animations to no longer be manipulated.
- Resolve
Animation Params - Gets the remote object of the Animation.
- Resolve
Animation Returns - Gets the remote object of the Animation.
- Seek
Animations Params - Seek a set of animations to a particular time within each animation.
- SetPaused
Params - Sets the paused state of a set of animations.
- SetPlayback
Rate Params - Sets the playback rate of the document timeline.
- SetTiming
Params - Sets the timing of an animation node.
- View
OrScroll Timeline - Timeline instance