pub struct ViewOrScrollTimeline {
pub sourceNodeId: Option<BackendNodeId>,
pub startOffset: Option<f64>,
pub endOffset: Option<f64>,
pub subjectNodeId: Option<BackendNodeId>,
pub axis: ScrollOrientation,
}Expand description
Timeline instance
Fields
sourceNodeId: Option<BackendNodeId>Scroll container node
startOffset: Option<f64>Represents the starting scroll position of the timeline as a length offset in pixels from scroll origin.
endOffset: Option<f64>Represents the ending scroll position of the timeline as a length offset in pixels from scroll origin.
subjectNodeId: Option<BackendNodeId>The element whose principal box’s visibility in the scrollport defined the progress of the timeline. Does not exist for animations with ScrollTimeline
axis: ScrollOrientationOrientation of the scroll