pub struct ViewOrScrollTimelineBuilder { /* private fields */ }Implementations
Sourceimpl ViewOrScrollTimelineBuilder
impl ViewOrScrollTimelineBuilder
Sourcepub fn sourceNodeId(self, sourceNodeId: BackendNodeId) -> Self
pub fn sourceNodeId(self, sourceNodeId: BackendNodeId) -> Self
Scroll container node
Sourcepub fn startOffset(self, startOffset: f64) -> Self
pub fn startOffset(self, startOffset: f64) -> Self
Represents the starting scroll position of the timeline as a length offset in pixels from scroll origin.
Sourcepub fn endOffset(self, endOffset: f64) -> Self
pub fn endOffset(self, endOffset: f64) -> Self
Represents the ending scroll position of the timeline as a length offset in pixels from scroll origin.
Sourcepub fn subjectNodeId(self, subjectNodeId: BackendNodeId) -> Self
pub fn subjectNodeId(self, subjectNodeId: BackendNodeId) -> Self
The element whose principal box’s visibility in the scrollport defined the progress of the timeline. Does not exist for animations with ScrollTimeline
pub fn build(self) -> ViewOrScrollTimeline