Audits domain allows investigation of page violations and possible improvements.
Structs
- Affected
Cookie - Information about a cookie that is affected by an inspector issue.
- Affected
Frame - Information about the frame affected by an inspector issue.
- Affected
Request - Information about a request that is affected by an inspector issue.
- Attribution
Reporting Issue Details - Details for issues around “Attribution Reporting API” usage. Explainer: https://github.com/WICG/attribution-reporting-api
- Blocked
ByResponse Issue Details - Details for a request that has been blocked with the BLOCKED_BY_RESPONSE code. Currently only used for COEP/COOP, but may be extended to include some CSP errors in the future.
- Bounce
Tracking Issue Details - This issue warns about sites in the redirect chain of a finished navigation that may be flagged as trackers and have their state cleared if they don’t receive a user interaction. Note that in this context ‘site’ means eTLD+1. For example, if the URL ‘https://example.test:80/bounce’ was in the redirect chain, the site reported would be ‘example.test’.
- Check
Forms Issues Params - Check
Forms Issues Returns - Runs the form issues check for the target page. Found issues are reported using Audits.issueAdded event.
- Client
Hint Issue Details - This issue tracks client hints related issues. It’s used to deprecate old features, encourage the use of new ones, and provide general guidance.
- Connection
Allowlist Issue Details - Content
Security Policy Issue Details - Cookie
Deprecation Metadata Issue Details - This issue warns about third-party sites that are accessing cookies on the current page, and have been permitted due to having a global metadata grant. Note that in this context ‘site’ means eTLD+1. For example, if the URL ‘https://example.test:80/web_page’ was accessing cookies, the site reported would be ‘example.test’.
- Cookie
Issue Details - This information is currently necessary, as the front-end has a difficult time finding a specific cookie. With this, we can convey specific error information without the cookie.
- Cookie
Issue Insight - Information about the suggested solution to a cookie issue.
- Cors
Issue Details - Details for a CORS related issue, e.g. a warning or error related to CORS RFC1918 enforcement.
- Deprecation
Issue Details - This issue tracks information needed to print a deprecation message. https://source.chromium.org/chromium/chromium/src/+/main:third_party/blink/renderer/core/frame/third_party/blink/renderer/core/frame/deprecation/README.md
- Disable
Params - Element
Accessibility Issue Details - This issue warns about errors in the select or summary element content model.
- Enable
Params - Failed
Request Info - Federated
Auth Request Issue Details - Federated
Auth User Info Request Issue Details - Generic
Issue Details - Depending on the concrete errorType, different properties are set.
- GetEncoded
Response Params - Returns the response body and size if it were re-encoded with the specified settings. Only applies to images.
- GetEncoded
Response Returns - Returns the response body and size if it were re-encoded with the specified settings. Only applies to images.
- Heavy
AdIssue Details - Inspector
Issue - An inspector issue reported from the back-end.
- Inspector
Issue Details - This struct holds a list of optional fields with additional information specific to the kind of issue. When adding a new issue code, please also add a new optional field to this type.
- Mixed
Content Issue Details - Navigator
User Agent Issue Details - Partitioning
BlobURL Issue Details - Performance
Issue Details - Details for a performance issue.
- Permission
Element Issue Details - This issue warns about improper usage of the
element. - Property
Rule Issue Details - This issue warns about errors in property rules that lead to property registrations being ignored.
- Quirks
Mode Issue Details - Details for issues about documents in Quirks Mode or Limited Quirks Mode that affects page layouting.
- SRIMessage
Signature Issue Details - Selective
Permissions Intervention Issue Details - The issue warns about blocked calls to privacy sensitive APIs via the Selective Permissions Intervention.
- Shared
Array Buffer Issue Details - Details for a issue arising from an SAB being instantiated in, or transferred to a context that is not cross-origin isolated.
- Shared
Dictionary Issue Details - Source
Code Location - Stylesheet
Loading Issue Details - This issue warns when a referenced stylesheet couldn’t be loaded.
- Unencoded
Digest Issue Details - User
Reidentification Issue Details - This issue warns about uses of APIs that may be considered misuse to re-identify users.
Enums
- Attribution
Reporting Issue Type - Blocked
ByResponse Reason - Enum indicating the reason a response has been blocked. These reasons are refinements of the net error BLOCKED_BY_RESPONSE.
- Client
Hint Issue Reason - Connection
Allowlist Error - Content
Security Policy Violation Type - Cookie
Exclusion Reason - Cookie
Operation - Cookie
Warning Reason - Element
Accessibility Issue Reason - Federated
Auth Request Issue Reason - Represents the failure reason when a federated authentication reason fails. Should be updated alongside RequestIdTokenStatus in third_party/blink/public/mojom/devtools/inspector_issue.mojom to include all cases except for success.
- Federated
Auth User Info Request Issue Reason - Represents the failure reason when a getUserInfo() call fails. Should be updated alongside FederatedAuthUserInfoRequestResult in third_party/blink/public/mojom/devtools/inspector_issue.mojom.
- Generic
Issue Error Type - Heavy
AdReason - Heavy
AdResolution Status - Insight
Type - Represents the category of insight that a cookie issue falls under.
- Inspector
Issue Code - A unique identifier for the type of issue. Each type may use one of the optional fields in InspectorIssueDetails to convey more specific information about the kind of issue.
- Mixed
Content Resolution Status - Mixed
Content Resource Type - Partitioning
BlobURL Info - Performance
Issue Type - Permission
Element Issue Type - Property
Rule Issue Reason - SRIMessage
Signature Error - Shared
Array Buffer Issue Type - Shared
Dictionary Error - Style
Sheet Loading Issue Reason - Unencoded
Digest Error - User
Reidentification Issue Type
Type Aliases
- IssueId
- A unique id for a DevTools inspector issue. Allows other entities (e.g. exceptions, CDP message, console messages, etc.) to reference an issue.