InspectorIssueDetails

Struct InspectorIssueDetails 

pub struct InspectorIssueDetails<'a> { /* private fields */ }
This struct holds a list of optional fields with additional information specific to the kind of issue. When adding a new issue code, please also add a new optional field to this type.

Implementations

Source

impl<'a> InspectorIssueDetails<'a>

pub fn builder() -> InspectorIssueDetailsBuilder<'a>

pub fn cookieIssueDetails(&self) -> Option<&CookieIssueDetails<'a>>

pub fn mixedContentIssueDetails(&self) -> Option<&MixedContentIssueDetails<'a>>

pub fn blockedByResponseIssueDetails( &self, ) -> Option<&BlockedByResponseIssueDetails<'a>>

pub fn heavyAdIssueDetails(&self) -> Option<&HeavyAdIssueDetails<'a>>

pub fn contentSecurityPolicyIssueDetails( &self, ) -> Option<&ContentSecurityPolicyIssueDetails<'a>>

pub fn sharedArrayBufferIssueDetails( &self, ) -> Option<&SharedArrayBufferIssueDetails<'a>>

pub fn corsIssueDetails(&self) -> Option<&CorsIssueDetails<'a>>

pub fn attributionReportingIssueDetails( &self, ) -> Option<&AttributionReportingIssueDetails<'a>>

pub fn quirksModeIssueDetails(&self) -> Option<&QuirksModeIssueDetails<'a>>

pub fn partitioningBlobURLIssueDetails( &self, ) -> Option<&PartitioningBlobURLIssueDetails<'a>>

pub fn navigatorUserAgentIssueDetails( &self, ) -> Option<&NavigatorUserAgentIssueDetails<'a>>

pub fn genericIssueDetails(&self) -> Option<&GenericIssueDetails<'a>>

pub fn deprecationIssueDetails(&self) -> Option<&DeprecationIssueDetails<'a>>

pub fn clientHintIssueDetails(&self) -> Option<&ClientHintIssueDetails<'a>>

pub fn federatedAuthRequestIssueDetails( &self, ) -> Option<&FederatedAuthRequestIssueDetails>

pub fn bounceTrackingIssueDetails( &self, ) -> Option<&BounceTrackingIssueDetails<'a>>

pub fn cookieDeprecationMetadataIssueDetails( &self, ) -> Option<&CookieDeprecationMetadataIssueDetails<'a>>

pub fn stylesheetLoadingIssueDetails( &self, ) -> Option<&StylesheetLoadingIssueDetails<'a>>

pub fn propertyRuleIssueDetails(&self) -> Option<&PropertyRuleIssueDetails<'a>>

pub fn federatedAuthUserInfoRequestIssueDetails( &self, ) -> Option<&FederatedAuthUserInfoRequestIssueDetails>

pub fn sharedDictionaryIssueDetails( &self, ) -> Option<&SharedDictionaryIssueDetails<'a>>

pub fn elementAccessibilityIssueDetails( &self, ) -> Option<&ElementAccessibilityIssueDetails>

pub fn sriMessageSignatureIssueDetails( &self, ) -> Option<&SRIMessageSignatureIssueDetails<'a>>

pub fn unencodedDigestIssueDetails( &self, ) -> Option<&UnencodedDigestIssueDetails<'a>>

pub fn connectionAllowlistIssueDetails( &self, ) -> Option<&ConnectionAllowlistIssueDetails<'a>>

pub fn userReidentificationIssueDetails( &self, ) -> Option<&UserReidentificationIssueDetails<'a>>

pub fn permissionElementIssueDetails( &self, ) -> Option<&PermissionElementIssueDetails<'a>>

pub fn performanceIssueDetails(&self) -> Option<&PerformanceIssueDetails<'a>>

pub fn selectivePermissionsInterventionIssueDetails( &self, ) -> Option<&SelectivePermissionsInterventionIssueDetails<'a>>