pub struct PropertyRuleIssueDetails {
pub sourceCodeLocation: SourceCodeLocation,
pub propertyRuleIssueReason: PropertyRuleIssueReason,
pub propertyValue: Option<String>,
}Expand description
This issue warns about errors in property rules that lead to property registrations being ignored.
Fields
sourceCodeLocation: SourceCodeLocationSource code position of the property rule.
propertyRuleIssueReason: PropertyRuleIssueReasonReason why the property rule was discarded.
propertyValue: Option<String>The value of the property rule property that failed to parse