Defines commands and events for Autofill.
Structs
- Address
- Address
Field - Address
Fields - A list of address fields.
- AddressUI
- Defines how an address can be displayed like in chrome://settings/addresses. Address UI is a two dimensional array, each inner array is an “address information line”, and when rendered in a UI surface should be displayed as such. The following address UI for instance: [[{name: “GIVE_NAME”, value: “Jon”}, {name: “FAMILY_NAME”, value: “Doe”}], [{name: “CITY”, value: “Munich”}, {name: “ZIP”, value: “81456”}]] should allow the receiver to render: Jon Doe Munich 81456
- Credit
Card - Filled
Field - SetAddresses
Params - Set addresses so that developers can verify their forms implementation.
- Trigger
Params - Trigger autofill on a form identified by the fieldId. If the field and related form cannot be autofilled, returns an error.
Enums
- Filling
Strategy - Specified whether a filled field was done so by using the html autocomplete attribute or autofill heuristics.