Module backgroundservice

Module backgroundservice 

Defines events for background web platform features.

Structs

BackgroundServiceEvent
ClearEventsParams
Clears all stored data for the service.
EventMetadata
A key-value pair for additional event information to pass along.
SetRecordingParams
Set the recording state for the service.
StartObservingParams
Enables event updates for the service.
StopObservingParams
Disables event updates for the service.

Enums

ServiceName
The Background Service that will be associated with the commands/events. Every Background Service operates independently, but they share the same API.