Defines events for background web platform features.
Structs
- Background
Service Event - Clear
Events Params - Clears all stored data for the service.
- Event
Metadata - A key-value pair for additional event information to pass along.
- SetRecording
Params - Set the recording state for the service.
- Start
Observing Params - Enables event updates for the service.
- Stop
Observing Params - Disables event updates for the service.
Enums
- Service
Name - The Background Service that will be associated with the commands/events. Every Background Service operates independently, but they share the same API.