This domain allows configuring virtual Bluetooth devices to test the web-bluetooth API.
Structs
- AddCharacteristic
Params - Adds a characteristic with |characteristicUuid| and |properties| to the service represented by |serviceId|.
- AddCharacteristic
Returns - Adds a characteristic with |characteristicUuid| and |properties| to the service represented by |serviceId|.
- AddDescriptor
Params - Adds a descriptor with |descriptorUuid| to the characteristic respresented by |characteristicId|.
- AddDescriptor
Returns - Adds a descriptor with |descriptorUuid| to the characteristic respresented by |characteristicId|.
- AddService
Params - Adds a service with |serviceUuid| to the peripheral with |address|.
- AddService
Returns - Adds a service with |serviceUuid| to the peripheral with |address|.
- Characteristic
Properties - Describes the properties of a characteristic. This follows Bluetooth Core Specification BT 4.2 Vol 3 Part G 3.3.1. Characteristic Properties.
- Disable
Params - Enable
Params - Enable the BluetoothEmulation domain.
- Manufacturer
Data - Stores the manufacturer data
- Remove
Characteristic Params - Removes the characteristic respresented by |characteristicId| from the simulated central.
- Remove
Descriptor Params - Removes the descriptor with |descriptorId| from the simulated central.
- Remove
Service Params - Removes the service respresented by |serviceId| from the simulated central.
- Scan
Entry - Stores the advertisement packet information that is sent by a Bluetooth device.
- Scan
Record - Stores the byte data of the advertisement packet sent by a Bluetooth device.
- SetSimulated
Central State Params - Set the state of the simulated central.
- Simulate
Advertisement Params - Simulates an advertisement packet described in |entry| being received by the central.
- Simulate
Characteristic Operation Response Params - Simulates the response from the characteristic with |characteristicId| for a characteristic operation of |type|. The |code| value follows the Error Codes from Bluetooth Core Specification Vol 3 Part F 3.4.1.1 Error Response. The |data| is expected to exist when simulating a successful read operation response.
- Simulate
Descriptor Operation Response Params - Simulates the response from the descriptor with |descriptorId| for a descriptor operation of |type|. The |code| value follows the Error Codes from Bluetooth Core Specification Vol 3 Part F 3.4.1.1 Error Response. The |data| is expected to exist when simulating a successful read operation response.
- SimulateGATT
Disconnection Params - Simulates a GATT disconnection from the peripheral with |address|.
- SimulateGATT
Operation Response Params - Simulates the response code from the peripheral with |address| for a GATT operation of |type|. The |code| value follows the HCI Error Codes from Bluetooth Core Specification Vol 2 Part D 1.3 List Of Error Codes.
- Simulate
Preconnected Peripheral Params - Simulates a peripheral with |address|, |name| and |knownServiceUuids| that has already been connected to the system.
Enums
- Central
State - Indicates the various states of Central.
- Characteristic
Operation Type - Indicates the various types of characteristic operation.
- Characteristic
Write Type - Indicates the various types of characteristic write.
- Descriptor
Operation Type - Indicates the various types of descriptor operation.
- GATT
Operation Type - Indicates the various types of GATT event.