pub struct SimulateCharacteristicOperationResponseParams {
pub characteristicId: String,
pub type_: CharacteristicOperationType,
pub code: i64,
pub data: Option<String>,
}Expand description
Simulates the response from the characteristic with |characteristicId| for a characteristic operation of |type|. The |code| value follows the Error Codes from Bluetooth Core Specification Vol 3 Part F 3.4.1.1 Error Response. The |data| is expected to exist when simulating a successful read operation response.
Fields
characteristicId: Stringtype_: CharacteristicOperationTypecode: i64data: Option<String>Implementations