pub struct SimulateDescriptorOperationResponseParams {
pub descriptorId: String,
pub type_: DescriptorOperationType,
pub code: i64,
pub data: Option<String>,
}Expand description
Simulates the response from the descriptor with |descriptorId| for a descriptor operation of |type|. The |code| value follows the Error Codes from Bluetooth Core Specification Vol 3 Part F 3.4.1.1 Error Response. The |data| is expected to exist when simulating a successful read operation response.
Fields
descriptorId: Stringtype_: DescriptorOperationTypecode: i64data: Option<String>Trait Implementations
Sourceimpl Clone for SimulateDescriptorOperationResponseParams
impl Clone for SimulateDescriptorOperationResponseParams
Sourcefn clone(&self) -> SimulateDescriptorOperationResponseParams
fn clone(&self) -> SimulateDescriptorOperationResponseParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for SimulateDescriptorOperationResponseParams
impl Default for SimulateDescriptorOperationResponseParams
Sourcefn default() -> SimulateDescriptorOperationResponseParams
fn default() -> SimulateDescriptorOperationResponseParams
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SimulateDescriptorOperationResponseParams
impl<'de> Deserialize<'de> for SimulateDescriptorOperationResponseParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more