pub struct SimulateGATTOperationResponseParams<'a> { /* private fields */ }Expand description
Simulates the response code from the peripheral with |address| for a GATT operation of |type|. The |code| value follows the HCI Error Codes from Bluetooth Core Specification Vol 2 Part D 1.3 List Of Error Codes.
Implementations
Sourceimpl<'a> SimulateGATTOperationResponseParams<'a>
impl<'a> SimulateGATTOperationResponseParams<'a>