The Browser domain defines methods and events for browser managing.
Structs
- AddPrivacy
Sandbox Coordinator KeyConfig Params - Configures encryption keys used with a given privacy sandbox API to talk to a trusted coordinator. Since this is intended for test automation only, coordinatorOrigin must be a .test domain. No existing coordinator configuration for the origin may exist.
- AddPrivacy
Sandbox Coordinator KeyConfig Params Builder - AddPrivacy
Sandbox Enrollment Override Params - Allows a site to use privacy sandbox features that require enrollment without the site actually being enrolled. Only supported on page targets.
- AddPrivacy
Sandbox Enrollment Override Params Builder - Bounds
- Browser window bounds information
- Bounds
Builder - Bucket
- Chrome histogram bucket.
- Bucket
Builder - Cancel
Download Params - Cancel a download if in progress
- Cancel
Download Params Builder - Close
Params - Crash
GpuProcess Params - Crash
Params - Execute
Browser Command Params - Invoke custom browser commands used by telemetry.
- Execute
Browser Command Params Builder - GetBrowser
Command Line Params - GetBrowser
Command Line Returns - Returns the command line switches for the browser process if, and only if –enable-automation is on the commandline.
- GetBrowser
Command Line Returns Builder - GetHistogram
Params - Get a Chrome histogram by name.
- GetHistogram
Params Builder - GetHistogram
Returns - Get a Chrome histogram by name.
- GetHistogram
Returns Builder - GetHistograms
Params - Get Chrome histograms.
- GetHistograms
Params Builder - GetHistograms
Returns - Get Chrome histograms.
- GetHistograms
Returns Builder - GetVersion
Params - GetVersion
Returns - Returns version information.
- GetVersion
Returns Builder - GetWindow
Bounds Params - Get position and size of the browser window.
- GetWindow
Bounds Params Builder - GetWindow
Bounds Returns - Get position and size of the browser window.
- GetWindow
Bounds Returns Builder - GetWindow
ForTarget Params - Get the browser window that contains the devtools target.
- GetWindow
ForTarget Params Builder - GetWindow
ForTarget Returns - Get the browser window that contains the devtools target.
- GetWindow
ForTarget Returns Builder - Grant
Permissions Params - Grant specific permissions to the given origin and reject all others. Deprecated. Use setPermission instead.
- Grant
Permissions Params Builder - Histogram
- Chrome histogram.
- Histogram
Builder - Permission
Descriptor - Definition of PermissionDescriptor defined in the Permissions API: https://w3c.github.io/permissions/#dom-permissiondescriptor.
- Permission
Descriptor Builder - Reset
Permissions Params - Reset all permission management for all origins.
- Reset
Permissions Params Builder - SetContents
Size Params - Set size of the browser contents resizing browser window as necessary.
- SetContents
Size Params Builder - SetDock
Tile Params - Set dock tile details, platform-specific.
- SetDock
Tile Params Builder - SetDownload
Behavior Params - Set the behavior when downloading a file.
- SetDownload
Behavior Params Builder - SetPermission
Params - Set permission settings for given embedding and embedded origins.
- SetPermission
Params Builder - SetWindow
Bounds Params - Set position and/or size of the browser window.
- SetWindow
Bounds Params Builder
Enums
- Browser
Command Id - Browser command ids used by executeBrowserCommand.
- Permission
Setting - Permission
Type - Privacy
SandboxAPI - Window
State - The state of the browser window.