Module browser

Module browser 

The Browser domain defines methods and events for browser managing.

Structs

AddPrivacySandboxCoordinatorKeyConfigParams
Configures encryption keys used with a given privacy sandbox API to talk to a trusted coordinator. Since this is intended for test automation only, coordinatorOrigin must be a .test domain. No existing coordinator configuration for the origin may exist.
AddPrivacySandboxEnrollmentOverrideParams
Allows a site to use privacy sandbox features that require enrollment without the site actually being enrolled. Only supported on page targets.
Bounds
Browser window bounds information
Bucket
Chrome histogram bucket.
CancelDownloadParams
Cancel a download if in progress
CloseParams
CrashGpuProcessParams
CrashParams
ExecuteBrowserCommandParams
Invoke custom browser commands used by telemetry.
GetBrowserCommandLineParams
GetBrowserCommandLineReturns
Returns the command line switches for the browser process if, and only if –enable-automation is on the commandline.
GetHistogramParams
Get a Chrome histogram by name.
GetHistogramReturns
Get a Chrome histogram by name.
GetHistogramsParams
Get Chrome histograms.
GetHistogramsReturns
Get Chrome histograms.
GetVersionParams
GetVersionReturns
Returns version information.
GetWindowBoundsParams
Get position and size of the browser window.
GetWindowBoundsReturns
Get position and size of the browser window.
GetWindowForTargetParams
Get the browser window that contains the devtools target.
GetWindowForTargetReturns
Get the browser window that contains the devtools target.
GrantPermissionsParams
Grant specific permissions to the given origin and reject all others. Deprecated. Use setPermission instead.
Histogram
Chrome histogram.
PermissionDescriptor
Definition of PermissionDescriptor defined in the Permissions API: https://w3c.github.io/permissions/#dom-permissiondescriptor.
ResetPermissionsParams
Reset all permission management for all origins.
SetContentsSizeParams
Set size of the browser contents resizing browser window as necessary.
SetDockTileParams
Set dock tile details, platform-specific.
SetDownloadBehaviorParams
Set the behavior when downloading a file.
SetPermissionParams
Set permission settings for given embedding and embedded origins.
SetWindowBoundsParams
Set position and/or size of the browser window.

Enums

BrowserCommandId
Browser command ids used by executeBrowserCommand.
PermissionSetting
PermissionType
PrivacySandboxAPI
WindowState
The state of the browser window.

Type Aliases

BrowserContextID
WindowID