The Browser domain defines methods and events for browser managing.
Structs
- AddPrivacy
Sandbox Coordinator KeyConfig Params - Configures encryption keys used with a given privacy sandbox API to talk to a trusted coordinator. Since this is intended for test automation only, coordinatorOrigin must be a .test domain. No existing coordinator configuration for the origin may exist.
- AddPrivacy
Sandbox Enrollment Override Params - Allows a site to use privacy sandbox features that require enrollment without the site actually being enrolled. Only supported on page targets.
- Bounds
- Browser window bounds information
- Bucket
- Chrome histogram bucket.
- Cancel
Download Params - Cancel a download if in progress
- Execute
Browser Command Params - Invoke custom browser commands used by telemetry.
- GetBrowser
Command Line Returns - Returns the command line switches for the browser process if, and only if –enable-automation is on the commandline.
- GetHistogram
Params - Get a Chrome histogram by name.
- GetHistogram
Returns - Get a Chrome histogram by name.
- GetHistograms
Params - Get Chrome histograms.
- GetHistograms
Returns - Get Chrome histograms.
- GetVersion
Returns - Returns version information.
- GetWindow
Bounds Params - Get position and size of the browser window.
- GetWindow
Bounds Returns - Get position and size of the browser window.
- GetWindow
ForTarget Params - Get the browser window that contains the devtools target.
- GetWindow
ForTarget Returns - Get the browser window that contains the devtools target.
- Grant
Permissions Params - Grant specific permissions to the given origin and reject all others. Deprecated. Use setPermission instead.
- Histogram
- Chrome histogram.
- Permission
Descriptor - Definition of PermissionDescriptor defined in the Permissions API: https://w3c.github.io/permissions/#dom-permissiondescriptor.
- Reset
Permissions Params - Reset all permission management for all origins.
- SetContents
Size Params - Set size of the browser contents resizing browser window as necessary.
- SetDock
Tile Params - Set dock tile details, platform-specific.
- SetDownload
Behavior Params - Set the behavior when downloading a file.
- SetPermission
Params - Set permission settings for given embedding and embedded origins.
- SetWindow
Bounds Params - Set position and/or size of the browser window.
Enums
- Browser
Command Id - Browser command ids used by executeBrowserCommand.
- Permission
Setting - Permission
Type - Privacy
SandboxAPI - Window
State - The state of the browser window.