SetPermissionParams

Struct SetPermissionParams 

pub struct SetPermissionParams<'a> { /* private fields */ }
Set permission settings for given embedding and embedded origins.

Implementations

Source

impl<'a> SetPermissionParams<'a>

pub fn builder( permission: PermissionDescriptor<'a>, setting: impl Into<PermissionSetting>, ) -> SetPermissionParamsBuilder<'a>

Creates a builder for this type with the required parameters:

  • permission: Descriptor of permission to override.
  • setting: Setting of the permission.
pub fn permission(&self) -> &PermissionDescriptor<'a>

Descriptor of permission to override.

pub fn setting(&self) -> &PermissionSetting

Setting of the permission.

pub fn origin(&self) -> Option<&str>

Embedding origin the permission applies to, all origins if not specified.

pub fn embedded_origin(&self) -> Option<&str>

Embedded origin the permission applies to. It is ignored unless the embedding origin is present and valid. If the embedding origin is provided but the embedded origin isn’t, the embedding origin is used as the embedded origin.

pub fn browser_context_id(&self) -> Option<&BrowserContextID<'a>>

Context to override. When omitted, default browser context is used.

Source

impl<'a> SetPermissionParams<'a>

pub const METHOD: &'static str = "Browser.setPermission"