SetPermissionParams

Struct SetPermissionParams 

pub struct SetPermissionParams {
    pub permission: PermissionDescriptor,
    pub setting: PermissionSetting,
    pub origin: Option<String>,
    pub embeddedOrigin: Option<String>,
    pub browserContextId: Option<BrowserContextID>,
}
Set permission settings for given embedding and embedded origins.

Fields

permission: PermissionDescriptor

Descriptor of permission to override.

setting: PermissionSetting

Setting of the permission.

origin: Option<String>

Embedding origin the permission applies to, all origins if not specified.

embeddedOrigin: Option<String>

Embedded origin the permission applies to. It is ignored unless the embedding origin is present and valid. If the embedding origin is provided but the embedded origin isn’t, the embedding origin is used as the embedded origin.

browserContextId: Option<BrowserContextID>

Context to override. When omitted, default browser context is used.