SetPermissionParamsBuilder

Struct SetPermissionParamsBuilder 

pub struct SetPermissionParamsBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> SetPermissionParamsBuilder<'a>

pub fn origin(self, origin: impl Into<Cow<'a, str>>) -> Self

Embedding origin the permission applies to, all origins if not specified.

pub fn embeddedOrigin(self, embeddedOrigin: impl Into<Cow<'a, str>>) -> Self

Embedded origin the permission applies to. It is ignored unless the embedding origin is present and valid. If the embedding origin is provided but the embedded origin isn’t, the embedding origin is used as the embedded origin.

pub fn browserContextId(self, browserContextId: BrowserContextID<'a>) -> Self

Context to override. When omitted, default browser context is used.

pub fn build(self) -> SetPermissionParams<'a>