A domain for interacting with Cast, Presentation API, and Remote Playback API functionalities.
Structs
- Enable
Params - Starts observing for sinks that can be used for tab mirroring, and if set, sinks compatible with |presentationUrl| as well. When sinks are found, a |sinksUpdated| event is fired. Also starts observing for issue messages. When an issue is added or removed, an |issueUpdated| event is fired.
- SetSink
ToUse Params - Sets a sink to be used when the web page requests the browser to choose a sink via Presentation API, Remote Playback API, or Cast SDK.
- Sink
- Start
Desktop Mirroring Params - Starts mirroring the desktop to the sink.
- Start
TabMirroring Params - Starts mirroring the tab to the sink.
- Stop
Casting Params - Stops the active Cast session on the sink.