Module css

Module css 

This domain exposes CSS read/write operations. All CSS objects (stylesheets, rules, and styles) have an associated ‘id’ used in subsequent operations on the related object. Each object type has a specific ‘id’ structure, and those are not interchangeable between objects of different kinds. CSS objects can be loaded using the ‘get*ForNode()’ calls (which accept a DOM node id). A client can also keep track of stylesheets via the ‘styleSheetAdded’/‘styleSheetRemoved’ events and subsequently load the required stylesheet contents using the ‘getStyleSheet[Text]()’ methods.

Structs

AddRuleParams
Inserts a new rule with the given ‘ruleText’ in a stylesheet with given ‘styleSheetId’, at the position specified by ‘location’.
AddRuleReturns
Inserts a new rule with the given ‘ruleText’ in a stylesheet with given ‘styleSheetId’, at the position specified by ‘location’.
CSSAnimationStyle
CSS style coming from animations with the name of the animation.
CSSAtRule
CSS generic @rule representation.
CSSComputedStyleProperty
CSSContainerQuery
CSS container query rule descriptor.
CSSFunctionConditionNode
CSS function conditional block representation.
CSSFunctionNode
Section of the body of a CSS function rule.
CSSFunctionParameter
CSS function argument representation.
CSSFunctionRule
CSS function at-rule representation.
CSSKeyframeRule
CSS keyframe rule representation.
CSSKeyframesRule
CSS keyframes rule representation.
CSSLayer
CSS Layer at-rule descriptor.
CSSLayerData
CSS Layer data.
CSSMedia
CSS media rule descriptor.
CSSNavigation
CSS Navigation at-rule descriptor.
CSSPositionTryRule
CSS @position-try rule representation.
CSSProperty
CSS property declaration data.
CSSPropertyRegistration
Representation of a custom property registration through CSS.registerProperty
CSSPropertyRule
CSS property at-rule representation.
CSSRule
CSS rule representation.
CSSScope
CSS Scope at-rule descriptor.
CSSStartingStyle
CSS Starting Style at-rule descriptor.
CSSStyle
CSS style representation.
CSSStyleSheetHeader
CSS stylesheet metainformation.
CSSSupports
CSS Supports at-rule descriptor.
CSSTryRule
CSS try rule representation.
CollectClassNamesParams
Returns all class names from specified stylesheet.
CollectClassNamesReturns
Returns all class names from specified stylesheet.
ComputedStyleExtraFields
CreateStyleSheetParams
Creates a new special “via-inspector” stylesheet in the frame with given ‘frameId’.
CreateStyleSheetReturns
Creates a new special “via-inspector” stylesheet in the frame with given ‘frameId’.
FontFace
Properties of a web font: https://www.w3.org/TR/2008/REC-CSS2-20080411/fonts.html#font-descriptions and additional information such as platformFontFamily and fontVariationAxes.
FontVariationAxis
Information about font variation axes for variable fonts
ForcePseudoStateParams
Ensures that the given node will have specified pseudo-classes whenever its style is computed by the browser.
ForceStartingStyleParams
Ensures that the given node is in its starting-style state.
GetAnimatedStylesForNodeParams
Returns the styles coming from animations & transitions including the animation & transition styles coming from inheritance chain.
GetAnimatedStylesForNodeReturns
Returns the styles coming from animations & transitions including the animation & transition styles coming from inheritance chain.
GetBackgroundColorsParams
GetBackgroundColorsReturns
GetComputedStyleForNodeParams
Returns the computed style for a DOM node identified by ‘nodeId’.
GetComputedStyleForNodeReturns
Returns the computed style for a DOM node identified by ‘nodeId’.
GetEnvironmentVariablesReturns
Returns the values of the default UA-defined environment variables used in env()
GetInlineStylesForNodeParams
Returns the styles defined inline (explicitly in the “style” attribute and implicitly, using DOM attributes) for a DOM node identified by ‘nodeId’.
GetInlineStylesForNodeReturns
Returns the styles defined inline (explicitly in the “style” attribute and implicitly, using DOM attributes) for a DOM node identified by ‘nodeId’.
GetLayersForNodeParams
Returns all layers parsed by the rendering engine for the tree scope of a node. Given a DOM element identified by nodeId, getLayersForNode returns the root layer for the nearest ancestor document or shadow root. The layer root contains the full layer tree for the tree scope and their ordering.
GetLayersForNodeReturns
Returns all layers parsed by the rendering engine for the tree scope of a node. Given a DOM element identified by nodeId, getLayersForNode returns the root layer for the nearest ancestor document or shadow root. The layer root contains the full layer tree for the tree scope and their ordering.
GetLocationForSelectorParams
Given a CSS selector text and a style sheet ID, getLocationForSelector returns an array of locations of the CSS selector in the style sheet.
GetLocationForSelectorReturns
Given a CSS selector text and a style sheet ID, getLocationForSelector returns an array of locations of the CSS selector in the style sheet.
GetLonghandPropertiesParams
GetLonghandPropertiesReturns
GetMatchedStylesForNodeParams
Returns requested styles for a DOM node identified by ‘nodeId’.
GetMatchedStylesForNodeReturns
Returns requested styles for a DOM node identified by ‘nodeId’.
GetMediaQueriesReturns
Returns all media queries parsed by the rendering engine.
GetPlatformFontsForNodeParams
Requests information about platform fonts which we used to render child TextNodes in the given node.
GetPlatformFontsForNodeReturns
Requests information about platform fonts which we used to render child TextNodes in the given node.
GetStyleSheetTextParams
Returns the current textual content for a stylesheet.
GetStyleSheetTextReturns
Returns the current textual content for a stylesheet.
InheritedAnimatedStyleEntry
Inherited CSS style collection for animated styles from ancestor node.
InheritedPseudoElementMatches
Inherited pseudo element matches from pseudos of an ancestor node.
InheritedStyleEntry
Inherited CSS rule collection from ancestor node.
MediaQuery
Media query descriptor.
MediaQueryExpression
Media query expression descriptor.
PlatformFontUsage
Information about amount of glyphs that were rendered with given font.
ProtocolValue
Data for a simple selector (these are delimited by commas in a selector list).
PseudoElementMatches
CSS rule collection for a single pseudo style.
ResolveValuesParams
Resolve the specified values in the context of the provided element. For example, a value of ‘1em’ is evaluated according to the computed ‘font-size’ of the element and a value ‘calc(1px + 2px)’ will be resolved to ‘3px’. If the ‘propertyName’ was specified the ‘values’ are resolved as if they were property’s declaration. If a value cannot be parsed according to the provided property syntax, the value is parsed using combined syntax as if null ‘propertyName’ was provided. If the value cannot be resolved even then, return the provided value without any changes. Note: this function currently does not resolve CSS random() function, it returns unmodified random() function parts.’
ResolveValuesReturns
Resolve the specified values in the context of the provided element. For example, a value of ‘1em’ is evaluated according to the computed ‘font-size’ of the element and a value ‘calc(1px + 2px)’ will be resolved to ‘3px’. If the ‘propertyName’ was specified the ‘values’ are resolved as if they were property’s declaration. If a value cannot be parsed according to the provided property syntax, the value is parsed using combined syntax as if null ‘propertyName’ was provided. If the value cannot be resolved even then, return the provided value without any changes. Note: this function currently does not resolve CSS random() function, it returns unmodified random() function parts.’
RuleMatch
Match data for a CSS rule.
RuleUsage
CSS coverage information.
SelectorList
Selector list data.
SetContainerQueryTextParams
Modifies the expression of a container query.
SetContainerQueryTextReturns
Modifies the expression of a container query.
SetEffectivePropertyValueForNodeParams
Find a rule with the given active property for the given node and set the new value for this property
SetKeyframeKeyParams
Modifies the keyframe rule key text.
SetKeyframeKeyReturns
Modifies the keyframe rule key text.
SetLocalFontsEnabledParams
Enables/disables rendering of local CSS fonts (enabled by default).
SetMediaTextParams
Modifies the rule selector.
SetMediaTextReturns
Modifies the rule selector.
SetNavigationTextParams
Modifies the expression of a navigation at-rule.
SetNavigationTextReturns
Modifies the expression of a navigation at-rule.
SetPropertyRulePropertyNameParams
Modifies the property rule property name.
SetPropertyRulePropertyNameReturns
Modifies the property rule property name.
SetRuleSelectorParams
Modifies the rule selector.
SetRuleSelectorReturns
Modifies the rule selector.
SetScopeTextParams
Modifies the expression of a scope at-rule.
SetScopeTextReturns
Modifies the expression of a scope at-rule.
SetStyleSheetTextParams
Sets the new stylesheet text.
SetStyleSheetTextReturns
Sets the new stylesheet text.
SetStyleTextsParams
Applies specified style edits one after another in the given order.
SetStyleTextsReturns
Applies specified style edits one after another in the given order.
SetSupportsTextParams
Modifies the expression of a supports at-rule.
SetSupportsTextReturns
Modifies the expression of a supports at-rule.
ShorthandEntry
SourceRange
Text range within a resource. All numbers are zero-based.
Specificity
Specificity: https://drafts.csswg.org/selectors/#specificity-rules
StopRuleUsageTrackingReturns
Stop tracking rule usage and return the list of rules that were used since last call to ‘takeCoverageDelta’ (or since start of coverage instrumentation).
StyleDeclarationEdit
A descriptor of operation to mutate style declaration text.
TakeComputedStyleUpdatesReturns
Polls the next batch of computed style updates.
TakeCoverageDeltaReturns
Obtain list of rules that became used since last call to this method (or since start of coverage instrumentation).
TrackComputedStyleUpdatesForNodeParams
Starts tracking the given node for the computed style updates and whenever the computed style is updated for node, it queues a ‘computedStyleUpdated’ event with throttling. There can only be 1 node tracked for computed style updates so passing a new node id removes tracking from the previous node. Pass ‘undefined’ to disable tracking.
TrackComputedStyleUpdatesParams
Starts tracking the given computed styles for updates. The specified array of properties replaces the one previously specified. Pass empty array to disable tracking. Use takeComputedStyleUpdates to retrieve the list of nodes that had properties modified. The changes to computed style properties are only tracked for nodes pushed to the front-end by the DOM agent. If no changes to the tracked properties occur after the node has been pushed to the front-end, no updates will be issued for the node.

Enums

CSSRuleType
Enum indicating the type of a CSS rule, used to represent the order of a style rule’s ancestors. This list only contains rule types that are collected during the ancestor rule collection.
StyleSheetOrigin
Stylesheet type: “injected” for stylesheets injected via extension, “user-agent” for user-agent stylesheets, “inspector” for stylesheets created by the inspector (i.e. those holding the “via inspector” rules), “regular” for regular stylesheets.