This domain exposes CSS read/write operations. All CSS objects (stylesheets, rules, and styles) have an associated ‘id’ used in subsequent operations on the related object. Each object type has a specific ‘id’ structure, and those are not interchangeable between objects of different kinds. CSS objects can be loaded using the ‘get*ForNode()’ calls (which accept a DOM node id). A client can also keep track of stylesheets via the ‘styleSheetAdded’/‘styleSheetRemoved’ events and subsequently load the required stylesheet contents using the ‘getStyleSheet[Text]()’ methods.
Structs
- AddRule
Params - Inserts a new rule with the given ‘ruleText’ in a stylesheet with given ‘styleSheetId’, at the position specified by ‘location’.
- AddRule
Returns - Inserts a new rule with the given ‘ruleText’ in a stylesheet with given ‘styleSheetId’, at the position specified by ‘location’.
- CSSAnimation
Style - CSS style coming from animations with the name of the animation.
- CSSAt
Rule - CSS generic @rule representation.
- CSSComputed
Style Property - CSSContainer
Query - CSS container query rule descriptor.
- CSSFunction
Condition Node - CSS function conditional block representation.
- CSSFunction
Node - Section of the body of a CSS function rule.
- CSSFunction
Parameter - CSS function argument representation.
- CSSFunction
Rule - CSS function at-rule representation.
- CSSKeyframe
Rule - CSS keyframe rule representation.
- CSSKeyframes
Rule - CSS keyframes rule representation.
- CSSLayer
- CSS Layer at-rule descriptor.
- CSSLayer
Data - CSS Layer data.
- CSSMedia
- CSS media rule descriptor.
- CSSNavigation
- CSS Navigation at-rule descriptor.
- CSSPosition
TryRule - CSS @position-try rule representation.
- CSSProperty
- CSS property declaration data.
- CSSProperty
Registration - Representation of a custom property registration through CSS.registerProperty
- CSSProperty
Rule - CSS property at-rule representation.
- CSSRule
- CSS rule representation.
- CSSScope
- CSS Scope at-rule descriptor.
- CSSStarting
Style - CSS Starting Style at-rule descriptor.
- CSSStyle
- CSS style representation.
- CSSStyle
Sheet Header - CSS stylesheet metainformation.
- CSSSupports
- CSS Supports at-rule descriptor.
- CSSTry
Rule - CSS try rule representation.
- Collect
Class Names Params - Returns all class names from specified stylesheet.
- Collect
Class Names Returns - Returns all class names from specified stylesheet.
- Computed
Style Extra Fields - Create
Style Sheet Params - Creates a new special “via-inspector” stylesheet in the frame with given ‘frameId’.
- Create
Style Sheet Returns - Creates a new special “via-inspector” stylesheet in the frame with given ‘frameId’.
- Font
Face - Properties of a web font: https://www.w3.org/TR/2008/REC-CSS2-20080411/fonts.html#font-descriptions and additional information such as platformFontFamily and fontVariationAxes.
- Font
Variation Axis - Information about font variation axes for variable fonts
- Force
Pseudo State Params - Ensures that the given node will have specified pseudo-classes whenever its style is computed by the browser.
- Force
Starting Style Params - Ensures that the given node is in its starting-style state.
- GetAnimated
Styles ForNode Params - Returns the styles coming from animations & transitions including the animation & transition styles coming from inheritance chain.
- GetAnimated
Styles ForNode Returns - Returns the styles coming from animations & transitions including the animation & transition styles coming from inheritance chain.
- GetBackground
Colors Params - GetBackground
Colors Returns - GetComputed
Style ForNode Params - Returns the computed style for a DOM node identified by ‘nodeId’.
- GetComputed
Style ForNode Returns - Returns the computed style for a DOM node identified by ‘nodeId’.
- GetEnvironment
Variables Returns - Returns the values of the default UA-defined environment variables used in env()
- GetInline
Styles ForNode Params - Returns the styles defined inline (explicitly in the “style” attribute and implicitly, using DOM attributes) for a DOM node identified by ‘nodeId’.
- GetInline
Styles ForNode Returns - Returns the styles defined inline (explicitly in the “style” attribute and implicitly, using DOM attributes) for a DOM node identified by ‘nodeId’.
- GetLayers
ForNode Params - Returns all layers parsed by the rendering engine for the tree scope of a node. Given a DOM element identified by nodeId, getLayersForNode returns the root layer for the nearest ancestor document or shadow root. The layer root contains the full layer tree for the tree scope and their ordering.
- GetLayers
ForNode Returns - Returns all layers parsed by the rendering engine for the tree scope of a node. Given a DOM element identified by nodeId, getLayersForNode returns the root layer for the nearest ancestor document or shadow root. The layer root contains the full layer tree for the tree scope and their ordering.
- GetLocation
ForSelector Params - Given a CSS selector text and a style sheet ID, getLocationForSelector returns an array of locations of the CSS selector in the style sheet.
- GetLocation
ForSelector Returns - Given a CSS selector text and a style sheet ID, getLocationForSelector returns an array of locations of the CSS selector in the style sheet.
- GetLonghand
Properties Params - GetLonghand
Properties Returns - GetMatched
Styles ForNode Params - Returns requested styles for a DOM node identified by ‘nodeId’.
- GetMatched
Styles ForNode Returns - Returns requested styles for a DOM node identified by ‘nodeId’.
- GetMedia
Queries Returns - Returns all media queries parsed by the rendering engine.
- GetPlatform
Fonts ForNode Params - Requests information about platform fonts which we used to render child TextNodes in the given node.
- GetPlatform
Fonts ForNode Returns - Requests information about platform fonts which we used to render child TextNodes in the given node.
- GetStyle
Sheet Text Params - Returns the current textual content for a stylesheet.
- GetStyle
Sheet Text Returns - Returns the current textual content for a stylesheet.
- Inherited
Animated Style Entry - Inherited CSS style collection for animated styles from ancestor node.
- Inherited
Pseudo Element Matches - Inherited pseudo element matches from pseudos of an ancestor node.
- Inherited
Style Entry - Inherited CSS rule collection from ancestor node.
- Media
Query - Media query descriptor.
- Media
Query Expression - Media query expression descriptor.
- Platform
Font Usage - Information about amount of glyphs that were rendered with given font.
- Protocol
Value - Data for a simple selector (these are delimited by commas in a selector list).
- Pseudo
Element Matches - CSS rule collection for a single pseudo style.
- Resolve
Values Params - Resolve the specified values in the context of the provided element. For example, a value of ‘1em’ is evaluated according to the computed ‘font-size’ of the element and a value ‘calc(1px + 2px)’ will be resolved to ‘3px’. If the ‘propertyName’ was specified the ‘values’ are resolved as if they were property’s declaration. If a value cannot be parsed according to the provided property syntax, the value is parsed using combined syntax as if null ‘propertyName’ was provided. If the value cannot be resolved even then, return the provided value without any changes. Note: this function currently does not resolve CSS random() function, it returns unmodified random() function parts.’
- Resolve
Values Returns - Resolve the specified values in the context of the provided element. For example, a value of ‘1em’ is evaluated according to the computed ‘font-size’ of the element and a value ‘calc(1px + 2px)’ will be resolved to ‘3px’. If the ‘propertyName’ was specified the ‘values’ are resolved as if they were property’s declaration. If a value cannot be parsed according to the provided property syntax, the value is parsed using combined syntax as if null ‘propertyName’ was provided. If the value cannot be resolved even then, return the provided value without any changes. Note: this function currently does not resolve CSS random() function, it returns unmodified random() function parts.’
- Rule
Match - Match data for a CSS rule.
- Rule
Usage - CSS coverage information.
- Selector
List - Selector list data.
- SetContainer
Query Text Params - Modifies the expression of a container query.
- SetContainer
Query Text Returns - Modifies the expression of a container query.
- SetEffective
Property Value ForNode Params - Find a rule with the given active property for the given node and set the new value for this property
- SetKeyframe
KeyParams - Modifies the keyframe rule key text.
- SetKeyframe
KeyReturns - Modifies the keyframe rule key text.
- SetLocal
Fonts Enabled Params - Enables/disables rendering of local CSS fonts (enabled by default).
- SetMedia
Text Params - Modifies the rule selector.
- SetMedia
Text Returns - Modifies the rule selector.
- SetNavigation
Text Params - Modifies the expression of a navigation at-rule.
- SetNavigation
Text Returns - Modifies the expression of a navigation at-rule.
- SetProperty
Rule Property Name Params - Modifies the property rule property name.
- SetProperty
Rule Property Name Returns - Modifies the property rule property name.
- SetRule
Selector Params - Modifies the rule selector.
- SetRule
Selector Returns - Modifies the rule selector.
- SetScope
Text Params - Modifies the expression of a scope at-rule.
- SetScope
Text Returns - Modifies the expression of a scope at-rule.
- SetStyle
Sheet Text Params - Sets the new stylesheet text.
- SetStyle
Sheet Text Returns - Sets the new stylesheet text.
- SetStyle
Texts Params - Applies specified style edits one after another in the given order.
- SetStyle
Texts Returns - Applies specified style edits one after another in the given order.
- SetSupports
Text Params - Modifies the expression of a supports at-rule.
- SetSupports
Text Returns - Modifies the expression of a supports at-rule.
- Shorthand
Entry - Source
Range - Text range within a resource. All numbers are zero-based.
- Specificity
- Specificity: https://drafts.csswg.org/selectors/#specificity-rules
- Stop
Rule Usage Tracking Returns - Stop tracking rule usage and return the list of rules that were used since last call to ‘takeCoverageDelta’ (or since start of coverage instrumentation).
- Style
Declaration Edit - A descriptor of operation to mutate style declaration text.
- Take
Computed Style Updates Returns - Polls the next batch of computed style updates.
- Take
Coverage Delta Returns - Obtain list of rules that became used since last call to this method (or since start of coverage instrumentation).
- Track
Computed Style Updates ForNode Params - Starts tracking the given node for the computed style updates and whenever the computed style is updated for node, it queues a ‘computedStyleUpdated’ event with throttling. There can only be 1 node tracked for computed style updates so passing a new node id removes tracking from the previous node. Pass ‘undefined’ to disable tracking.
- Track
Computed Style Updates Params - Starts tracking the given computed styles for updates. The specified array of properties replaces the one previously specified. Pass empty array to disable tracking. Use takeComputedStyleUpdates to retrieve the list of nodes that had properties modified. The changes to computed style properties are only tracked for nodes pushed to the front-end by the DOM agent. If no changes to the tracked properties occur after the node has been pushed to the front-end, no updates will be issued for the node.
Enums
- CSSRule
Type - Enum indicating the type of a CSS rule, used to represent the order of a style rule’s ancestors. This list only contains rule types that are collected during the ancestor rule collection.
- Style
Sheet Origin - Stylesheet type: “injected” for stylesheets injected via extension, “user-agent” for user-agent stylesheets, “inspector” for stylesheets created by the inspector (i.e. those holding the “via inspector” rules), “regular” for regular stylesheets.