pub struct AddRuleParams<'a> { /* private fields */ }Expand description
Inserts a new rule with the given ‘ruleText’ in a stylesheet with given ‘styleSheetId’, at the position specified by ‘location’.
Implementations
Sourceimpl<'a> AddRuleParams<'a>
impl<'a> AddRuleParams<'a>
Sourcepub fn builder(
style_sheet_id: StyleSheetId<'a>,
rule_text: impl Into<Cow<'a, str>>,
location: SourceRange,
) -> AddRuleParamsBuilder<'a>
pub fn builder( style_sheet_id: StyleSheetId<'a>, rule_text: impl Into<Cow<'a, str>>, location: SourceRange, ) -> AddRuleParamsBuilder<'a>
Creates a builder for this type with the required parameters:
style_sheet_id: The css style sheet identifier where a new rule should be inserted.rule_text: The text of a new rule.location: Text position of a new rule in the target style sheet.
Sourcepub fn style_sheet_id(&self) -> &StyleSheetId<'a>
pub fn style_sheet_id(&self) -> &StyleSheetId<'a>
The css style sheet identifier where a new rule should be inserted.
Sourcepub fn location(&self) -> &SourceRange
pub fn location(&self) -> &SourceRange
Text position of a new rule in the target style sheet.
Sourcepub fn node_for_property_syntax_validation(&self) -> Option<&NodeId>
pub fn node_for_property_syntax_validation(&self) -> Option<&NodeId>
NodeId for the DOM node in whose context custom property declarations for registered properties should be validated. If omitted, declarations in the new rule text can only be validated statically, which may produce incorrect results if the declaration contains a var() for example.