pub struct AddRuleParams {
pub styleSheetId: StyleSheetId,
pub ruleText: String,
pub location: SourceRange,
pub nodeForPropertySyntaxValidation: Option<NodeId>,
}Expand description
Inserts a new rule with the given ‘ruleText’ in a stylesheet with given ‘styleSheetId’, at the position specified by ‘location’.
Fields
styleSheetId: StyleSheetIdThe css style sheet identifier where a new rule should be inserted.
ruleText: StringThe text of a new rule.
location: SourceRangeText position of a new rule in the target style sheet.
nodeForPropertySyntaxValidation: Option<NodeId>NodeId for the DOM node in whose context custom property declarations for registered properties should be validated. If omitted, declarations in the new rule text can only be validated statically, which may produce incorrect results if the declaration contains a var() for example.