pub struct CSSProperty {
pub name: String,
pub value: String,
pub important: Option<bool>,
pub implicit: Option<bool>,
pub text: Option<String>,
pub parsedOk: Option<bool>,
pub disabled: Option<bool>,
pub range: Option<SourceRange>,
pub longhandProperties: Option<Vec<CSSProperty>>,
}Expand description
CSS property declaration data.
Fields
name: StringThe property name.
value: StringThe property value.
important: Option<bool>Whether the property has “!important” annotation (implies ‘false’ if absent).
implicit: Option<bool>Whether the property is implicit (implies ‘false’ if absent).
text: Option<String>The full property text as specified in the style.
parsedOk: Option<bool>Whether the property is understood by the browser (implies ‘true’ if absent).
disabled: Option<bool>Whether the property is disabled by the user (present for source-based properties only).
range: Option<SourceRange>The entire property range in the enclosing style declaration (if available).
longhandProperties: Option<Vec<CSSProperty>>Parsed longhand components of this property if it is a shorthand. This field will be empty if the given property is not a shorthand.