pub struct CSSPropertyBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> CSSPropertyBuilder<'a>
impl<'a> CSSPropertyBuilder<'a>
Sourcepub fn important(self, important: bool) -> Self
pub fn important(self, important: bool) -> Self
Whether the property has “!important” annotation (implies ‘false’ if absent).
Sourcepub fn implicit(self, implicit: bool) -> Self
pub fn implicit(self, implicit: bool) -> Self
Whether the property is implicit (implies ‘false’ if absent).
Sourcepub fn text(self, text: impl Into<Cow<'a, str>>) -> Self
pub fn text(self, text: impl Into<Cow<'a, str>>) -> Self
The full property text as specified in the style.
Sourcepub fn parsedOk(self, parsedOk: bool) -> Self
pub fn parsedOk(self, parsedOk: bool) -> Self
Whether the property is understood by the browser (implies ‘true’ if absent).
Sourcepub fn disabled(self, disabled: bool) -> Self
pub fn disabled(self, disabled: bool) -> Self
Whether the property is disabled by the user (present for source-based properties only).
Sourcepub fn range(self, range: SourceRange) -> Self
pub fn range(self, range: SourceRange) -> Self
The entire property range in the enclosing style declaration (if available).
Sourcepub fn longhandProperties(
self,
longhandProperties: Vec<Box<CSSProperty<'a>>>,
) -> Self
pub fn longhandProperties( self, longhandProperties: Vec<Box<CSSProperty<'a>>>, ) -> Self
Parsed longhand components of this property if it is a shorthand. This field will be empty if the given property is not a shorthand.
pub fn build(self) -> CSSProperty<'a>