pub struct CSSRule {Show 14 fields
pub styleSheetId: Option<StyleSheetId>,
pub selectorList: SelectorList,
pub nestingSelectors: Option<Vec<String>>,
pub origin: StyleSheetOrigin,
pub style: CSSStyle,
pub originTreeScopeNodeId: Option<BackendNodeId>,
pub media: Option<Vec<CSSMedia>>,
pub containerQueries: Option<Vec<CSSContainerQuery>>,
pub supports: Option<Vec<CSSSupports>>,
pub layers: Option<Vec<CSSLayer>>,
pub scopes: Option<Vec<CSSScope>>,
pub ruleTypes: Option<Vec<CSSRuleType>>,
pub startingStyles: Option<Vec<CSSStartingStyle>>,
pub navigations: Option<Vec<CSSNavigation>>,
}Expand description
CSS rule representation.
Fields
styleSheetId: Option<StyleSheetId>The css style sheet identifier (absent for user agent stylesheet and user-specified stylesheet rules) this rule came from.
selectorList: SelectorListRule selector data.
nestingSelectors: Option<Vec<String>>Array of selectors from ancestor style rules, sorted by distance from the current rule.
origin: StyleSheetOriginParent stylesheet’s origin.
style: CSSStyleAssociated style declaration.
originTreeScopeNodeId: Option<BackendNodeId>The BackendNodeId of the DOM node that constitutes the origin tree scope of this rule.
media: Option<Vec<CSSMedia>>Media list array (for rules involving media queries). The array enumerates media queries starting with the innermost one, going outwards.
containerQueries: Option<Vec<CSSContainerQuery>>Container query list array (for rules involving container queries). The array enumerates container queries starting with the innermost one, going outwards.
supports: Option<Vec<CSSSupports>>@supports CSS at-rule array. The array enumerates @supports at-rules starting with the innermost one, going outwards.
layers: Option<Vec<CSSLayer>>Cascade layer array. Contains the layer hierarchy that this rule belongs to starting with the innermost layer and going outwards.
scopes: Option<Vec<CSSScope>>@scope CSS at-rule array. The array enumerates @scope at-rules starting with the innermost one, going outwards.
ruleTypes: Option<Vec<CSSRuleType>>The array keeps the types of ancestor CSSRules from the innermost going outwards.
startingStyles: Option<Vec<CSSStartingStyle>>@starting-style CSS at-rule array. The array enumerates @starting-style at-rules starting with the innermost one, going outwards.
@navigation CSS at-rule array. The array enumerates @navigation at-rules starting with the innermost one, going outwards.