CSSRuleBuilder

Struct CSSRuleBuilder 

pub struct CSSRuleBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> CSSRuleBuilder<'a>

pub fn style_sheet_id(self, style_sheet_id: StyleSheetId<'a>) -> Self

The css style sheet identifier (absent for user agent stylesheet and user-specified stylesheet rules) this rule came from.

pub fn nesting_selectors(self, nesting_selectors: Vec<Cow<'a, str>>) -> Self

Array of selectors from ancestor style rules, sorted by distance from the current rule.

pub fn origin_tree_scope_node_id( self, origin_tree_scope_node_id: BackendNodeId, ) -> Self

The BackendNodeId of the DOM node that constitutes the origin tree scope of this rule.

pub fn media(self, media: Vec<CSSMedia<'a>>) -> Self

Media list array (for rules involving media queries). The array enumerates media queries starting with the innermost one, going outwards.

pub fn container_queries( self, container_queries: Vec<CSSContainerQuery<'a>>, ) -> Self

Container query list array (for rules involving container queries). The array enumerates container queries starting with the innermost one, going outwards.

pub fn supports(self, supports: Vec<CSSSupports<'a>>) -> Self

@supports CSS at-rule array. The array enumerates @supports at-rules starting with the innermost one, going outwards.

pub fn layers(self, layers: Vec<CSSLayer<'a>>) -> Self

Cascade layer array. Contains the layer hierarchy that this rule belongs to starting with the innermost layer and going outwards.

pub fn scopes(self, scopes: Vec<CSSScope<'a>>) -> Self

@scope CSS at-rule array. The array enumerates @scope at-rules starting with the innermost one, going outwards.

pub fn rule_types(self, rule_types: Vec<CSSRuleType>) -> Self

The array keeps the types of ancestor CSSRules from the innermost going outwards.

pub fn starting_styles(self, starting_styles: Vec<CSSStartingStyle<'a>>) -> Self

@starting-style CSS at-rule array. The array enumerates @starting-style at-rules starting with the innermost one, going outwards.

pub fn navigations(self, navigations: Vec<CSSNavigation<'a>>) -> Self

@navigation CSS at-rule array. The array enumerates @navigation at-rules starting with the innermost one, going outwards.

pub fn build(self) -> CSSRule<'a>