pub struct CSSRuleBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> CSSRuleBuilder<'a>
impl<'a> CSSRuleBuilder<'a>
Sourcepub fn styleSheetId(self, styleSheetId: StyleSheetId<'a>) -> Self
pub fn styleSheetId(self, styleSheetId: StyleSheetId<'a>) -> Self
The css style sheet identifier (absent for user agent stylesheet and user-specified stylesheet rules) this rule came from.
Sourcepub fn nestingSelectors(self, nestingSelectors: Vec<Cow<'a, str>>) -> Self
pub fn nestingSelectors(self, nestingSelectors: Vec<Cow<'a, str>>) -> Self
Array of selectors from ancestor style rules, sorted by distance from the current rule.
Sourcepub fn originTreeScopeNodeId(self, originTreeScopeNodeId: BackendNodeId) -> Self
pub fn originTreeScopeNodeId(self, originTreeScopeNodeId: BackendNodeId) -> Self
The BackendNodeId of the DOM node that constitutes the origin tree scope of this rule.
Sourcepub fn media(self, media: Vec<CSSMedia<'a>>) -> Self
pub fn media(self, media: Vec<CSSMedia<'a>>) -> Self
Media list array (for rules involving media queries). The array enumerates media queries starting with the innermost one, going outwards.
Sourcepub fn containerQueries(
self,
containerQueries: Vec<CSSContainerQuery<'a>>,
) -> Self
pub fn containerQueries( self, containerQueries: Vec<CSSContainerQuery<'a>>, ) -> Self
Container query list array (for rules involving container queries). The array enumerates container queries starting with the innermost one, going outwards.
Sourcepub fn supports(self, supports: Vec<CSSSupports<'a>>) -> Self
pub fn supports(self, supports: Vec<CSSSupports<'a>>) -> Self
@supports CSS at-rule array. The array enumerates @supports at-rules starting with the innermost one, going outwards.
Sourcepub fn layers(self, layers: Vec<CSSLayer<'a>>) -> Self
pub fn layers(self, layers: Vec<CSSLayer<'a>>) -> Self
Cascade layer array. Contains the layer hierarchy that this rule belongs to starting with the innermost layer and going outwards.
Sourcepub fn scopes(self, scopes: Vec<CSSScope<'a>>) -> Self
pub fn scopes(self, scopes: Vec<CSSScope<'a>>) -> Self
@scope CSS at-rule array. The array enumerates @scope at-rules starting with the innermost one, going outwards.
Sourcepub fn ruleTypes(self, ruleTypes: Vec<CSSRuleType>) -> Self
pub fn ruleTypes(self, ruleTypes: Vec<CSSRuleType>) -> Self
The array keeps the types of ancestor CSSRules from the innermost going outwards.
Sourcepub fn startingStyles(self, startingStyles: Vec<CSSStartingStyle<'a>>) -> Self
pub fn startingStyles(self, startingStyles: Vec<CSSStartingStyle<'a>>) -> Self
@starting-style CSS at-rule array. The array enumerates @starting-style at-rules starting with the innermost one, going outwards.
@navigation CSS at-rule array. The array enumerates @navigation at-rules starting with the innermost one, going outwards.