CSSStyleSheetHeader

Struct CSSStyleSheetHeader 

pub struct CSSStyleSheetHeader<'a> { /* private fields */ }
CSS stylesheet metainformation.

Implementations

Source

impl<'a> CSSStyleSheetHeader<'a>

pub fn builder( style_sheet_id: StyleSheetId<'a>, frame_id: FrameId<'a>, source_url: impl Into<Cow<'a, str>>, origin: impl Into<StyleSheetOrigin>, title: impl Into<Cow<'a, str>>, disabled: bool, is_inline: bool, is_mutable: bool, is_constructed: bool, start_line: f64, start_column: f64, length: f64, end_line: f64, end_column: f64, ) -> CSSStyleSheetHeaderBuilder<'a>

Creates a builder for this type with the required parameters:

  • style_sheet_id: The stylesheet identifier.
  • frame_id: Owner frame identifier.
  • source_url: Stylesheet resource URL. Empty if this is a constructed stylesheet created using new CSSStyleSheet() (but non-empty if this is a constructed stylesheet imported as a CSS module script).
  • origin: Stylesheet origin.
  • title: Stylesheet title.
  • disabled: Denotes whether the stylesheet is disabled.
  • is_inline: Whether this stylesheet is created for STYLE tag by parser. This flag is not set for document.written STYLE tags.
  • is_mutable: Whether this stylesheet is mutable. Inline stylesheets become mutable after they have been modified via CSSOM API. \<link\> element’s stylesheets become mutable only if DevTools modifies them. Constructed stylesheets (new CSSStyleSheet()) are mutable immediately after creation.
  • is_constructed: True if this stylesheet is created through new CSSStyleSheet() or imported as a CSS module script.
  • start_line: Line offset of the stylesheet within the resource (zero based).
  • start_column: Column offset of the stylesheet within the resource (zero based).
  • length: Size of the content (in characters).
  • end_line: Line offset of the end of the stylesheet within the resource (zero based).
  • end_column: Column offset of the end of the stylesheet within the resource (zero based).
pub fn style_sheet_id(&self) -> &StyleSheetId<'a>

The stylesheet identifier.

pub fn frame_id(&self) -> &FrameId<'a>

Owner frame identifier.

pub fn source_url(&self) -> &str

Stylesheet resource URL. Empty if this is a constructed stylesheet created using new CSSStyleSheet() (but non-empty if this is a constructed stylesheet imported as a CSS module script).

pub fn source_map_url(&self) -> Option<&str>

URL of source map associated with the stylesheet (if any).

pub fn origin(&self) -> &StyleSheetOrigin

Stylesheet origin.

pub fn title(&self) -> &str

Stylesheet title.

pub fn owner_node(&self) -> Option<&BackendNodeId>

The backend id for the owner node of the stylesheet.

pub fn disabled(&self) -> bool

Denotes whether the stylesheet is disabled.

pub fn has_source_url(&self) -> Option<bool>

Whether the sourceURL field value comes from the sourceURL comment.

pub fn is_inline(&self) -> bool

Whether this stylesheet is created for STYLE tag by parser. This flag is not set for document.written STYLE tags.

pub fn is_mutable(&self) -> bool

Whether this stylesheet is mutable. Inline stylesheets become mutable after they have been modified via CSSOM API. ‘<link>’ element’s stylesheets become mutable only if DevTools modifies them. Constructed stylesheets (new CSSStyleSheet()) are mutable immediately after creation.

pub fn is_constructed(&self) -> bool

True if this stylesheet is created through new CSSStyleSheet() or imported as a CSS module script.

pub fn start_line(&self) -> f64

Line offset of the stylesheet within the resource (zero based).

pub fn start_column(&self) -> f64

Column offset of the stylesheet within the resource (zero based).

pub fn length(&self) -> f64

Size of the content (in characters).

pub fn end_line(&self) -> f64

Line offset of the end of the stylesheet within the resource (zero based).

pub fn end_column(&self) -> f64

Column offset of the end of the stylesheet within the resource (zero based).

pub fn loading_failed(&self) -> Option<bool>

If the style sheet was loaded from a network resource, this indicates when the resource failed to load