CSSStyleSheetHeader

Struct CSSStyleSheetHeader 

pub struct CSSStyleSheetHeader {
Show 18 fields pub styleSheetId: StyleSheetId, pub frameId: FrameId, pub sourceURL: String, pub sourceMapURL: Option<String>, pub origin: StyleSheetOrigin, pub title: String, pub ownerNode: Option<BackendNodeId>, pub disabled: bool, pub hasSourceURL: Option<bool>, pub isInline: bool, pub isMutable: bool, pub isConstructed: bool, pub startLine: f64, pub startColumn: f64, pub length: f64, pub endLine: f64, pub endColumn: f64, pub loadingFailed: Option<bool>,
}
CSS stylesheet metainformation.

Fields

styleSheetId: StyleSheetId

The stylesheet identifier.

frameId: FrameId

Owner frame identifier.

sourceURL: String

Stylesheet resource URL. Empty if this is a constructed stylesheet created using new CSSStyleSheet() (but non-empty if this is a constructed stylesheet imported as a CSS module script).

sourceMapURL: Option<String>

URL of source map associated with the stylesheet (if any).

origin: StyleSheetOrigin

Stylesheet origin.

title: String

Stylesheet title.

ownerNode: Option<BackendNodeId>

The backend id for the owner node of the stylesheet.

disabled: bool

Denotes whether the stylesheet is disabled.

hasSourceURL: Option<bool>

Whether the sourceURL field value comes from the sourceURL comment.

isInline: bool

Whether this stylesheet is created for STYLE tag by parser. This flag is not set for document.written STYLE tags.

isMutable: bool

Whether this stylesheet is mutable. Inline stylesheets become mutable after they have been modified via CSSOM API. ‘<link>’ element’s stylesheets become mutable only if DevTools modifies them. Constructed stylesheets (new CSSStyleSheet()) are mutable immediately after creation.

isConstructed: bool

True if this stylesheet is created through new CSSStyleSheet() or imported as a CSS module script.

startLine: f64

Line offset of the stylesheet within the resource (zero based).

startColumn: f64

Column offset of the stylesheet within the resource (zero based).

length: f64

Size of the content (in characters).

endLine: f64

Line offset of the end of the stylesheet within the resource (zero based).

endColumn: f64

Column offset of the end of the stylesheet within the resource (zero based).

loadingFailed: Option<bool>

If the style sheet was loaded from a network resource, this indicates when the resource failed to load