pub struct CSSStyleSheetHeaderBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> CSSStyleSheetHeaderBuilder<'a>
impl<'a> CSSStyleSheetHeaderBuilder<'a>
Sourcepub fn sourceMapURL(self, sourceMapURL: impl Into<Cow<'a, str>>) -> Self
pub fn sourceMapURL(self, sourceMapURL: impl Into<Cow<'a, str>>) -> Self
URL of source map associated with the stylesheet (if any).
Sourcepub fn ownerNode(self, ownerNode: BackendNodeId) -> Self
pub fn ownerNode(self, ownerNode: BackendNodeId) -> Self
The backend id for the owner node of the stylesheet.
Sourcepub fn hasSourceURL(self, hasSourceURL: bool) -> Self
pub fn hasSourceURL(self, hasSourceURL: bool) -> Self
Whether the sourceURL field value comes from the sourceURL comment.
Sourcepub fn loadingFailed(self, loadingFailed: bool) -> Self
pub fn loadingFailed(self, loadingFailed: bool) -> Self
If the style sheet was loaded from a network resource, this indicates when the resource failed to load
pub fn build(self) -> CSSStyleSheetHeader<'a>