pub struct GetLayersForNodeReturns {
pub rootLayer: CSSLayerData,
}Expand description
Returns all layers parsed by the rendering engine for the tree scope of a node. Given a DOM element identified by nodeId, getLayersForNode returns the root layer for the nearest ancestor document or shadow root. The layer root contains the full layer tree for the tree scope and their ordering.
Fields
rootLayer: CSSLayerDataTrait Implementations
Sourceimpl Clone for GetLayersForNodeReturns
impl Clone for GetLayersForNodeReturns
Sourcefn clone(&self) -> GetLayersForNodeReturns
fn clone(&self) -> GetLayersForNodeReturns
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetLayersForNodeReturns
impl Debug for GetLayersForNodeReturns
Sourceimpl Default for GetLayersForNodeReturns
impl Default for GetLayersForNodeReturns
Sourcefn default() -> GetLayersForNodeReturns
fn default() -> GetLayersForNodeReturns
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for GetLayersForNodeReturns
impl<'de> Deserialize<'de> for GetLayersForNodeReturns
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more