pub struct GetMatchedStylesForNodeReturns<'a> { /* private fields */ }Expand description
Returns requested styles for a DOM node identified by ‘nodeId’.
Implementations
Sourceimpl<'a> GetMatchedStylesForNodeReturns<'a>
impl<'a> GetMatchedStylesForNodeReturns<'a>
Sourcepub fn builder() -> GetMatchedStylesForNodeReturnsBuilder<'a>
pub fn builder() -> GetMatchedStylesForNodeReturnsBuilder<'a>
Creates a builder for this type.
Sourcepub fn inline_style(&self) -> Option<&CSSStyle<'a>>
pub fn inline_style(&self) -> Option<&CSSStyle<'a>>
Inline style for the specified DOM node.
Sourcepub fn attributes_style(&self) -> Option<&CSSStyle<'a>>
pub fn attributes_style(&self) -> Option<&CSSStyle<'a>>
Attribute-defined element style (e.g. resulting from “width=20 height=100%”).
Sourcepub fn matched_css_rules(&self) -> Option<&[RuleMatch<'a>]>
pub fn matched_css_rules(&self) -> Option<&[RuleMatch<'a>]>
CSS rules matching this node, from all applicable stylesheets.
Sourcepub fn pseudo_elements(&self) -> Option<&[PseudoElementMatches<'a>]>
pub fn pseudo_elements(&self) -> Option<&[PseudoElementMatches<'a>]>
Pseudo style matches for this node.
Sourcepub fn inherited(&self) -> Option<&[InheritedStyleEntry<'a>]>
pub fn inherited(&self) -> Option<&[InheritedStyleEntry<'a>]>
A chain of inherited styles (from the immediate node parent up to the DOM tree root).
Sourcepub fn inherited_pseudo_elements(
&self,
) -> Option<&[InheritedPseudoElementMatches<'a>]>
pub fn inherited_pseudo_elements( &self, ) -> Option<&[InheritedPseudoElementMatches<'a>]>
A chain of inherited pseudo element styles (from the immediate node parent up to the DOM tree root).
Sourcepub fn css_keyframes_rules(&self) -> Option<&[CSSKeyframesRule<'a>]>
pub fn css_keyframes_rules(&self) -> Option<&[CSSKeyframesRule<'a>]>
A list of CSS keyframed animations matching this node.
Sourcepub fn css_position_try_rules(&self) -> Option<&[CSSPositionTryRule<'a>]>
pub fn css_position_try_rules(&self) -> Option<&[CSSPositionTryRule<'a>]>
A list of CSS @position-try rules matching this node, based on the position-try-fallbacks property.
Sourcepub fn active_position_fallback_index(&self) -> Option<u64>
pub fn active_position_fallback_index(&self) -> Option<u64>
Index of the active fallback in the applied position-try-fallback property, will not be set if there is no active position-try fallback.
Sourcepub fn css_property_rules(&self) -> Option<&[CSSPropertyRule<'a>]>
pub fn css_property_rules(&self) -> Option<&[CSSPropertyRule<'a>]>
A list of CSS at-property rules matching this node.
Sourcepub fn css_property_registrations(
&self,
) -> Option<&[CSSPropertyRegistration<'a>]>
pub fn css_property_registrations( &self, ) -> Option<&[CSSPropertyRegistration<'a>]>
A list of CSS property registrations matching this node.
Sourcepub fn css_at_rules(&self) -> Option<&[CSSAtRule<'a>]>
pub fn css_at_rules(&self) -> Option<&[CSSAtRule<'a>]>
A list of simple @rules matching this node or its pseudo-elements.
Sourcepub fn parent_layout_node_id(&self) -> Option<&NodeId>
pub fn parent_layout_node_id(&self) -> Option<&NodeId>
Id of the first parent element that does not have display: contents.
Sourcepub fn css_function_rules(&self) -> Option<&[CSSFunctionRule<'a>]>
pub fn css_function_rules(&self) -> Option<&[CSSFunctionRule<'a>]>
A list of CSS at-function rules referenced by styles of this node.