pub struct GetMatchedStylesForNodeReturns {Show 14 fields
pub inlineStyle: Option<CSSStyle>,
pub attributesStyle: Option<CSSStyle>,
pub matchedCSSRules: Option<Vec<RuleMatch>>,
pub pseudoElements: Option<Vec<PseudoElementMatches>>,
pub inherited: Option<Vec<InheritedStyleEntry>>,
pub inheritedPseudoElements: Option<Vec<InheritedPseudoElementMatches>>,
pub cssKeyframesRules: Option<Vec<CSSKeyframesRule>>,
pub cssPositionTryRules: Option<Vec<CSSPositionTryRule>>,
pub activePositionFallbackIndex: Option<u64>,
pub cssPropertyRules: Option<Vec<CSSPropertyRule>>,
pub cssPropertyRegistrations: Option<Vec<CSSPropertyRegistration>>,
pub cssAtRules: Option<Vec<CSSAtRule>>,
pub parentLayoutNodeId: Option<NodeId>,
pub cssFunctionRules: Option<Vec<CSSFunctionRule>>,
}Expand description
Returns requested styles for a DOM node identified by ‘nodeId’.
Fields
inlineStyle: Option<CSSStyle>Inline style for the specified DOM node.
attributesStyle: Option<CSSStyle>Attribute-defined element style (e.g. resulting from “width=20 height=100%”).
matchedCSSRules: Option<Vec<RuleMatch>>CSS rules matching this node, from all applicable stylesheets.
pseudoElements: Option<Vec<PseudoElementMatches>>Pseudo style matches for this node.
inherited: Option<Vec<InheritedStyleEntry>>A chain of inherited styles (from the immediate node parent up to the DOM tree root).
inheritedPseudoElements: Option<Vec<InheritedPseudoElementMatches>>A chain of inherited pseudo element styles (from the immediate node parent up to the DOM tree root).
cssKeyframesRules: Option<Vec<CSSKeyframesRule>>A list of CSS keyframed animations matching this node.
cssPositionTryRules: Option<Vec<CSSPositionTryRule>>A list of CSS @position-try rules matching this node, based on the position-try-fallbacks property.
activePositionFallbackIndex: Option<u64>Index of the active fallback in the applied position-try-fallback property, will not be set if there is no active position-try fallback.
cssPropertyRules: Option<Vec<CSSPropertyRule>>A list of CSS at-property rules matching this node.
cssPropertyRegistrations: Option<Vec<CSSPropertyRegistration>>A list of CSS property registrations matching this node.
cssAtRules: Option<Vec<CSSAtRule>>A list of simple @rules matching this node or its pseudo-elements.
parentLayoutNodeId: Option<NodeId>Id of the first parent element that does not have display: contents.
cssFunctionRules: Option<Vec<CSSFunctionRule>>A list of CSS at-function rules referenced by styles of this node.