pub struct GetMatchedStylesForNodeReturnsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> GetMatchedStylesForNodeReturnsBuilder<'a>
impl<'a> GetMatchedStylesForNodeReturnsBuilder<'a>
Sourcepub fn inline_style(self, inline_style: CSSStyle<'a>) -> Self
pub fn inline_style(self, inline_style: CSSStyle<'a>) -> Self
Inline style for the specified DOM node.
Sourcepub fn attributes_style(self, attributes_style: CSSStyle<'a>) -> Self
pub fn attributes_style(self, attributes_style: CSSStyle<'a>) -> Self
Attribute-defined element style (e.g. resulting from “width=20 height=100%”).
Sourcepub fn matched_css_rules(self, matched_css_rules: Vec<RuleMatch<'a>>) -> Self
pub fn matched_css_rules(self, matched_css_rules: Vec<RuleMatch<'a>>) -> Self
CSS rules matching this node, from all applicable stylesheets.
Sourcepub fn pseudo_elements(
self,
pseudo_elements: Vec<PseudoElementMatches<'a>>,
) -> Self
pub fn pseudo_elements( self, pseudo_elements: Vec<PseudoElementMatches<'a>>, ) -> Self
Pseudo style matches for this node.
Sourcepub fn inherited(self, inherited: Vec<InheritedStyleEntry<'a>>) -> Self
pub fn inherited(self, inherited: Vec<InheritedStyleEntry<'a>>) -> Self
A chain of inherited styles (from the immediate node parent up to the DOM tree root).
Sourcepub fn inherited_pseudo_elements(
self,
inherited_pseudo_elements: Vec<InheritedPseudoElementMatches<'a>>,
) -> Self
pub fn inherited_pseudo_elements( self, inherited_pseudo_elements: Vec<InheritedPseudoElementMatches<'a>>, ) -> Self
A chain of inherited pseudo element styles (from the immediate node parent up to the DOM tree root).
Sourcepub fn css_keyframes_rules(
self,
css_keyframes_rules: Vec<CSSKeyframesRule<'a>>,
) -> Self
pub fn css_keyframes_rules( self, css_keyframes_rules: Vec<CSSKeyframesRule<'a>>, ) -> Self
A list of CSS keyframed animations matching this node.
Sourcepub fn css_position_try_rules(
self,
css_position_try_rules: Vec<CSSPositionTryRule<'a>>,
) -> Self
pub fn css_position_try_rules( self, css_position_try_rules: Vec<CSSPositionTryRule<'a>>, ) -> Self
A list of CSS @position-try rules matching this node, based on the position-try-fallbacks property.
Sourcepub fn active_position_fallback_index(
self,
active_position_fallback_index: u64,
) -> Self
pub fn active_position_fallback_index( self, active_position_fallback_index: u64, ) -> Self
Index of the active fallback in the applied position-try-fallback property, will not be set if there is no active position-try fallback.
Sourcepub fn css_property_rules(
self,
css_property_rules: Vec<CSSPropertyRule<'a>>,
) -> Self
pub fn css_property_rules( self, css_property_rules: Vec<CSSPropertyRule<'a>>, ) -> Self
A list of CSS at-property rules matching this node.
Sourcepub fn css_property_registrations(
self,
css_property_registrations: Vec<CSSPropertyRegistration<'a>>,
) -> Self
pub fn css_property_registrations( self, css_property_registrations: Vec<CSSPropertyRegistration<'a>>, ) -> Self
A list of CSS property registrations matching this node.
Sourcepub fn css_at_rules(self, css_at_rules: Vec<CSSAtRule<'a>>) -> Self
pub fn css_at_rules(self, css_at_rules: Vec<CSSAtRule<'a>>) -> Self
A list of simple @rules matching this node or its pseudo-elements.
Sourcepub fn parent_layout_node_id(self, parent_layout_node_id: NodeId) -> Self
pub fn parent_layout_node_id(self, parent_layout_node_id: NodeId) -> Self
Id of the first parent element that does not have display: contents.
Sourcepub fn css_function_rules(
self,
css_function_rules: Vec<CSSFunctionRule<'a>>,
) -> Self
pub fn css_function_rules( self, css_function_rules: Vec<CSSFunctionRule<'a>>, ) -> Self
A list of CSS at-function rules referenced by styles of this node.