GetMatchedStylesForNodeReturnsBuilder

Struct GetMatchedStylesForNodeReturnsBuilder 

pub struct GetMatchedStylesForNodeReturnsBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> GetMatchedStylesForNodeReturnsBuilder<'a>

pub fn inlineStyle(self, inlineStyle: CSSStyle<'a>) -> Self

Inline style for the specified DOM node.

pub fn attributesStyle(self, attributesStyle: CSSStyle<'a>) -> Self

Attribute-defined element style (e.g. resulting from “width=20 height=100%”).

pub fn matchedCSSRules(self, matchedCSSRules: Vec<RuleMatch<'a>>) -> Self

CSS rules matching this node, from all applicable stylesheets.

pub fn pseudoElements( self, pseudoElements: Vec<PseudoElementMatches<'a>>, ) -> Self

Pseudo style matches for this node.

pub fn inherited(self, inherited: Vec<InheritedStyleEntry<'a>>) -> Self

A chain of inherited styles (from the immediate node parent up to the DOM tree root).

pub fn inheritedPseudoElements( self, inheritedPseudoElements: Vec<InheritedPseudoElementMatches<'a>>, ) -> Self

A chain of inherited pseudo element styles (from the immediate node parent up to the DOM tree root).

pub fn cssKeyframesRules( self, cssKeyframesRules: Vec<CSSKeyframesRule<'a>>, ) -> Self

A list of CSS keyframed animations matching this node.

pub fn cssPositionTryRules( self, cssPositionTryRules: Vec<CSSPositionTryRule<'a>>, ) -> Self

A list of CSS @position-try rules matching this node, based on the position-try-fallbacks property.

pub fn activePositionFallbackIndex( self, activePositionFallbackIndex: u64, ) -> Self

Index of the active fallback in the applied position-try-fallback property, will not be set if there is no active position-try fallback.

pub fn cssPropertyRules( self, cssPropertyRules: Vec<CSSPropertyRule<'a>>, ) -> Self

A list of CSS at-property rules matching this node.

pub fn cssPropertyRegistrations( self, cssPropertyRegistrations: Vec<CSSPropertyRegistration<'a>>, ) -> Self

A list of CSS property registrations matching this node.

pub fn cssAtRules(self, cssAtRules: Vec<CSSAtRule<'a>>) -> Self

A list of simple @rules matching this node or its pseudo-elements.

pub fn parentLayoutNodeId(self, parentLayoutNodeId: NodeId) -> Self

Id of the first parent element that does not have display: contents.

pub fn cssFunctionRules( self, cssFunctionRules: Vec<CSSFunctionRule<'a>>, ) -> Self

A list of CSS at-function rules referenced by styles of this node.

pub fn build(self) -> GetMatchedStylesForNodeReturns<'a>