pub struct GetMatchedStylesForNodeReturnsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> GetMatchedStylesForNodeReturnsBuilder<'a>
impl<'a> GetMatchedStylesForNodeReturnsBuilder<'a>
Sourcepub fn inlineStyle(self, inlineStyle: CSSStyle<'a>) -> Self
pub fn inlineStyle(self, inlineStyle: CSSStyle<'a>) -> Self
Inline style for the specified DOM node.
Sourcepub fn attributesStyle(self, attributesStyle: CSSStyle<'a>) -> Self
pub fn attributesStyle(self, attributesStyle: CSSStyle<'a>) -> Self
Attribute-defined element style (e.g. resulting from “width=20 height=100%”).
Sourcepub fn matchedCSSRules(self, matchedCSSRules: Vec<RuleMatch<'a>>) -> Self
pub fn matchedCSSRules(self, matchedCSSRules: Vec<RuleMatch<'a>>) -> Self
CSS rules matching this node, from all applicable stylesheets.
Sourcepub fn pseudoElements(
self,
pseudoElements: Vec<PseudoElementMatches<'a>>,
) -> Self
pub fn pseudoElements( self, pseudoElements: Vec<PseudoElementMatches<'a>>, ) -> Self
Pseudo style matches for this node.
Sourcepub fn inherited(self, inherited: Vec<InheritedStyleEntry<'a>>) -> Self
pub fn inherited(self, inherited: Vec<InheritedStyleEntry<'a>>) -> Self
A chain of inherited styles (from the immediate node parent up to the DOM tree root).
Sourcepub fn inheritedPseudoElements(
self,
inheritedPseudoElements: Vec<InheritedPseudoElementMatches<'a>>,
) -> Self
pub fn inheritedPseudoElements( self, inheritedPseudoElements: Vec<InheritedPseudoElementMatches<'a>>, ) -> Self
A chain of inherited pseudo element styles (from the immediate node parent up to the DOM tree root).
Sourcepub fn cssKeyframesRules(
self,
cssKeyframesRules: Vec<CSSKeyframesRule<'a>>,
) -> Self
pub fn cssKeyframesRules( self, cssKeyframesRules: Vec<CSSKeyframesRule<'a>>, ) -> Self
A list of CSS keyframed animations matching this node.
Sourcepub fn cssPositionTryRules(
self,
cssPositionTryRules: Vec<CSSPositionTryRule<'a>>,
) -> Self
pub fn cssPositionTryRules( self, cssPositionTryRules: Vec<CSSPositionTryRule<'a>>, ) -> Self
A list of CSS @position-try rules matching this node, based on the position-try-fallbacks property.
Sourcepub fn activePositionFallbackIndex(
self,
activePositionFallbackIndex: u64,
) -> Self
pub fn activePositionFallbackIndex( self, activePositionFallbackIndex: u64, ) -> Self
Index of the active fallback in the applied position-try-fallback property, will not be set if there is no active position-try fallback.
Sourcepub fn cssPropertyRules(
self,
cssPropertyRules: Vec<CSSPropertyRule<'a>>,
) -> Self
pub fn cssPropertyRules( self, cssPropertyRules: Vec<CSSPropertyRule<'a>>, ) -> Self
A list of CSS at-property rules matching this node.
Sourcepub fn cssPropertyRegistrations(
self,
cssPropertyRegistrations: Vec<CSSPropertyRegistration<'a>>,
) -> Self
pub fn cssPropertyRegistrations( self, cssPropertyRegistrations: Vec<CSSPropertyRegistration<'a>>, ) -> Self
A list of CSS property registrations matching this node.
Sourcepub fn cssAtRules(self, cssAtRules: Vec<CSSAtRule<'a>>) -> Self
pub fn cssAtRules(self, cssAtRules: Vec<CSSAtRule<'a>>) -> Self
A list of simple @rules matching this node or its pseudo-elements.
Sourcepub fn parentLayoutNodeId(self, parentLayoutNodeId: NodeId) -> Self
pub fn parentLayoutNodeId(self, parentLayoutNodeId: NodeId) -> Self
Id of the first parent element that does not have display: contents.
Sourcepub fn cssFunctionRules(
self,
cssFunctionRules: Vec<CSSFunctionRule<'a>>,
) -> Self
pub fn cssFunctionRules( self, cssFunctionRules: Vec<CSSFunctionRule<'a>>, ) -> Self
A list of CSS at-function rules referenced by styles of this node.