pub struct InheritedAnimatedStyleEntry {
pub animationStyles: Option<Vec<CSSAnimationStyle>>,
pub transitionsStyle: Option<CSSStyle>,
}Expand description
Inherited CSS style collection for animated styles from ancestor node.
Fields
animationStyles: Option<Vec<CSSAnimationStyle>>Styles coming from the animations of the ancestor, if any, in the style inheritance chain.
transitionsStyle: Option<CSSStyle>The style coming from the transitions of the ancestor, if any, in the style inheritance chain.