InheritedAnimatedStyleEntryBuilder

Struct InheritedAnimatedStyleEntryBuilder 

pub struct InheritedAnimatedStyleEntryBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> InheritedAnimatedStyleEntryBuilder<'a>

pub fn animation_styles( self, animation_styles: Vec<CSSAnimationStyle<'a>>, ) -> Self

Styles coming from the animations of the ancestor, if any, in the style inheritance chain.

pub fn transitions_style(self, transitions_style: CSSStyle<'a>) -> Self

The style coming from the transitions of the ancestor, if any, in the style inheritance chain.

pub fn build(self) -> InheritedAnimatedStyleEntry<'a>