pub struct InheritedAnimatedStyleEntryBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> InheritedAnimatedStyleEntryBuilder<'a>
impl<'a> InheritedAnimatedStyleEntryBuilder<'a>
Sourcepub fn animationStyles(
self,
animationStyles: Vec<CSSAnimationStyle<'a>>,
) -> Self
pub fn animationStyles( self, animationStyles: Vec<CSSAnimationStyle<'a>>, ) -> Self
Styles coming from the animations of the ancestor, if any, in the style inheritance chain.
Sourcepub fn transitionsStyle(self, transitionsStyle: CSSStyle<'a>) -> Self
pub fn transitionsStyle(self, transitionsStyle: CSSStyle<'a>) -> Self
The style coming from the transitions of the ancestor, if any, in the style inheritance chain.
pub fn build(self) -> InheritedAnimatedStyleEntry<'a>