pub struct InheritedStyleEntry {
pub inlineStyle: Option<CSSStyle>,
pub matchedCSSRules: Vec<RuleMatch>,
}Expand description
Inherited CSS rule collection from ancestor node.
Fields
inlineStyle: Option<CSSStyle>The ancestor node’s inline style, if any, in the style inheritance chain.
matchedCSSRules: Vec<RuleMatch>Matches of CSS rules matching the ancestor node in the style inheritance chain.