pub struct PlatformFontUsage {
pub familyName: String,
pub postScriptName: String,
pub isCustomFont: bool,
pub glyphCount: f64,
}Expand description
Information about amount of glyphs that were rendered with given font.
Fields
familyName: StringFont’s family name reported by platform.
postScriptName: StringFont’s PostScript name reported by platform.
isCustomFont: boolIndicates if the font was downloaded or resolved locally.
glyphCount: f64Amount of glyphs that were rendered with this font.