pub struct ResolveValuesParams<'a> { /* private fields */ }Expand description
Resolve the specified values in the context of the provided element. For example, a value of ‘1em’ is evaluated according to the computed ‘font-size’ of the element and a value ‘calc(1px + 2px)’ will be resolved to ‘3px’. If the ‘propertyName’ was specified the ‘values’ are resolved as if they were property’s declaration. If a value cannot be parsed according to the provided property syntax, the value is parsed using combined syntax as if null ‘propertyName’ was provided. If the value cannot be resolved even then, return the provided value without any changes. Note: this function currently does not resolve CSS random() function, it returns unmodified random() function parts.’
Implementations
Sourceimpl<'a> ResolveValuesParams<'a>
impl<'a> ResolveValuesParams<'a>
pub fn builder( values: Vec<Cow<'a, str>>, nodeId: NodeId, ) -> ResolveValuesParamsBuilder<'a>
pub fn values(&self) -> &[Cow<'a, str>]
pub fn nodeId(&self) -> &NodeId
pub fn propertyName(&self) -> Option<&str>
pub fn pseudoType(&self) -> Option<&PseudoType>
pub fn pseudoIdentifier(&self) -> Option<&str>