pub struct ResolveValuesParamsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ResolveValuesParamsBuilder<'a>
impl<'a> ResolveValuesParamsBuilder<'a>
Sourcepub fn propertyName(self, propertyName: impl Into<Cow<'a, str>>) -> Self
pub fn propertyName(self, propertyName: impl Into<Cow<'a, str>>) -> Self
Only longhands and custom property names are accepted.
Sourcepub fn pseudoType(self, pseudoType: PseudoType) -> Self
pub fn pseudoType(self, pseudoType: PseudoType) -> Self
Pseudo element type, only works for pseudo elements that generate elements in the tree, such as ::before and ::after.
Sourcepub fn pseudoIdentifier(self, pseudoIdentifier: impl Into<Cow<'a, str>>) -> Self
pub fn pseudoIdentifier(self, pseudoIdentifier: impl Into<Cow<'a, str>>) -> Self
Pseudo element custom ident.
pub fn build(self) -> ResolveValuesParams<'a>