pub struct ResolveValuesReturns {
pub results: Vec<String>,
}Expand description
Resolve the specified values in the context of the provided element. For example, a value of ‘1em’ is evaluated according to the computed ‘font-size’ of the element and a value ‘calc(1px + 2px)’ will be resolved to ‘3px’. If the ‘propertyName’ was specified the ‘values’ are resolved as if they were property’s declaration. If a value cannot be parsed according to the provided property syntax, the value is parsed using combined syntax as if null ‘propertyName’ was provided. If the value cannot be resolved even then, return the provided value without any changes. Note: this function currently does not resolve CSS random() function, it returns unmodified random() function parts.’
Fields
results: Vec<String>Trait Implementations
Sourceimpl Clone for ResolveValuesReturns
impl Clone for ResolveValuesReturns
Sourcefn clone(&self) -> ResolveValuesReturns
fn clone(&self) -> ResolveValuesReturns
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResolveValuesReturns
impl Debug for ResolveValuesReturns
Sourceimpl Default for ResolveValuesReturns
impl Default for ResolveValuesReturns
Sourcefn default() -> ResolveValuesReturns
fn default() -> ResolveValuesReturns
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ResolveValuesReturns
impl<'de> Deserialize<'de> for ResolveValuesReturns
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more