pub struct RuleUsage {
pub styleSheetId: StyleSheetId,
pub startOffset: f64,
pub endOffset: f64,
pub used: bool,
}Expand description
CSS coverage information.
Fields
styleSheetId: StyleSheetIdThe css style sheet identifier (absent for user agent stylesheet and user-specified stylesheet rules) this rule came from.
startOffset: f64Offset of the start of the rule (including selector) from the beginning of the stylesheet.
endOffset: f64Offset of the end of the rule body from the beginning of the stylesheet.
used: boolIndicates whether the rule was actually used by some element in the page.