pub struct SetEffectivePropertyValueForNodeParams {
pub nodeId: NodeId,
pub propertyName: String,
pub value: String,
}Expand description
Find a rule with the given active property for the given node and set the new value for this property
Fields
nodeId: NodeIdThe element id for which to set property.
propertyName: Stringvalue: StringImplementations