pub struct SetStyleTextsParams {
pub edits: Vec<StyleDeclarationEdit>,
pub nodeForPropertySyntaxValidation: Option<NodeId>,
}Expand description
Applies specified style edits one after another in the given order.
Fields
edits: Vec<StyleDeclarationEdit>nodeForPropertySyntaxValidation: Option<NodeId>NodeId for the DOM node in whose context custom property declarations for registered properties should be validated. If omitted, declarations in the new rule text can only be validated statically, which may produce incorrect results if the declaration contains a var() for example.