SetStyleTextsParamsBuilder

Struct SetStyleTextsParamsBuilder 

pub struct SetStyleTextsParamsBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> SetStyleTextsParamsBuilder<'a>

pub fn nodeForPropertySyntaxValidation( self, nodeForPropertySyntaxValidation: NodeId, ) -> Self

NodeId for the DOM node in whose context custom property declarations for registered properties should be validated. If omitted, declarations in the new rule text can only be validated statically, which may produce incorrect results if the declaration contains a var() for example.

pub fn build(self) -> SetStyleTextsParams<'a>