pub struct TrackComputedStyleUpdatesParams<'a> { /* private fields */ }Expand description
Starts tracking the given computed styles for updates. The specified array of properties replaces the one previously specified. Pass empty array to disable tracking. Use takeComputedStyleUpdates to retrieve the list of nodes that had properties modified. The changes to computed style properties are only tracked for nodes pushed to the front-end by the DOM agent. If no changes to the tracked properties occur after the node has been pushed to the front-end, no updates will be issued for the node.
Implementations
Sourceimpl<'a> TrackComputedStyleUpdatesParams<'a>
impl<'a> TrackComputedStyleUpdatesParams<'a>
pub fn builder( propertiesToTrack: Vec<CSSComputedStyleProperty<'a>>, ) -> TrackComputedStyleUpdatesParamsBuilder<'a>
pub fn propertiesToTrack(&self) -> &[CSSComputedStyleProperty<'a>]