Module dom

Module dom 

This domain exposes DOM read/write operations. Each DOM Node is represented with its mirror object that has an ‘id’. This ‘id’ can be used to get additional information on the Node, resolve it into the JavaScript object wrapper, etc. It is important that client receives DOM events only for the nodes that are known to the client. Backend keeps track of the nodes that were sent to the client and never sends the same node twice. It is client’s responsibility to collect information about the nodes that were sent to the client. Note that ‘iframe’ owner elements will return corresponding document elements as their child nodes.

Structs

BackendNode
Backend node with a friendly name.
BoxModel
Box model.
CSSComputedStyleProperty
CollectClassNamesFromSubtreeParams
Collects class names for the node with given id and all of it’s child nodes.
CollectClassNamesFromSubtreeReturns
Collects class names for the node with given id and all of it’s child nodes.
CopyToParams
Creates a deep copy of the specified node and places it into the target container before the given anchor.
CopyToReturns
Creates a deep copy of the specified node and places it into the target container before the given anchor.
DescribeNodeParams
Describes node given its id, does not require domain to be enabled. Does not start tracking any objects, can be used for automation.
DescribeNodeReturns
Describes node given its id, does not require domain to be enabled. Does not start tracking any objects, can be used for automation.
DetachedElementInfo
A structure to hold the top-level node of a detached tree and an array of its retained descendants.
DisableParams
DiscardSearchResultsParams
Discards search results from the session with the given id. ‘getSearchResults’ should no longer be called for that search.
EnableParams
Enables DOM agent for the given page.
FocusParams
Focuses the given element.
ForceShowPopoverParams
When enabling, this API force-opens the popover identified by nodeId and keeps it open until disabled.
ForceShowPopoverReturns
When enabling, this API force-opens the popover identified by nodeId and keeps it open until disabled.
GetAnchorElementParams
Returns the target anchor element of the given anchor query according to https://www.w3.org/TR/css-anchor-position-1/#target.
GetAnchorElementReturns
Returns the target anchor element of the given anchor query according to https://www.w3.org/TR/css-anchor-position-1/#target.
GetAttributesParams
Returns attributes for the specified node.
GetAttributesReturns
Returns attributes for the specified node.
GetBoxModelParams
Returns boxes for the given node.
GetBoxModelReturns
Returns boxes for the given node.
GetContainerForNodeParams
Returns the query container of the given node based on container query conditions: containerName, physical and logical axes, and whether it queries scroll-state or anchored elements. If no axes are provided and queriesScrollState is false, the style container is returned, which is the direct parent or the closest element with a matching container-name.
GetContainerForNodeReturns
Returns the query container of the given node based on container query conditions: containerName, physical and logical axes, and whether it queries scroll-state or anchored elements. If no axes are provided and queriesScrollState is false, the style container is returned, which is the direct parent or the closest element with a matching container-name.
GetContentQuadsParams
Returns quads that describe node position on the page. This method might return multiple quads for inline nodes.
GetContentQuadsReturns
Returns quads that describe node position on the page. This method might return multiple quads for inline nodes.
GetDetachedDomNodesParams
GetDetachedDomNodesReturns
Returns list of detached nodes
GetDocumentParams
Returns the root DOM node (and optionally the subtree) to the caller. Implicitly enables the DOM domain events for the current target.
GetDocumentReturns
Returns the root DOM node (and optionally the subtree) to the caller. Implicitly enables the DOM domain events for the current target.
GetElementByRelationParams
Returns the NodeId of the matched element according to certain relations.
GetElementByRelationReturns
Returns the NodeId of the matched element according to certain relations.
GetFileInfoParams
Returns file information for the given File wrapper.
GetFileInfoReturns
Returns file information for the given File wrapper.
GetFlattenedDocumentParams
Returns the root DOM node (and optionally the subtree) to the caller. Deprecated, as it is not designed to work well with the rest of the DOM agent. Use DOMSnapshot.captureSnapshot instead.
GetFlattenedDocumentReturns
Returns the root DOM node (and optionally the subtree) to the caller. Deprecated, as it is not designed to work well with the rest of the DOM agent. Use DOMSnapshot.captureSnapshot instead.
GetFrameOwnerParams
Returns iframe node that owns iframe with the given domain.
GetFrameOwnerReturns
Returns iframe node that owns iframe with the given domain.
GetNodeForLocationParams
Returns node id at given location. Depending on whether DOM domain is enabled, nodeId is either returned or not.
GetNodeForLocationReturns
Returns node id at given location. Depending on whether DOM domain is enabled, nodeId is either returned or not.
GetNodeStackTracesParams
Gets stack traces associated with a Node. As of now, only provides stack trace for Node creation.
GetNodeStackTracesReturns
Gets stack traces associated with a Node. As of now, only provides stack trace for Node creation.
GetNodesForSubtreeByStyleParams
Finds nodes with a given computed style in a subtree.
GetNodesForSubtreeByStyleReturns
Finds nodes with a given computed style in a subtree.
GetOuterHTMLParams
Returns node’s HTML markup.
GetOuterHTMLReturns
Returns node’s HTML markup.
GetQueryingDescendantsForContainerParams
Returns the descendants of a container query container that have container queries against this container.
GetQueryingDescendantsForContainerReturns
Returns the descendants of a container query container that have container queries against this container.
GetRelayoutBoundaryParams
Returns the id of the nearest ancestor that is a relayout boundary.
GetRelayoutBoundaryReturns
Returns the id of the nearest ancestor that is a relayout boundary.
GetSearchResultsParams
Returns search results from given ‘fromIndex’ to given ‘toIndex’ from the search with the given identifier.
GetSearchResultsReturns
Returns search results from given ‘fromIndex’ to given ‘toIndex’ from the search with the given identifier.
GetTopLayerElementsParams
GetTopLayerElementsReturns
Returns NodeIds of current top layer elements. Top layer is rendered closest to the user within a viewport, therefore its elements always appear on top of all other content.
HideHighlightParams
HighlightNodeParams
HighlightRectParams
MarkUndoableStateParams
MoveToParams
Moves node into the new container, places it before the given anchor.
MoveToReturns
Moves node into the new container, places it before the given anchor.
Node
DOM interaction is implemented in terms of mirror objects that represent the actual DOM nodes. DOMNode is a base node mirror type.
PerformSearchParams
Searches for a given string in the DOM tree. Use ‘getSearchResults’ to access search results or ‘cancelSearch’ to end this search session.
PerformSearchReturns
Searches for a given string in the DOM tree. Use ‘getSearchResults’ to access search results or ‘cancelSearch’ to end this search session.
PushNodeByPathToFrontendParams
Requests that the node is sent to the caller given its path. // FIXME, use XPath
PushNodeByPathToFrontendReturns
Requests that the node is sent to the caller given its path. // FIXME, use XPath
PushNodesByBackendIdsToFrontendParams
Requests that a batch of nodes is sent to the caller given their backend node ids.
PushNodesByBackendIdsToFrontendReturns
Requests that a batch of nodes is sent to the caller given their backend node ids.
QuerySelectorAllParams
Executes ‘querySelectorAll’ on a given node.
QuerySelectorAllReturns
Executes ‘querySelectorAll’ on a given node.
QuerySelectorParams
Executes ‘querySelector’ on a given node.
QuerySelectorReturns
Executes ‘querySelector’ on a given node.
RGBA
A structure holding an RGBA color.
Rect
Rectangle.
RedoParams
RemoveAttributeParams
Removes attribute with given name from an element with given id.
RemoveNodeParams
Removes node with given id.
RequestChildNodesParams
Requests that children of the node with given id are returned to the caller in form of ‘setChildNodes’ events where not only immediate children are retrieved, but all children down to the specified depth.
RequestNodeParams
Requests that the node is sent to the caller given the JavaScript node object reference. All nodes that form the path from the node to the root are also sent to the client as a series of ‘setChildNodes’ notifications.
RequestNodeReturns
Requests that the node is sent to the caller given the JavaScript node object reference. All nodes that form the path from the node to the root are also sent to the client as a series of ‘setChildNodes’ notifications.
ResolveNodeParams
Resolves the JavaScript node object for a given NodeId or BackendNodeId.
ResolveNodeReturns
Resolves the JavaScript node object for a given NodeId or BackendNodeId.
ScrollIntoViewIfNeededParams
Scrolls the specified rect of the given node into view if not already visible. Note: exactly one between nodeId, backendNodeId and objectId should be passed to identify the node.
SetAttributeValueParams
Sets attribute for an element with given id.
SetAttributesAsTextParams
Sets attributes on element with given id. This method is useful when user edits some existing attribute value and types in several attribute name/value pairs.
SetFileInputFilesParams
Sets files for the given file input element.
SetInspectedNodeParams
Enables console to refer to the node with given id via $x (see Command Line API for more details $x functions).
SetNodeNameParams
Sets node name for a node with given id.
SetNodeNameReturns
Sets node name for a node with given id.
SetNodeStackTracesEnabledParams
Sets if stack traces should be captured for Nodes. See ‘Node.getNodeStackTraces’. Default is disabled.
SetNodeValueParams
Sets node value for a node with given id.
SetOuterHTMLParams
Sets node HTML markup, returns new node id.
ShapeOutsideInfo
CSS Shape Outside details.
UndoParams

Enums

CompatibilityMode
Document compatibility mode.
LogicalAxes
ContainerSelector logical axes
PhysicalAxes
ContainerSelector physical axes
PseudoType
Pseudo element type.
ScrollOrientation
Physical scroll orientation
ShadowRootType
Shadow root type.

Type Aliases

BackendNodeId
Unique DOM node identifier used to reference a node that may not have been pushed to the front-end.
NodeId
Unique DOM node identifier.
Quad
An array of quad vertices, x immediately followed by y for each point, points clock-wise.
StyleSheetId
Unique identifier for a CSS stylesheet.