pub struct CopyToParams {
pub nodeId: NodeId,
pub targetNodeId: NodeId,
pub insertBeforeNodeId: Option<NodeId>,
}Expand description
Creates a deep copy of the specified node and places it into the target container before the given anchor.
Fields
nodeId: NodeIdId of the node to copy.
targetNodeId: NodeIdId of the element to drop the copy into.
insertBeforeNodeId: Option<NodeId>Drop the copy before this node (if absent, the copy becomes the last child of ‘targetNodeId’).