pub struct GetContainerForNodeParams {
pub nodeId: NodeId,
pub containerName: Option<String>,
pub physicalAxes: Option<PhysicalAxes>,
pub logicalAxes: Option<LogicalAxes>,
pub queriesScrollState: Option<bool>,
pub queriesAnchored: Option<bool>,
}Expand description
Returns the query container of the given node based on container query conditions: containerName, physical and logical axes, and whether it queries scroll-state or anchored elements. If no axes are provided and queriesScrollState is false, the style container is returned, which is the direct parent or the closest element with a matching container-name.
Fields
nodeId: NodeIdcontainerName: Option<String>physicalAxes: Option<PhysicalAxes>logicalAxes: Option<LogicalAxes>queriesScrollState: Option<bool>queriesAnchored: Option<bool>Implementations