pub struct GetFrameOwnerReturns {
pub backendNodeId: BackendNodeId,
pub nodeId: Option<NodeId>,
}Expand description
Returns iframe node that owns iframe with the given domain.
Fields
backendNodeId: BackendNodeIdResulting node.
nodeId: Option<NodeId>Id of the node at given coordinates, only when enabled and requested document.