pub struct GetNodesForSubtreeByStyleParams<'a> { /* private fields */ }Expand description
Finds nodes with a given computed style in a subtree.
Implementations
Sourceimpl<'a> GetNodesForSubtreeByStyleParams<'a>
impl<'a> GetNodesForSubtreeByStyleParams<'a>
Sourcepub fn builder(
node_id: NodeId,
computed_styles: Vec<CSSComputedStyleProperty<'a>>,
) -> GetNodesForSubtreeByStyleParamsBuilder<'a>
pub fn builder( node_id: NodeId, computed_styles: Vec<CSSComputedStyleProperty<'a>>, ) -> GetNodesForSubtreeByStyleParamsBuilder<'a>
Creates a builder for this type with the required parameters:
node_id: Node ID pointing to the root of a subtree.computed_styles: The style to filter nodes by (includes nodes if any of properties matches).
Sourcepub fn computed_styles(&self) -> &[CSSComputedStyleProperty<'a>]
pub fn computed_styles(&self) -> &[CSSComputedStyleProperty<'a>]
The style to filter nodes by (includes nodes if any of properties matches).