GetNodesForSubtreeByStyleParams

Struct GetNodesForSubtreeByStyleParams 

pub struct GetNodesForSubtreeByStyleParams {
    pub nodeId: NodeId,
    pub computedStyles: Vec<CSSComputedStyleProperty>,
    pub pierce: Option<bool>,
}
Finds nodes with a given computed style in a subtree.

Fields

nodeId: NodeId

Node ID pointing to the root of a subtree.

computedStyles: Vec<CSSComputedStyleProperty>

The style to filter nodes by (includes nodes if any of properties matches).

pierce: Option<bool>

Whether or not iframes and shadow roots in the same target should be traversed when returning the results (default is false).