pub struct GetQueryingDescendantsForContainerParams { /* private fields */ }Expand description
Returns the descendants of a container query container that have container queries against this container.
Implementations
Sourceimpl GetQueryingDescendantsForContainerParams
impl GetQueryingDescendantsForContainerParams
Sourcepub fn builder(
node_id: NodeId,
) -> GetQueryingDescendantsForContainerParamsBuilder
pub fn builder( node_id: NodeId, ) -> GetQueryingDescendantsForContainerParamsBuilder
Creates a builder for this type with the required parameters:
node_id: Id of the container node to find querying descendants from.