pub struct MoveToParams { /* private fields */ }Expand description
Moves node into the new container, places it before the given anchor.
Implementations
Sourceimpl MoveToParams
impl MoveToParams
Sourcepub fn builder(node_id: NodeId, target_node_id: NodeId) -> MoveToParamsBuilder
pub fn builder(node_id: NodeId, target_node_id: NodeId) -> MoveToParamsBuilder
Creates a builder for this type with the required parameters:
node_id: Id of the node to move.target_node_id: Id of the element to drop the moved node into.
Sourcepub fn target_node_id(&self) -> &NodeId
pub fn target_node_id(&self) -> &NodeId
Id of the element to drop the moved node into.
Sourcepub fn insert_before_node_id(&self) -> Option<&NodeId>
pub fn insert_before_node_id(&self) -> Option<&NodeId>
Drop node before this one (if absent, the moved node becomes the last child of ‘targetNodeId’).