pub struct NodeBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> NodeBuilder<'a>
impl<'a> NodeBuilder<'a>
Sourcepub fn child_node_count(self, child_node_count: u64) -> Self
pub fn child_node_count(self, child_node_count: u64) -> Self
Child count for ‘Container’ nodes.
Sourcepub fn children(self, children: Vec<Box<Node<'a>>>) -> Self
pub fn children(self, children: Vec<Box<Node<'a>>>) -> Self
Child nodes of this node when requested with children.
Sourcepub fn attributes(self, attributes: Vec<Cow<'a, str>>) -> Self
pub fn attributes(self, attributes: Vec<Cow<'a, str>>) -> Self
Attributes of the ‘Element’ node in the form of flat array ‘[name1, value1, name2, value2]’.
Sourcepub fn document_url(self, document_url: impl Into<Cow<'a, str>>) -> Self
pub fn document_url(self, document_url: impl Into<Cow<'a, str>>) -> Self
Document URL that ‘Document’ or ‘FrameOwner’ node points to.
Sourcepub fn base_url(self, base_url: impl Into<Cow<'a, str>>) -> Self
pub fn base_url(self, base_url: impl Into<Cow<'a, str>>) -> Self
Base URL that ‘Document’ or ‘FrameOwner’ node uses for URL completion.
Sourcepub fn internal_subset(self, internal_subset: impl Into<Cow<'a, str>>) -> Self
pub fn internal_subset(self, internal_subset: impl Into<Cow<'a, str>>) -> Self
‘DocumentType’’s internalSubset.
Sourcepub fn xml_version(self, xml_version: impl Into<Cow<'a, str>>) -> Self
pub fn xml_version(self, xml_version: impl Into<Cow<'a, str>>) -> Self
‘Document’’s XML version in case of XML documents.
Sourcepub fn pseudo_type(self, pseudo_type: impl Into<PseudoType>) -> Self
pub fn pseudo_type(self, pseudo_type: impl Into<PseudoType>) -> Self
Pseudo element type for this node.
Sourcepub fn pseudo_identifier(
self,
pseudo_identifier: impl Into<Cow<'a, str>>,
) -> Self
pub fn pseudo_identifier( self, pseudo_identifier: impl Into<Cow<'a, str>>, ) -> Self
Pseudo element identifier for this node. Only present if there is a valid pseudoType.
Sourcepub fn shadow_root_type(
self,
shadow_root_type: impl Into<ShadowRootType>,
) -> Self
pub fn shadow_root_type( self, shadow_root_type: impl Into<ShadowRootType>, ) -> Self
Shadow root type.
Sourcepub fn content_document(self, content_document: Box<Node<'a>>) -> Self
pub fn content_document(self, content_document: Box<Node<'a>>) -> Self
Content document for frame owner elements.
Sourcepub fn shadow_roots(self, shadow_roots: Vec<Box<Node<'a>>>) -> Self
pub fn shadow_roots(self, shadow_roots: Vec<Box<Node<'a>>>) -> Self
Shadow root list for given element host.
Sourcepub fn template_content(self, template_content: Box<Node<'a>>) -> Self
pub fn template_content(self, template_content: Box<Node<'a>>) -> Self
Content document fragment for template elements.
Sourcepub fn pseudo_elements(self, pseudo_elements: Vec<Box<Node<'a>>>) -> Self
pub fn pseudo_elements(self, pseudo_elements: Vec<Box<Node<'a>>>) -> Self
Pseudo elements associated with this node.
Sourcepub fn imported_document(self, imported_document: Box<Node<'a>>) -> Self
pub fn imported_document(self, imported_document: Box<Node<'a>>) -> Self
Deprecated, as the HTML Imports API has been removed (crbug.com/937746). This property used to return the imported document for the HTMLImport links. The property is always undefined now.
Sourcepub fn distributed_nodes(self, distributed_nodes: Vec<BackendNode<'a>>) -> Self
pub fn distributed_nodes(self, distributed_nodes: Vec<BackendNode<'a>>) -> Self
Distributed nodes for given insertion point.