NodeBuilder

Struct NodeBuilder 

pub struct NodeBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> NodeBuilder<'a>

pub fn parentId(self, parentId: NodeId) -> Self

The id of the parent node if any.

pub fn childNodeCount(self, childNodeCount: u64) -> Self

Child count for ‘Container’ nodes.

pub fn children(self, children: Vec<Box<Node<'a>>>) -> Self

Child nodes of this node when requested with children.

pub fn attributes(self, attributes: Vec<Cow<'a, str>>) -> Self

Attributes of the ‘Element’ node in the form of flat array ‘[name1, value1, name2, value2]’.

pub fn documentURL(self, documentURL: impl Into<Cow<'a, str>>) -> Self

Document URL that ‘Document’ or ‘FrameOwner’ node points to.

pub fn baseURL(self, baseURL: impl Into<Cow<'a, str>>) -> Self

Base URL that ‘Document’ or ‘FrameOwner’ node uses for URL completion.

pub fn publicId(self, publicId: impl Into<Cow<'a, str>>) -> Self

‘DocumentType’’s publicId.

pub fn systemId(self, systemId: impl Into<Cow<'a, str>>) -> Self

‘DocumentType’’s systemId.

pub fn internalSubset(self, internalSubset: impl Into<Cow<'a, str>>) -> Self

‘DocumentType’’s internalSubset.

pub fn xmlVersion(self, xmlVersion: impl Into<Cow<'a, str>>) -> Self

‘Document’’s XML version in case of XML documents.

pub fn name(self, name: impl Into<Cow<'a, str>>) -> Self

‘Attr’’s name.

pub fn value(self, value: impl Into<Cow<'a, str>>) -> Self

‘Attr’’s value.

pub fn pseudoType(self, pseudoType: PseudoType) -> Self

Pseudo element type for this node.

pub fn pseudoIdentifier(self, pseudoIdentifier: impl Into<Cow<'a, str>>) -> Self

Pseudo element identifier for this node. Only present if there is a valid pseudoType.

pub fn shadowRootType(self, shadowRootType: ShadowRootType) -> Self

Shadow root type.

pub fn frameId(self, frameId: FrameId<'a>) -> Self

Frame ID for frame owner elements.

pub fn contentDocument(self, contentDocument: Box<Node<'a>>) -> Self

Content document for frame owner elements.

pub fn shadowRoots(self, shadowRoots: Vec<Box<Node<'a>>>) -> Self

Shadow root list for given element host.

pub fn templateContent(self, templateContent: Box<Node<'a>>) -> Self

Content document fragment for template elements.

pub fn pseudoElements(self, pseudoElements: Vec<Box<Node<'a>>>) -> Self

Pseudo elements associated with this node.

pub fn importedDocument(self, importedDocument: Box<Node<'a>>) -> Self

Deprecated, as the HTML Imports API has been removed (crbug.com/937746). This property used to return the imported document for the HTMLImport links. The property is always undefined now.

pub fn distributedNodes(self, distributedNodes: Vec<BackendNode<'a>>) -> Self

Distributed nodes for given insertion point.

pub fn isSVG(self, isSVG: bool) -> Self

Whether the node is SVG.

pub fn compatibilityMode(self, compatibilityMode: CompatibilityMode) -> Self

pub fn assignedSlot(self, assignedSlot: BackendNode<'a>) -> Self

pub fn isScrollable(self, isScrollable: bool) -> Self

pub fn affectedByStartingStyles(self, affectedByStartingStyles: bool) -> Self

pub fn adoptedStyleSheets( self, adoptedStyleSheets: Vec<StyleSheetId<'a>>, ) -> Self

pub fn adProvenance(self, adProvenance: AdProvenance<'a>) -> Self

pub fn build(self) -> Node<'a>