pub struct NodeBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> NodeBuilder<'a>
impl<'a> NodeBuilder<'a>
Sourcepub fn childNodeCount(self, childNodeCount: u64) -> Self
pub fn childNodeCount(self, childNodeCount: u64) -> Self
Child count for ‘Container’ nodes.
Sourcepub fn children(self, children: Vec<Box<Node<'a>>>) -> Self
pub fn children(self, children: Vec<Box<Node<'a>>>) -> Self
Child nodes of this node when requested with children.
Sourcepub fn attributes(self, attributes: Vec<Cow<'a, str>>) -> Self
pub fn attributes(self, attributes: Vec<Cow<'a, str>>) -> Self
Attributes of the ‘Element’ node in the form of flat array ‘[name1, value1, name2, value2]’.
Sourcepub fn documentURL(self, documentURL: impl Into<Cow<'a, str>>) -> Self
pub fn documentURL(self, documentURL: impl Into<Cow<'a, str>>) -> Self
Document URL that ‘Document’ or ‘FrameOwner’ node points to.
Sourcepub fn baseURL(self, baseURL: impl Into<Cow<'a, str>>) -> Self
pub fn baseURL(self, baseURL: impl Into<Cow<'a, str>>) -> Self
Base URL that ‘Document’ or ‘FrameOwner’ node uses for URL completion.
Sourcepub fn internalSubset(self, internalSubset: impl Into<Cow<'a, str>>) -> Self
pub fn internalSubset(self, internalSubset: impl Into<Cow<'a, str>>) -> Self
‘DocumentType’’s internalSubset.
Sourcepub fn xmlVersion(self, xmlVersion: impl Into<Cow<'a, str>>) -> Self
pub fn xmlVersion(self, xmlVersion: impl Into<Cow<'a, str>>) -> Self
‘Document’’s XML version in case of XML documents.
Sourcepub fn pseudoType(self, pseudoType: PseudoType) -> Self
pub fn pseudoType(self, pseudoType: PseudoType) -> Self
Pseudo element type for this node.
Sourcepub fn pseudoIdentifier(self, pseudoIdentifier: impl Into<Cow<'a, str>>) -> Self
pub fn pseudoIdentifier(self, pseudoIdentifier: impl Into<Cow<'a, str>>) -> Self
Pseudo element identifier for this node. Only present if there is a valid pseudoType.
Sourcepub fn shadowRootType(self, shadowRootType: ShadowRootType) -> Self
pub fn shadowRootType(self, shadowRootType: ShadowRootType) -> Self
Shadow root type.
Sourcepub fn contentDocument(self, contentDocument: Box<Node<'a>>) -> Self
pub fn contentDocument(self, contentDocument: Box<Node<'a>>) -> Self
Content document for frame owner elements.
Sourcepub fn shadowRoots(self, shadowRoots: Vec<Box<Node<'a>>>) -> Self
pub fn shadowRoots(self, shadowRoots: Vec<Box<Node<'a>>>) -> Self
Shadow root list for given element host.
Sourcepub fn templateContent(self, templateContent: Box<Node<'a>>) -> Self
pub fn templateContent(self, templateContent: Box<Node<'a>>) -> Self
Content document fragment for template elements.
Sourcepub fn pseudoElements(self, pseudoElements: Vec<Box<Node<'a>>>) -> Self
pub fn pseudoElements(self, pseudoElements: Vec<Box<Node<'a>>>) -> Self
Pseudo elements associated with this node.
Sourcepub fn importedDocument(self, importedDocument: Box<Node<'a>>) -> Self
pub fn importedDocument(self, importedDocument: Box<Node<'a>>) -> Self
Deprecated, as the HTML Imports API has been removed (crbug.com/937746). This property used to return the imported document for the HTMLImport links. The property is always undefined now.
Sourcepub fn distributedNodes(self, distributedNodes: Vec<BackendNode<'a>>) -> Self
pub fn distributedNodes(self, distributedNodes: Vec<BackendNode<'a>>) -> Self
Distributed nodes for given insertion point.