pub struct RequestNodeParams {
pub objectId: RemoteObjectId,
}Expand description
Requests that the node is sent to the caller given the JavaScript node object reference. All nodes that form the path from the node to the root are also sent to the client as a series of ‘setChildNodes’ notifications.
Fields
objectId: RemoteObjectIdJavaScript object id to convert into node.