Module domsnapshot

Module domsnapshot 

This domain facilitates obtaining document snapshots with DOM, layout, and style information.

Structs

CaptureSnapshotParams
Returns a document snapshot, including the full DOM tree of the root node (including iframes, template contents, and imported documents) in a flattened array, as well as layout and white-listed computed style information for the nodes. Shadow DOM in the returned DOM tree is flattened.
CaptureSnapshotReturns
Returns a document snapshot, including the full DOM tree of the root node (including iframes, template contents, and imported documents) in a flattened array, as well as layout and white-listed computed style information for the nodes. Shadow DOM in the returned DOM tree is flattened.
ComputedStyle
A subset of the full ComputedStyle as defined by the request whitelist.
DOMNode
A Node in the DOM tree.
DisableParams
DocumentSnapshot
Document snapshot.
EnableParams
GetSnapshotParams
Returns a document snapshot, including the full DOM tree of the root node (including iframes, template contents, and imported documents) in a flattened array, as well as layout and white-listed computed style information for the nodes. Shadow DOM in the returned DOM tree is flattened.
GetSnapshotReturns
Returns a document snapshot, including the full DOM tree of the root node (including iframes, template contents, and imported documents) in a flattened array, as well as layout and white-listed computed style information for the nodes. Shadow DOM in the returned DOM tree is flattened.
InlineTextBox
Details of post layout rendered text positions. The exact layout should not be regarded as stable and may change between versions.
LayoutTreeNode
Details of an element in the DOM tree with a LayoutObject.
LayoutTreeSnapshot
Table of details of an element in the DOM tree with a LayoutObject.
NameValue
A name/value pair.
NodeTreeSnapshot
Table containing nodes.
RareBooleanData
RareIntegerData
RareStringData
Data that is only present on rare nodes.
TextBoxSnapshot
Table of details of the post layout rendered text positions. The exact layout should not be regarded as stable and may change between versions.

Type Aliases

ArrayOfStrings
Index of the string in the strings table.
Rectangle
StringIndex
Index of the string in the strings table.