This domain facilitates obtaining document snapshots with DOM, layout, and style information.
Structs
- Capture
Snapshot Params - Returns a document snapshot, including the full DOM tree of the root node (including iframes, template contents, and imported documents) in a flattened array, as well as layout and white-listed computed style information for the nodes. Shadow DOM in the returned DOM tree is flattened.
- Capture
Snapshot Returns - Returns a document snapshot, including the full DOM tree of the root node (including iframes, template contents, and imported documents) in a flattened array, as well as layout and white-listed computed style information for the nodes. Shadow DOM in the returned DOM tree is flattened.
- Computed
Style - A subset of the full ComputedStyle as defined by the request whitelist.
- DOMNode
- A Node in the DOM tree.
- Disable
Params - Document
Snapshot - Document snapshot.
- Enable
Params - GetSnapshot
Params - Returns a document snapshot, including the full DOM tree of the root node (including iframes, template contents, and imported documents) in a flattened array, as well as layout and white-listed computed style information for the nodes. Shadow DOM in the returned DOM tree is flattened.
- GetSnapshot
Returns - Returns a document snapshot, including the full DOM tree of the root node (including iframes, template contents, and imported documents) in a flattened array, as well as layout and white-listed computed style information for the nodes. Shadow DOM in the returned DOM tree is flattened.
- Inline
Text Box - Details of post layout rendered text positions. The exact layout should not be regarded as stable and may change between versions.
- Layout
Tree Node - Details of an element in the DOM tree with a LayoutObject.
- Layout
Tree Snapshot - Table of details of an element in the DOM tree with a LayoutObject.
- Name
Value - A name/value pair.
- Node
Tree Snapshot - Table containing nodes.
- Rare
Boolean Data - Rare
Integer Data - Rare
String Data - Data that is only present on rare nodes.
- Text
BoxSnapshot - Table of details of the post layout rendered text positions. The exact layout should not be regarded as stable and may change between versions.
Type Aliases
- Array
OfStrings - Index of the string in the strings table.
- Rectangle
- String
Index - Index of the string in the strings table.