pub struct CaptureSnapshotParamsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> CaptureSnapshotParamsBuilder<'a>
impl<'a> CaptureSnapshotParamsBuilder<'a>
Sourcepub fn includePaintOrder(self, includePaintOrder: bool) -> Self
pub fn includePaintOrder(self, includePaintOrder: bool) -> Self
Whether to include layout object paint orders into the snapshot.
Sourcepub fn includeDOMRects(self, includeDOMRects: bool) -> Self
pub fn includeDOMRects(self, includeDOMRects: bool) -> Self
Whether to include DOM rectangles (offsetRects, clientRects, scrollRects) into the snapshot
Sourcepub fn includeBlendedBackgroundColors(
self,
includeBlendedBackgroundColors: bool,
) -> Self
pub fn includeBlendedBackgroundColors( self, includeBlendedBackgroundColors: bool, ) -> Self
Whether to include blended background colors in the snapshot (default: false). Blended background color is achieved by blending background colors of all elements that overlap with the current element.
Sourcepub fn includeTextColorOpacities(self, includeTextColorOpacities: bool) -> Self
pub fn includeTextColorOpacities(self, includeTextColorOpacities: bool) -> Self
Whether to include text color opacity in the snapshot (default: false). An element might have the opacity property set that affects the text color of the element. The final text color opacity is computed based on the opacity of all overlapping elements.
pub fn build(self) -> CaptureSnapshotParams<'a>