pub struct DOMNode {Show 28 fields
pub nodeType: i64,
pub nodeName: String,
pub nodeValue: String,
pub textValue: Option<String>,
pub inputValue: Option<String>,
pub inputChecked: Option<bool>,
pub optionSelected: Option<bool>,
pub backendNodeId: BackendNodeId,
pub childNodeIndexes: Option<Vec<i64>>,
pub attributes: Option<Vec<NameValue>>,
pub pseudoElementIndexes: Option<Vec<i64>>,
pub layoutNodeIndex: Option<u64>,
pub documentURL: Option<String>,
pub baseURL: Option<String>,
pub contentLanguage: Option<String>,
pub documentEncoding: Option<String>,
pub publicId: Option<String>,
pub systemId: Option<String>,
pub frameId: Option<FrameId>,
pub contentDocumentIndex: Option<u64>,
pub pseudoType: Option<PseudoType>,
pub shadowRootType: Option<ShadowRootType>,
pub isClickable: Option<bool>,
pub eventListeners: Option<Vec<EventListener>>,
pub currentSourceURL: Option<String>,
pub originURL: Option<String>,
pub scrollOffsetX: Option<f64>,
pub scrollOffsetY: Option<f64>,
}Expand description
A Node in the DOM tree.
Fields
nodeType: i64‘Node’’s nodeType.
nodeName: String‘Node’’s nodeName.
nodeValue: String‘Node’’s nodeValue.
textValue: Option<String>Only set for textarea elements, contains the text value.
inputValue: Option<String>Only set for input elements, contains the input’s associated text value.
inputChecked: Option<bool>Only set for radio and checkbox input elements, indicates if the element has been checked
optionSelected: Option<bool>Only set for option elements, indicates if the element has been selected
backendNodeId: BackendNodeId‘Node’’s id, corresponds to DOM.Node.backendNodeId.
childNodeIndexes: Option<Vec<i64>>The indexes of the node’s child nodes in the ‘domNodes’ array returned by ‘getSnapshot’, if any.
attributes: Option<Vec<NameValue>>Attributes of an ‘Element’ node.
pseudoElementIndexes: Option<Vec<i64>>Indexes of pseudo elements associated with this node in the ‘domNodes’ array returned by ‘getSnapshot’, if any.
layoutNodeIndex: Option<u64>The index of the node’s related layout tree node in the ‘layoutTreeNodes’ array returned by ‘getSnapshot’, if any.
documentURL: Option<String>Document URL that ‘Document’ or ‘FrameOwner’ node points to.
baseURL: Option<String>Base URL that ‘Document’ or ‘FrameOwner’ node uses for URL completion.
contentLanguage: Option<String>Only set for documents, contains the document’s content language.
documentEncoding: Option<String>Only set for documents, contains the document’s character set encoding.
publicId: Option<String>‘DocumentType’ node’s publicId.
systemId: Option<String>‘DocumentType’ node’s systemId.
frameId: Option<FrameId>Frame ID for frame owner elements and also for the document node.
contentDocumentIndex: Option<u64>The index of a frame owner element’s content document in the ‘domNodes’ array returned by ‘getSnapshot’, if any.
pseudoType: Option<PseudoType>Type of a pseudo element node.
shadowRootType: Option<ShadowRootType>Shadow root type.
isClickable: Option<bool>Whether this DOM node responds to mouse clicks. This includes nodes that have had click event listeners attached via JavaScript as well as anchor tags that naturally navigate when clicked.
eventListeners: Option<Vec<EventListener>>Details of the node’s event listeners, if any.
currentSourceURL: Option<String>The selected url for nodes with a srcset attribute.
originURL: Option<String>The url of the script (if any) that generates this node.
scrollOffsetX: Option<f64>Scroll offsets, set when this node is a Document.
scrollOffsetY: Option<f64>