DOMNodeBuilder

Struct DOMNodeBuilder 

pub struct DOMNodeBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> DOMNodeBuilder<'a>

pub fn text_value(self, text_value: impl Into<Cow<'a, str>>) -> Self

Only set for textarea elements, contains the text value.

pub fn input_value(self, input_value: impl Into<Cow<'a, str>>) -> Self

Only set for input elements, contains the input’s associated text value.

pub fn input_checked(self, input_checked: bool) -> Self

Only set for radio and checkbox input elements, indicates if the element has been checked

pub fn option_selected(self, option_selected: bool) -> Self

Only set for option elements, indicates if the element has been selected

pub fn child_node_indexes(self, child_node_indexes: Vec<i64>) -> Self

The indexes of the node’s child nodes in the ‘domNodes’ array returned by ‘getSnapshot’, if any.

pub fn attributes(self, attributes: Vec<NameValue<'a>>) -> Self

Attributes of an ‘Element’ node.

pub fn pseudo_element_indexes(self, pseudo_element_indexes: Vec<i64>) -> Self

Indexes of pseudo elements associated with this node in the ‘domNodes’ array returned by ‘getSnapshot’, if any.

pub fn layout_node_index(self, layout_node_index: u64) -> Self

The index of the node’s related layout tree node in the ‘layoutTreeNodes’ array returned by ‘getSnapshot’, if any.

pub fn document_url(self, document_url: impl Into<Cow<'a, str>>) -> Self

Document URL that ‘Document’ or ‘FrameOwner’ node points to.

pub fn base_url(self, base_url: impl Into<Cow<'a, str>>) -> Self

Base URL that ‘Document’ or ‘FrameOwner’ node uses for URL completion.

pub fn content_language(self, content_language: impl Into<Cow<'a, str>>) -> Self

Only set for documents, contains the document’s content language.

pub fn document_encoding( self, document_encoding: impl Into<Cow<'a, str>>, ) -> Self

Only set for documents, contains the document’s character set encoding.

pub fn public_id(self, public_id: impl Into<Cow<'a, str>>) -> Self

‘DocumentType’ node’s publicId.

pub fn system_id(self, system_id: impl Into<Cow<'a, str>>) -> Self

‘DocumentType’ node’s systemId.

pub fn frame_id(self, frame_id: FrameId<'a>) -> Self

Frame ID for frame owner elements and also for the document node.

pub fn content_document_index(self, content_document_index: u64) -> Self

The index of a frame owner element’s content document in the ‘domNodes’ array returned by ‘getSnapshot’, if any.

pub fn pseudo_type(self, pseudo_type: PseudoType) -> Self

Type of a pseudo element node.

pub fn shadow_root_type(self, shadow_root_type: ShadowRootType) -> Self

Shadow root type.

pub fn is_clickable(self, is_clickable: bool) -> Self

Whether this DOM node responds to mouse clicks. This includes nodes that have had click event listeners attached via JavaScript as well as anchor tags that naturally navigate when clicked.

pub fn event_listeners(self, event_listeners: Vec<EventListener<'a>>) -> Self

Details of the node’s event listeners, if any.

pub fn current_source_url( self, current_source_url: impl Into<Cow<'a, str>>, ) -> Self

The selected url for nodes with a srcset attribute.

pub fn origin_url(self, origin_url: impl Into<Cow<'a, str>>) -> Self

The url of the script (if any) that generates this node.

pub fn scroll_offset_x(self, scroll_offset_x: f64) -> Self

Scroll offsets, set when this node is a Document.

pub fn scroll_offset_y(self, scroll_offset_y: f64) -> Self

pub fn build(self) -> DOMNode<'a>