DOMNodeBuilder

Struct DOMNodeBuilder 

pub struct DOMNodeBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> DOMNodeBuilder<'a>

pub fn textValue(self, textValue: impl Into<Cow<'a, str>>) -> Self

Only set for textarea elements, contains the text value.

pub fn inputValue(self, inputValue: impl Into<Cow<'a, str>>) -> Self

Only set for input elements, contains the input’s associated text value.

pub fn inputChecked(self, inputChecked: bool) -> Self

Only set for radio and checkbox input elements, indicates if the element has been checked

pub fn optionSelected(self, optionSelected: bool) -> Self

Only set for option elements, indicates if the element has been selected

pub fn childNodeIndexes(self, childNodeIndexes: Vec<i64>) -> Self

The indexes of the node’s child nodes in the ‘domNodes’ array returned by ‘getSnapshot’, if any.

pub fn attributes(self, attributes: Vec<NameValue<'a>>) -> Self

Attributes of an ‘Element’ node.

pub fn pseudoElementIndexes(self, pseudoElementIndexes: Vec<i64>) -> Self

Indexes of pseudo elements associated with this node in the ‘domNodes’ array returned by ‘getSnapshot’, if any.

pub fn layoutNodeIndex(self, layoutNodeIndex: u64) -> Self

The index of the node’s related layout tree node in the ‘layoutTreeNodes’ array returned by ‘getSnapshot’, if any.

pub fn documentURL(self, documentURL: impl Into<Cow<'a, str>>) -> Self

Document URL that ‘Document’ or ‘FrameOwner’ node points to.

pub fn baseURL(self, baseURL: impl Into<Cow<'a, str>>) -> Self

Base URL that ‘Document’ or ‘FrameOwner’ node uses for URL completion.

pub fn contentLanguage(self, contentLanguage: impl Into<Cow<'a, str>>) -> Self

Only set for documents, contains the document’s content language.

pub fn documentEncoding(self, documentEncoding: impl Into<Cow<'a, str>>) -> Self

Only set for documents, contains the document’s character set encoding.

pub fn publicId(self, publicId: impl Into<Cow<'a, str>>) -> Self

‘DocumentType’ node’s publicId.

pub fn systemId(self, systemId: impl Into<Cow<'a, str>>) -> Self

‘DocumentType’ node’s systemId.

pub fn frameId(self, frameId: FrameId<'a>) -> Self

Frame ID for frame owner elements and also for the document node.

pub fn contentDocumentIndex(self, contentDocumentIndex: u64) -> Self

The index of a frame owner element’s content document in the ‘domNodes’ array returned by ‘getSnapshot’, if any.

pub fn pseudoType(self, pseudoType: PseudoType) -> Self

Type of a pseudo element node.

pub fn shadowRootType(self, shadowRootType: ShadowRootType) -> Self

Shadow root type.

pub fn isClickable(self, isClickable: bool) -> Self

Whether this DOM node responds to mouse clicks. This includes nodes that have had click event listeners attached via JavaScript as well as anchor tags that naturally navigate when clicked.

pub fn eventListeners(self, eventListeners: Vec<EventListener<'a>>) -> Self

Details of the node’s event listeners, if any.

pub fn currentSourceURL(self, currentSourceURL: impl Into<Cow<'a, str>>) -> Self

The selected url for nodes with a srcset attribute.

pub fn originURL(self, originURL: impl Into<Cow<'a, str>>) -> Self

The url of the script (if any) that generates this node.

pub fn scrollOffsetX(self, scrollOffsetX: f64) -> Self

Scroll offsets, set when this node is a Document.

pub fn scrollOffsetY(self, scrollOffsetY: f64) -> Self

pub fn build(self) -> DOMNode<'a>