pub struct DOMNodeBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> DOMNodeBuilder<'a>
impl<'a> DOMNodeBuilder<'a>
Sourcepub fn textValue(self, textValue: impl Into<Cow<'a, str>>) -> Self
pub fn textValue(self, textValue: impl Into<Cow<'a, str>>) -> Self
Only set for textarea elements, contains the text value.
Sourcepub fn inputValue(self, inputValue: impl Into<Cow<'a, str>>) -> Self
pub fn inputValue(self, inputValue: impl Into<Cow<'a, str>>) -> Self
Only set for input elements, contains the input’s associated text value.
Sourcepub fn inputChecked(self, inputChecked: bool) -> Self
pub fn inputChecked(self, inputChecked: bool) -> Self
Only set for radio and checkbox input elements, indicates if the element has been checked
Sourcepub fn optionSelected(self, optionSelected: bool) -> Self
pub fn optionSelected(self, optionSelected: bool) -> Self
Only set for option elements, indicates if the element has been selected
Sourcepub fn childNodeIndexes(self, childNodeIndexes: Vec<i64>) -> Self
pub fn childNodeIndexes(self, childNodeIndexes: Vec<i64>) -> Self
The indexes of the node’s child nodes in the ‘domNodes’ array returned by ‘getSnapshot’, if any.
Sourcepub fn attributes(self, attributes: Vec<NameValue<'a>>) -> Self
pub fn attributes(self, attributes: Vec<NameValue<'a>>) -> Self
Attributes of an ‘Element’ node.
Sourcepub fn pseudoElementIndexes(self, pseudoElementIndexes: Vec<i64>) -> Self
pub fn pseudoElementIndexes(self, pseudoElementIndexes: Vec<i64>) -> Self
Indexes of pseudo elements associated with this node in the ‘domNodes’ array returned by ‘getSnapshot’, if any.
Sourcepub fn layoutNodeIndex(self, layoutNodeIndex: u64) -> Self
pub fn layoutNodeIndex(self, layoutNodeIndex: u64) -> Self
The index of the node’s related layout tree node in the ‘layoutTreeNodes’ array returned by ‘getSnapshot’, if any.
Sourcepub fn documentURL(self, documentURL: impl Into<Cow<'a, str>>) -> Self
pub fn documentURL(self, documentURL: impl Into<Cow<'a, str>>) -> Self
Document URL that ‘Document’ or ‘FrameOwner’ node points to.
Sourcepub fn baseURL(self, baseURL: impl Into<Cow<'a, str>>) -> Self
pub fn baseURL(self, baseURL: impl Into<Cow<'a, str>>) -> Self
Base URL that ‘Document’ or ‘FrameOwner’ node uses for URL completion.
Sourcepub fn contentLanguage(self, contentLanguage: impl Into<Cow<'a, str>>) -> Self
pub fn contentLanguage(self, contentLanguage: impl Into<Cow<'a, str>>) -> Self
Only set for documents, contains the document’s content language.
Sourcepub fn documentEncoding(self, documentEncoding: impl Into<Cow<'a, str>>) -> Self
pub fn documentEncoding(self, documentEncoding: impl Into<Cow<'a, str>>) -> Self
Only set for documents, contains the document’s character set encoding.
Sourcepub fn publicId(self, publicId: impl Into<Cow<'a, str>>) -> Self
pub fn publicId(self, publicId: impl Into<Cow<'a, str>>) -> Self
‘DocumentType’ node’s publicId.
Sourcepub fn systemId(self, systemId: impl Into<Cow<'a, str>>) -> Self
pub fn systemId(self, systemId: impl Into<Cow<'a, str>>) -> Self
‘DocumentType’ node’s systemId.
Sourcepub fn frameId(self, frameId: FrameId<'a>) -> Self
pub fn frameId(self, frameId: FrameId<'a>) -> Self
Frame ID for frame owner elements and also for the document node.
Sourcepub fn contentDocumentIndex(self, contentDocumentIndex: u64) -> Self
pub fn contentDocumentIndex(self, contentDocumentIndex: u64) -> Self
The index of a frame owner element’s content document in the ‘domNodes’ array returned by ‘getSnapshot’, if any.
Sourcepub fn pseudoType(self, pseudoType: PseudoType) -> Self
pub fn pseudoType(self, pseudoType: PseudoType) -> Self
Type of a pseudo element node.
Sourcepub fn shadowRootType(self, shadowRootType: ShadowRootType) -> Self
pub fn shadowRootType(self, shadowRootType: ShadowRootType) -> Self
Shadow root type.
Sourcepub fn isClickable(self, isClickable: bool) -> Self
pub fn isClickable(self, isClickable: bool) -> Self
Whether this DOM node responds to mouse clicks. This includes nodes that have had click event listeners attached via JavaScript as well as anchor tags that naturally navigate when clicked.
Sourcepub fn eventListeners(self, eventListeners: Vec<EventListener<'a>>) -> Self
pub fn eventListeners(self, eventListeners: Vec<EventListener<'a>>) -> Self
Details of the node’s event listeners, if any.
Sourcepub fn currentSourceURL(self, currentSourceURL: impl Into<Cow<'a, str>>) -> Self
pub fn currentSourceURL(self, currentSourceURL: impl Into<Cow<'a, str>>) -> Self
The selected url for nodes with a srcset attribute.
Sourcepub fn originURL(self, originURL: impl Into<Cow<'a, str>>) -> Self
pub fn originURL(self, originURL: impl Into<Cow<'a, str>>) -> Self
The url of the script (if any) that generates this node.
Sourcepub fn scrollOffsetX(self, scrollOffsetX: f64) -> Self
pub fn scrollOffsetX(self, scrollOffsetX: f64) -> Self
Scroll offsets, set when this node is a Document.