pub struct GetSnapshotParams {
pub computedStyleWhitelist: Vec<String>,
pub includeEventListeners: Option<bool>,
pub includePaintOrder: Option<bool>,
pub includeUserAgentShadowTree: Option<bool>,
}Expand description
Returns a document snapshot, including the full DOM tree of the root node (including iframes, template contents, and imported documents) in a flattened array, as well as layout and white-listed computed style information for the nodes. Shadow DOM in the returned DOM tree is flattened.
Fields
computedStyleWhitelist: Vec<String>Whitelist of computed styles to return.
includeEventListeners: Option<bool>Whether or not to retrieve details of DOM listeners (default false).
includePaintOrder: Option<bool>Whether to determine and include the paint order index of LayoutTreeNodes (default false).
includeUserAgentShadowTree: Option<bool>Whether to include UA shadow tree in the snapshot (default false).
Implementations