pub struct GetSnapshotReturns {
pub domNodes: Vec<DOMNode>,
pub layoutTreeNodes: Vec<LayoutTreeNode>,
pub computedStyles: Vec<ComputedStyle>,
}Expand description
Returns a document snapshot, including the full DOM tree of the root node (including iframes, template contents, and imported documents) in a flattened array, as well as layout and white-listed computed style information for the nodes. Shadow DOM in the returned DOM tree is flattened.
Fields
domNodes: Vec<DOMNode>The nodes in the DOM tree. The DOMNode at index 0 corresponds to the root document.
layoutTreeNodes: Vec<LayoutTreeNode>The nodes in the layout tree.
computedStyles: Vec<ComputedStyle>Whitelisted ComputedStyle properties for each node in the layout tree.