pub struct LayoutTreeNode<'a> { /* private fields */ }Expand description
Details of an element in the DOM tree with a LayoutObject.
Implementations
Sourceimpl<'a> LayoutTreeNode<'a>
impl<'a> LayoutTreeNode<'a>
Sourcepub fn builder(
dom_node_index: u64,
bounding_box: Rect,
) -> LayoutTreeNodeBuilder<'a>
pub fn builder( dom_node_index: u64, bounding_box: Rect, ) -> LayoutTreeNodeBuilder<'a>
Creates a builder for this type with the required parameters:
dom_node_index: The index of the related DOM node in thedomNodesarray returned bygetSnapshot.bounding_box: The bounding box in document coordinates. Note that scroll offset of the document is ignored.
Sourcepub fn dom_node_index(&self) -> u64
pub fn dom_node_index(&self) -> u64
The index of the related DOM node in the ‘domNodes’ array returned by ‘getSnapshot’.
Sourcepub fn bounding_box(&self) -> &Rect
pub fn bounding_box(&self) -> &Rect
The bounding box in document coordinates. Note that scroll offset of the document is ignored.
Sourcepub fn layout_text(&self) -> Option<&str>
pub fn layout_text(&self) -> Option<&str>
Contents of the LayoutText, if any.
Sourcepub fn inline_text_nodes(&self) -> Option<&[InlineTextBox]>
pub fn inline_text_nodes(&self) -> Option<&[InlineTextBox]>
The post-layout inline text nodes, if any.
Sourcepub fn style_index(&self) -> Option<u64>
pub fn style_index(&self) -> Option<u64>
Index into the ‘computedStyles’ array returned by ‘getSnapshot’.
Sourcepub fn paint_order(&self) -> Option<i64>
pub fn paint_order(&self) -> Option<i64>
Global paint order index, which is determined by the stacking order of the nodes. Nodes that are painted together will have the same index. Only provided if includePaintOrder in getSnapshot was true.
Sourcepub fn is_stacking_context(&self) -> Option<bool>
pub fn is_stacking_context(&self) -> Option<bool>
Set to true to indicate the element begins a new stacking context.