pub struct LayoutTreeNode {
pub domNodeIndex: u64,
pub boundingBox: Rect,
pub layoutText: Option<String>,
pub inlineTextNodes: Option<Vec<InlineTextBox>>,
pub styleIndex: Option<u64>,
pub paintOrder: Option<i64>,
pub isStackingContext: Option<bool>,
}Expand description
Details of an element in the DOM tree with a LayoutObject.
Fields
domNodeIndex: u64The index of the related DOM node in the ‘domNodes’ array returned by ‘getSnapshot’.
boundingBox: RectThe bounding box in document coordinates. Note that scroll offset of the document is ignored.
layoutText: Option<String>Contents of the LayoutText, if any.
inlineTextNodes: Option<Vec<InlineTextBox>>The post-layout inline text nodes, if any.
styleIndex: Option<u64>Index into the ‘computedStyles’ array returned by ‘getSnapshot’.
paintOrder: Option<i64>Global paint order index, which is determined by the stacking order of the nodes. Nodes that are painted together will have the same index. Only provided if includePaintOrder in getSnapshot was true.
isStackingContext: Option<bool>Set to true to indicate the element begins a new stacking context.