LayoutTreeNodeBuilder

Struct LayoutTreeNodeBuilder 

pub struct LayoutTreeNodeBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> LayoutTreeNodeBuilder<'a>

pub fn layout_text(self, layout_text: impl Into<Cow<'a, str>>) -> Self

Contents of the LayoutText, if any.

pub fn inline_text_nodes(self, inline_text_nodes: Vec<InlineTextBox>) -> Self

The post-layout inline text nodes, if any.

pub fn style_index(self, style_index: u64) -> Self

Index into the ‘computedStyles’ array returned by ‘getSnapshot’.

pub fn paint_order(self, paint_order: i64) -> Self

Global paint order index, which is determined by the stacking order of the nodes. Nodes that are painted together will have the same index. Only provided if includePaintOrder in getSnapshot was true.

pub fn is_stacking_context(self, is_stacking_context: bool) -> Self

Set to true to indicate the element begins a new stacking context.

pub fn build(self) -> LayoutTreeNode<'a>