LayoutTreeNodeBuilder

Struct LayoutTreeNodeBuilder 

pub struct LayoutTreeNodeBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> LayoutTreeNodeBuilder<'a>

pub fn layoutText(self, layoutText: impl Into<Cow<'a, str>>) -> Self

Contents of the LayoutText, if any.

pub fn inlineTextNodes(self, inlineTextNodes: Vec<InlineTextBox>) -> Self

The post-layout inline text nodes, if any.

pub fn styleIndex(self, styleIndex: u64) -> Self

Index into the ‘computedStyles’ array returned by ‘getSnapshot’.

pub fn paintOrder(self, paintOrder: i64) -> Self

Global paint order index, which is determined by the stacking order of the nodes. Nodes that are painted together will have the same index. Only provided if includePaintOrder in getSnapshot was true.

pub fn isStackingContext(self, isStackingContext: bool) -> Self

Set to true to indicate the element begins a new stacking context.

pub fn build(self) -> LayoutTreeNode<'a>