pub struct LayoutTreeSnapshot {
pub nodeIndex: Vec<i64>,
pub styles: Vec<ArrayOfStrings>,
pub bounds: Vec<Rectangle>,
pub text: Vec<StringIndex>,
pub stackingContexts: RareBooleanData,
pub paintOrders: Option<Vec<i64>>,
pub offsetRects: Option<Vec<Rectangle>>,
pub scrollRects: Option<Vec<Rectangle>>,
pub clientRects: Option<Vec<Rectangle>>,
pub blendedBackgroundColors: Option<Vec<StringIndex>>,
pub textColorOpacities: Option<Vec<f64>>,
}Expand description
Table of details of an element in the DOM tree with a LayoutObject.
Fields
nodeIndex: Vec<i64>Index of the corresponding node in the ‘NodeTreeSnapshot’ array returned by ‘captureSnapshot’.
styles: Vec<ArrayOfStrings>Array of indexes specifying computed style strings, filtered according to the ‘computedStyles’ parameter passed to ‘captureSnapshot’.
bounds: Vec<Rectangle>The absolute position bounding box.
text: Vec<StringIndex>Contents of the LayoutText, if any.
stackingContexts: RareBooleanDataStacking context information.
paintOrders: Option<Vec<i64>>Global paint order index, which is determined by the stacking order of the nodes. Nodes that are painted together will have the same index. Only provided if includePaintOrder in captureSnapshot was true.
offsetRects: Option<Vec<Rectangle>>The offset rect of nodes. Only available when includeDOMRects is set to true
scrollRects: Option<Vec<Rectangle>>The scroll rect of nodes. Only available when includeDOMRects is set to true
clientRects: Option<Vec<Rectangle>>The client rect of nodes. Only available when includeDOMRects is set to true
blendedBackgroundColors: Option<Vec<StringIndex>>The list of background colors that are blended with colors of overlapping elements.
textColorOpacities: Option<Vec<f64>>The list of computed text opacities.