pub struct LayoutTreeSnapshotBuilder { /* private fields */ }Implementations
Sourceimpl LayoutTreeSnapshotBuilder
impl LayoutTreeSnapshotBuilder
Sourcepub fn paintOrders(self, paintOrders: Vec<i64>) -> Self
pub fn paintOrders(self, paintOrders: Vec<i64>) -> Self
Global paint order index, which is determined by the stacking order of the nodes. Nodes that are painted together will have the same index. Only provided if includePaintOrder in captureSnapshot was true.
Sourcepub fn offsetRects(self, offsetRects: Vec<Rectangle>) -> Self
pub fn offsetRects(self, offsetRects: Vec<Rectangle>) -> Self
The offset rect of nodes. Only available when includeDOMRects is set to true
Sourcepub fn scrollRects(self, scrollRects: Vec<Rectangle>) -> Self
pub fn scrollRects(self, scrollRects: Vec<Rectangle>) -> Self
The scroll rect of nodes. Only available when includeDOMRects is set to true
Sourcepub fn clientRects(self, clientRects: Vec<Rectangle>) -> Self
pub fn clientRects(self, clientRects: Vec<Rectangle>) -> Self
The client rect of nodes. Only available when includeDOMRects is set to true
Sourcepub fn blendedBackgroundColors(
self,
blendedBackgroundColors: Vec<StringIndex>,
) -> Self
pub fn blendedBackgroundColors( self, blendedBackgroundColors: Vec<StringIndex>, ) -> Self
The list of background colors that are blended with colors of overlapping elements.
Sourcepub fn textColorOpacities(self, textColorOpacities: Vec<f64>) -> Self
pub fn textColorOpacities(self, textColorOpacities: Vec<f64>) -> Self
The list of computed text opacities.
pub fn build(self) -> LayoutTreeSnapshot