pub struct NodeTreeSnapshot {Show 17 fields
pub parentIndex: Option<Vec<i64>>,
pub nodeType: Option<Vec<i64>>,
pub shadowRootType: Option<RareStringData>,
pub nodeName: Option<Vec<StringIndex>>,
pub nodeValue: Option<Vec<StringIndex>>,
pub backendNodeId: Option<Vec<BackendNodeId>>,
pub attributes: Option<Vec<ArrayOfStrings>>,
pub textValue: Option<RareStringData>,
pub inputValue: Option<RareStringData>,
pub inputChecked: Option<RareBooleanData>,
pub optionSelected: Option<RareBooleanData>,
pub contentDocumentIndex: Option<RareIntegerData>,
pub pseudoType: Option<RareStringData>,
pub pseudoIdentifier: Option<RareStringData>,
pub isClickable: Option<RareBooleanData>,
pub currentSourceURL: Option<RareStringData>,
pub originURL: Option<RareStringData>,
}Expand description
Table containing nodes.
Fields
parentIndex: Option<Vec<i64>>Parent node index.
nodeType: Option<Vec<i64>>‘Node’’s nodeType.
shadowRootType: Option<RareStringData>Type of the shadow root the ‘Node’ is in. String values are equal to the ‘ShadowRootType’ enum.
nodeName: Option<Vec<StringIndex>>‘Node’’s nodeName.
nodeValue: Option<Vec<StringIndex>>‘Node’’s nodeValue.
backendNodeId: Option<Vec<BackendNodeId>>‘Node’’s id, corresponds to DOM.Node.backendNodeId.
attributes: Option<Vec<ArrayOfStrings>>Attributes of an ‘Element’ node. Flatten name, value pairs.
textValue: Option<RareStringData>Only set for textarea elements, contains the text value.
inputValue: Option<RareStringData>Only set for input elements, contains the input’s associated text value.
inputChecked: Option<RareBooleanData>Only set for radio and checkbox input elements, indicates if the element has been checked
optionSelected: Option<RareBooleanData>Only set for option elements, indicates if the element has been selected
contentDocumentIndex: Option<RareIntegerData>The index of the document in the list of the snapshot documents.
pseudoType: Option<RareStringData>Type of a pseudo element node.
pseudoIdentifier: Option<RareStringData>Pseudo element identifier for this node. Only present if there is a valid pseudoType.
isClickable: Option<RareBooleanData>Whether this DOM node responds to mouse clicks. This includes nodes that have had click event listeners attached via JavaScript as well as anchor tags that naturally navigate when clicked.
currentSourceURL: Option<RareStringData>The selected url for nodes with a srcset attribute.
originURL: Option<RareStringData>The url of the script (if any) that generates this node.