pub struct NodeTreeSnapshotBuilder { /* private fields */ }Implementations
Sourceimpl NodeTreeSnapshotBuilder
impl NodeTreeSnapshotBuilder
Sourcepub fn parent_index(self, parent_index: Vec<i64>) -> Self
pub fn parent_index(self, parent_index: Vec<i64>) -> Self
Parent node index.
Sourcepub fn shadow_root_type(self, shadow_root_type: RareStringData) -> Self
pub fn shadow_root_type(self, shadow_root_type: RareStringData) -> Self
Type of the shadow root the ‘Node’ is in. String values are equal to the ‘ShadowRootType’ enum.
Sourcepub fn node_name(self, node_name: Vec<StringIndex>) -> Self
pub fn node_name(self, node_name: Vec<StringIndex>) -> Self
‘Node’’s nodeName.
Sourcepub fn node_value(self, node_value: Vec<StringIndex>) -> Self
pub fn node_value(self, node_value: Vec<StringIndex>) -> Self
‘Node’’s nodeValue.
Sourcepub fn backend_node_id(self, backend_node_id: Vec<BackendNodeId>) -> Self
pub fn backend_node_id(self, backend_node_id: Vec<BackendNodeId>) -> Self
‘Node’’s id, corresponds to DOM.Node.backendNodeId.
Sourcepub fn attributes(self, attributes: Vec<ArrayOfStrings>) -> Self
pub fn attributes(self, attributes: Vec<ArrayOfStrings>) -> Self
Attributes of an ‘Element’ node. Flatten name, value pairs.
Sourcepub fn text_value(self, text_value: RareStringData) -> Self
pub fn text_value(self, text_value: RareStringData) -> Self
Only set for textarea elements, contains the text value.
Sourcepub fn input_value(self, input_value: RareStringData) -> Self
pub fn input_value(self, input_value: RareStringData) -> Self
Only set for input elements, contains the input’s associated text value.
Sourcepub fn input_checked(self, input_checked: RareBooleanData) -> Self
pub fn input_checked(self, input_checked: RareBooleanData) -> Self
Only set for radio and checkbox input elements, indicates if the element has been checked
Sourcepub fn option_selected(self, option_selected: RareBooleanData) -> Self
pub fn option_selected(self, option_selected: RareBooleanData) -> Self
Only set for option elements, indicates if the element has been selected
Sourcepub fn content_document_index(
self,
content_document_index: RareIntegerData,
) -> Self
pub fn content_document_index( self, content_document_index: RareIntegerData, ) -> Self
The index of the document in the list of the snapshot documents.
Sourcepub fn pseudo_type(self, pseudo_type: RareStringData) -> Self
pub fn pseudo_type(self, pseudo_type: RareStringData) -> Self
Type of a pseudo element node.
Sourcepub fn pseudo_identifier(self, pseudo_identifier: RareStringData) -> Self
pub fn pseudo_identifier(self, pseudo_identifier: RareStringData) -> Self
Pseudo element identifier for this node. Only present if there is a valid pseudoType.
Sourcepub fn is_clickable(self, is_clickable: RareBooleanData) -> Self
pub fn is_clickable(self, is_clickable: RareBooleanData) -> Self
Whether this DOM node responds to mouse clicks. This includes nodes that have had click event listeners attached via JavaScript as well as anchor tags that naturally navigate when clicked.
Sourcepub fn current_source_url(self, current_source_url: RareStringData) -> Self
pub fn current_source_url(self, current_source_url: RareStringData) -> Self
The selected url for nodes with a srcset attribute.
Sourcepub fn origin_url(self, origin_url: RareStringData) -> Self
pub fn origin_url(self, origin_url: RareStringData) -> Self
The url of the script (if any) that generates this node.