NodeTreeSnapshotBuilder

Struct NodeTreeSnapshotBuilder 

pub struct NodeTreeSnapshotBuilder { /* private fields */ }

Implementations

Source

impl NodeTreeSnapshotBuilder

pub fn parentIndex(self, parentIndex: Vec<i64>) -> Self

Parent node index.

pub fn nodeType(self, nodeType: Vec<i64>) -> Self

‘Node’’s nodeType.

pub fn shadowRootType(self, shadowRootType: RareStringData) -> Self

Type of the shadow root the ‘Node’ is in. String values are equal to the ‘ShadowRootType’ enum.

pub fn nodeName(self, nodeName: Vec<StringIndex>) -> Self

‘Node’’s nodeName.

pub fn nodeValue(self, nodeValue: Vec<StringIndex>) -> Self

‘Node’’s nodeValue.

pub fn backendNodeId(self, backendNodeId: Vec<BackendNodeId>) -> Self

‘Node’’s id, corresponds to DOM.Node.backendNodeId.

pub fn attributes(self, attributes: Vec<ArrayOfStrings>) -> Self

Attributes of an ‘Element’ node. Flatten name, value pairs.

pub fn textValue(self, textValue: RareStringData) -> Self

Only set for textarea elements, contains the text value.

pub fn inputValue(self, inputValue: RareStringData) -> Self

Only set for input elements, contains the input’s associated text value.

pub fn inputChecked(self, inputChecked: RareBooleanData) -> Self

Only set for radio and checkbox input elements, indicates if the element has been checked

pub fn optionSelected(self, optionSelected: RareBooleanData) -> Self

Only set for option elements, indicates if the element has been selected

pub fn contentDocumentIndex(self, contentDocumentIndex: RareIntegerData) -> Self

The index of the document in the list of the snapshot documents.

pub fn pseudoType(self, pseudoType: RareStringData) -> Self

Type of a pseudo element node.

pub fn pseudoIdentifier(self, pseudoIdentifier: RareStringData) -> Self

Pseudo element identifier for this node. Only present if there is a valid pseudoType.

pub fn isClickable(self, isClickable: RareBooleanData) -> Self

Whether this DOM node responds to mouse clicks. This includes nodes that have had click event listeners attached via JavaScript as well as anchor tags that naturally navigate when clicked.

pub fn currentSourceURL(self, currentSourceURL: RareStringData) -> Self

The selected url for nodes with a srcset attribute.

pub fn originURL(self, originURL: RareStringData) -> Self

The url of the script (if any) that generates this node.

pub fn build(self) -> NodeTreeSnapshot