pub struct NodeTreeSnapshotBuilder { /* private fields */ }Implementations
Sourceimpl NodeTreeSnapshotBuilder
impl NodeTreeSnapshotBuilder
Sourcepub fn parentIndex(self, parentIndex: Vec<i64>) -> Self
pub fn parentIndex(self, parentIndex: Vec<i64>) -> Self
Parent node index.
Sourcepub fn shadowRootType(self, shadowRootType: RareStringData) -> Self
pub fn shadowRootType(self, shadowRootType: RareStringData) -> Self
Type of the shadow root the ‘Node’ is in. String values are equal to the ‘ShadowRootType’ enum.
Sourcepub fn nodeName(self, nodeName: Vec<StringIndex>) -> Self
pub fn nodeName(self, nodeName: Vec<StringIndex>) -> Self
‘Node’’s nodeName.
Sourcepub fn nodeValue(self, nodeValue: Vec<StringIndex>) -> Self
pub fn nodeValue(self, nodeValue: Vec<StringIndex>) -> Self
‘Node’’s nodeValue.
Sourcepub fn backendNodeId(self, backendNodeId: Vec<BackendNodeId>) -> Self
pub fn backendNodeId(self, backendNodeId: Vec<BackendNodeId>) -> Self
‘Node’’s id, corresponds to DOM.Node.backendNodeId.
Sourcepub fn attributes(self, attributes: Vec<ArrayOfStrings>) -> Self
pub fn attributes(self, attributes: Vec<ArrayOfStrings>) -> Self
Attributes of an ‘Element’ node. Flatten name, value pairs.
Sourcepub fn textValue(self, textValue: RareStringData) -> Self
pub fn textValue(self, textValue: RareStringData) -> Self
Only set for textarea elements, contains the text value.
Sourcepub fn inputValue(self, inputValue: RareStringData) -> Self
pub fn inputValue(self, inputValue: RareStringData) -> Self
Only set for input elements, contains the input’s associated text value.
Sourcepub fn inputChecked(self, inputChecked: RareBooleanData) -> Self
pub fn inputChecked(self, inputChecked: RareBooleanData) -> Self
Only set for radio and checkbox input elements, indicates if the element has been checked
Sourcepub fn optionSelected(self, optionSelected: RareBooleanData) -> Self
pub fn optionSelected(self, optionSelected: RareBooleanData) -> Self
Only set for option elements, indicates if the element has been selected
Sourcepub fn contentDocumentIndex(self, contentDocumentIndex: RareIntegerData) -> Self
pub fn contentDocumentIndex(self, contentDocumentIndex: RareIntegerData) -> Self
The index of the document in the list of the snapshot documents.
Sourcepub fn pseudoType(self, pseudoType: RareStringData) -> Self
pub fn pseudoType(self, pseudoType: RareStringData) -> Self
Type of a pseudo element node.
Sourcepub fn pseudoIdentifier(self, pseudoIdentifier: RareStringData) -> Self
pub fn pseudoIdentifier(self, pseudoIdentifier: RareStringData) -> Self
Pseudo element identifier for this node. Only present if there is a valid pseudoType.
Sourcepub fn isClickable(self, isClickable: RareBooleanData) -> Self
pub fn isClickable(self, isClickable: RareBooleanData) -> Self
Whether this DOM node responds to mouse clicks. This includes nodes that have had click event listeners attached via JavaScript as well as anchor tags that naturally navigate when clicked.
Sourcepub fn currentSourceURL(self, currentSourceURL: RareStringData) -> Self
pub fn currentSourceURL(self, currentSourceURL: RareStringData) -> Self
The selected url for nodes with a srcset attribute.
Sourcepub fn originURL(self, originURL: RareStringData) -> Self
pub fn originURL(self, originURL: RareStringData) -> Self
The url of the script (if any) that generates this node.