pub struct ScreenInfo {Show 16 fields
pub left: i64,
pub top: i64,
pub width: u64,
pub height: i64,
pub availLeft: i64,
pub availTop: i64,
pub availWidth: u64,
pub availHeight: i64,
pub devicePixelRatio: f64,
pub orientation: ScreenOrientation,
pub colorDepth: i64,
pub isExtended: bool,
pub isInternal: bool,
pub isPrimary: bool,
pub label: String,
pub id: ScreenId,
}Expand description
Screen information similar to the one returned by window.getScreenDetails() method, see https://w3c.github.io/window-management/#screendetailed.
Fields
left: i64Offset of the left edge of the screen.
top: i64Offset of the top edge of the screen.
width: u64Width of the screen.
height: i64Height of the screen.
availLeft: i64Offset of the left edge of the available screen area.
availTop: i64Offset of the top edge of the available screen area.
availWidth: u64Width of the available screen area.
availHeight: i64Height of the available screen area.
devicePixelRatio: f64Specifies the screen’s device pixel ratio.
orientation: ScreenOrientationSpecifies the screen’s orientation.
colorDepth: i64Specifies the screen’s color depth in bits.
isExtended: boolIndicates whether the device has multiple screens.
isInternal: boolIndicates whether the screen is internal to the device or external, attached to the device.
isPrimary: boolIndicates whether the screen is set as the the operating system primary screen.
label: StringSpecifies the descriptive label for the screen.
id: ScreenIdSpecifies the unique identifier of the screen.