pub struct SetDefaultBackgroundColorOverrideParams {
pub color: Option<RGBA>,
}Expand description
Sets or clears an override of the default background color of the frame. This override is used if the content does not specify one.
Fields
color: Option<RGBA>RGBA of the default background color. If not specified, any existing override will be cleared.