SetDeviceMetricsOverrideParams

Struct SetDeviceMetricsOverrideParams 

pub struct SetDeviceMetricsOverrideParams {
Show 16 fields pub width: u64, pub height: i64, pub deviceScaleFactor: f64, pub mobile: bool, pub scale: Option<f64>, pub screenWidth: Option<u64>, pub screenHeight: Option<i64>, pub positionX: Option<i64>, pub positionY: Option<i64>, pub dontSetVisibleSize: Option<bool>, pub screenOrientation: Option<ScreenOrientation>, pub viewport: Option<Viewport>, pub displayFeature: Option<DisplayFeature>, pub devicePosture: Option<DevicePosture>, pub scrollbarType: Option<String>, pub screenOrientationLockEmulation: Option<bool>,
}
Overrides the values of device screen dimensions (window.screen.width, window.screen.height, window.innerWidth, window.innerHeight, and “device-width”/“device-height”-related CSS media query results).

Fields

width: u64

Overriding width value in pixels (minimum 0, maximum 10000000). 0 disables the override.

height: i64

Overriding height value in pixels (minimum 0, maximum 10000000). 0 disables the override.

deviceScaleFactor: f64

Overriding device scale factor value. 0 disables the override.

mobile: bool

Whether to emulate mobile device. This includes viewport meta tag, overlay scrollbars, text autosizing and more.

scale: Option<f64>

Scale to apply to resulting view image.

screenWidth: Option<u64>

Overriding screen width value in pixels (minimum 0, maximum 10000000).

screenHeight: Option<i64>

Overriding screen height value in pixels (minimum 0, maximum 10000000).

positionX: Option<i64>

Overriding view X position on screen in pixels (minimum 0, maximum 10000000).

positionY: Option<i64>

Overriding view Y position on screen in pixels (minimum 0, maximum 10000000).

dontSetVisibleSize: Option<bool>

Do not set visible view size, rely upon explicit setVisibleSize call.

screenOrientation: Option<ScreenOrientation>

Screen orientation override.

viewport: Option<Viewport>

If set, the visible area of the page will be overridden to this viewport. This viewport change is not observed by the page, e.g. viewport-relative elements do not change positions.

displayFeature: Option<DisplayFeature>

If set, the display feature of a multi-segment screen. If not set, multi-segment support is turned-off. Deprecated, use Emulation.setDisplayFeaturesOverride.

devicePosture: Option<DevicePosture>

If set, the posture of a foldable device. If not set the posture is set to continuous. Deprecated, use Emulation.setDevicePostureOverride.

scrollbarType: Option<String>

Scrollbar type. Default: ‘default’.

screenOrientationLockEmulation: Option<bool>

If set to true, enables screen orientation lock emulation, which intercepts screen.orientation.lock() calls from the page and reports orientation changes via screenOrientationLockChanged events. This is useful for emulating mobile device orientation lock behavior in responsive design mode.

Implementations

Source

impl SetDeviceMetricsOverrideParams

pub const METHOD: &'static str = "Emulation.setDeviceMetricsOverride"