SetDeviceMetricsOverrideParamsBuilder

Struct SetDeviceMetricsOverrideParamsBuilder 

pub struct SetDeviceMetricsOverrideParamsBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> SetDeviceMetricsOverrideParamsBuilder<'a>

pub fn scale(self, scale: f64) -> Self

Scale to apply to resulting view image.

pub fn screenWidth(self, screenWidth: u64) -> Self

Overriding screen width value in pixels (minimum 0, maximum 10000000).

pub fn screenHeight(self, screenHeight: i64) -> Self

Overriding screen height value in pixels (minimum 0, maximum 10000000).

pub fn positionX(self, positionX: i64) -> Self

Overriding view X position on screen in pixels (minimum 0, maximum 10000000).

pub fn positionY(self, positionY: i64) -> Self

Overriding view Y position on screen in pixels (minimum 0, maximum 10000000).

pub fn dontSetVisibleSize(self, dontSetVisibleSize: bool) -> Self

Do not set visible view size, rely upon explicit setVisibleSize call.

pub fn screenOrientation(self, screenOrientation: ScreenOrientation<'a>) -> Self

Screen orientation override.

pub fn viewport(self, viewport: Viewport) -> Self

If set, the visible area of the page will be overridden to this viewport. This viewport change is not observed by the page, e.g. viewport-relative elements do not change positions.

pub fn displayFeature(self, displayFeature: DisplayFeature<'a>) -> Self

If set, the display feature of a multi-segment screen. If not set, multi-segment support is turned-off. Deprecated, use Emulation.setDisplayFeaturesOverride.

pub fn devicePosture(self, devicePosture: DevicePosture<'a>) -> Self

If set, the posture of a foldable device. If not set the posture is set to continuous. Deprecated, use Emulation.setDevicePostureOverride.

pub fn scrollbarType(self, scrollbarType: impl Into<Cow<'a, str>>) -> Self

Scrollbar type. Default: ‘default’.

pub fn screenOrientationLockEmulation( self, screenOrientationLockEmulation: bool, ) -> Self

If set to true, enables screen orientation lock emulation, which intercepts screen.orientation.lock() calls from the page and reports orientation changes via screenOrientationLockChanged events. This is useful for emulating mobile device orientation lock behavior in responsive design mode.

pub fn build(self) -> SetDeviceMetricsOverrideParams<'a>