pub struct UpdateScreenParams<'a> { /* private fields */ }Expand description
Updates specified screen parameters. Only supported in headless mode.
Implementations
Sourceimpl<'a> UpdateScreenParams<'a>
impl<'a> UpdateScreenParams<'a>
Sourcepub fn builder(
screen_id: impl Into<ScreenId<'a>>,
) -> UpdateScreenParamsBuilder<'a>
pub fn builder( screen_id: impl Into<ScreenId<'a>>, ) -> UpdateScreenParamsBuilder<'a>
Creates a builder for this type with the required parameters:
screen_id: Target screen identifier.
Sourcepub fn work_area_insets(&self) -> Option<&WorkAreaInsets>
pub fn work_area_insets(&self) -> Option<&WorkAreaInsets>
Specifies the screen’s work area.
Sourcepub fn device_pixel_ratio(&self) -> Option<f64>
pub fn device_pixel_ratio(&self) -> Option<f64>
Specifies the screen’s device pixel ratio.
Sourcepub fn rotation(&self) -> Option<i64>
pub fn rotation(&self) -> Option<i64>
Specifies the screen’s rotation angle. Available values are 0, 90, 180 and 270.
Sourcepub fn color_depth(&self) -> Option<i64>
pub fn color_depth(&self) -> Option<i64>
Specifies the screen’s color depth in bits.
Sourcepub fn is_internal(&self) -> Option<bool>
pub fn is_internal(&self) -> Option<bool>
Indicates whether the screen is internal to the device or external, attached to the device. Default is false.