Defines commands and events for browser extensions.
Structs
- Clear
Storage Items Params - Clears extension storage in the given ‘storageArea’.
- Extension
Info - Detailed information about an extension.
- GetExtensions
Params - GetExtensions
Returns - Gets a list of all unpacked extensions. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging flag is set.
- GetStorage
Items Params - Gets data from extension storage in the given ‘storageArea’. If ‘keys’ is specified, these are used to filter the result.
- GetStorage
Items Returns - Gets data from extension storage in the given ‘storageArea’. If ‘keys’ is specified, these are used to filter the result.
- Load
Unpacked Params - Installs an unpacked extension from the filesystem similar to –load-extension CLI flags. Returns extension ID once the extension has been installed. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging flag is set.
- Load
Unpacked Returns - Installs an unpacked extension from the filesystem similar to –load-extension CLI flags. Returns extension ID once the extension has been installed. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging flag is set.
- Remove
Storage Items Params - Removes ‘keys’ from extension storage in the given ‘storageArea’.
- SetStorage
Items Params - Sets ‘values’ in extension storage in the given ‘storageArea’. The provided ‘values’ will be merged with existing values in the storage area.
- Trigger
Action Params - Runs an extension default action. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging flag is set.
- Uninstall
Params - Uninstalls an unpacked extension (others not supported) from the profile. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging.
Enums
- Storage
Area - Storage areas.