Module extensions

Module extensions 

Defines commands and events for browser extensions.

Structs

ClearStorageItemsParams
Clears extension storage in the given ‘storageArea’.
ExtensionInfo
Detailed information about an extension.
GetExtensionsReturns
Gets a list of all unpacked extensions. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging flag is set.
GetStorageItemsParams
Gets data from extension storage in the given ‘storageArea’. If ‘keys’ is specified, these are used to filter the result.
GetStorageItemsReturns
Gets data from extension storage in the given ‘storageArea’. If ‘keys’ is specified, these are used to filter the result.
LoadUnpackedParams
Installs an unpacked extension from the filesystem similar to –load-extension CLI flags. Returns extension ID once the extension has been installed. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging flag is set.
LoadUnpackedReturns
Installs an unpacked extension from the filesystem similar to –load-extension CLI flags. Returns extension ID once the extension has been installed. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging flag is set.
RemoveStorageItemsParams
Removes ‘keys’ from extension storage in the given ‘storageArea’.
SetStorageItemsParams
Sets ‘values’ in extension storage in the given ‘storageArea’. The provided ‘values’ will be merged with existing values in the storage area.
TriggerActionParams
Runs an extension default action. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging flag is set.
UninstallParams
Uninstalls an unpacked extension (others not supported) from the profile. Available if the client is connected using the –remote-debugging-pipe flag and the –enable-unsafe-extension-debugging.

Enums

StorageArea
Storage areas.