pub struct GetStorageItemsParams {
pub id: String,
pub storageArea: StorageArea,
pub keys: Option<Vec<String>>,
}Expand description
Gets data from extension storage in the given ‘storageArea’. If ‘keys’ is specified, these are used to filter the result.
Fields
id: StringID of extension.
storageArea: StorageAreaStorageArea to retrieve data from.
keys: Option<Vec<String>>Keys to retrieve.
Implementations