Module fetch

Module fetch 

A domain for letting clients substitute browser’s network layer with client code.

Structs

AuthChallenge
Authorization challenge for HTTP status code 401 or 407.
AuthChallengeBuilder
AuthChallengeResponse
Response to an AuthChallenge.
AuthChallengeResponseBuilder
ContinueRequestParams
Continues the request, optionally modifying some of its parameters.
ContinueRequestParamsBuilder
ContinueResponseParams
Continues loading of the paused response, optionally modifying the response headers. If either responseCode or headers are modified, all of them must be present.
ContinueResponseParamsBuilder
ContinueWithAuthParams
Continues a request supplying authChallengeResponse following authRequired event.
ContinueWithAuthParamsBuilder
DisableParams
EnableParams
Enables issuing of requestPaused events. A request will be paused until client calls one of failRequest, fulfillRequest or continueRequest/continueWithAuth.
EnableParamsBuilder
FailRequestParams
Causes the request to fail with specified reason.
FailRequestParamsBuilder
FulfillRequestParams
Provides response to the request.
FulfillRequestParamsBuilder
GetResponseBodyParams
Causes the body of the response to be received from the server and returned as a single string. May only be issued for a request that is paused in the Response stage and is mutually exclusive with takeResponseBodyForInterceptionAsStream. Calling other methods that affect the request or disabling fetch domain before body is received results in an undefined behavior. Note that the response body is not available for redirects. Requests paused in the redirect received state may be differentiated by ‘responseCode’ and presence of ‘location’ response header, see comments to ‘requestPaused’ for details.
GetResponseBodyParamsBuilder
GetResponseBodyReturns
Causes the body of the response to be received from the server and returned as a single string. May only be issued for a request that is paused in the Response stage and is mutually exclusive with takeResponseBodyForInterceptionAsStream. Calling other methods that affect the request or disabling fetch domain before body is received results in an undefined behavior. Note that the response body is not available for redirects. Requests paused in the redirect received state may be differentiated by ‘responseCode’ and presence of ‘location’ response header, see comments to ‘requestPaused’ for details.
GetResponseBodyReturnsBuilder
HeaderEntry
Response HTTP header entry
HeaderEntryBuilder
RequestPattern
RequestPatternBuilder
TakeResponseBodyAsStreamParams
Returns a handle to the stream representing the response body. The request must be paused in the HeadersReceived stage. Note that after this command the request can’t be continued as is – client either needs to cancel it or to provide the response body. The stream only supports sequential read, IO.read will fail if the position is specified. This method is mutually exclusive with getResponseBody. Calling other methods that affect the request or disabling fetch domain before body is received results in an undefined behavior.
TakeResponseBodyAsStreamParamsBuilder
TakeResponseBodyAsStreamReturns
Returns a handle to the stream representing the response body. The request must be paused in the HeadersReceived stage. Note that after this command the request can’t be continued as is – client either needs to cancel it or to provide the response body. The stream only supports sequential read, IO.read will fail if the position is specified. This method is mutually exclusive with getResponseBody. Calling other methods that affect the request or disabling fetch domain before body is received results in an undefined behavior.
TakeResponseBodyAsStreamReturnsBuilder

Enums

RequestStage
Stages of the request to handle. Request will intercept before the request is sent. Response will intercept after the response is received (but before response body is received).

Type Aliases

RequestId
Unique request identifier. Note that this does not identify individual HTTP requests that are part of a network request.