pub struct ContinueResponseParams<'a> { /* private fields */ }Expand description
Continues loading of the paused response, optionally modifying the response headers. If either responseCode or headers are modified, all of them must be present.
Implementations
Sourceimpl<'a> ContinueResponseParams<'a>
impl<'a> ContinueResponseParams<'a>
pub fn builder(requestId: RequestId<'a>) -> ContinueResponseParamsBuilder<'a>
pub fn requestId(&self) -> &RequestId<'a>
pub fn responseCode(&self) -> Option<i64>
pub fn responsePhrase(&self) -> Option<&str>
pub fn responseHeaders(&self) -> Option<&[HeaderEntry<'a>]>
pub fn binaryResponseHeaders(&self) -> Option<&str>