FulfillRequestParams

Struct FulfillRequestParams 

pub struct FulfillRequestParams<'a> { /* private fields */ }
Provides response to the request.

Implementations

Source

impl<'a> FulfillRequestParams<'a>

pub fn builder( request_id: impl Into<RequestId<'a>>, response_code: i64, ) -> FulfillRequestParamsBuilder<'a>

Creates a builder for this type with the required parameters:

  • request_id: An id the client received in requestPaused event.
  • response_code: An HTTP response code.
pub fn request_id(&self) -> &RequestId<'a>

An id the client received in requestPaused event.

pub fn response_code(&self) -> i64

An HTTP response code.

pub fn response_headers(&self) -> Option<&[HeaderEntry<'a>]>

Response headers.

pub fn binary_response_headers(&self) -> Option<&str>

Alternative way of specifying response headers as a \0-separated series of name: value pairs. Prefer the above method unless you need to represent some non-UTF8 values that can’t be transmitted over the protocol as text. (Encoded as a base64 string when passed over JSON)

pub fn body(&self) -> Option<&str>

A response body. If absent, original response body will be used if the request is intercepted at the response stage and empty body will be used if the request is intercepted at the request stage. (Encoded as a base64 string when passed over JSON)

pub fn response_phrase(&self) -> Option<&str>

A textual representation of responseCode. If absent, a standard phrase matching responseCode is used.

Source

impl<'a> FulfillRequestParams<'a>

pub const METHOD: &'static str = "Fetch.fulfillRequest"