pub struct FulfillRequestParams<'a> { /* private fields */ }Expand description
Provides response to the request.
Implementations
Sourceimpl<'a> FulfillRequestParams<'a>
impl<'a> FulfillRequestParams<'a>
Sourcepub fn builder(
request_id: impl Into<RequestId<'a>>,
response_code: i64,
) -> FulfillRequestParamsBuilder<'a>
pub fn builder( request_id: impl Into<RequestId<'a>>, response_code: i64, ) -> FulfillRequestParamsBuilder<'a>
Creates a builder for this type with the required parameters:
request_id: An id the client received in requestPaused event.response_code: An HTTP response code.
Sourcepub fn request_id(&self) -> &RequestId<'a>
pub fn request_id(&self) -> &RequestId<'a>
An id the client received in requestPaused event.
Sourcepub fn response_code(&self) -> i64
pub fn response_code(&self) -> i64
An HTTP response code.
Sourcepub fn response_headers(&self) -> Option<&[HeaderEntry<'a>]>
pub fn response_headers(&self) -> Option<&[HeaderEntry<'a>]>
Response headers.
Sourcepub fn binary_response_headers(&self) -> Option<&str>
pub fn binary_response_headers(&self) -> Option<&str>
Alternative way of specifying response headers as a \0-separated series of name: value pairs. Prefer the above method unless you need to represent some non-UTF8 values that can’t be transmitted over the protocol as text. (Encoded as a base64 string when passed over JSON)
Sourcepub fn body(&self) -> Option<&str>
pub fn body(&self) -> Option<&str>
A response body. If absent, original response body will be used if the request is intercepted at the response stage and empty body will be used if the request is intercepted at the request stage. (Encoded as a base64 string when passed over JSON)
Sourcepub fn response_phrase(&self) -> Option<&str>
pub fn response_phrase(&self) -> Option<&str>
A textual representation of responseCode. If absent, a standard phrase matching responseCode is used.