pub struct FulfillRequestParamsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> FulfillRequestParamsBuilder<'a>
impl<'a> FulfillRequestParamsBuilder<'a>
Sourcepub fn response_headers(self, response_headers: Vec<HeaderEntry<'a>>) -> Self
pub fn response_headers(self, response_headers: Vec<HeaderEntry<'a>>) -> Self
Response headers.
Sourcepub fn binary_response_headers(
self,
binary_response_headers: impl Into<Cow<'a, str>>,
) -> Self
pub fn binary_response_headers( self, binary_response_headers: impl Into<Cow<'a, str>>, ) -> Self
Alternative way of specifying response headers as a \0-separated series of name: value pairs. Prefer the above method unless you need to represent some non-UTF8 values that can’t be transmitted over the protocol as text. (Encoded as a base64 string when passed over JSON)
Sourcepub fn body(self, body: impl Into<Cow<'a, str>>) -> Self
pub fn body(self, body: impl Into<Cow<'a, str>>) -> Self
A response body. If absent, original response body will be used if the request is intercepted at the response stage and empty body will be used if the request is intercepted at the request stage. (Encoded as a base64 string when passed over JSON)
Sourcepub fn response_phrase(self, response_phrase: impl Into<Cow<'a, str>>) -> Self
pub fn response_phrase(self, response_phrase: impl Into<Cow<'a, str>>) -> Self
A textual representation of responseCode. If absent, a standard phrase matching responseCode is used.
pub fn build(self) -> FulfillRequestParams<'a>