pub struct TakeResponseBodyAsStreamParams<'a> { /* private fields */ }Expand description
Returns a handle to the stream representing the response body. The request must be paused in the HeadersReceived stage. Note that after this command the request can’t be continued as is – client either needs to cancel it or to provide the response body. The stream only supports sequential read, IO.read will fail if the position is specified. This method is mutually exclusive with getResponseBody. Calling other methods that affect the request or disabling fetch domain before body is received results in an undefined behavior.
Implementations
Sourceimpl<'a> TakeResponseBodyAsStreamParams<'a>
impl<'a> TakeResponseBodyAsStreamParams<'a>