pub struct BeginFrameParams<'a> { /* private fields */ }Expand description
Sends a BeginFrame to the target and returns when the frame was completed. Optionally captures a screenshot from the resulting frame. Requires that the target was created with enabled BeginFrameControl. Designed for use with –run-all-compositor-stages-before-draw, see also https://goo.gle/chrome-headless-rendering for more background.
Implementations
Sourceimpl<'a> BeginFrameParams<'a>
impl<'a> BeginFrameParams<'a>
Sourcepub fn builder() -> BeginFrameParamsBuilder<'a>
pub fn builder() -> BeginFrameParamsBuilder<'a>
Creates a builder for this type.
Sourcepub fn frame_time_ticks(&self) -> Option<f64>
pub fn frame_time_ticks(&self) -> Option<f64>
Timestamp of this BeginFrame in Renderer TimeTicks (milliseconds of uptime). If not set, the current time will be used.
Sourcepub fn interval(&self) -> Option<f64>
pub fn interval(&self) -> Option<f64>
The interval between BeginFrames that is reported to the compositor, in milliseconds. Defaults to a 60 frames/second interval, i.e. about 16.666 milliseconds.
Sourcepub fn no_display_updates(&self) -> Option<bool>
pub fn no_display_updates(&self) -> Option<bool>
Whether updates should not be committed and drawn onto the display. False by default. If true, only side effects of the BeginFrame will be run, such as layout and animations, but any visual updates may not be visible on the display or in screenshots.
Sourcepub fn screenshot(&self) -> Option<&ScreenshotParams<'a>>
pub fn screenshot(&self) -> Option<&ScreenshotParams<'a>>
If set, a screenshot of the frame will be captured and returned in the response. Otherwise, no screenshot will be captured. Note that capturing a screenshot can fail, for example, during renderer initialization. In such a case, no screenshot data will be returned.