pub struct BeginFrameReturns<'a> { /* private fields */ }Expand description
Sends a BeginFrame to the target and returns when the frame was completed. Optionally captures a screenshot from the resulting frame. Requires that the target was created with enabled BeginFrameControl. Designed for use with –run-all-compositor-stages-before-draw, see also https://goo.gle/chrome-headless-rendering for more background.
Implementations
Sourceimpl<'a> BeginFrameReturns<'a>
impl<'a> BeginFrameReturns<'a>