pub struct RequestDataParams<'a> { /* private fields */ }Expand description
Requests data from object store or index.
Implementations
Sourceimpl<'a> RequestDataParams<'a>
impl<'a> RequestDataParams<'a>
Sourcepub fn builder(
database_name: impl Into<Cow<'a, str>>,
object_store_name: impl Into<Cow<'a, str>>,
skip_count: u64,
page_size: u64,
) -> RequestDataParamsBuilder<'a>
pub fn builder( database_name: impl Into<Cow<'a, str>>, object_store_name: impl Into<Cow<'a, str>>, skip_count: u64, page_size: u64, ) -> RequestDataParamsBuilder<'a>
Creates a builder for this type with the required parameters:
database_name: Database name.object_store_name: Object store name.skip_count: Number of records to skip.page_size: Number of records to fetch.
Sourcepub fn security_origin(&self) -> Option<&str>
pub fn security_origin(&self) -> Option<&str>
At least and at most one of securityOrigin, storageKey, or storageBucket must be specified. Security origin.
Sourcepub fn storage_key(&self) -> Option<&str>
pub fn storage_key(&self) -> Option<&str>
Storage key.
Sourcepub fn storage_bucket(&self) -> Option<&StorageBucket<'a>>
pub fn storage_bucket(&self) -> Option<&StorageBucket<'a>>
Storage bucket. If not specified, it uses the default bucket.
Sourcepub fn database_name(&self) -> &str
pub fn database_name(&self) -> &str
Database name.
Sourcepub fn object_store_name(&self) -> &str
pub fn object_store_name(&self) -> &str
Object store name.
Sourcepub fn index_name(&self) -> Option<&str>
pub fn index_name(&self) -> Option<&str>
Index name. If not specified, it performs an object store data request.
Sourcepub fn skip_count(&self) -> u64
pub fn skip_count(&self) -> u64
Number of records to skip.