Structs
- Cancel
Dragging Params - Dispatch
Drag Event Params - Dispatches a drag event into the page.
- Dispatch
KeyEvent Params - Dispatches a key event to the page.
- Dispatch
Mouse Event Params - Dispatches a mouse event to the page.
- Dispatch
Touch Event Params - Dispatches a touch event to the page.
- Drag
Data - Drag
Data Item - Emulate
Touch From Mouse Event Params - Emulates touch event from the mouse event parameters.
- ImeSet
Composition Params - This method sets the current candidate text for IME. Use imeCommitComposition to commit the final text. Use imeSetComposition with empty string as text to cancel composition.
- Insert
Text Params - This method emulates inserting text that doesn’t come from a key press, for example an emoji keyboard or an IME.
- SetIgnore
Input Events Params - Ignores input events (useful while auditing page).
- SetIntercept
Drags Params - Prevents default drag and drop behavior and instead emits ‘Input.dragIntercepted’ events. Drag and drop behavior can be directly controlled via ‘Input.dispatchDragEvent’.
- Synthesize
Pinch Gesture Params - Synthesizes a pinch gesture over a time period by issuing appropriate touch events.
- Synthesize
Scroll Gesture Params - Synthesizes a scroll gesture over a time period by issuing appropriate touch events.
- Synthesize
TapGesture Params - Synthesizes a tap gesture over a time period by issuing appropriate touch events.
- Touch
Point
Enums
Type Aliases
- Time
Since Epoch - UTC time in seconds, counted from January 1, 1970.