Module input

Module input 

Structs

CancelDraggingParams
DispatchDragEventParams
Dispatches a drag event into the page.
DispatchDragEventParamsBuilder
DispatchKeyEventParams
Dispatches a key event to the page.
DispatchKeyEventParamsBuilder
DispatchMouseEventParams
Dispatches a mouse event to the page.
DispatchMouseEventParamsBuilder
DispatchTouchEventParams
Dispatches a touch event to the page.
DispatchTouchEventParamsBuilder
DragData
DragDataBuilder
DragDataItem
DragDataItemBuilder
EmulateTouchFromMouseEventParams
Emulates touch event from the mouse event parameters.
EmulateTouchFromMouseEventParamsBuilder
ImeSetCompositionParams
This method sets the current candidate text for IME. Use imeCommitComposition to commit the final text. Use imeSetComposition with empty string as text to cancel composition.
ImeSetCompositionParamsBuilder
InsertTextParams
This method emulates inserting text that doesn’t come from a key press, for example an emoji keyboard or an IME.
InsertTextParamsBuilder
SetIgnoreInputEventsParams
Ignores input events (useful while auditing page).
SetIgnoreInputEventsParamsBuilder
SetInterceptDragsParams
Prevents default drag and drop behavior and instead emits ‘Input.dragIntercepted’ events. Drag and drop behavior can be directly controlled via ‘Input.dispatchDragEvent’.
SetInterceptDragsParamsBuilder
SynthesizePinchGestureParams
Synthesizes a pinch gesture over a time period by issuing appropriate touch events.
SynthesizePinchGestureParamsBuilder
SynthesizeScrollGestureParams
Synthesizes a scroll gesture over a time period by issuing appropriate touch events.
SynthesizeScrollGestureParamsBuilder
SynthesizeTapGestureParams
Synthesizes a tap gesture over a time period by issuing appropriate touch events.
SynthesizeTapGestureParamsBuilder
TouchPoint
TouchPointBuilder

Enums

GestureSourceType
MouseButton

Type Aliases

TimeSinceEpoch
UTC time in seconds, counted from January 1, 1970.