DispatchMouseEventParamsBuilder

Struct DispatchMouseEventParamsBuilder 

pub struct DispatchMouseEventParamsBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> DispatchMouseEventParamsBuilder<'a>

pub fn modifiers(self, modifiers: i64) -> Self

Bit field representing pressed modifier keys. Alt=1, Ctrl=2, Meta/Command=4, Shift=8 (default: 0).

pub fn timestamp(self, timestamp: TimeSinceEpoch) -> Self

Time at which the event occurred.

pub fn button(self, button: MouseButton) -> Self

Mouse button (default: “none”).

pub fn buttons(self, buttons: i64) -> Self

A number indicating which buttons are pressed on the mouse when a mouse event is triggered. Left=1, Right=2, Middle=4, Back=8, Forward=16, None=0.

pub fn clickCount(self, clickCount: u64) -> Self

Number of times the mouse button was clicked (default: 0).

pub fn force(self, force: f64) -> Self

The normalized pressure, which has a range of [0,1] (default: 0).

pub fn tangentialPressure(self, tangentialPressure: f64) -> Self

The normalized tangential pressure, which has a range of [-1,1] (default: 0).

pub fn tiltX(self, tiltX: f64) -> Self

The plane angle between the Y-Z plane and the plane containing both the stylus axis and the Y axis, in degrees of the range [-90,90], a positive tiltX is to the right (default: 0).

pub fn tiltY(self, tiltY: f64) -> Self

The plane angle between the X-Z plane and the plane containing both the stylus axis and the X axis, in degrees of the range [-90,90], a positive tiltY is towards the user (default: 0).

pub fn twist(self, twist: i64) -> Self

The clockwise rotation of a pen stylus around its own major axis, in degrees in the range [0,359] (default: 0).

pub fn deltaX(self, deltaX: f64) -> Self

X delta in CSS pixels for mouse wheel event (default: 0).

pub fn deltaY(self, deltaY: f64) -> Self

Y delta in CSS pixels for mouse wheel event (default: 0).

pub fn pointerType(self, pointerType: impl Into<Cow<'a, str>>) -> Self

Pointer type (default: “mouse”).

pub fn build(self) -> DispatchMouseEventParams<'a>