pub struct SetInterceptDragsParams {
pub enabled: bool,
}Expand description
Prevents default drag and drop behavior and instead emits ‘Input.dragIntercepted’ events. Drag and drop behavior can be directly controlled via ‘Input.dispatchDragEvent’.
Fields
enabled: boolTrait Implementations
Sourceimpl Clone for SetInterceptDragsParams
impl Clone for SetInterceptDragsParams
Sourcefn clone(&self) -> SetInterceptDragsParams
fn clone(&self) -> SetInterceptDragsParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SetInterceptDragsParams
impl Debug for SetInterceptDragsParams
Sourceimpl Default for SetInterceptDragsParams
impl Default for SetInterceptDragsParams
Sourcefn default() -> SetInterceptDragsParams
fn default() -> SetInterceptDragsParams
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SetInterceptDragsParams
impl<'de> Deserialize<'de> for SetInterceptDragsParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more