pub struct SynthesizePinchGestureParams {
pub x: f64,
pub y: f64,
pub scaleFactor: f64,
pub relativeSpeed: Option<i64>,
pub gestureSourceType: Option<GestureSourceType>,
}Expand description
Synthesizes a pinch gesture over a time period by issuing appropriate touch events.
Fields
x: f64X coordinate of the start of the gesture in CSS pixels.
y: f64Y coordinate of the start of the gesture in CSS pixels.
scaleFactor: f64Relative scale factor after zooming (>1.0 zooms in, <1.0 zooms out).
relativeSpeed: Option<i64>Relative pointer speed in pixels per second (default: 800).
gestureSourceType: Option<GestureSourceType>Which type of input events to be generated (default: ‘default’, which queries the platform for the preferred input type).