pub struct SynthesizePinchGestureParamsBuilder { /* private fields */ }Implementations
Sourceimpl SynthesizePinchGestureParamsBuilder
impl SynthesizePinchGestureParamsBuilder
Sourcepub fn relativeSpeed(self, relativeSpeed: i64) -> Self
pub fn relativeSpeed(self, relativeSpeed: i64) -> Self
Relative pointer speed in pixels per second (default: 800).
Sourcepub fn gestureSourceType(self, gestureSourceType: GestureSourceType) -> Self
pub fn gestureSourceType(self, gestureSourceType: GestureSourceType) -> Self
Which type of input events to be generated (default: ‘default’, which queries the platform for the preferred input type).
pub fn build(self) -> SynthesizePinchGestureParams