pub struct SynthesizeScrollGestureParams {
pub x: f64,
pub y: f64,
pub xDistance: Option<f64>,
pub yDistance: Option<f64>,
pub xOverscroll: Option<f64>,
pub yOverscroll: Option<f64>,
pub preventFling: Option<bool>,
pub speed: Option<i64>,
pub gestureSourceType: Option<GestureSourceType>,
pub repeatCount: Option<u64>,
pub repeatDelayMs: Option<i64>,
pub interactionMarkerName: Option<String>,
}Expand description
Synthesizes a scroll gesture over a time period by issuing appropriate touch events.
Fields
x: f64X coordinate of the start of the gesture in CSS pixels.
y: f64Y coordinate of the start of the gesture in CSS pixels.
xDistance: Option<f64>The distance to scroll along the X axis (positive to scroll left).
yDistance: Option<f64>The distance to scroll along the Y axis (positive to scroll up).
xOverscroll: Option<f64>The number of additional pixels to scroll back along the X axis, in addition to the given distance.
yOverscroll: Option<f64>The number of additional pixels to scroll back along the Y axis, in addition to the given distance.
preventFling: Option<bool>Prevent fling (default: true).
speed: Option<i64>Swipe speed in pixels per second (default: 800).
gestureSourceType: Option<GestureSourceType>Which type of input events to be generated (default: ‘default’, which queries the platform for the preferred input type).
repeatCount: Option<u64>The number of times to repeat the gesture (default: 0).
repeatDelayMs: Option<i64>The number of milliseconds delay between each repeat. (default: 250).
interactionMarkerName: Option<String>The name of the interaction markers to generate, if not empty (default: “”).