pub struct SynthesizeScrollGestureParamsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> SynthesizeScrollGestureParamsBuilder<'a>
impl<'a> SynthesizeScrollGestureParamsBuilder<'a>
Sourcepub fn xDistance(self, xDistance: f64) -> Self
pub fn xDistance(self, xDistance: f64) -> Self
The distance to scroll along the X axis (positive to scroll left).
Sourcepub fn yDistance(self, yDistance: f64) -> Self
pub fn yDistance(self, yDistance: f64) -> Self
The distance to scroll along the Y axis (positive to scroll up).
Sourcepub fn xOverscroll(self, xOverscroll: f64) -> Self
pub fn xOverscroll(self, xOverscroll: f64) -> Self
The number of additional pixels to scroll back along the X axis, in addition to the given distance.
Sourcepub fn yOverscroll(self, yOverscroll: f64) -> Self
pub fn yOverscroll(self, yOverscroll: f64) -> Self
The number of additional pixels to scroll back along the Y axis, in addition to the given distance.
Sourcepub fn preventFling(self, preventFling: bool) -> Self
pub fn preventFling(self, preventFling: bool) -> Self
Prevent fling (default: true).
Sourcepub fn gestureSourceType(self, gestureSourceType: GestureSourceType) -> Self
pub fn gestureSourceType(self, gestureSourceType: GestureSourceType) -> Self
Which type of input events to be generated (default: ‘default’, which queries the platform for the preferred input type).
Sourcepub fn repeatCount(self, repeatCount: u64) -> Self
pub fn repeatCount(self, repeatCount: u64) -> Self
The number of times to repeat the gesture (default: 0).
Sourcepub fn repeatDelayMs(self, repeatDelayMs: i64) -> Self
pub fn repeatDelayMs(self, repeatDelayMs: i64) -> Self
The number of milliseconds delay between each repeat. (default: 250).
Sourcepub fn interactionMarkerName(
self,
interactionMarkerName: impl Into<Cow<'a, str>>,
) -> Self
pub fn interactionMarkerName( self, interactionMarkerName: impl Into<Cow<'a, str>>, ) -> Self
The name of the interaction markers to generate, if not empty (default: “”).
pub fn build(self) -> SynthesizeScrollGestureParams<'a>