pub struct SynthesizeTapGestureParams {
pub x: f64,
pub y: f64,
pub duration: Option<i64>,
pub tapCount: Option<u64>,
pub gestureSourceType: Option<GestureSourceType>,
}Expand description
Synthesizes a tap gesture over a time period by issuing appropriate touch events.
Fields
x: f64X coordinate of the start of the gesture in CSS pixels.
y: f64Y coordinate of the start of the gesture in CSS pixels.
duration: Option<i64>Duration between touchdown and touchup events in ms (default: 50).
tapCount: Option<u64>Number of times to perform the tap (e.g. 2 for double tap, default: 1).
gestureSourceType: Option<GestureSourceType>Which type of input events to be generated (default: ‘default’, which queries the platform for the preferred input type).