pub struct TouchPoint {
pub x: f64,
pub y: f64,
pub radiusX: Option<f64>,
pub radiusY: Option<f64>,
pub rotationAngle: Option<f64>,
pub force: Option<f64>,
pub tangentialPressure: Option<f64>,
pub tiltX: Option<f64>,
pub tiltY: Option<f64>,
pub twist: Option<i64>,
pub id: Option<f64>,
}Fields
x: f64X coordinate of the event relative to the main frame’s viewport in CSS pixels.
y: f64Y coordinate of the event relative to the main frame’s viewport in CSS pixels. 0 refers to the top of the viewport and Y increases as it proceeds towards the bottom of the viewport.
radiusX: Option<f64>X radius of the touch area (default: 1.0).
radiusY: Option<f64>Y radius of the touch area (default: 1.0).
rotationAngle: Option<f64>Rotation angle (default: 0.0).
force: Option<f64>Force (default: 1.0).
tangentialPressure: Option<f64>The normalized tangential pressure, which has a range of [-1,1] (default: 0).
tiltX: Option<f64>The plane angle between the Y-Z plane and the plane containing both the stylus axis and the Y axis, in degrees of the range [-90,90], a positive tiltX is to the right (default: 0)
tiltY: Option<f64>The plane angle between the X-Z plane and the plane containing both the stylus axis and the X axis, in degrees of the range [-90,90], a positive tiltY is towards the user (default: 0).
twist: Option<i64>The clockwise rotation of a pen stylus around its own major axis, in degrees in the range [0,359] (default: 0).
id: Option<f64>Identifier used to track touch sources between events, must be unique within an event.