pub struct TouchPointBuilder { /* private fields */ }Implementations
Sourceimpl TouchPointBuilder
impl TouchPointBuilder
Sourcepub fn rotation_angle(self, rotation_angle: f64) -> Self
pub fn rotation_angle(self, rotation_angle: f64) -> Self
Rotation angle (default: 0.0).
Sourcepub fn tangential_pressure(self, tangential_pressure: f64) -> Self
pub fn tangential_pressure(self, tangential_pressure: f64) -> Self
The normalized tangential pressure, which has a range of [-1,1] (default: 0).
Sourcepub fn tilt_x(self, tilt_x: f64) -> Self
pub fn tilt_x(self, tilt_x: f64) -> Self
The plane angle between the Y-Z plane and the plane containing both the stylus axis and the Y axis, in degrees of the range [-90,90], a positive tiltX is to the right (default: 0)
Sourcepub fn tilt_y(self, tilt_y: f64) -> Self
pub fn tilt_y(self, tilt_y: f64) -> Self
The plane angle between the X-Z plane and the plane containing both the stylus axis and the X axis, in degrees of the range [-90,90], a positive tiltY is towards the user (default: 0).
Sourcepub fn twist(self, twist: i64) -> Self
pub fn twist(self, twist: i64) -> Self
The clockwise rotation of a pen stylus around its own major axis, in degrees in the range [0,359] (default: 0).
Sourcepub fn id(self, id: f64) -> Self
pub fn id(self, id: f64) -> Self
Identifier used to track touch sources between events, must be unique within an event.
pub fn build(self) -> TouchPoint