Module io

Module io 

Input/Output operations for streams produced by DevTools.

Structs

CloseParams
Close the stream, discard any temporary backing storage.
ReadParams
Read a chunk of the stream
ReadReturns
Read a chunk of the stream
ResolveBlobParams
Return UUID of Blob object specified by a remote object id.
ResolveBlobReturns
Return UUID of Blob object specified by a remote object id.

Type Aliases

StreamHandle
This is either obtained from another method or specified as ‘blob:<uuid>’ where ‘<uuid>’ is an UUID of a Blob.