Input/Output operations for streams produced by DevTools.
Structs
- Close
Params - Close the stream, discard any temporary backing storage.
- Read
Params - Read a chunk of the stream
- Read
Returns - Read a chunk of the stream
- Resolve
Blob Params - Return UUID of Blob object specified by a remote object id.
- Resolve
Blob Returns - Return UUID of Blob object specified by a remote object id.
Type Aliases
- Stream
Handle - This is either obtained from another method or specified as ‘blob:<uuid>’ where ‘<uuid>’ is an UUID of a Blob.