Module layertree

Module layertree 

Structs

CompositingReasonsParams
Provides the reasons why the given layer was composited.
CompositingReasonsReturns
Provides the reasons why the given layer was composited.
Layer
Information about a compositing layer.
LoadSnapshotParams
Returns the snapshot identifier.
LoadSnapshotReturns
Returns the snapshot identifier.
MakeSnapshotParams
Returns the layer snapshot identifier.
MakeSnapshotReturns
Returns the layer snapshot identifier.
PictureTile
Serialized fragment of layer picture along with its offset within the layer.
ProfileSnapshotParams
ProfileSnapshotReturns
ReleaseSnapshotParams
Releases layer snapshot captured by the back-end.
ReplaySnapshotParams
Replays the layer snapshot and returns the resulting bitmap.
ReplaySnapshotReturns
Replays the layer snapshot and returns the resulting bitmap.
ScrollRect
Rectangle where scrolling happens on the main thread.
SnapshotCommandLogParams
Replays the layer snapshot and returns canvas log.
SnapshotCommandLogReturns
Replays the layer snapshot and returns canvas log.
StickyPositionConstraint
Sticky position constraints.

Type Aliases

LayerId
Unique Layer identifier.
PaintProfile
Array of timings, one per paint step.
SnapshotId
Unique snapshot identifier.