pub struct Layer {Show 16 fields
pub layerId: LayerId,
pub parentLayerId: Option<LayerId>,
pub backendNodeId: Option<BackendNodeId>,
pub offsetX: f64,
pub offsetY: f64,
pub width: f64,
pub height: f64,
pub transform: Option<Vec<f64>>,
pub anchorX: Option<f64>,
pub anchorY: Option<f64>,
pub anchorZ: Option<f64>,
pub paintCount: u64,
pub drawsContent: bool,
pub invisible: Option<bool>,
pub scrollRects: Option<Vec<ScrollRect>>,
pub stickyPositionConstraint: Option<StickyPositionConstraint>,
}Expand description
Information about a compositing layer.
Fields
layerId: LayerIdThe unique id for this layer.
parentLayerId: Option<LayerId>The id of parent (not present for root).
backendNodeId: Option<BackendNodeId>The backend id for the node associated with this layer.
offsetX: f64Offset from parent layer, X coordinate.
offsetY: f64Offset from parent layer, Y coordinate.
width: f64Layer width.
height: f64Layer height.
transform: Option<Vec<f64>>Transformation matrix for layer, default is identity matrix
anchorX: Option<f64>Transform anchor point X, absent if no transform specified
anchorY: Option<f64>Transform anchor point Y, absent if no transform specified
anchorZ: Option<f64>Transform anchor point Z, absent if no transform specified
paintCount: u64Indicates how many time this layer has painted.
drawsContent: boolIndicates whether this layer hosts any content, rather than being used for transform/scrolling purposes only.
invisible: Option<bool>Set if layer is not visible.
scrollRects: Option<Vec<ScrollRect>>Rectangles scrolling on main thread only.
stickyPositionConstraint: Option<StickyPositionConstraint>Sticky position constraint information