LayerBuilder

Struct LayerBuilder 

pub struct LayerBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> LayerBuilder<'a>

pub fn parentLayerId(self, parentLayerId: LayerId<'a>) -> Self

The id of parent (not present for root).

pub fn backendNodeId(self, backendNodeId: BackendNodeId) -> Self

The backend id for the node associated with this layer.

pub fn transform(self, transform: Vec<f64>) -> Self

Transformation matrix for layer, default is identity matrix

pub fn anchorX(self, anchorX: f64) -> Self

Transform anchor point X, absent if no transform specified

pub fn anchorY(self, anchorY: f64) -> Self

Transform anchor point Y, absent if no transform specified

pub fn anchorZ(self, anchorZ: f64) -> Self

Transform anchor point Z, absent if no transform specified

pub fn invisible(self, invisible: bool) -> Self

Set if layer is not visible.

pub fn scrollRects(self, scrollRects: Vec<ScrollRect<'a>>) -> Self

Rectangles scrolling on main thread only.

pub fn stickyPositionConstraint( self, stickyPositionConstraint: StickyPositionConstraint<'a>, ) -> Self

Sticky position constraint information

pub fn build(self) -> Layer<'a>