pub struct LayerBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> LayerBuilder<'a>
impl<'a> LayerBuilder<'a>
Sourcepub fn parentLayerId(self, parentLayerId: LayerId<'a>) -> Self
pub fn parentLayerId(self, parentLayerId: LayerId<'a>) -> Self
The id of parent (not present for root).
Sourcepub fn backendNodeId(self, backendNodeId: BackendNodeId) -> Self
pub fn backendNodeId(self, backendNodeId: BackendNodeId) -> Self
The backend id for the node associated with this layer.
Sourcepub fn transform(self, transform: Vec<f64>) -> Self
pub fn transform(self, transform: Vec<f64>) -> Self
Transformation matrix for layer, default is identity matrix
Sourcepub fn anchorX(self, anchorX: f64) -> Self
pub fn anchorX(self, anchorX: f64) -> Self
Transform anchor point X, absent if no transform specified
Sourcepub fn anchorY(self, anchorY: f64) -> Self
pub fn anchorY(self, anchorY: f64) -> Self
Transform anchor point Y, absent if no transform specified
Sourcepub fn anchorZ(self, anchorZ: f64) -> Self
pub fn anchorZ(self, anchorZ: f64) -> Self
Transform anchor point Z, absent if no transform specified
Sourcepub fn scrollRects(self, scrollRects: Vec<ScrollRect<'a>>) -> Self
pub fn scrollRects(self, scrollRects: Vec<ScrollRect<'a>>) -> Self
Rectangles scrolling on main thread only.
Sourcepub fn stickyPositionConstraint(
self,
stickyPositionConstraint: StickyPositionConstraint<'a>,
) -> Self
pub fn stickyPositionConstraint( self, stickyPositionConstraint: StickyPositionConstraint<'a>, ) -> Self
Sticky position constraint information
pub fn build(self) -> Layer<'a>