pub struct ProfileSnapshotParamsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ProfileSnapshotParamsBuilder<'a>
impl<'a> ProfileSnapshotParamsBuilder<'a>
Sourcepub fn minRepeatCount(self, minRepeatCount: u64) -> Self
pub fn minRepeatCount(self, minRepeatCount: u64) -> Self
The maximum number of times to replay the snapshot (1, if not specified).
Sourcepub fn minDuration(self, minDuration: f64) -> Self
pub fn minDuration(self, minDuration: f64) -> Self
The minimum duration (in seconds) to replay the snapshot.
Sourcepub fn clipRect(self, clipRect: Rect) -> Self
pub fn clipRect(self, clipRect: Rect) -> Self
The clip rectangle to apply when replaying the snapshot.
pub fn build(self) -> ProfileSnapshotParams<'a>