pub struct StickyPositionConstraintBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> StickyPositionConstraintBuilder<'a>
impl<'a> StickyPositionConstraintBuilder<'a>
Sourcepub fn nearestLayerShiftingStickyBox(
self,
nearestLayerShiftingStickyBox: LayerId<'a>,
) -> Self
pub fn nearestLayerShiftingStickyBox( self, nearestLayerShiftingStickyBox: LayerId<'a>, ) -> Self
The nearest sticky layer that shifts the sticky box
Sourcepub fn nearestLayerShiftingContainingBlock(
self,
nearestLayerShiftingContainingBlock: LayerId<'a>,
) -> Self
pub fn nearestLayerShiftingContainingBlock( self, nearestLayerShiftingContainingBlock: LayerId<'a>, ) -> Self
The nearest sticky layer that shifts the containing block
pub fn build(self) -> StickyPositionConstraint<'a>