Structs
- DOMCounter
- DOM object counter data.
- GetAll
Time Sampling Profile Returns - Retrieve native memory allocations profile collected since renderer process startup.
- GetBrowser
Sampling Profile Returns - Retrieve native memory allocations profile collected since browser process startup.
- GetDOM
Counters ForLeak Detection Returns - Retruns DOM object counters after preparing renderer for leak detection.
- GetDOM
Counters Returns - Retruns current DOM object counters.
- GetSampling
Profile Returns - Retrieve native memory allocations profile collected since last ‘startSampling’ call.
- Module
- Executable module information
- Sampling
Profile - Array of heap profile samples.
- Sampling
Profile Node - Heap profile sample.
- SetPressure
Notifications Suppressed Params - Enable/disable suppressing memory pressure notifications in all processes.
- Simulate
Pressure Notification Params - Simulate a memory pressure notification in all processes.
- Start
Sampling Params - Start collecting native memory profile.
Enums
- Pressure
Level - Memory pressure level.