Module network

Module network 

Network domain allows tracking network activities of the page. It exposes information about http, file, data and other requests and responses, their headers, bodies, timing, etc.

Structs

AdAncestry
Encapsulates the script ancestry and the root script filter list rule that caused the resource or element to be labeled as an ad.
AdAncestryBuilder
AdProvenance
Represents the provenance of an ad resource or element. Only one of ‘filterlistRule’ or ‘adScriptAncestry’ can be set. If ‘filterlistRule’ is provided, the resource URL directly matches a filter list rule. If ‘adScriptAncestry’ is provided, an ad script initiated the resource fetch or appended the element to the DOM. If neither is provided, the entity is known to be an ad, but provenance tracking information is unavailable.
AdProvenanceBuilder
AdScriptIdentifier
Identifies the script on the stack that caused a resource or element to be labeled as an ad. For resources, this indicates the context that triggered the fetch. For elements, this indicates the context that caused the element to be appended to the DOM.
AdScriptIdentifierBuilder
AssociatedCookie
A cookie associated with the request which may or may not be sent with it. Includes the cookies itself and reasons for blocking or exemption.
AssociatedCookieBuilder
AuthChallenge
Authorization challenge for HTTP status code 401 or 407.
AuthChallengeBuilder
AuthChallengeResponse
Response to an AuthChallenge.
AuthChallengeResponseBuilder
BlockPattern
BlockPatternBuilder
BlockedSetCookieWithReason
A cookie which was not stored from a response with the corresponding reason.
BlockedSetCookieWithReasonBuilder
CachedResource
Information about the cached resource.
CachedResourceBuilder
CanClearBrowserCacheParams
CanClearBrowserCacheReturns
Tells whether clearing browser cache is supported.
CanClearBrowserCacheReturnsBuilder
CanClearBrowserCookiesParams
CanClearBrowserCookiesReturns
Tells whether clearing browser cookies is supported.
CanClearBrowserCookiesReturnsBuilder
CanEmulateNetworkConditionsParams
CanEmulateNetworkConditionsReturns
Tells whether emulation of network conditions is supported.
CanEmulateNetworkConditionsReturnsBuilder
ChallengeEventDetails
Session event details specific to challenges.
ChallengeEventDetailsBuilder
ClearAcceptedEncodingsOverrideParams
ClearBrowserCacheParams
ClearBrowserCookiesParams
ClientSecurityState
ClientSecurityStateBuilder
ConfigureDurableMessagesParams
Configures storing response bodies outside of renderer, so that these survive a cross-process navigation. If maxTotalBufferSize is not set, durable messages are disabled.
ConfigureDurableMessagesParamsBuilder
ConnectTiming
ConnectTimingBuilder
ContentSecurityPolicyStatus
ContentSecurityPolicyStatusBuilder
ContinueInterceptedRequestParams
Response to Network.requestIntercepted which either modifies the request to continue with any modifications, or blocks it, or completes it with the provided response bytes. If a network fetch occurs as a result which encounters a redirect an additional Network.requestIntercepted event will be sent with the same InterceptionId. Deprecated, use Fetch.continueRequest, Fetch.fulfillRequest and Fetch.failRequest instead.
ContinueInterceptedRequestParamsBuilder
Cookie
Cookie object
CookieBuilder
CookieParam
Cookie parameter object
CookieParamBuilder
CookiePartitionKey
cookiePartitionKey object The representation of the components of the key that are created by the cookiePartitionKey class contained in net/cookies/cookie_partition_key.h.
CookiePartitionKeyBuilder
CorsErrorStatus
CorsErrorStatusBuilder
CreationEventDetails
Session event details specific to creation.
CreationEventDetailsBuilder
CrossOriginEmbedderPolicyStatus
CrossOriginEmbedderPolicyStatusBuilder
CrossOriginOpenerPolicyStatus
CrossOriginOpenerPolicyStatusBuilder
DeleteCookiesParams
Deletes browser cookies with matching name and url or domain/path/partitionKey pair.
DeleteCookiesParamsBuilder
DeleteDeviceBoundSessionParams
Deletes a device bound session.
DeleteDeviceBoundSessionParamsBuilder
DeviceBoundSession
A device bound session.
DeviceBoundSessionBuilder
DeviceBoundSessionCookieCraving
A device bound session’s cookie craving.
DeviceBoundSessionCookieCravingBuilder
DeviceBoundSessionFailedRequest
Details about a failed device bound session network request.
DeviceBoundSessionFailedRequestBuilder
DeviceBoundSessionInclusionRules
A device bound session’s inclusion rules.
DeviceBoundSessionInclusionRulesBuilder
DeviceBoundSessionKey
Unique identifier for a device bound session.
DeviceBoundSessionKeyBuilder
DeviceBoundSessionUrlRule
A device bound session’s inclusion URL rule.
DeviceBoundSessionUrlRuleBuilder
DeviceBoundSessionWithUsage
How a device bound session was used during a request.
DeviceBoundSessionWithUsageBuilder
DirectTCPSocketOptions
DirectTCPSocketOptionsBuilder
DirectUDPMessage
DirectUDPMessageBuilder
DirectUDPSocketOptions
DirectUDPSocketOptionsBuilder
DisableParams
EmulateNetworkConditionsByRuleParams
Activates emulation of network conditions for individual requests using URL match patterns. Unlike the deprecated Network.emulateNetworkConditions this method does not affect ‘navigator’ state. Use Network.overrideNetworkState to explicitly modify ‘navigator’ behavior.
EmulateNetworkConditionsByRuleParamsBuilder
EmulateNetworkConditionsByRuleReturns
Activates emulation of network conditions for individual requests using URL match patterns. Unlike the deprecated Network.emulateNetworkConditions this method does not affect ‘navigator’ state. Use Network.overrideNetworkState to explicitly modify ‘navigator’ behavior.
EmulateNetworkConditionsByRuleReturnsBuilder
EmulateNetworkConditionsParams
Activates emulation of network conditions. This command is deprecated in favor of the emulateNetworkConditionsByRule and overrideNetworkState commands, which can be used together to the same effect.
EmulateNetworkConditionsParamsBuilder
EnableDeviceBoundSessionsParams
Sets up tracking device bound sessions and fetching of initial set of sessions.
EnableDeviceBoundSessionsParamsBuilder
EnableParams
Enables network tracking, network events will now be delivered to the client.
EnableParamsBuilder
EnableReportingApiParams
Enables tracking for the Reporting API, events generated by the Reporting API will now be delivered to the client. Enabling triggers ‘reportingApiReportAdded’ for all existing reports.
EnableReportingApiParamsBuilder
ExemptedSetCookieWithReason
A cookie should have been blocked by 3PCD but is exempted and stored from a response with the corresponding reason. A cookie could only have at most one exemption reason.
ExemptedSetCookieWithReasonBuilder
FetchSchemefulSiteParams
Fetches the schemeful site for a specific origin.
FetchSchemefulSiteParamsBuilder
FetchSchemefulSiteReturns
Fetches the schemeful site for a specific origin.
FetchSchemefulSiteReturnsBuilder
GetAllCookiesParams
GetAllCookiesReturns
Returns all browser cookies. Depending on the backend support, will return detailed cookie information in the ‘cookies’ field. Deprecated. Use Storage.getCookies instead.
GetAllCookiesReturnsBuilder
GetCertificateParams
Returns the DER-encoded certificate.
GetCertificateParamsBuilder
GetCertificateReturns
Returns the DER-encoded certificate.
GetCertificateReturnsBuilder
GetCookiesParams
Returns all browser cookies for the current URL. Depending on the backend support, will return detailed cookie information in the ‘cookies’ field.
GetCookiesParamsBuilder
GetCookiesReturns
Returns all browser cookies for the current URL. Depending on the backend support, will return detailed cookie information in the ‘cookies’ field.
GetCookiesReturnsBuilder
GetRequestPostDataParams
Returns post data sent with the request. Returns an error when no data was sent with the request.
GetRequestPostDataParamsBuilder
GetRequestPostDataReturns
Returns post data sent with the request. Returns an error when no data was sent with the request.
GetRequestPostDataReturnsBuilder
GetResponseBodyForInterceptionParams
Returns content served for the given currently intercepted request.
GetResponseBodyForInterceptionParamsBuilder
GetResponseBodyForInterceptionReturns
Returns content served for the given currently intercepted request.
GetResponseBodyForInterceptionReturnsBuilder
GetResponseBodyParams
Returns content served for the given request.
GetResponseBodyParamsBuilder
GetResponseBodyReturns
Returns content served for the given request.
GetResponseBodyReturnsBuilder
GetSecurityIsolationStatusParams
Returns information about the COEP/COOP isolation status.
GetSecurityIsolationStatusParamsBuilder
GetSecurityIsolationStatusReturns
Returns information about the COEP/COOP isolation status.
GetSecurityIsolationStatusReturnsBuilder
Initiator
Information about the request initiator.
InitiatorBuilder
LoadNetworkResourceOptions
An options object that may be extended later to better support CORS, CORB and streaming.
LoadNetworkResourceOptionsBuilder
LoadNetworkResourcePageResult
An object providing the result of a network resource load.
LoadNetworkResourcePageResultBuilder
LoadNetworkResourceParams
Fetches the resource and returns the content.
LoadNetworkResourceParamsBuilder
LoadNetworkResourceReturns
Fetches the resource and returns the content.
LoadNetworkResourceReturnsBuilder
NetworkConditions
NetworkConditionsBuilder
OverrideNetworkStateParams
Override the state of navigator.onLine and navigator.connection.
OverrideNetworkStateParamsBuilder
PostDataEntry
Post data entry for HTTP request
PostDataEntryBuilder
RefreshEventDetails
Session event details specific to refresh.
RefreshEventDetailsBuilder
ReplayXHRParams
This method sends a new XMLHttpRequest which is identical to the original one. The following parameters should be identical: method, url, async, request body, extra headers, withCredentials attribute, user, password.
ReplayXHRParamsBuilder
ReportingApiEndpoint
ReportingApiEndpointBuilder
ReportingApiReport
An object representing a report generated by the Reporting API.
ReportingApiReportBuilder
Request
HTTP request data.
RequestBuilder
RequestPattern
Request pattern for interception.
RequestPatternBuilder
ResourceTiming
Timing information for the request.
ResourceTimingBuilder
Response
HTTP response data.
ResponseBuilder
SearchInResponseBodyParams
Searches for given string in response content.
SearchInResponseBodyParamsBuilder
SearchInResponseBodyReturns
Searches for given string in response content.
SearchInResponseBodyReturnsBuilder
SecurityDetails
Security details about a request.
SecurityDetailsBuilder
SecurityIsolationStatus
SecurityIsolationStatusBuilder
ServiceWorkerRouterInfo
ServiceWorkerRouterInfoBuilder
SetAcceptedEncodingsParams
Sets a list of content encodings that will be accepted. Empty list means no encoding is accepted.
SetAcceptedEncodingsParamsBuilder
SetAttachDebugStackParams
Specifies whether to attach a page script stack id in requests
SetAttachDebugStackParamsBuilder
SetBlockedURLsParams
Blocks URLs from loading.
SetBlockedURLsParamsBuilder
SetBypassServiceWorkerParams
Toggles ignoring of service worker for each request.
SetBypassServiceWorkerParamsBuilder
SetCacheDisabledParams
Toggles ignoring cache for each request. If ‘true’, cache will not be used.
SetCacheDisabledParamsBuilder
SetCookieControlsParams
Sets Controls for third-party cookie access Page reload is required before the new cookie behavior will be observed
SetCookieControlsParamsBuilder
SetCookieParams
Sets a cookie with the given cookie data; may overwrite equivalent cookies if they exist.
SetCookieParamsBuilder
SetCookieReturns
Sets a cookie with the given cookie data; may overwrite equivalent cookies if they exist.
SetCookieReturnsBuilder
SetCookiesParams
Sets given cookies.
SetCookiesParamsBuilder
SetExtraHTTPHeadersParams
Specifies whether to always send extra HTTP headers with the requests from this page.
SetExtraHTTPHeadersParamsBuilder
SetRequestInterceptionParams
Sets the requests to intercept that match the provided patterns and optionally resource types. Deprecated, please use Fetch.enable instead.
SetRequestInterceptionParamsBuilder
SetUserAgentOverrideParams
Allows overriding user agent with the given string.
SetUserAgentOverrideParamsBuilder
SignedCertificateTimestamp
Details of a signed certificate timestamp (SCT).
SignedCertificateTimestampBuilder
SignedExchangeError
Information about a signed exchange response.
SignedExchangeErrorBuilder
SignedExchangeHeader
Information about a signed exchange header. https://wicg.github.io/webpackage/draft-yasskin-httpbis-origin-signed-exchanges-impl.html#cbor-representation
SignedExchangeHeaderBuilder
SignedExchangeInfo
Information about a signed exchange response.
SignedExchangeInfoBuilder
SignedExchangeSignature
Information about a signed exchange signature. https://wicg.github.io/webpackage/draft-yasskin-httpbis-origin-signed-exchanges-impl.html#rfc.section.3.1
SignedExchangeSignatureBuilder
StreamResourceContentParams
Enables streaming of the response for the given requestId. If enabled, the dataReceived event contains the data that was received during streaming.
StreamResourceContentParamsBuilder
StreamResourceContentReturns
Enables streaming of the response for the given requestId. If enabled, the dataReceived event contains the data that was received during streaming.
StreamResourceContentReturnsBuilder
TakeResponseBodyForInterceptionAsStreamParams
Returns a handle to the stream representing the response body. Note that after this command, the intercepted request can’t be continued as is – you either need to cancel it or to provide the response body. The stream only supports sequential read, IO.read will fail if the position is specified.
TakeResponseBodyForInterceptionAsStreamParamsBuilder
TakeResponseBodyForInterceptionAsStreamReturns
Returns a handle to the stream representing the response body. Note that after this command, the intercepted request can’t be continued as is – you either need to cancel it or to provide the response body. The stream only supports sequential read, IO.read will fail if the position is specified.
TakeResponseBodyForInterceptionAsStreamReturnsBuilder
TerminationEventDetails
Session event details specific to termination.
TerminationEventDetailsBuilder
TrustTokenParams
Determines what type of Trust Token operation is executed and depending on the type, some additional parameters. The values are specified in third_party/blink/renderer/core/fetch/trust_token.idl.
TrustTokenParamsBuilder
WebSocketFrame
WebSocket message data. This represents an entire WebSocket message, not just a fragmented frame as the name suggests.
WebSocketFrameBuilder
WebSocketRequest
WebSocket request data.
WebSocketRequestBuilder
WebSocketResponse
WebSocket response data.
WebSocketResponseBuilder

Enums

AlternateProtocolUsage
The reason why Chrome uses a specific transport protocol for HTTP semantics.
BlockedReason
The reason why request was blocked.
CertificateTransparencyCompliance
Whether the request complied with Certificate Transparency policy.
ConnectionType
The underlying connection technology that the browser is supposedly using.
ContentEncoding
List of content encodings supported by the backend.
ContentSecurityPolicySource
CookieBlockedReason
Types of reasons why a cookie may not be sent with a request.
CookieExemptionReason
Types of reasons why a cookie should have been blocked by 3PCD but is exempted for the request.
CookiePriority
Represents the cookie’s ‘Priority’ status: https://tools.ietf.org/html/draft-west-cookie-priority-00
CookieSameSite
Represents the cookie’s ‘SameSite’ status: https://tools.ietf.org/html/draft-west-first-party-cookies
CookieSourceScheme
Represents the source scheme of the origin that originally set the cookie. A value of “Unset” allows protocol clients to emulate legacy cookie scope for the scheme. This is a temporary ability and it will be removed in the future.
CorsError
The reason why request was blocked.
CrossOriginEmbedderPolicyValue
CrossOriginOpenerPolicyValue
DeviceBoundSessionFetchResult
A fetch result for a device bound session creation or refresh.
DirectSocketDnsQueryType
ErrorReason
Network level fetch failure reason.
IPAddressSpace
InterceptionStage
Stages of the interception to begin intercepting. Request will intercept before the request is sent. Response will intercept after the response is received.
LocalNetworkAccessRequestPolicy
RenderBlockingBehavior
The render-blocking behavior of a resource request.
ReportStatus
The status of a Reporting API report.
ResourcePriority
Loading priority of a resource request.
ResourceType
Resource type as it was perceived by the rendering engine.
ServiceWorkerResponseSource
Source of serviceworker response.
ServiceWorkerRouterSource
Source of service worker router.
SetCookieBlockedReason
Types of reasons why a cookie may not be stored from a response.
SignedExchangeErrorField
Field type for a signed exchange related error.
TrustTokenOperationType

Type Aliases

DeviceBoundSessionEventId
A unique identifier for a device bound session event.
Headers
Request / response headers as keys / values of JSON object.
InterceptionId
Unique intercepted request identifier.
LoaderId
Unique loader identifier.
MonotonicTime
Monotonically increasing time in seconds since an arbitrary point in the past.
ReportId
RequestId
Unique network request identifier. Note that this does not identify individual HTTP requests that are part of a network request.
TimeSinceEpoch
UTC time in seconds, counted from January 1, 1970.