Module network

Module network 

Network domain allows tracking network activities of the page. It exposes information about http, file, data and other requests and responses, their headers, bodies, timing, etc.

Structs

AdAncestry
Encapsulates the script ancestry and the root script filter list rule that caused the resource or element to be labeled as an ad.
AdProvenance
Represents the provenance of an ad resource or element. Only one of ‘filterlistRule’ or ‘adScriptAncestry’ can be set. If ‘filterlistRule’ is provided, the resource URL directly matches a filter list rule. If ‘adScriptAncestry’ is provided, an ad script initiated the resource fetch or appended the element to the DOM. If neither is provided, the entity is known to be an ad, but provenance tracking information is unavailable.
AdScriptIdentifier
Identifies the script on the stack that caused a resource or element to be labeled as an ad. For resources, this indicates the context that triggered the fetch. For elements, this indicates the context that caused the element to be appended to the DOM.
AssociatedCookie
A cookie associated with the request which may or may not be sent with it. Includes the cookies itself and reasons for blocking or exemption.
AuthChallenge
Authorization challenge for HTTP status code 401 or 407.
AuthChallengeResponse
Response to an AuthChallenge.
BlockPattern
BlockedSetCookieWithReason
A cookie which was not stored from a response with the corresponding reason.
CachedResource
Information about the cached resource.
CanClearBrowserCacheReturns
Tells whether clearing browser cache is supported.
CanClearBrowserCookiesReturns
Tells whether clearing browser cookies is supported.
CanEmulateNetworkConditionsReturns
Tells whether emulation of network conditions is supported.
ChallengeEventDetails
Session event details specific to challenges.
ClientSecurityState
ConfigureDurableMessagesParams
Configures storing response bodies outside of renderer, so that these survive a cross-process navigation. If maxTotalBufferSize is not set, durable messages are disabled.
ConnectTiming
ContentSecurityPolicyStatus
ContinueInterceptedRequestParams
Response to Network.requestIntercepted which either modifies the request to continue with any modifications, or blocks it, or completes it with the provided response bytes. If a network fetch occurs as a result which encounters a redirect an additional Network.requestIntercepted event will be sent with the same InterceptionId. Deprecated, use Fetch.continueRequest, Fetch.fulfillRequest and Fetch.failRequest instead.
Cookie
Cookie object
CookieParam
Cookie parameter object
CookiePartitionKey
cookiePartitionKey object The representation of the components of the key that are created by the cookiePartitionKey class contained in net/cookies/cookie_partition_key.h.
CorsErrorStatus
CreationEventDetails
Session event details specific to creation.
CrossOriginEmbedderPolicyStatus
CrossOriginOpenerPolicyStatus
DeleteCookiesParams
Deletes browser cookies with matching name and url or domain/path/partitionKey pair.
DeleteDeviceBoundSessionParams
Deletes a device bound session.
DeviceBoundSession
A device bound session.
DeviceBoundSessionCookieCraving
A device bound session’s cookie craving.
DeviceBoundSessionFailedRequest
Details about a failed device bound session network request.
DeviceBoundSessionInclusionRules
A device bound session’s inclusion rules.
DeviceBoundSessionKey
Unique identifier for a device bound session.
DeviceBoundSessionUrlRule
A device bound session’s inclusion URL rule.
DeviceBoundSessionWithUsage
How a device bound session was used during a request.
DirectTCPSocketOptions
DirectUDPMessage
DirectUDPSocketOptions
EmulateNetworkConditionsByRuleParams
Activates emulation of network conditions for individual requests using URL match patterns. Unlike the deprecated Network.emulateNetworkConditions this method does not affect ‘navigator’ state. Use Network.overrideNetworkState to explicitly modify ‘navigator’ behavior.
EmulateNetworkConditionsByRuleReturns
Activates emulation of network conditions for individual requests using URL match patterns. Unlike the deprecated Network.emulateNetworkConditions this method does not affect ‘navigator’ state. Use Network.overrideNetworkState to explicitly modify ‘navigator’ behavior.
EmulateNetworkConditionsParams
Activates emulation of network conditions. This command is deprecated in favor of the emulateNetworkConditionsByRule and overrideNetworkState commands, which can be used together to the same effect.
EnableDeviceBoundSessionsParams
Sets up tracking device bound sessions and fetching of initial set of sessions.
EnableParams
Enables network tracking, network events will now be delivered to the client.
EnableReportingApiParams
Enables tracking for the Reporting API, events generated by the Reporting API will now be delivered to the client. Enabling triggers ‘reportingApiReportAdded’ for all existing reports.
ExemptedSetCookieWithReason
A cookie should have been blocked by 3PCD but is exempted and stored from a response with the corresponding reason. A cookie could only have at most one exemption reason.
FetchSchemefulSiteParams
Fetches the schemeful site for a specific origin.
FetchSchemefulSiteReturns
Fetches the schemeful site for a specific origin.
GetAllCookiesReturns
Returns all browser cookies. Depending on the backend support, will return detailed cookie information in the ‘cookies’ field. Deprecated. Use Storage.getCookies instead.
GetCertificateParams
Returns the DER-encoded certificate.
GetCertificateReturns
Returns the DER-encoded certificate.
GetCookiesParams
Returns all browser cookies for the current URL. Depending on the backend support, will return detailed cookie information in the ‘cookies’ field.
GetCookiesReturns
Returns all browser cookies for the current URL. Depending on the backend support, will return detailed cookie information in the ‘cookies’ field.
GetRequestPostDataParams
Returns post data sent with the request. Returns an error when no data was sent with the request.
GetRequestPostDataReturns
Returns post data sent with the request. Returns an error when no data was sent with the request.
GetResponseBodyForInterceptionParams
Returns content served for the given currently intercepted request.
GetResponseBodyForInterceptionReturns
Returns content served for the given currently intercepted request.
GetResponseBodyParams
Returns content served for the given request.
GetResponseBodyReturns
Returns content served for the given request.
GetSecurityIsolationStatusParams
Returns information about the COEP/COOP isolation status.
GetSecurityIsolationStatusReturns
Returns information about the COEP/COOP isolation status.
Initiator
Information about the request initiator.
LoadNetworkResourceOptions
An options object that may be extended later to better support CORS, CORB and streaming.
LoadNetworkResourcePageResult
An object providing the result of a network resource load.
LoadNetworkResourceParams
Fetches the resource and returns the content.
LoadNetworkResourceReturns
Fetches the resource and returns the content.
NetworkConditions
OverrideNetworkStateParams
Override the state of navigator.onLine and navigator.connection.
PostDataEntry
Post data entry for HTTP request
RefreshEventDetails
Session event details specific to refresh.
ReplayXHRParams
This method sends a new XMLHttpRequest which is identical to the original one. The following parameters should be identical: method, url, async, request body, extra headers, withCredentials attribute, user, password.
ReportingApiEndpoint
ReportingApiReport
An object representing a report generated by the Reporting API.
Request
HTTP request data.
RequestPattern
Request pattern for interception.
ResourceTiming
Timing information for the request.
Response
HTTP response data.
SearchInResponseBodyParams
Searches for given string in response content.
SearchInResponseBodyReturns
Searches for given string in response content.
SecurityDetails
Security details about a request.
SecurityIsolationStatus
ServiceWorkerRouterInfo
SetAcceptedEncodingsParams
Sets a list of content encodings that will be accepted. Empty list means no encoding is accepted.
SetAttachDebugStackParams
Specifies whether to attach a page script stack id in requests
SetBlockedURLsParams
Blocks URLs from loading.
SetBypassServiceWorkerParams
Toggles ignoring of service worker for each request.
SetCacheDisabledParams
Toggles ignoring cache for each request. If ‘true’, cache will not be used.
SetCookieControlsParams
Sets Controls for third-party cookie access Page reload is required before the new cookie behavior will be observed
SetCookieParams
Sets a cookie with the given cookie data; may overwrite equivalent cookies if they exist.
SetCookieReturns
Sets a cookie with the given cookie data; may overwrite equivalent cookies if they exist.
SetCookiesParams
Sets given cookies.
SetExtraHTTPHeadersParams
Specifies whether to always send extra HTTP headers with the requests from this page.
SetRequestInterceptionParams
Sets the requests to intercept that match the provided patterns and optionally resource types. Deprecated, please use Fetch.enable instead.
SetUserAgentOverrideParams
Allows overriding user agent with the given string.
SignedCertificateTimestamp
Details of a signed certificate timestamp (SCT).
SignedExchangeError
Information about a signed exchange response.
SignedExchangeHeader
Information about a signed exchange header. https://wicg.github.io/webpackage/draft-yasskin-httpbis-origin-signed-exchanges-impl.html#cbor-representation
SignedExchangeInfo
Information about a signed exchange response.
SignedExchangeSignature
Information about a signed exchange signature. https://wicg.github.io/webpackage/draft-yasskin-httpbis-origin-signed-exchanges-impl.html#rfc.section.3.1
StreamResourceContentParams
Enables streaming of the response for the given requestId. If enabled, the dataReceived event contains the data that was received during streaming.
StreamResourceContentReturns
Enables streaming of the response for the given requestId. If enabled, the dataReceived event contains the data that was received during streaming.
TakeResponseBodyForInterceptionAsStreamParams
Returns a handle to the stream representing the response body. Note that after this command, the intercepted request can’t be continued as is – you either need to cancel it or to provide the response body. The stream only supports sequential read, IO.read will fail if the position is specified.
TakeResponseBodyForInterceptionAsStreamReturns
Returns a handle to the stream representing the response body. Note that after this command, the intercepted request can’t be continued as is – you either need to cancel it or to provide the response body. The stream only supports sequential read, IO.read will fail if the position is specified.
TerminationEventDetails
Session event details specific to termination.
TrustTokenParams
Determines what type of Trust Token operation is executed and depending on the type, some additional parameters. The values are specified in third_party/blink/renderer/core/fetch/trust_token.idl.
WebSocketFrame
WebSocket message data. This represents an entire WebSocket message, not just a fragmented frame as the name suggests.
WebSocketRequest
WebSocket request data.
WebSocketResponse
WebSocket response data.

Enums

AlternateProtocolUsage
The reason why Chrome uses a specific transport protocol for HTTP semantics.
BlockedReason
The reason why request was blocked.
CertificateTransparencyCompliance
Whether the request complied with Certificate Transparency policy.
ConnectionType
The underlying connection technology that the browser is supposedly using.
ContentEncoding
List of content encodings supported by the backend.
ContentSecurityPolicySource
CookieBlockedReason
Types of reasons why a cookie may not be sent with a request.
CookieExemptionReason
Types of reasons why a cookie should have been blocked by 3PCD but is exempted for the request.
CookiePriority
Represents the cookie’s ‘Priority’ status: https://tools.ietf.org/html/draft-west-cookie-priority-00
CookieSameSite
Represents the cookie’s ‘SameSite’ status: https://tools.ietf.org/html/draft-west-first-party-cookies
CookieSourceScheme
Represents the source scheme of the origin that originally set the cookie. A value of “Unset” allows protocol clients to emulate legacy cookie scope for the scheme. This is a temporary ability and it will be removed in the future.
CorsError
The reason why request was blocked.
CrossOriginEmbedderPolicyValue
CrossOriginOpenerPolicyValue
DeviceBoundSessionFetchResult
A fetch result for a device bound session creation or refresh.
DirectSocketDnsQueryType
ErrorReason
Network level fetch failure reason.
IPAddressSpace
InterceptionStage
Stages of the interception to begin intercepting. Request will intercept before the request is sent. Response will intercept after the response is received.
LocalNetworkAccessRequestPolicy
RenderBlockingBehavior
The render-blocking behavior of a resource request.
ReportStatus
The status of a Reporting API report.
ResourcePriority
Loading priority of a resource request.
ResourceType
Resource type as it was perceived by the rendering engine.
ServiceWorkerResponseSource
Source of serviceworker response.
ServiceWorkerRouterSource
Source of service worker router.
SetCookieBlockedReason
Types of reasons why a cookie may not be stored from a response.
SignedExchangeErrorField
Field type for a signed exchange related error.
TrustTokenOperationType

Type Aliases

DeviceBoundSessionEventId
A unique identifier for a device bound session event.
Headers
Request / response headers as keys / values of JSON object.
InterceptionId
Unique intercepted request identifier.
LoaderId
Unique loader identifier.
MonotonicTime
Monotonically increasing time in seconds since an arbitrary point in the past.
ReportId
RequestId
Unique network request identifier. Note that this does not identify individual HTTP requests that are part of a network request.
TimeSinceEpoch
UTC time in seconds, counted from January 1, 1970.