pub struct AdAncestry {
pub ancestryChain: Vec<AdScriptIdentifier>,
pub rootScriptFilterlistRule: Option<String>,
}Expand description
Encapsulates the script ancestry and the root script filter list rule that caused the resource or element to be labeled as an ad.
Fields
ancestryChain: Vec<AdScriptIdentifier>A chain of ’AdScriptIdentifier’s representing the ancestry of an ad script that led to the creation of a resource or element. The chain is ordered from the script itself (lowest level) up to its root ancestor that was flagged by a filter list.
rootScriptFilterlistRule: Option<String>The filter list rule that caused the root (last) script in ‘ancestryChain’ to be tagged as an ad.