pub struct AdProvenance<'a> { /* private fields */ }Expand description
Represents the provenance of an ad resource or element. Only one of ‘filterlistRule’ or ‘adScriptAncestry’ can be set. If ‘filterlistRule’ is provided, the resource URL directly matches a filter list rule. If ‘adScriptAncestry’ is provided, an ad script initiated the resource fetch or appended the element to the DOM. If neither is provided, the entity is known to be an ad, but provenance tracking information is unavailable.
Implementations
Sourceimpl<'a> AdProvenance<'a>
impl<'a> AdProvenance<'a>
pub fn builder() -> AdProvenanceBuilder<'a>
pub fn filterlistRule(&self) -> Option<&str>
pub fn adScriptAncestry(&self) -> Option<&AdAncestry<'a>>