pub struct AdProvenance {
pub filterlistRule: Option<String>,
pub adScriptAncestry: Option<AdAncestry>,
}Expand description
Represents the provenance of an ad resource or element. Only one of ‘filterlistRule’ or ‘adScriptAncestry’ can be set. If ‘filterlistRule’ is provided, the resource URL directly matches a filter list rule. If ‘adScriptAncestry’ is provided, an ad script initiated the resource fetch or appended the element to the DOM. If neither is provided, the entity is known to be an ad, but provenance tracking information is unavailable.
Fields
filterlistRule: Option<String>The filterlist rule that matched, if any.
adScriptAncestry: Option<AdAncestry>The script ancestry that created the ad, if any.