pub struct AdScriptIdentifier<'a> { /* private fields */ }Expand description
Identifies the script on the stack that caused a resource or element to be labeled as an ad. For resources, this indicates the context that triggered the fetch. For elements, this indicates the context that caused the element to be appended to the DOM.
Implementations
Sourceimpl<'a> AdScriptIdentifier<'a>
impl<'a> AdScriptIdentifier<'a>
Sourcepub fn builder(
script_id: ScriptId<'a>,
debugger_id: UniqueDebuggerId<'a>,
name: impl Into<Cow<'a, str>>,
) -> AdScriptIdentifierBuilder<'a>
pub fn builder( script_id: ScriptId<'a>, debugger_id: UniqueDebuggerId<'a>, name: impl Into<Cow<'a, str>>, ) -> AdScriptIdentifierBuilder<'a>
Creates a builder for this type with the required parameters:
script_id: The script’s V8 identifier.debugger_id: V8’s debugging ID for the v8::Context.name: The script’s url (or generated name based on id if inline script).
Sourcepub fn debugger_id(&self) -> &UniqueDebuggerId<'a>
pub fn debugger_id(&self) -> &UniqueDebuggerId<'a>
V8’s debugging ID for the v8::Context.