AdScriptIdentifier

Struct AdScriptIdentifier 

pub struct AdScriptIdentifier {
    pub scriptId: ScriptId,
    pub debuggerId: UniqueDebuggerId,
    pub name: String,
}
Identifies the script on the stack that caused a resource or element to be labeled as an ad. For resources, this indicates the context that triggered the fetch. For elements, this indicates the context that caused the element to be appended to the DOM.

Fields

scriptId: ScriptId

The script’s V8 identifier.

debuggerId: UniqueDebuggerId

V8’s debugging ID for the v8::Context.

name: String

The script’s url (or generated name based on id if inline script).