pub struct AdScriptIdentifier<'a> { /* private fields */ }Expand description
Identifies the script on the stack that caused a resource or element to be labeled as an ad. For resources, this indicates the context that triggered the fetch. For elements, this indicates the context that caused the element to be appended to the DOM.
Implementations
Sourceimpl<'a> AdScriptIdentifier<'a>
impl<'a> AdScriptIdentifier<'a>
pub fn builder( scriptId: ScriptId<'a>, debuggerId: UniqueDebuggerId<'a>, name: impl Into<Cow<'a, str>>, ) -> AdScriptIdentifierBuilder<'a>
pub fn scriptId(&self) -> &ScriptId<'a>
pub fn debuggerId(&self) -> &UniqueDebuggerId<'a>
pub fn name(&self) -> &str