pub struct AssociatedCookie<'a> { /* private fields */ }Expand description
A cookie associated with the request which may or may not be sent with it. Includes the cookies itself and reasons for blocking or exemption.
Implementations
Sourceimpl<'a> AssociatedCookie<'a>
impl<'a> AssociatedCookie<'a>
pub fn builder( cookie: Cookie<'a>, blockedReasons: Vec<CookieBlockedReason>, ) -> AssociatedCookieBuilder<'a>
pub fn blockedReasons(&self) -> &[CookieBlockedReason]
pub fn exemptionReason(&self) -> Option<&CookieExemptionReason>