ContinueInterceptedRequestParams

Struct ContinueInterceptedRequestParams 

pub struct ContinueInterceptedRequestParams {
    pub interceptionId: InterceptionId,
    pub errorReason: Option<ErrorReason>,
    pub rawResponse: Option<String>,
    pub url: Option<String>,
    pub method: Option<String>,
    pub postData: Option<String>,
    pub headers: Option<Headers>,
    pub authChallengeResponse: Option<AuthChallengeResponse>,
}
Response to Network.requestIntercepted which either modifies the request to continue with any modifications, or blocks it, or completes it with the provided response bytes. If a network fetch occurs as a result which encounters a redirect an additional Network.requestIntercepted event will be sent with the same InterceptionId. Deprecated, use Fetch.continueRequest, Fetch.fulfillRequest and Fetch.failRequest instead.

Fields

interceptionId: InterceptionIderrorReason: Option<ErrorReason>

If set this causes the request to fail with the given reason. Passing ‘Aborted’ for requests marked with ‘isNavigationRequest’ also cancels the navigation. Must not be set in response to an authChallenge.

rawResponse: Option<String>

If set the requests completes using with the provided base64 encoded raw response, including HTTP status line and headers etc… Must not be set in response to an authChallenge. (Encoded as a base64 string when passed over JSON)

url: Option<String>

If set the request url will be modified in a way that’s not observable by page. Must not be set in response to an authChallenge.

method: Option<String>

If set this allows the request method to be overridden. Must not be set in response to an authChallenge.

postData: Option<String>

If set this allows postData to be set. Must not be set in response to an authChallenge.

headers: Option<Headers>

If set this allows the request headers to be changed. Must not be set in response to an authChallenge.

authChallengeResponse: Option<AuthChallengeResponse>

Response to a requestIntercepted with an authChallenge. Must not be set otherwise.

Implementations

Source

impl ContinueInterceptedRequestParams

pub const METHOD: &'static str = "Network.continueInterceptedRequest"