pub struct ContinueInterceptedRequestParams<'a> { /* private fields */ }Expand description
Response to Network.requestIntercepted which either modifies the request to continue with any modifications, or blocks it, or completes it with the provided response bytes. If a network fetch occurs as a result which encounters a redirect an additional Network.requestIntercepted event will be sent with the same InterceptionId. Deprecated, use Fetch.continueRequest, Fetch.fulfillRequest and Fetch.failRequest instead.
Implementations
Sourceimpl<'a> ContinueInterceptedRequestParams<'a>
impl<'a> ContinueInterceptedRequestParams<'a>
pub fn builder( interceptionId: InterceptionId<'a>, ) -> ContinueInterceptedRequestParamsBuilder<'a>
pub fn interceptionId(&self) -> &InterceptionId<'a>
pub fn errorReason(&self) -> Option<&ErrorReason>
pub fn rawResponse(&self) -> Option<&str>
pub fn url(&self) -> Option<&str>
pub fn method(&self) -> Option<&str>
pub fn postData(&self) -> Option<&str>
pub fn headers(&self) -> Option<&Headers>
pub fn authChallengeResponse(&self) -> Option<&AuthChallengeResponse<'a>>