pub struct CookieParamBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> CookieParamBuilder<'a>
impl<'a> CookieParamBuilder<'a>
Sourcepub fn url(self, url: impl Into<Cow<'a, str>>) -> Self
pub fn url(self, url: impl Into<Cow<'a, str>>) -> Self
The request-URI to associate with the setting of the cookie. This value can affect the default domain, path, source port, and source scheme values of the created cookie.
Sourcepub fn sameSite(self, sameSite: CookieSameSite) -> Self
pub fn sameSite(self, sameSite: CookieSameSite) -> Self
Cookie SameSite type.
Sourcepub fn expires(self, expires: TimeSinceEpoch) -> Self
pub fn expires(self, expires: TimeSinceEpoch) -> Self
Cookie expiration date, session cookie if not set
Sourcepub fn priority(self, priority: CookiePriority) -> Self
pub fn priority(self, priority: CookiePriority) -> Self
Cookie Priority.
Sourcepub fn sourceScheme(self, sourceScheme: CookieSourceScheme) -> Self
pub fn sourceScheme(self, sourceScheme: CookieSourceScheme) -> Self
Cookie source scheme type.
Sourcepub fn sourcePort(self, sourcePort: i64) -> Self
pub fn sourcePort(self, sourcePort: i64) -> Self
Cookie source port. Valid values are {-1, [1, 65535]}, -1 indicates an unspecified port. An unspecified port value allows protocol clients to emulate legacy cookie scope for the port. This is a temporary ability and it will be removed in the future.
Sourcepub fn partitionKey(self, partitionKey: CookiePartitionKey<'a>) -> Self
pub fn partitionKey(self, partitionKey: CookiePartitionKey<'a>) -> Self
Cookie partition key. If not set, the cookie will be set as not partitioned.
pub fn build(self) -> CookieParam<'a>