pub struct DeviceBoundSessionFailedRequest {
pub requestUrl: String,
pub netError: Option<String>,
pub responseError: Option<i64>,
pub responseErrorBody: Option<String>,
}Expand description
Details about a failed device bound session network request.
Fields
requestUrl: StringThe failed request URL.
netError: Option<String>The net error of the response if it was not OK.
responseError: Option<i64>The response code if the net error was OK and the response code was not 200.
responseErrorBody: Option<String>The body of the response if the net error was OK, the response code was not 200, and the response body was not empty.