EmulateNetworkConditionsByRuleParams

Struct EmulateNetworkConditionsByRuleParams 

pub struct EmulateNetworkConditionsByRuleParams {
    pub offline: Option<bool>,
    pub emulateOfflineServiceWorker: Option<bool>,
    pub matchedNetworkConditions: Vec<NetworkConditions>,
}
Activates emulation of network conditions for individual requests using URL match patterns. Unlike the deprecated Network.emulateNetworkConditions this method does not affect ‘navigator’ state. Use Network.overrideNetworkState to explicitly modify ‘navigator’ behavior.

Fields

offline: Option<bool>

True to emulate internet disconnection. Deprecated, use the offline property in matchedNetworkConditions or emulateOfflineServiceWorker instead.

emulateOfflineServiceWorker: Option<bool>

True to emulate offline service worker.

matchedNetworkConditions: Vec<NetworkConditions>

Configure conditions for matching requests. If multiple entries match a request, the first entry wins. Global conditions can be configured by leaving the urlPattern for the conditions empty. These global conditions are also applied for throttling of p2p connections.