EmulateNetworkConditionsParams

Struct EmulateNetworkConditionsParams 

pub struct EmulateNetworkConditionsParams { /* private fields */ }
Activates emulation of network conditions. This command is deprecated in favor of the emulateNetworkConditionsByRule and overrideNetworkState commands, which can be used together to the same effect.

Implementations

Source

impl EmulateNetworkConditionsParams

pub fn builder( offline: bool, latency: f64, downloadThroughput: f64, uploadThroughput: f64, ) -> EmulateNetworkConditionsParamsBuilder

pub fn offline(&self) -> bool

pub fn latency(&self) -> f64

pub fn downloadThroughput(&self) -> f64

pub fn uploadThroughput(&self) -> f64

pub fn connectionType(&self) -> Option<&ConnectionType>

pub fn packetLoss(&self) -> Option<f64>

pub fn packetQueueLength(&self) -> Option<u64>

pub fn packetReordering(&self) -> Option<bool>

Source

impl EmulateNetworkConditionsParams

pub const METHOD: &'static str = "Network.emulateNetworkConditions"