pub struct EmulateNetworkConditionsParams {
pub offline: bool,
pub latency: f64,
pub downloadThroughput: f64,
pub uploadThroughput: f64,
pub connectionType: Option<ConnectionType>,
pub packetLoss: Option<f64>,
pub packetQueueLength: Option<u64>,
pub packetReordering: Option<bool>,
}Expand description
Activates emulation of network conditions. This command is deprecated in favor of the emulateNetworkConditionsByRule and overrideNetworkState commands, which can be used together to the same effect.
Fields
offline: boolTrue to emulate internet disconnection.
latency: f64Minimum latency from request sent to response headers received (ms).
downloadThroughput: f64Maximal aggregated download throughput (bytes/sec). -1 disables download throttling.
uploadThroughput: f64Maximal aggregated upload throughput (bytes/sec). -1 disables upload throttling.
connectionType: Option<ConnectionType>Connection type if known.
packetLoss: Option<f64>WebRTC packet loss (percent, 0-100). 0 disables packet loss emulation, 100 drops all the packets.
packetQueueLength: Option<u64>WebRTC packet queue length (packet). 0 removes any queue length limitations.
packetReordering: Option<bool>WebRTC packetReordering feature.
Implementations