pub struct EnableParams {
pub maxTotalBufferSize: Option<u64>,
pub maxResourceBufferSize: Option<u64>,
pub maxPostDataSize: Option<u64>,
pub reportDirectSocketTraffic: Option<bool>,
pub enableDurableMessages: Option<bool>,
}Expand description
Enables network tracking, network events will now be delivered to the client.
Fields
maxTotalBufferSize: Option<u64>Buffer size in bytes to use when preserving network payloads (XHRs, etc). This is the maximum number of bytes that will be collected by this DevTools session.
maxResourceBufferSize: Option<u64>Per-resource buffer size in bytes to use when preserving network payloads (XHRs, etc).
maxPostDataSize: Option<u64>Longest post body size (in bytes) that would be included in requestWillBeSent notification
reportDirectSocketTraffic: Option<bool>Whether DirectSocket chunk send/receive events should be reported.
enableDurableMessages: Option<bool>Enable storing response bodies outside of renderer, so that these survive a cross-process navigation. Requires maxTotalBufferSize to be set. Currently defaults to false. This field is being deprecated in favor of the dedicated configureDurableMessages command, due to the possibility of deadlocks when awaiting Network.enable before issuing Runtime.runIfWaitingForDebugger.