pub struct EnableParamsBuilder { /* private fields */ }Implementations
Sourceimpl EnableParamsBuilder
impl EnableParamsBuilder
Sourcepub fn maxTotalBufferSize(self, maxTotalBufferSize: u64) -> Self
pub fn maxTotalBufferSize(self, maxTotalBufferSize: u64) -> Self
Buffer size in bytes to use when preserving network payloads (XHRs, etc). This is the maximum number of bytes that will be collected by this DevTools session.
Sourcepub fn maxResourceBufferSize(self, maxResourceBufferSize: u64) -> Self
pub fn maxResourceBufferSize(self, maxResourceBufferSize: u64) -> Self
Per-resource buffer size in bytes to use when preserving network payloads (XHRs, etc).
Sourcepub fn maxPostDataSize(self, maxPostDataSize: u64) -> Self
pub fn maxPostDataSize(self, maxPostDataSize: u64) -> Self
Longest post body size (in bytes) that would be included in requestWillBeSent notification
Sourcepub fn reportDirectSocketTraffic(self, reportDirectSocketTraffic: bool) -> Self
pub fn reportDirectSocketTraffic(self, reportDirectSocketTraffic: bool) -> Self
Whether DirectSocket chunk send/receive events should be reported.
Sourcepub fn enableDurableMessages(self, enableDurableMessages: bool) -> Self
pub fn enableDurableMessages(self, enableDurableMessages: bool) -> Self
Enable storing response bodies outside of renderer, so that these survive a cross-process navigation. Requires maxTotalBufferSize to be set. Currently defaults to false. This field is being deprecated in favor of the dedicated configureDurableMessages command, due to the possibility of deadlocks when awaiting Network.enable before issuing Runtime.runIfWaitingForDebugger.