pub struct RefreshEventDetailsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> RefreshEventDetailsBuilder<'a>
impl<'a> RefreshEventDetailsBuilder<'a>
Sourcepub fn fetchResult(self, fetchResult: DeviceBoundSessionFetchResult) -> Self
pub fn fetchResult(self, fetchResult: DeviceBoundSessionFetchResult) -> Self
If there was a fetch attempt, the result of that.
Sourcepub fn newSession(self, newSession: DeviceBoundSession<'a>) -> Self
pub fn newSession(self, newSession: DeviceBoundSession<'a>) -> Self
The session display if there was a newly created session. This is populated for any refresh event that modifies the session config.
Sourcepub fn failedRequest(
self,
failedRequest: DeviceBoundSessionFailedRequest<'a>,
) -> Self
pub fn failedRequest( self, failedRequest: DeviceBoundSessionFailedRequest<'a>, ) -> Self
Details about a failed device bound session network request if there was one.
pub fn build(self) -> RefreshEventDetails<'a>