pub struct ReportingApiReport<'a> { /* private fields */ }Expand description
An object representing a report generated by the Reporting API.
Implementations
Sourceimpl<'a> ReportingApiReport<'a>
impl<'a> ReportingApiReport<'a>
Sourcepub fn builder(
id: impl Into<ReportId<'a>>,
initiator_url: impl Into<Cow<'a, str>>,
destination: impl Into<Cow<'a, str>>,
type_: impl Into<Cow<'a, str>>,
timestamp: TimeSinceEpoch,
depth: i64,
completed_attempts: i64,
body: Map<String, JsonValue>,
status: impl Into<ReportStatus>,
) -> ReportingApiReportBuilder<'a>
pub fn builder( id: impl Into<ReportId<'a>>, initiator_url: impl Into<Cow<'a, str>>, destination: impl Into<Cow<'a, str>>, type_: impl Into<Cow<'a, str>>, timestamp: TimeSinceEpoch, depth: i64, completed_attempts: i64, body: Map<String, JsonValue>, status: impl Into<ReportStatus>, ) -> ReportingApiReportBuilder<'a>
Creates a builder for this type with the required parameters:
id:initiator_url: The URL of the document that triggered the report.destination: The name of the endpoint group that should be used to deliver the report.type_: The type of the report (specifies the set of data that is contained in the report body).timestamp: When the report was generated.depth: How many uploads deep the related request was.completed_attempts: The number of delivery attempts made so far, not including an active attempt.body:status:
pub fn id(&self) -> &ReportId<'a>
Sourcepub fn initiator_url(&self) -> &str
pub fn initiator_url(&self) -> &str
The URL of the document that triggered the report.
Sourcepub fn destination(&self) -> &str
pub fn destination(&self) -> &str
The name of the endpoint group that should be used to deliver the report.
Sourcepub fn type_(&self) -> &str
pub fn type_(&self) -> &str
The type of the report (specifies the set of data that is contained in the report body).
Sourcepub fn timestamp(&self) -> &TimeSinceEpoch
pub fn timestamp(&self) -> &TimeSinceEpoch
When the report was generated.
Sourcepub fn completed_attempts(&self) -> i64
pub fn completed_attempts(&self) -> i64
The number of delivery attempts made so far, not including an active attempt.
pub fn body(&self) -> &Map<String, JsonValue>
pub fn status(&self) -> &ReportStatus