pub struct ReportingApiReport {
pub id: ReportId,
pub initiatorUrl: String,
pub destination: String,
pub type_: String,
pub timestamp: TimeSinceEpoch,
pub depth: i64,
pub completedAttempts: i64,
pub body: Map<String, Value>,
pub status: ReportStatus,
}Expand description
An object representing a report generated by the Reporting API.
Fields
id: ReportIdinitiatorUrl: StringThe URL of the document that triggered the report.
destination: StringThe name of the endpoint group that should be used to deliver the report.
type_: StringThe type of the report (specifies the set of data that is contained in the report body).
timestamp: TimeSinceEpochWhen the report was generated.
depth: i64How many uploads deep the related request was.
completedAttempts: i64The number of delivery attempts made so far, not including an active attempt.
body: Map<String, Value>status: ReportStatusTrait Implementations
Sourceimpl Clone for ReportingApiReport
impl Clone for ReportingApiReport
Sourcefn clone(&self) -> ReportingApiReport
fn clone(&self) -> ReportingApiReport
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReportingApiReport
impl Debug for ReportingApiReport
Sourceimpl Default for ReportingApiReport
impl Default for ReportingApiReport
Sourcefn default() -> ReportingApiReport
fn default() -> ReportingApiReport
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ReportingApiReport
impl<'de> Deserialize<'de> for ReportingApiReport
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more