pub struct Request {Show 14 fields
pub url: String,
pub urlFragment: Option<String>,
pub method: String,
pub headers: Headers,
pub postData: Option<String>,
pub hasPostData: Option<bool>,
pub postDataEntries: Option<Vec<PostDataEntry>>,
pub mixedContentType: Option<MixedContentType>,
pub initialPriority: ResourcePriority,
pub referrerPolicy: String,
pub isLinkPreload: Option<bool>,
pub trustTokenParams: Option<TrustTokenParams>,
pub isSameSite: Option<bool>,
pub isAdRelated: Option<bool>,
}Expand description
HTTP request data.
Fields
url: StringRequest URL (without fragment).
urlFragment: Option<String>Fragment of the requested URL starting with hash, if present.
method: StringHTTP request method.
headers: HeadersHTTP request headers.
postData: Option<String>HTTP POST request data. Use postDataEntries instead.
hasPostData: Option<bool>True when the request has POST data. Note that postData might still be omitted when this flag is true when the data is too long.
postDataEntries: Option<Vec<PostDataEntry>>Request body elements (post data broken into individual entries).
mixedContentType: Option<MixedContentType>The mixed content type of the request.
initialPriority: ResourcePriorityPriority of the resource request at the time request is sent.
referrerPolicy: StringThe referrer policy of the request, as defined in https://www.w3.org/TR/referrer-policy/
isLinkPreload: Option<bool>Whether is loaded via link preload.
trustTokenParams: Option<TrustTokenParams>Set for requests when the TrustToken API is used. Contains the parameters passed by the developer (e.g. via “fetch”) as understood by the backend.
isSameSite: Option<bool>True if this resource request is considered to be the ‘same site’ as the request corresponding to the main frame.
isAdRelated: Option<bool>True when the resource request is ad-related.