Request

Struct Request 

pub struct Request<'a> { /* private fields */ }
HTTP request data.

Implementations

Source

impl<'a> Request<'a>

pub fn builder( url: impl Into<Cow<'a, str>>, method: impl Into<Cow<'a, str>>, headers: Headers, initial_priority: impl Into<ResourcePriority>, referrer_policy: impl Into<Cow<'a, str>>, ) -> RequestBuilder<'a>

Creates a builder for this type with the required parameters:

  • url: Request URL (without fragment).
  • method: HTTP request method.
  • headers: HTTP request headers.
  • initial_priority: Priority of the resource request at the time request is sent.
  • referrer_policy: The referrer policy of the request, as defined in https://www.w3.org/TR/referrer-policy/
pub fn url(&self) -> &str

Request URL (without fragment).

pub fn url_fragment(&self) -> Option<&str>

Fragment of the requested URL starting with hash, if present.

pub fn method(&self) -> &str

HTTP request method.

pub fn headers(&self) -> &Headers

HTTP request headers.

pub fn post_data(&self) -> Option<&str>

HTTP POST request data. Use postDataEntries instead.

pub fn has_post_data(&self) -> Option<bool>

True when the request has POST data. Note that postData might still be omitted when this flag is true when the data is too long.

pub fn post_data_entries(&self) -> Option<&[PostDataEntry<'a>]>

Request body elements (post data broken into individual entries).

pub fn mixed_content_type(&self) -> Option<&MixedContentType>

The mixed content type of the request.

pub fn initial_priority(&self) -> &ResourcePriority

Priority of the resource request at the time request is sent.

pub fn referrer_policy(&self) -> &str

The referrer policy of the request, as defined in https://www.w3.org/TR/referrer-policy/

Whether is loaded via link preload.

pub fn trust_token_params(&self) -> Option<&TrustTokenParams<'a>>

Set for requests when the TrustToken API is used. Contains the parameters passed by the developer (e.g. via “fetch”) as understood by the backend.

pub fn is_same_site(&self) -> Option<bool>

True if this resource request is considered to be the ‘same site’ as the request corresponding to the main frame.

True when the resource request is ad-related.