pub struct RequestBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> RequestBuilder<'a>
impl<'a> RequestBuilder<'a>
Sourcepub fn url_fragment(self, url_fragment: impl Into<Cow<'a, str>>) -> Self
pub fn url_fragment(self, url_fragment: impl Into<Cow<'a, str>>) -> Self
Fragment of the requested URL starting with hash, if present.
Sourcepub fn post_data(self, post_data: impl Into<Cow<'a, str>>) -> Self
pub fn post_data(self, post_data: impl Into<Cow<'a, str>>) -> Self
HTTP POST request data. Use postDataEntries instead.
Sourcepub fn has_post_data(self, has_post_data: bool) -> Self
pub fn has_post_data(self, has_post_data: bool) -> Self
True when the request has POST data. Note that postData might still be omitted when this flag is true when the data is too long.
Sourcepub fn post_data_entries(
self,
post_data_entries: Vec<PostDataEntry<'a>>,
) -> Self
pub fn post_data_entries( self, post_data_entries: Vec<PostDataEntry<'a>>, ) -> Self
Request body elements (post data broken into individual entries).
Sourcepub fn mixed_content_type(self, mixed_content_type: MixedContentType) -> Self
pub fn mixed_content_type(self, mixed_content_type: MixedContentType) -> Self
The mixed content type of the request.
Sourcepub fn is_link_preload(self, is_link_preload: bool) -> Self
pub fn is_link_preload(self, is_link_preload: bool) -> Self
Whether is loaded via link preload.
Sourcepub fn trust_token_params(
self,
trust_token_params: TrustTokenParams<'a>,
) -> Self
pub fn trust_token_params( self, trust_token_params: TrustTokenParams<'a>, ) -> Self
Set for requests when the TrustToken API is used. Contains the parameters passed by the developer (e.g. via “fetch”) as understood by the backend.
Sourcepub fn is_same_site(self, is_same_site: bool) -> Self
pub fn is_same_site(self, is_same_site: bool) -> Self
True if this resource request is considered to be the ‘same site’ as the request corresponding to the main frame.
True when the resource request is ad-related.
pub fn build(self) -> Request<'a>