pub struct RequestBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> RequestBuilder<'a>
impl<'a> RequestBuilder<'a>
Sourcepub fn urlFragment(self, urlFragment: impl Into<Cow<'a, str>>) -> Self
pub fn urlFragment(self, urlFragment: impl Into<Cow<'a, str>>) -> Self
Fragment of the requested URL starting with hash, if present.
Sourcepub fn postData(self, postData: impl Into<Cow<'a, str>>) -> Self
pub fn postData(self, postData: impl Into<Cow<'a, str>>) -> Self
HTTP POST request data. Use postDataEntries instead.
Sourcepub fn hasPostData(self, hasPostData: bool) -> Self
pub fn hasPostData(self, hasPostData: bool) -> Self
True when the request has POST data. Note that postData might still be omitted when this flag is true when the data is too long.
Sourcepub fn postDataEntries(self, postDataEntries: Vec<PostDataEntry<'a>>) -> Self
pub fn postDataEntries(self, postDataEntries: Vec<PostDataEntry<'a>>) -> Self
Request body elements (post data broken into individual entries).
Sourcepub fn mixedContentType(self, mixedContentType: MixedContentType) -> Self
pub fn mixedContentType(self, mixedContentType: MixedContentType) -> Self
The mixed content type of the request.
Sourcepub fn isLinkPreload(self, isLinkPreload: bool) -> Self
pub fn isLinkPreload(self, isLinkPreload: bool) -> Self
Whether is loaded via link preload.
Sourcepub fn trustTokenParams(self, trustTokenParams: TrustTokenParams<'a>) -> Self
pub fn trustTokenParams(self, trustTokenParams: TrustTokenParams<'a>) -> Self
Set for requests when the TrustToken API is used. Contains the parameters passed by the developer (e.g. via “fetch”) as understood by the backend.
Sourcepub fn isSameSite(self, isSameSite: bool) -> Self
pub fn isSameSite(self, isSameSite: bool) -> Self
True if this resource request is considered to be the ‘same site’ as the request corresponding to the main frame.
Sourcepub fn isAdRelated(self, isAdRelated: bool) -> Self
pub fn isAdRelated(self, isAdRelated: bool) -> Self
True when the resource request is ad-related.
pub fn build(self) -> Request<'a>