ResourceTiming

Struct ResourceTiming 

pub struct ResourceTiming {
Show 21 fields pub requestTime: f64, pub proxyStart: f64, pub proxyEnd: f64, pub dnsStart: f64, pub dnsEnd: f64, pub connectStart: f64, pub connectEnd: f64, pub sslStart: f64, pub sslEnd: f64, pub workerStart: f64, pub workerReady: f64, pub workerFetchStart: f64, pub workerRespondWithSettled: f64, pub workerRouterEvaluationStart: Option<f64>, pub workerCacheLookupStart: Option<f64>, pub sendStart: f64, pub sendEnd: f64, pub pushStart: f64, pub pushEnd: f64, pub receiveHeadersStart: f64, pub receiveHeadersEnd: f64,
}
Timing information for the request.

Fields

requestTime: f64

Timing’s requestTime is a baseline in seconds, while the other numbers are ticks in milliseconds relatively to this requestTime.

proxyStart: f64

Started resolving proxy.

proxyEnd: f64

Finished resolving proxy.

dnsStart: f64

Started DNS address resolve.

dnsEnd: f64

Finished DNS address resolve.

connectStart: f64

Started connecting to the remote host.

connectEnd: f64

Connected to the remote host.

sslStart: f64

Started SSL handshake.

sslEnd: f64

Finished SSL handshake.

workerStart: f64

Started running ServiceWorker.

workerReady: f64

Finished Starting ServiceWorker.

workerFetchStart: f64

Started fetch event.

workerRespondWithSettled: f64

Settled fetch event respondWith promise.

workerRouterEvaluationStart: Option<f64>

Started ServiceWorker static routing source evaluation.

workerCacheLookupStart: Option<f64>

Started cache lookup when the source was evaluated to ‘cache’.

sendStart: f64

Started sending request.

sendEnd: f64

Finished sending request.

pushStart: f64

Time the server started pushing request.

pushEnd: f64

Time the server finished pushing request.

receiveHeadersStart: f64

Started receiving response headers.

receiveHeadersEnd: f64

Finished receiving response headers.