pub struct ResourceTiming {Show 21 fields
pub requestTime: f64,
pub proxyStart: f64,
pub proxyEnd: f64,
pub dnsStart: f64,
pub dnsEnd: f64,
pub connectStart: f64,
pub connectEnd: f64,
pub sslStart: f64,
pub sslEnd: f64,
pub workerStart: f64,
pub workerReady: f64,
pub workerFetchStart: f64,
pub workerRespondWithSettled: f64,
pub workerRouterEvaluationStart: Option<f64>,
pub workerCacheLookupStart: Option<f64>,
pub sendStart: f64,
pub sendEnd: f64,
pub pushStart: f64,
pub pushEnd: f64,
pub receiveHeadersStart: f64,
pub receiveHeadersEnd: f64,
}Expand description
Timing information for the request.
Fields
requestTime: f64Timing’s requestTime is a baseline in seconds, while the other numbers are ticks in milliseconds relatively to this requestTime.
proxyStart: f64Started resolving proxy.
proxyEnd: f64Finished resolving proxy.
dnsStart: f64Started DNS address resolve.
dnsEnd: f64Finished DNS address resolve.
connectStart: f64Started connecting to the remote host.
connectEnd: f64Connected to the remote host.
sslStart: f64Started SSL handshake.
sslEnd: f64Finished SSL handshake.
workerStart: f64Started running ServiceWorker.
workerReady: f64Finished Starting ServiceWorker.
workerFetchStart: f64Started fetch event.
workerRespondWithSettled: f64Settled fetch event respondWith promise.
workerRouterEvaluationStart: Option<f64>Started ServiceWorker static routing source evaluation.
workerCacheLookupStart: Option<f64>Started cache lookup when the source was evaluated to ‘cache’.
sendStart: f64Started sending request.
sendEnd: f64Finished sending request.
pushStart: f64Time the server started pushing request.
pushEnd: f64Time the server finished pushing request.
receiveHeadersStart: f64Started receiving response headers.
receiveHeadersEnd: f64Finished receiving response headers.