pub struct ResourceTiming { /* private fields */ }Expand description
Timing information for the request.
Implementations
Sourceimpl ResourceTiming
impl ResourceTiming
Sourcepub fn builder(
request_time: f64,
proxy_start: f64,
proxy_end: f64,
dns_start: f64,
dns_end: f64,
connect_start: f64,
connect_end: f64,
ssl_start: f64,
ssl_end: f64,
worker_start: f64,
worker_ready: f64,
worker_fetch_start: f64,
worker_respond_with_settled: f64,
send_start: f64,
send_end: f64,
push_start: f64,
push_end: f64,
receive_headers_start: f64,
receive_headers_end: f64,
) -> ResourceTimingBuilder
pub fn builder( request_time: f64, proxy_start: f64, proxy_end: f64, dns_start: f64, dns_end: f64, connect_start: f64, connect_end: f64, ssl_start: f64, ssl_end: f64, worker_start: f64, worker_ready: f64, worker_fetch_start: f64, worker_respond_with_settled: f64, send_start: f64, send_end: f64, push_start: f64, push_end: f64, receive_headers_start: f64, receive_headers_end: f64, ) -> ResourceTimingBuilder
Creates a builder for this type with the required parameters:
request_time: Timing’s requestTime is a baseline in seconds, while the other numbers are ticks in milliseconds relatively to this requestTime.proxy_start: Started resolving proxy.proxy_end: Finished resolving proxy.dns_start: Started DNS address resolve.dns_end: Finished DNS address resolve.connect_start: Started connecting to the remote host.connect_end: Connected to the remote host.ssl_start: Started SSL handshake.ssl_end: Finished SSL handshake.worker_start: Started running ServiceWorker.worker_ready: Finished Starting ServiceWorker.worker_fetch_start: Started fetch event.worker_respond_with_settled: Settled fetch event respondWith promise.send_start: Started sending request.send_end: Finished sending request.push_start: Time the server started pushing request.push_end: Time the server finished pushing request.receive_headers_start: Started receiving response headers.receive_headers_end: Finished receiving response headers.
Sourcepub fn request_time(&self) -> f64
pub fn request_time(&self) -> f64
Timing’s requestTime is a baseline in seconds, while the other numbers are ticks in milliseconds relatively to this requestTime.
Sourcepub fn proxy_start(&self) -> f64
pub fn proxy_start(&self) -> f64
Started resolving proxy.
Sourcepub fn connect_start(&self) -> f64
pub fn connect_start(&self) -> f64
Started connecting to the remote host.
Sourcepub fn connect_end(&self) -> f64
pub fn connect_end(&self) -> f64
Connected to the remote host.
Sourcepub fn worker_start(&self) -> f64
pub fn worker_start(&self) -> f64
Started running ServiceWorker.
Sourcepub fn worker_ready(&self) -> f64
pub fn worker_ready(&self) -> f64
Finished Starting ServiceWorker.
Sourcepub fn worker_fetch_start(&self) -> f64
pub fn worker_fetch_start(&self) -> f64
Started fetch event.
Sourcepub fn worker_respond_with_settled(&self) -> f64
pub fn worker_respond_with_settled(&self) -> f64
Settled fetch event respondWith promise.
Sourcepub fn worker_router_evaluation_start(&self) -> Option<f64>
pub fn worker_router_evaluation_start(&self) -> Option<f64>
Started ServiceWorker static routing source evaluation.
Sourcepub fn worker_cache_lookup_start(&self) -> Option<f64>
pub fn worker_cache_lookup_start(&self) -> Option<f64>
Started cache lookup when the source was evaluated to ‘cache’.
Sourcepub fn send_start(&self) -> f64
pub fn send_start(&self) -> f64
Started sending request.
Sourcepub fn push_start(&self) -> f64
pub fn push_start(&self) -> f64
Time the server started pushing request.
Sourcepub fn receive_headers_start(&self) -> f64
pub fn receive_headers_start(&self) -> f64
Started receiving response headers.
Sourcepub fn receive_headers_end(&self) -> f64
pub fn receive_headers_end(&self) -> f64
Finished receiving response headers.