pub struct Response {Show 27 fields
pub url: String,
pub status: i64,
pub statusText: String,
pub headers: Headers,
pub headersText: Option<String>,
pub mimeType: String,
pub charset: String,
pub requestHeaders: Option<Headers>,
pub requestHeadersText: Option<String>,
pub connectionReused: bool,
pub connectionId: f64,
pub remoteIPAddress: Option<String>,
pub remotePort: Option<i64>,
pub fromDiskCache: Option<bool>,
pub fromServiceWorker: Option<bool>,
pub fromPrefetchCache: Option<bool>,
pub fromEarlyHints: Option<bool>,
pub serviceWorkerRouterInfo: Option<ServiceWorkerRouterInfo>,
pub encodedDataLength: f64,
pub timing: Option<ResourceTiming>,
pub serviceWorkerResponseSource: Option<ServiceWorkerResponseSource>,
pub responseTime: Option<TimeSinceEpoch>,
pub cacheStorageCacheName: Option<String>,
pub protocol: Option<String>,
pub alternateProtocolUsage: Option<AlternateProtocolUsage>,
pub securityState: SecurityState,
pub securityDetails: Option<SecurityDetails>,
}Expand description
HTTP response data.
Fields
url: StringResponse URL. This URL can be different from CachedResource.url in case of redirect.
status: i64HTTP response status code.
statusText: StringHTTP response status text.
headers: HeadersHTTP response headers.
headersText: Option<String>HTTP response headers text. This has been replaced by the headers in Network.responseReceivedExtraInfo.
mimeType: StringResource mimeType as determined by the browser.
charset: StringResource charset as determined by the browser (if applicable).
requestHeaders: Option<Headers>Refined HTTP request headers that were actually transmitted over the network.
requestHeadersText: Option<String>HTTP request headers text. This has been replaced by the headers in Network.requestWillBeSentExtraInfo.
connectionReused: boolSpecifies whether physical connection was actually reused for this request.
connectionId: f64Physical connection id that was actually used for this request.
remoteIPAddress: Option<String>Remote IP address.
remotePort: Option<i64>Remote port.
fromDiskCache: Option<bool>Specifies that the request was served from the disk cache.
fromServiceWorker: Option<bool>Specifies that the request was served from the ServiceWorker.
fromPrefetchCache: Option<bool>Specifies that the request was served from the prefetch cache.
fromEarlyHints: Option<bool>Specifies that the request was served from the prefetch cache.
serviceWorkerRouterInfo: Option<ServiceWorkerRouterInfo>Information about how ServiceWorker Static Router API was used. If this field is set with ‘matchedSourceType’ field, a matching rule is found. If this field is set without ‘matchedSource’, no matching rule is found. Otherwise, the API is not used.
encodedDataLength: f64Total number of bytes received for this request so far.
timing: Option<ResourceTiming>Timing information for the given request.
serviceWorkerResponseSource: Option<ServiceWorkerResponseSource>Response source of response from ServiceWorker.
responseTime: Option<TimeSinceEpoch>The time at which the returned response was generated.
cacheStorageCacheName: Option<String>Cache Storage Cache Name.
protocol: Option<String>Protocol used to fetch this request.
alternateProtocolUsage: Option<AlternateProtocolUsage>The reason why Chrome uses a specific transport protocol for HTTP semantics.
securityState: SecurityStateSecurity state of the request resource.
securityDetails: Option<SecurityDetails>Security details for the request.