ResponseBuilder

Struct ResponseBuilder 

pub struct ResponseBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> ResponseBuilder<'a>

pub fn headersText(self, headersText: impl Into<Cow<'a, str>>) -> Self

HTTP response headers text. This has been replaced by the headers in Network.responseReceivedExtraInfo.

pub fn requestHeaders(self, requestHeaders: Headers) -> Self

Refined HTTP request headers that were actually transmitted over the network.

pub fn requestHeadersText( self, requestHeadersText: impl Into<Cow<'a, str>>, ) -> Self

HTTP request headers text. This has been replaced by the headers in Network.requestWillBeSentExtraInfo.

pub fn remoteIPAddress(self, remoteIPAddress: impl Into<Cow<'a, str>>) -> Self

Remote IP address.

pub fn remotePort(self, remotePort: i64) -> Self

Remote port.

pub fn fromDiskCache(self, fromDiskCache: bool) -> Self

Specifies that the request was served from the disk cache.

pub fn fromServiceWorker(self, fromServiceWorker: bool) -> Self

Specifies that the request was served from the ServiceWorker.

pub fn fromPrefetchCache(self, fromPrefetchCache: bool) -> Self

Specifies that the request was served from the prefetch cache.

pub fn fromEarlyHints(self, fromEarlyHints: bool) -> Self

Specifies that the request was served from the prefetch cache.

pub fn serviceWorkerRouterInfo( self, serviceWorkerRouterInfo: ServiceWorkerRouterInfo, ) -> Self

Information about how ServiceWorker Static Router API was used. If this field is set with ‘matchedSourceType’ field, a matching rule is found. If this field is set without ‘matchedSource’, no matching rule is found. Otherwise, the API is not used.

pub fn timing(self, timing: ResourceTiming) -> Self

Timing information for the given request.

pub fn serviceWorkerResponseSource( self, serviceWorkerResponseSource: ServiceWorkerResponseSource, ) -> Self

Response source of response from ServiceWorker.

pub fn responseTime(self, responseTime: TimeSinceEpoch) -> Self

The time at which the returned response was generated.

pub fn cacheStorageCacheName( self, cacheStorageCacheName: impl Into<Cow<'a, str>>, ) -> Self

Cache Storage Cache Name.

pub fn protocol(self, protocol: impl Into<Cow<'a, str>>) -> Self

Protocol used to fetch this request.

pub fn alternateProtocolUsage( self, alternateProtocolUsage: AlternateProtocolUsage, ) -> Self

The reason why Chrome uses a specific transport protocol for HTTP semantics.

pub fn securityDetails(self, securityDetails: SecurityDetails<'a>) -> Self

Security details for the request.

pub fn build(self) -> Response<'a>