pub struct ResponseBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ResponseBuilder<'a>
impl<'a> ResponseBuilder<'a>
Sourcepub fn headersText(self, headersText: impl Into<Cow<'a, str>>) -> Self
pub fn headersText(self, headersText: impl Into<Cow<'a, str>>) -> Self
HTTP response headers text. This has been replaced by the headers in Network.responseReceivedExtraInfo.
Sourcepub fn requestHeaders(self, requestHeaders: Headers) -> Self
pub fn requestHeaders(self, requestHeaders: Headers) -> Self
Refined HTTP request headers that were actually transmitted over the network.
Sourcepub fn requestHeadersText(
self,
requestHeadersText: impl Into<Cow<'a, str>>,
) -> Self
pub fn requestHeadersText( self, requestHeadersText: impl Into<Cow<'a, str>>, ) -> Self
HTTP request headers text. This has been replaced by the headers in Network.requestWillBeSentExtraInfo.
Sourcepub fn remoteIPAddress(self, remoteIPAddress: impl Into<Cow<'a, str>>) -> Self
pub fn remoteIPAddress(self, remoteIPAddress: impl Into<Cow<'a, str>>) -> Self
Remote IP address.
Sourcepub fn remotePort(self, remotePort: i64) -> Self
pub fn remotePort(self, remotePort: i64) -> Self
Remote port.
Sourcepub fn fromDiskCache(self, fromDiskCache: bool) -> Self
pub fn fromDiskCache(self, fromDiskCache: bool) -> Self
Specifies that the request was served from the disk cache.
Sourcepub fn fromServiceWorker(self, fromServiceWorker: bool) -> Self
pub fn fromServiceWorker(self, fromServiceWorker: bool) -> Self
Specifies that the request was served from the ServiceWorker.
Sourcepub fn fromPrefetchCache(self, fromPrefetchCache: bool) -> Self
pub fn fromPrefetchCache(self, fromPrefetchCache: bool) -> Self
Specifies that the request was served from the prefetch cache.
Sourcepub fn fromEarlyHints(self, fromEarlyHints: bool) -> Self
pub fn fromEarlyHints(self, fromEarlyHints: bool) -> Self
Specifies that the request was served from the prefetch cache.
Sourcepub fn serviceWorkerRouterInfo(
self,
serviceWorkerRouterInfo: ServiceWorkerRouterInfo,
) -> Self
pub fn serviceWorkerRouterInfo( self, serviceWorkerRouterInfo: ServiceWorkerRouterInfo, ) -> Self
Information about how ServiceWorker Static Router API was used. If this field is set with ‘matchedSourceType’ field, a matching rule is found. If this field is set without ‘matchedSource’, no matching rule is found. Otherwise, the API is not used.
Sourcepub fn timing(self, timing: ResourceTiming) -> Self
pub fn timing(self, timing: ResourceTiming) -> Self
Timing information for the given request.
Sourcepub fn serviceWorkerResponseSource(
self,
serviceWorkerResponseSource: ServiceWorkerResponseSource,
) -> Self
pub fn serviceWorkerResponseSource( self, serviceWorkerResponseSource: ServiceWorkerResponseSource, ) -> Self
Response source of response from ServiceWorker.
Sourcepub fn responseTime(self, responseTime: TimeSinceEpoch) -> Self
pub fn responseTime(self, responseTime: TimeSinceEpoch) -> Self
The time at which the returned response was generated.
Sourcepub fn cacheStorageCacheName(
self,
cacheStorageCacheName: impl Into<Cow<'a, str>>,
) -> Self
pub fn cacheStorageCacheName( self, cacheStorageCacheName: impl Into<Cow<'a, str>>, ) -> Self
Cache Storage Cache Name.
Sourcepub fn protocol(self, protocol: impl Into<Cow<'a, str>>) -> Self
pub fn protocol(self, protocol: impl Into<Cow<'a, str>>) -> Self
Protocol used to fetch this request.
Sourcepub fn alternateProtocolUsage(
self,
alternateProtocolUsage: AlternateProtocolUsage,
) -> Self
pub fn alternateProtocolUsage( self, alternateProtocolUsage: AlternateProtocolUsage, ) -> Self
The reason why Chrome uses a specific transport protocol for HTTP semantics.
Sourcepub fn securityDetails(self, securityDetails: SecurityDetails<'a>) -> Self
pub fn securityDetails(self, securityDetails: SecurityDetails<'a>) -> Self
Security details for the request.