SecurityDetails

Struct SecurityDetails 

pub struct SecurityDetails<'a> { /* private fields */ }
Security details about a request.

Implementations

Source

impl<'a> SecurityDetails<'a>

pub fn builder( protocol: impl Into<Cow<'a, str>>, key_exchange: impl Into<Cow<'a, str>>, cipher: impl Into<Cow<'a, str>>, certificate_id: CertificateId, subject_name: impl Into<Cow<'a, str>>, san_list: Vec<Cow<'a, str>>, issuer: impl Into<Cow<'a, str>>, valid_from: TimeSinceEpoch, valid_to: TimeSinceEpoch, signed_certificate_timestamp_list: Vec<SignedCertificateTimestamp<'a>>, certificate_transparency_compliance: impl Into<CertificateTransparencyCompliance>, encrypted_client_hello: bool, ) -> SecurityDetailsBuilder<'a>

Creates a builder for this type with the required parameters:

  • protocol: Protocol name (e.g. “TLS 1.2” or “QUIC”).
  • key_exchange: Key Exchange used by the connection, or the empty string if not applicable.
  • cipher: Cipher name.
  • certificate_id: Certificate ID value.
  • subject_name: Certificate subject name.
  • san_list: Subject Alternative Name (SAN) DNS names and IP addresses.
  • issuer: Name of the issuing CA.
  • valid_from: Certificate valid from date.
  • valid_to: Certificate valid to (expiration) date
  • signed_certificate_timestamp_list: List of signed certificate timestamps (SCTs).
  • certificate_transparency_compliance: Whether the request complied with Certificate Transparency policy
  • encrypted_client_hello: Whether the connection used Encrypted ClientHello
pub fn protocol(&self) -> &str

Protocol name (e.g. “TLS 1.2” or “QUIC”).

pub fn key_exchange(&self) -> &str

Key Exchange used by the connection, or the empty string if not applicable.

pub fn key_exchange_group(&self) -> Option<&str>

(EC)DH group used by the connection, if applicable.

pub fn cipher(&self) -> &str

Cipher name.

pub fn mac(&self) -> Option<&str>

TLS MAC. Note that AEAD ciphers do not have separate MACs.

pub fn certificate_id(&self) -> &CertificateId

Certificate ID value.

pub fn subject_name(&self) -> &str

Certificate subject name.

pub fn san_list(&self) -> &[Cow<'a, str>]

Subject Alternative Name (SAN) DNS names and IP addresses.

pub fn issuer(&self) -> &str

Name of the issuing CA.

pub fn valid_from(&self) -> &TimeSinceEpoch

Certificate valid from date.

pub fn valid_to(&self) -> &TimeSinceEpoch

Certificate valid to (expiration) date

pub fn signed_certificate_timestamp_list( &self, ) -> &[SignedCertificateTimestamp<'a>]

List of signed certificate timestamps (SCTs).

pub fn certificate_transparency_compliance( &self, ) -> &CertificateTransparencyCompliance

Whether the request complied with Certificate Transparency policy

pub fn server_signature_algorithm(&self) -> Option<i64>

The signature algorithm used by the server in the TLS server signature, represented as a TLS SignatureScheme code point. Omitted if not applicable or not known.

pub fn encrypted_client_hello(&self) -> bool

Whether the connection used Encrypted ClientHello