pub struct SecurityDetails {Show 15 fields
pub protocol: String,
pub keyExchange: String,
pub keyExchangeGroup: Option<String>,
pub cipher: String,
pub mac: Option<String>,
pub certificateId: CertificateId,
pub subjectName: String,
pub sanList: Vec<String>,
pub issuer: String,
pub validFrom: TimeSinceEpoch,
pub validTo: TimeSinceEpoch,
pub signedCertificateTimestampList: Vec<SignedCertificateTimestamp>,
pub certificateTransparencyCompliance: CertificateTransparencyCompliance,
pub serverSignatureAlgorithm: Option<i64>,
pub encryptedClientHello: bool,
}Expand description
Security details about a request.
Fields
protocol: StringProtocol name (e.g. “TLS 1.2” or “QUIC”).
keyExchange: StringKey Exchange used by the connection, or the empty string if not applicable.
keyExchangeGroup: Option<String>(EC)DH group used by the connection, if applicable.
cipher: StringCipher name.
mac: Option<String>TLS MAC. Note that AEAD ciphers do not have separate MACs.
certificateId: CertificateIdCertificate ID value.
subjectName: StringCertificate subject name.
sanList: Vec<String>Subject Alternative Name (SAN) DNS names and IP addresses.
issuer: StringName of the issuing CA.
validFrom: TimeSinceEpochCertificate valid from date.
validTo: TimeSinceEpochCertificate valid to (expiration) date
signedCertificateTimestampList: Vec<SignedCertificateTimestamp>List of signed certificate timestamps (SCTs).
certificateTransparencyCompliance: CertificateTransparencyComplianceWhether the request complied with Certificate Transparency policy
serverSignatureAlgorithm: Option<i64>The signature algorithm used by the server in the TLS server signature, represented as a TLS SignatureScheme code point. Omitted if not applicable or not known.
encryptedClientHello: boolWhether the connection used Encrypted ClientHello