pub struct TakeResponseBodyForInterceptionAsStreamReturns<'a> { /* private fields */ }Expand description
Returns a handle to the stream representing the response body. Note that after this command, the intercepted request can’t be continued as is – you either need to cancel it or to provide the response body. The stream only supports sequential read, IO.read will fail if the position is specified.
Implementations
Sourceimpl<'a> TakeResponseBodyForInterceptionAsStreamReturns<'a>
impl<'a> TakeResponseBodyForInterceptionAsStreamReturns<'a>
pub fn builder( stream: StreamHandle<'a>, ) -> TakeResponseBodyForInterceptionAsStreamReturnsBuilder<'a>
pub fn stream(&self) -> &StreamHandle<'a>