pub struct TrustTokenParams<'a> { /* private fields */ }Expand description
Determines what type of Trust Token operation is executed and depending on the type, some additional parameters. The values are specified in third_party/blink/renderer/core/fetch/trust_token.idl.
Implementations
Sourceimpl<'a> TrustTokenParams<'a>
impl<'a> TrustTokenParams<'a>
pub fn builder( operation: TrustTokenOperationType, refreshPolicy: impl Into<Cow<'a, str>>, ) -> TrustTokenParamsBuilder<'a>
pub fn operation(&self) -> &TrustTokenOperationType
pub fn refreshPolicy(&self) -> &str
pub fn issuers(&self) -> Option<&[Cow<'a, str>]>