Module overlay

Module overlay 

This domain provides various functionality related to drawing atop the inspected page.

Structs

BoxStyle
Style information for drawing a box.
ContainerQueryContainerHighlightConfig
ContainerQueryHighlightConfig
FlexContainerHighlightConfig
Configuration data for the highlighting of Flex container elements.
FlexItemHighlightConfig
Configuration data for the highlighting of Flex item elements.
FlexNodeHighlightConfig
GetGridHighlightObjectsForTestParams
For Persistent Grid testing.
GetGridHighlightObjectsForTestReturns
For Persistent Grid testing.
GetHighlightObjectForTestParams
For testing.
GetHighlightObjectForTestReturns
For testing.
GetSourceOrderHighlightObjectForTestParams
For Source Order Viewer testing.
GetSourceOrderHighlightObjectForTestReturns
For Source Order Viewer testing.
GridHighlightConfig
Configuration data for the highlighting of Grid elements.
GridNodeHighlightConfig
Configurations for Persistent Grid Highlight
HighlightConfig
Configuration data for the highlighting of page elements.
HighlightFrameParams
Highlights owner element of the frame with given id. Deprecated: Doesn’t work reliably and cannot be fixed due to process separation (the owner node might be in a different process). Determine the owner node in the client and use highlightNode.
HighlightNodeParams
Highlights DOM node with given id or with the given JavaScript object wrapper. Either nodeId or objectId must be specified.
HighlightQuadParams
Highlights given quad. Coordinates are absolute with respect to the main frame viewport.
HighlightRectParams
Highlights given rectangle. Coordinates are absolute with respect to the main frame viewport. Issue: the method does not handle device pixel ratio (DPR) correctly. The coordinates currently have to be adjusted by the client if DPR is not 1 (see crbug.com/437807128).
HighlightSourceOrderParams
Highlights the source order of the children of the DOM node with given id or with the given JavaScript object wrapper. Either nodeId or objectId must be specified.
HingeConfig
Configuration for dual screen hinge
InspectedElementAnchorConfig
IsolatedElementHighlightConfig
IsolationModeHighlightConfig
LineStyle
Style information for drawing a line.
ScrollSnapContainerHighlightConfig
ScrollSnapHighlightConfig
SetInspectModeParams
Enters the ‘inspect’ mode. In this mode, elements that user is hovering over are highlighted. Backend then generates ‘inspectNodeRequested’ event upon element selection.
SetPausedInDebuggerMessageParams
SetShowAdHighlightsParams
Highlights owner element of all frames detected to be ads.
SetShowContainerQueryOverlaysParams
SetShowDebugBordersParams
Requests that backend shows debug borders on layers
SetShowFPSCounterParams
Requests that backend shows the FPS counter
SetShowFlexOverlaysParams
SetShowGridOverlaysParams
Highlight multiple elements with the CSS Grid overlay.
SetShowHingeParams
Add a dual screen device hinge
SetShowHitTestBordersParams
Deprecated, no longer has any effect.
SetShowInspectedElementAnchorParams
SetShowIsolatedElementsParams
Show elements in isolation mode with overlays.
SetShowLayoutShiftRegionsParams
Requests that backend shows layout shift regions
SetShowPaintRectsParams
Requests that backend shows paint rectangles
SetShowScrollBottleneckRectsParams
Requests that backend shows scroll bottleneck rects
SetShowScrollSnapOverlaysParams
SetShowViewportSizeOnResizeParams
Paints viewport size upon main frame resize.
SetShowWebVitalsParams
Deprecated, no longer has any effect.
SetShowWindowControlsOverlayParams
Show Window Controls Overlay for PWA
SourceOrderConfig
Configuration data for drawing the source order of an elements children.
WindowControlsOverlayConfig
Configuration for Window Controls Overlay

Enums

ColorFormat
ContrastAlgorithm
InspectMode