This domain provides various functionality related to drawing atop the inspected page.
Structs
- BoxStyle
- Style information for drawing a box.
- Container
Query Container Highlight Config - Container
Query Highlight Config - Flex
Container Highlight Config - Configuration data for the highlighting of Flex container elements.
- Flex
Item Highlight Config - Configuration data for the highlighting of Flex item elements.
- Flex
Node Highlight Config - GetGrid
Highlight Objects ForTest Params - For Persistent Grid testing.
- GetGrid
Highlight Objects ForTest Returns - For Persistent Grid testing.
- GetHighlight
Object ForTest Params - For testing.
- GetHighlight
Object ForTest Returns - For testing.
- GetSource
Order Highlight Object ForTest Params - For Source Order Viewer testing.
- GetSource
Order Highlight Object ForTest Returns - For Source Order Viewer testing.
- Grid
Highlight Config - Configuration data for the highlighting of Grid elements.
- Grid
Node Highlight Config - Configurations for Persistent Grid Highlight
- Highlight
Config - Configuration data for the highlighting of page elements.
- Highlight
Frame Params - Highlights owner element of the frame with given id. Deprecated: Doesn’t work reliably and cannot be fixed due to process separation (the owner node might be in a different process). Determine the owner node in the client and use highlightNode.
- Highlight
Node Params - Highlights DOM node with given id or with the given JavaScript object wrapper. Either nodeId or objectId must be specified.
- Highlight
Quad Params - Highlights given quad. Coordinates are absolute with respect to the main frame viewport.
- Highlight
Rect Params - Highlights given rectangle. Coordinates are absolute with respect to the main frame viewport. Issue: the method does not handle device pixel ratio (DPR) correctly. The coordinates currently have to be adjusted by the client if DPR is not 1 (see crbug.com/437807128).
- Highlight
Source Order Params - Highlights the source order of the children of the DOM node with given id or with the given JavaScript object wrapper. Either nodeId or objectId must be specified.
- Hinge
Config - Configuration for dual screen hinge
- Inspected
Element Anchor Config - Isolated
Element Highlight Config - Isolation
Mode Highlight Config - Line
Style - Style information for drawing a line.
- Scroll
Snap Container Highlight Config - Scroll
Snap Highlight Config - SetInspect
Mode Params - Enters the ‘inspect’ mode. In this mode, elements that user is hovering over are highlighted. Backend then generates ‘inspectNodeRequested’ event upon element selection.
- SetPaused
InDebugger Message Params - SetShow
AdHighlights Params - Highlights owner element of all frames detected to be ads.
- SetShow
Container Query Overlays Params - SetShow
Debug Borders Params - Requests that backend shows debug borders on layers
- SetShowFPS
Counter Params - Requests that backend shows the FPS counter
- SetShow
Flex Overlays Params - SetShow
Grid Overlays Params - Highlight multiple elements with the CSS Grid overlay.
- SetShow
Hinge Params - Add a dual screen device hinge
- SetShow
HitTest Borders Params - Deprecated, no longer has any effect.
- SetShow
Inspected Element Anchor Params - SetShow
Isolated Elements Params - Show elements in isolation mode with overlays.
- SetShow
Layout Shift Regions Params - Requests that backend shows layout shift regions
- SetShow
Paint Rects Params - Requests that backend shows paint rectangles
- SetShow
Scroll Bottleneck Rects Params - Requests that backend shows scroll bottleneck rects
- SetShow
Scroll Snap Overlays Params - SetShow
Viewport Size OnResize Params - Paints viewport size upon main frame resize.
- SetShow
WebVitals Params - Deprecated, no longer has any effect.
- SetShow
Window Controls Overlay Params - Show Window Controls Overlay for PWA
- Source
Order Config - Configuration data for drawing the source order of an elements children.
- Window
Controls Overlay Config - Configuration for Window Controls Overlay