pub struct FlexContainerHighlightConfig {
pub containerBorder: Option<LineStyle>,
pub lineSeparator: Option<LineStyle>,
pub itemSeparator: Option<LineStyle>,
pub mainDistributedSpace: Option<BoxStyle>,
pub crossDistributedSpace: Option<BoxStyle>,
pub rowGapSpace: Option<BoxStyle>,
pub columnGapSpace: Option<BoxStyle>,
pub crossAlignment: Option<LineStyle>,
}Expand description
Configuration data for the highlighting of Flex container elements.
Fields
containerBorder: Option<LineStyle>The style of the container border
lineSeparator: Option<LineStyle>The style of the separator between lines
itemSeparator: Option<LineStyle>The style of the separator between items
mainDistributedSpace: Option<BoxStyle>Style of content-distribution space on the main axis (justify-content).
crossDistributedSpace: Option<BoxStyle>Style of content-distribution space on the cross axis (align-content).
rowGapSpace: Option<BoxStyle>Style of empty space caused by row gaps (gap/row-gap).
columnGapSpace: Option<BoxStyle>Style of empty space caused by columns gaps (gap/column-gap).
crossAlignment: Option<LineStyle>Style of the self-alignment line (align-items).