pub struct FlexContainerHighlightConfigBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> FlexContainerHighlightConfigBuilder<'a>
impl<'a> FlexContainerHighlightConfigBuilder<'a>
Sourcepub fn container_border(self, container_border: LineStyle<'a>) -> Self
pub fn container_border(self, container_border: LineStyle<'a>) -> Self
The style of the container border
Sourcepub fn line_separator(self, line_separator: LineStyle<'a>) -> Self
pub fn line_separator(self, line_separator: LineStyle<'a>) -> Self
The style of the separator between lines
Sourcepub fn item_separator(self, item_separator: LineStyle<'a>) -> Self
pub fn item_separator(self, item_separator: LineStyle<'a>) -> Self
The style of the separator between items
Sourcepub fn main_distributed_space(self, main_distributed_space: BoxStyle) -> Self
pub fn main_distributed_space(self, main_distributed_space: BoxStyle) -> Self
Style of content-distribution space on the main axis (justify-content).
Sourcepub fn cross_distributed_space(self, cross_distributed_space: BoxStyle) -> Self
pub fn cross_distributed_space(self, cross_distributed_space: BoxStyle) -> Self
Style of content-distribution space on the cross axis (align-content).
Sourcepub fn row_gap_space(self, row_gap_space: BoxStyle) -> Self
pub fn row_gap_space(self, row_gap_space: BoxStyle) -> Self
Style of empty space caused by row gaps (gap/row-gap).
Sourcepub fn column_gap_space(self, column_gap_space: BoxStyle) -> Self
pub fn column_gap_space(self, column_gap_space: BoxStyle) -> Self
Style of empty space caused by columns gaps (gap/column-gap).
Sourcepub fn cross_alignment(self, cross_alignment: LineStyle<'a>) -> Self
pub fn cross_alignment(self, cross_alignment: LineStyle<'a>) -> Self
Style of the self-alignment line (align-items).
pub fn build(self) -> FlexContainerHighlightConfig<'a>