pub struct FlexContainerHighlightConfigBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> FlexContainerHighlightConfigBuilder<'a>
impl<'a> FlexContainerHighlightConfigBuilder<'a>
Sourcepub fn containerBorder(self, containerBorder: LineStyle<'a>) -> Self
pub fn containerBorder(self, containerBorder: LineStyle<'a>) -> Self
The style of the container border
Sourcepub fn lineSeparator(self, lineSeparator: LineStyle<'a>) -> Self
pub fn lineSeparator(self, lineSeparator: LineStyle<'a>) -> Self
The style of the separator between lines
Sourcepub fn itemSeparator(self, itemSeparator: LineStyle<'a>) -> Self
pub fn itemSeparator(self, itemSeparator: LineStyle<'a>) -> Self
The style of the separator between items
Sourcepub fn mainDistributedSpace(self, mainDistributedSpace: BoxStyle) -> Self
pub fn mainDistributedSpace(self, mainDistributedSpace: BoxStyle) -> Self
Style of content-distribution space on the main axis (justify-content).
Sourcepub fn crossDistributedSpace(self, crossDistributedSpace: BoxStyle) -> Self
pub fn crossDistributedSpace(self, crossDistributedSpace: BoxStyle) -> Self
Style of content-distribution space on the cross axis (align-content).
Sourcepub fn rowGapSpace(self, rowGapSpace: BoxStyle) -> Self
pub fn rowGapSpace(self, rowGapSpace: BoxStyle) -> Self
Style of empty space caused by row gaps (gap/row-gap).
Sourcepub fn columnGapSpace(self, columnGapSpace: BoxStyle) -> Self
pub fn columnGapSpace(self, columnGapSpace: BoxStyle) -> Self
Style of empty space caused by columns gaps (gap/column-gap).
Sourcepub fn crossAlignment(self, crossAlignment: LineStyle<'a>) -> Self
pub fn crossAlignment(self, crossAlignment: LineStyle<'a>) -> Self
Style of the self-alignment line (align-items).
pub fn build(self) -> FlexContainerHighlightConfig<'a>