pub struct FlexItemHighlightConfig {
pub baseSizeBox: Option<BoxStyle>,
pub baseSizeBorder: Option<LineStyle>,
pub flexibilityArrow: Option<LineStyle>,
}Expand description
Configuration data for the highlighting of Flex item elements.
Fields
baseSizeBox: Option<BoxStyle>Style of the box representing the item’s base size
baseSizeBorder: Option<LineStyle>Style of the border around the box representing the item’s base size
flexibilityArrow: Option<LineStyle>Style of the arrow representing if the item grew or shrank