pub struct HighlightConfig {Show 19 fields
pub showInfo: Option<bool>,
pub showStyles: Option<bool>,
pub showRulers: Option<bool>,
pub showAccessibilityInfo: Option<bool>,
pub showExtensionLines: Option<bool>,
pub contentColor: Option<RGBA>,
pub paddingColor: Option<RGBA>,
pub borderColor: Option<RGBA>,
pub marginColor: Option<RGBA>,
pub eventTargetColor: Option<RGBA>,
pub shapeColor: Option<RGBA>,
pub shapeMarginColor: Option<RGBA>,
pub cssGridColor: Option<RGBA>,
pub colorFormat: Option<ColorFormat>,
pub gridHighlightConfig: Option<GridHighlightConfig>,
pub flexContainerHighlightConfig: Option<FlexContainerHighlightConfig>,
pub flexItemHighlightConfig: Option<FlexItemHighlightConfig>,
pub contrastAlgorithm: Option<ContrastAlgorithm>,
pub containerQueryContainerHighlightConfig: Option<ContainerQueryContainerHighlightConfig>,
}Expand description
Configuration data for the highlighting of page elements.
Fields
showInfo: Option<bool>Whether the node info tooltip should be shown (default: false).
showStyles: Option<bool>Whether the node styles in the tooltip (default: false).
showRulers: Option<bool>Whether the rulers should be shown (default: false).
showAccessibilityInfo: Option<bool>Whether the a11y info should be shown (default: true).
showExtensionLines: Option<bool>Whether the extension lines from node to the rulers should be shown (default: false).
contentColor: Option<RGBA>The content box highlight fill color (default: transparent).
paddingColor: Option<RGBA>The padding highlight fill color (default: transparent).
borderColor: Option<RGBA>The border highlight fill color (default: transparent).
marginColor: Option<RGBA>The margin highlight fill color (default: transparent).
eventTargetColor: Option<RGBA>The event target element highlight fill color (default: transparent).
shapeColor: Option<RGBA>The shape outside fill color (default: transparent).
shapeMarginColor: Option<RGBA>The shape margin fill color (default: transparent).
cssGridColor: Option<RGBA>The grid layout color (default: transparent).
colorFormat: Option<ColorFormat>The color format used to format color styles (default: hex).
gridHighlightConfig: Option<GridHighlightConfig>The grid layout highlight configuration (default: all transparent).
flexContainerHighlightConfig: Option<FlexContainerHighlightConfig>The flex container highlight configuration (default: all transparent).
flexItemHighlightConfig: Option<FlexItemHighlightConfig>The flex item highlight configuration (default: all transparent).
contrastAlgorithm: Option<ContrastAlgorithm>The contrast algorithm to use for the contrast ratio (default: aa).
containerQueryContainerHighlightConfig: Option<ContainerQueryContainerHighlightConfig>The container query container highlight configuration (default: all transparent).