HighlightConfigBuilder

Struct HighlightConfigBuilder 

pub struct HighlightConfigBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> HighlightConfigBuilder<'a>

pub fn showInfo(self, showInfo: bool) -> Self

Whether the node info tooltip should be shown (default: false).

pub fn showStyles(self, showStyles: bool) -> Self

Whether the node styles in the tooltip (default: false).

pub fn showRulers(self, showRulers: bool) -> Self

Whether the rulers should be shown (default: false).

pub fn showAccessibilityInfo(self, showAccessibilityInfo: bool) -> Self

Whether the a11y info should be shown (default: true).

pub fn showExtensionLines(self, showExtensionLines: bool) -> Self

Whether the extension lines from node to the rulers should be shown (default: false).

pub fn contentColor(self, contentColor: RGBA) -> Self

The content box highlight fill color (default: transparent).

pub fn paddingColor(self, paddingColor: RGBA) -> Self

The padding highlight fill color (default: transparent).

pub fn borderColor(self, borderColor: RGBA) -> Self

The border highlight fill color (default: transparent).

pub fn marginColor(self, marginColor: RGBA) -> Self

The margin highlight fill color (default: transparent).

pub fn eventTargetColor(self, eventTargetColor: RGBA) -> Self

The event target element highlight fill color (default: transparent).

pub fn shapeColor(self, shapeColor: RGBA) -> Self

The shape outside fill color (default: transparent).

pub fn shapeMarginColor(self, shapeMarginColor: RGBA) -> Self

The shape margin fill color (default: transparent).

pub fn cssGridColor(self, cssGridColor: RGBA) -> Self

The grid layout color (default: transparent).

pub fn colorFormat(self, colorFormat: ColorFormat) -> Self

The color format used to format color styles (default: hex).

pub fn gridHighlightConfig( self, gridHighlightConfig: GridHighlightConfig, ) -> Self

The grid layout highlight configuration (default: all transparent).

pub fn flexContainerHighlightConfig( self, flexContainerHighlightConfig: FlexContainerHighlightConfig<'a>, ) -> Self

The flex container highlight configuration (default: all transparent).

pub fn flexItemHighlightConfig( self, flexItemHighlightConfig: FlexItemHighlightConfig<'a>, ) -> Self

The flex item highlight configuration (default: all transparent).

pub fn contrastAlgorithm(self, contrastAlgorithm: ContrastAlgorithm) -> Self

The contrast algorithm to use for the contrast ratio (default: aa).

pub fn containerQueryContainerHighlightConfig( self, containerQueryContainerHighlightConfig: ContainerQueryContainerHighlightConfig<'a>, ) -> Self

The container query container highlight configuration (default: all transparent).

pub fn build(self) -> HighlightConfig<'a>