pub struct HighlightConfigBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> HighlightConfigBuilder<'a>
impl<'a> HighlightConfigBuilder<'a>
Sourcepub fn showInfo(self, showInfo: bool) -> Self
pub fn showInfo(self, showInfo: bool) -> Self
Whether the node info tooltip should be shown (default: false).
Sourcepub fn showStyles(self, showStyles: bool) -> Self
pub fn showStyles(self, showStyles: bool) -> Self
Whether the node styles in the tooltip (default: false).
Sourcepub fn showRulers(self, showRulers: bool) -> Self
pub fn showRulers(self, showRulers: bool) -> Self
Whether the rulers should be shown (default: false).
Sourcepub fn showAccessibilityInfo(self, showAccessibilityInfo: bool) -> Self
pub fn showAccessibilityInfo(self, showAccessibilityInfo: bool) -> Self
Whether the a11y info should be shown (default: true).
Sourcepub fn showExtensionLines(self, showExtensionLines: bool) -> Self
pub fn showExtensionLines(self, showExtensionLines: bool) -> Self
Whether the extension lines from node to the rulers should be shown (default: false).
Sourcepub fn contentColor(self, contentColor: RGBA) -> Self
pub fn contentColor(self, contentColor: RGBA) -> Self
The content box highlight fill color (default: transparent).
Sourcepub fn paddingColor(self, paddingColor: RGBA) -> Self
pub fn paddingColor(self, paddingColor: RGBA) -> Self
The padding highlight fill color (default: transparent).
Sourcepub fn borderColor(self, borderColor: RGBA) -> Self
pub fn borderColor(self, borderColor: RGBA) -> Self
The border highlight fill color (default: transparent).
Sourcepub fn marginColor(self, marginColor: RGBA) -> Self
pub fn marginColor(self, marginColor: RGBA) -> Self
The margin highlight fill color (default: transparent).
Sourcepub fn eventTargetColor(self, eventTargetColor: RGBA) -> Self
pub fn eventTargetColor(self, eventTargetColor: RGBA) -> Self
The event target element highlight fill color (default: transparent).
Sourcepub fn shapeColor(self, shapeColor: RGBA) -> Self
pub fn shapeColor(self, shapeColor: RGBA) -> Self
The shape outside fill color (default: transparent).
Sourcepub fn shapeMarginColor(self, shapeMarginColor: RGBA) -> Self
pub fn shapeMarginColor(self, shapeMarginColor: RGBA) -> Self
The shape margin fill color (default: transparent).
Sourcepub fn cssGridColor(self, cssGridColor: RGBA) -> Self
pub fn cssGridColor(self, cssGridColor: RGBA) -> Self
The grid layout color (default: transparent).
Sourcepub fn colorFormat(self, colorFormat: ColorFormat) -> Self
pub fn colorFormat(self, colorFormat: ColorFormat) -> Self
The color format used to format color styles (default: hex).
Sourcepub fn gridHighlightConfig(
self,
gridHighlightConfig: GridHighlightConfig,
) -> Self
pub fn gridHighlightConfig( self, gridHighlightConfig: GridHighlightConfig, ) -> Self
The grid layout highlight configuration (default: all transparent).
Sourcepub fn flexContainerHighlightConfig(
self,
flexContainerHighlightConfig: FlexContainerHighlightConfig<'a>,
) -> Self
pub fn flexContainerHighlightConfig( self, flexContainerHighlightConfig: FlexContainerHighlightConfig<'a>, ) -> Self
The flex container highlight configuration (default: all transparent).
Sourcepub fn flexItemHighlightConfig(
self,
flexItemHighlightConfig: FlexItemHighlightConfig<'a>,
) -> Self
pub fn flexItemHighlightConfig( self, flexItemHighlightConfig: FlexItemHighlightConfig<'a>, ) -> Self
The flex item highlight configuration (default: all transparent).
Sourcepub fn contrastAlgorithm(self, contrastAlgorithm: ContrastAlgorithm) -> Self
pub fn contrastAlgorithm(self, contrastAlgorithm: ContrastAlgorithm) -> Self
The contrast algorithm to use for the contrast ratio (default: aa).
Sourcepub fn containerQueryContainerHighlightConfig(
self,
containerQueryContainerHighlightConfig: ContainerQueryContainerHighlightConfig<'a>,
) -> Self
pub fn containerQueryContainerHighlightConfig( self, containerQueryContainerHighlightConfig: ContainerQueryContainerHighlightConfig<'a>, ) -> Self
The container query container highlight configuration (default: all transparent).