pub struct HighlightFrameParams {
pub frameId: FrameId,
pub contentColor: Option<RGBA>,
pub contentOutlineColor: Option<RGBA>,
}Expand description
Highlights owner element of the frame with given id. Deprecated: Doesn’t work reliably and cannot be fixed due to process separation (the owner node might be in a different process). Determine the owner node in the client and use highlightNode.
Fields
frameId: FrameIdIdentifier of the frame to highlight.
contentColor: Option<RGBA>The content box highlight fill color (default: transparent).
contentOutlineColor: Option<RGBA>The content box highlight outline color (default: transparent).