HighlightSourceOrderParams

Struct HighlightSourceOrderParams 

pub struct HighlightSourceOrderParams<'a> { /* private fields */ }
Highlights the source order of the children of the DOM node with given id or with the given JavaScript object wrapper. Either nodeId or objectId must be specified.

Implementations

Source

impl<'a> HighlightSourceOrderParams<'a>

Source

impl<'a> HighlightSourceOrderParams<'a>

pub const METHOD: &'static str = "Overlay.highlightSourceOrder"