pub struct HighlightSourceOrderParams<'a> { /* private fields */ }Expand description
Highlights the source order of the children of the DOM node with given id or with the given JavaScript object wrapper. Either nodeId or objectId must be specified.
Implementations
Sourceimpl<'a> HighlightSourceOrderParams<'a>
impl<'a> HighlightSourceOrderParams<'a>
pub fn builder( sourceOrderConfig: SourceOrderConfig, ) -> HighlightSourceOrderParamsBuilder<'a>
pub fn sourceOrderConfig(&self) -> &SourceOrderConfig
pub fn nodeId(&self) -> Option<&NodeId>
pub fn backendNodeId(&self) -> Option<&BackendNodeId>
pub fn objectId(&self) -> Option<&RemoteObjectId<'a>>