HighlightSourceOrderParams

Struct HighlightSourceOrderParams 

pub struct HighlightSourceOrderParams {
    pub sourceOrderConfig: SourceOrderConfig,
    pub nodeId: Option<NodeId>,
    pub backendNodeId: Option<BackendNodeId>,
    pub objectId: Option<RemoteObjectId>,
}
Highlights the source order of the children of the DOM node with given id or with the given JavaScript object wrapper. Either nodeId or objectId must be specified.

Fields

sourceOrderConfig: SourceOrderConfig

A descriptor for the appearance of the overlay drawing.

nodeId: Option<NodeId>

Identifier of the node to highlight.

backendNodeId: Option<BackendNodeId>

Identifier of the backend node to highlight.

objectId: Option<RemoteObjectId>

JavaScript object id of the node to be highlighted.