Module page

Module page 

Actions and events related to the inspected page belong to the page domain.

Structs

AdFrameStatus
Indicates whether a frame has been identified as an ad and why.
AdFrameStatusBuilder
AddCompilationCacheParams
Seeds compilation cache for given url. Compilation cache does not survive cross-process navigation.
AddCompilationCacheParamsBuilder
AddScriptToEvaluateOnLoadParams
Deprecated, please use addScriptToEvaluateOnNewDocument instead.
AddScriptToEvaluateOnLoadParamsBuilder
AddScriptToEvaluateOnLoadReturns
Deprecated, please use addScriptToEvaluateOnNewDocument instead.
AddScriptToEvaluateOnLoadReturnsBuilder
AddScriptToEvaluateOnNewDocumentParams
Evaluates given script in every frame upon creation (before loading frame’s scripts).
AddScriptToEvaluateOnNewDocumentParamsBuilder
AddScriptToEvaluateOnNewDocumentReturns
Evaluates given script in every frame upon creation (before loading frame’s scripts).
AddScriptToEvaluateOnNewDocumentReturnsBuilder
AppManifestError
Error while paring app manifest.
AppManifestErrorBuilder
AppManifestParsedProperties
Parsed app manifest properties.
AppManifestParsedPropertiesBuilder
BackForwardCacheBlockingDetails
BackForwardCacheBlockingDetailsBuilder
BackForwardCacheNotRestoredExplanation
BackForwardCacheNotRestoredExplanationBuilder
BackForwardCacheNotRestoredExplanationTree
BackForwardCacheNotRestoredExplanationTreeBuilder
BringToFrontParams
CaptureScreenshotParams
Capture page screenshot.
CaptureScreenshotParamsBuilder
CaptureScreenshotReturns
Capture page screenshot.
CaptureScreenshotReturnsBuilder
CaptureSnapshotParams
Returns a snapshot of the page as a string. For MHTML format, the serialization includes iframes, shadow DOM, external resources, and element-inline styles.
CaptureSnapshotParamsBuilder
CaptureSnapshotReturns
Returns a snapshot of the page as a string. For MHTML format, the serialization includes iframes, shadow DOM, external resources, and element-inline styles.
CaptureSnapshotReturnsBuilder
ClearCompilationCacheParams
ClearDeviceMetricsOverrideParams
ClearDeviceOrientationOverrideParams
ClearGeolocationOverrideParams
CloseParams
CompilationCacheParams
Per-script compilation cache parameters for ‘Page.produceCompilationCache’
CompilationCacheParamsBuilder
CrashParams
CreateIsolatedWorldParams
Creates an isolated world for the given frame.
CreateIsolatedWorldParamsBuilder
CreateIsolatedWorldReturns
Creates an isolated world for the given frame.
CreateIsolatedWorldReturnsBuilder
DeleteCookieParams
Deletes browser cookie with given name, domain and path.
DeleteCookieParamsBuilder
DisableParams
EnableParams
Enables page domain notifications.
EnableParamsBuilder
FileFilter
FileFilterBuilder
FileHandler
FileHandlerBuilder
FontFamilies
Generic font families collection.
FontFamiliesBuilder
FontSizes
Default font sizes.
FontSizesBuilder
Frame
Information about the Frame on the page.
FrameBuilder
FrameResource
Information about the Resource on the page.
FrameResourceBuilder
FrameResourceTree
Information about the Frame hierarchy along with their cached resources.
FrameResourceTreeBuilder
FrameTree
Information about the Frame hierarchy.
FrameTreeBuilder
GenerateTestReportParams
Generates a report for testing.
GenerateTestReportParamsBuilder
GetAdScriptAncestryParams
GetAdScriptAncestryParamsBuilder
GetAdScriptAncestryReturns
GetAdScriptAncestryReturnsBuilder
GetAnnotatedPageContentParams
Get the annotated page content for the main frame. This is an experimental command that is subject to change.
GetAnnotatedPageContentParamsBuilder
GetAnnotatedPageContentReturns
Get the annotated page content for the main frame. This is an experimental command that is subject to change.
GetAnnotatedPageContentReturnsBuilder
GetAppIdParams
GetAppIdReturns
Returns the unique (PWA) app id. Only returns values if the feature flag ‘WebAppEnableManifestId’ is enabled
GetAppIdReturnsBuilder
GetAppManifestParams
Gets the processed manifest for this current document. This API always waits for the manifest to be loaded. If manifestId is provided, and it does not match the manifest of the current document, this API errors out. If there is not a loaded page, this API errors out immediately.
GetAppManifestParamsBuilder
GetAppManifestReturns
Gets the processed manifest for this current document. This API always waits for the manifest to be loaded. If manifestId is provided, and it does not match the manifest of the current document, this API errors out. If there is not a loaded page, this API errors out immediately.
GetAppManifestReturnsBuilder
GetFrameTreeParams
GetFrameTreeReturns
Returns present frame tree structure.
GetFrameTreeReturnsBuilder
GetInstallabilityErrorsParams
GetInstallabilityErrorsReturns
GetInstallabilityErrorsReturnsBuilder
GetLayoutMetricsParams
GetLayoutMetricsReturns
Returns metrics relating to the layouting of the page, such as viewport bounds/scale.
GetLayoutMetricsReturnsBuilder
GetManifestIconsParams
GetManifestIconsReturns
Deprecated because it’s not guaranteed that the returned icon is in fact the one used for PWA installation.
GetManifestIconsReturnsBuilder
GetNavigationHistoryParams
GetNavigationHistoryReturns
Returns navigation history for the current page.
GetNavigationHistoryReturnsBuilder
GetOriginTrialsParams
Get Origin Trials on given frame.
GetOriginTrialsParamsBuilder
GetOriginTrialsReturns
Get Origin Trials on given frame.
GetOriginTrialsReturnsBuilder
GetPermissionsPolicyStateParams
Get Permissions Policy state on given frame.
GetPermissionsPolicyStateParamsBuilder
GetPermissionsPolicyStateReturns
Get Permissions Policy state on given frame.
GetPermissionsPolicyStateReturnsBuilder
GetResourceContentParams
Returns content of the given resource.
GetResourceContentParamsBuilder
GetResourceContentReturns
Returns content of the given resource.
GetResourceContentReturnsBuilder
GetResourceTreeParams
GetResourceTreeReturns
Returns present frame / resource tree structure.
GetResourceTreeReturnsBuilder
HandleJavaScriptDialogParams
Accepts or dismisses a JavaScript initiated dialog (alert, confirm, prompt, or onbeforeunload).
HandleJavaScriptDialogParamsBuilder
ImageResource
The image definition used in both icon and screenshot.
ImageResourceBuilder
InstallabilityError
The installability error
InstallabilityErrorArgument
InstallabilityErrorArgumentBuilder
InstallabilityErrorBuilder
LaunchHandler
LaunchHandlerBuilder
LayoutViewport
Layout viewport position and dimensions.
LayoutViewportBuilder
NavigateParams
Navigates current page to the given URL.
NavigateParamsBuilder
NavigateReturns
Navigates current page to the given URL.
NavigateReturnsBuilder
NavigateToHistoryEntryParams
Navigates current page to the given history entry.
NavigateToHistoryEntryParamsBuilder
NavigationEntry
Navigation history entry.
NavigationEntryBuilder
OriginTrial
OriginTrialBuilder
OriginTrialToken
OriginTrialTokenBuilder
OriginTrialTokenWithStatus
OriginTrialTokenWithStatusBuilder
PermissionsPolicyBlockLocator
PermissionsPolicyBlockLocatorBuilder
PermissionsPolicyFeatureState
PermissionsPolicyFeatureStateBuilder
PrintToPDFParams
Print page as PDF.
PrintToPDFParamsBuilder
PrintToPDFReturns
Print page as PDF.
PrintToPDFReturnsBuilder
ProduceCompilationCacheParams
Requests backend to produce compilation cache for the specified scripts. ‘scripts’ are appended to the list of scripts for which the cache would be produced. The list may be reset during page navigation. When script with a matching URL is encountered, the cache is optionally produced upon backend discretion, based on internal heuristics. See also: ‘Page.compilationCacheProduced’.
ProduceCompilationCacheParamsBuilder
ProtocolHandler
ProtocolHandlerBuilder
RelatedApplication
RelatedApplicationBuilder
ReloadParams
Reloads given page optionally ignoring the cache.
ReloadParamsBuilder
RemoveScriptToEvaluateOnLoadParams
Deprecated, please use removeScriptToEvaluateOnNewDocument instead.
RemoveScriptToEvaluateOnLoadParamsBuilder
RemoveScriptToEvaluateOnNewDocumentParams
Removes given script from the list.
RemoveScriptToEvaluateOnNewDocumentParamsBuilder
ResetNavigationHistoryParams
ScopeExtension
ScopeExtensionBuilder
ScreencastFrameAckParams
Acknowledges that a screencast frame has been received by the frontend.
ScreencastFrameAckParamsBuilder
ScreencastFrameMetadata
Screencast frame metadata.
ScreencastFrameMetadataBuilder
Screenshot
ScreenshotBuilder
ScriptFontFamilies
Font families collection for a script.
ScriptFontFamiliesBuilder
SearchInResourceParams
Searches for given string in resource content.
SearchInResourceParamsBuilder
SearchInResourceReturns
Searches for given string in resource content.
SearchInResourceReturnsBuilder
SecurityOriginDetails
Additional information about the frame document’s security origin.
SecurityOriginDetailsBuilder
SetAdBlockingEnabledParams
Enable Chrome’s experimental ad filter on all sites.
SetAdBlockingEnabledParamsBuilder
SetBypassCSPParams
Enable page Content Security Policy by-passing.
SetBypassCSPParamsBuilder
SetDeviceMetricsOverrideParams
Overrides the values of device screen dimensions (window.screen.width, window.screen.height, window.innerWidth, window.innerHeight, and “device-width”/“device-height”-related CSS media query results).
SetDeviceMetricsOverrideParamsBuilder
SetDeviceOrientationOverrideParams
Overrides the Device Orientation.
SetDeviceOrientationOverrideParamsBuilder
SetDocumentContentParams
Sets given markup as the document’s HTML.
SetDocumentContentParamsBuilder
SetDownloadBehaviorParams
Set the behavior when downloading a file.
SetDownloadBehaviorParamsBuilder
SetFontFamiliesParams
Set generic font families.
SetFontFamiliesParamsBuilder
SetFontSizesParams
Set default font sizes.
SetFontSizesParamsBuilder
SetGeolocationOverrideParams
Overrides the Geolocation Position or Error. Omitting any of the parameters emulates position unavailable.
SetGeolocationOverrideParamsBuilder
SetInterceptFileChooserDialogParams
Intercept file chooser requests and transfer control to protocol clients. When file chooser interception is enabled, native file chooser dialog is not shown. Instead, a protocol event ‘Page.fileChooserOpened’ is emitted.
SetInterceptFileChooserDialogParamsBuilder
SetLifecycleEventsEnabledParams
Controls whether page will emit lifecycle events.
SetLifecycleEventsEnabledParamsBuilder
SetPrerenderingAllowedParams
Enable/disable prerendering manually.
SetPrerenderingAllowedParamsBuilder
SetRPHRegistrationModeParams
Extensions for Custom Handlers API: https://html.spec.whatwg.org/multipage/system-state.html#rph-automation
SetRPHRegistrationModeParamsBuilder
SetSPCTransactionModeParams
Sets the Secure Payment Confirmation transaction mode. https://w3c.github.io/secure-payment-confirmation/#sctn-automation-set-spc-transaction-mode
SetSPCTransactionModeParamsBuilder
SetTouchEmulationEnabledParams
Toggles mouse event-based touch event emulation.
SetTouchEmulationEnabledParamsBuilder
SetWebLifecycleStateParams
Tries to update the web lifecycle state of the page. It will transition the page to the given state according to: https://github.com/WICG/web-lifecycle/
SetWebLifecycleStateParamsBuilder
ShareTarget
ShareTargetBuilder
Shortcut
ShortcutBuilder
StartScreencastParams
Starts sending each frame using the ‘screencastFrame’ event.
StartScreencastParamsBuilder
StopLoadingParams
StopScreencastParams
Viewport
Viewport for capturing screenshot.
ViewportBuilder
VisualViewport
Visual viewport position, dimensions, and scale.
VisualViewportBuilder
WaitForDebuggerParams
WebAppManifest
WebAppManifestBuilder

Enums

AdFrameExplanation
AdFrameType
Indicates whether a frame has been identified as an ad.
BackForwardCacheNotRestoredReason
List of not restored reasons for back-forward cache.
BackForwardCacheNotRestoredReasonType
Types of not restored reasons for back-forward cache.
ClientNavigationDisposition
ClientNavigationReason
CrossOriginIsolatedContextType
Indicates whether the frame is cross-origin isolated and why it is the case.
DialogType
Javascript dialog type.
GatedAPIFeatures
NavigationType
The type of a frameNavigated event.
OriginTrialStatus
Status for an Origin Trial.
OriginTrialTokenStatus
Origin Trial(https://www.chromium.org/blink/origin-trials) support. Status for an Origin Trial token.
OriginTrialUsageRestriction
PermissionsPolicyBlockReason
Reason for a permissions policy feature to be disabled.
PermissionsPolicyFeature
All Permissions Policy features. This enum should match the one defined in services/network/public/cpp/permissions_policy/permissions_policy_features.json5. LINT.IfChange(PermissionsPolicyFeature)
ReferrerPolicy
The referring-policy used for the navigation.
SecureContextType
Indicates whether the frame is a secure context and why it is the case.
TransitionType
Transition type.

Type Aliases

FrameId
Unique frame identifier.
ScriptIdentifier
Unique script identifier.