Module page

Module page 

Actions and events related to the inspected page belong to the page domain.

Structs

AdFrameStatus
Indicates whether a frame has been identified as an ad and why.
AddCompilationCacheParams
Seeds compilation cache for given url. Compilation cache does not survive cross-process navigation.
AddScriptToEvaluateOnLoadParams
Deprecated, please use addScriptToEvaluateOnNewDocument instead.
AddScriptToEvaluateOnLoadReturns
Deprecated, please use addScriptToEvaluateOnNewDocument instead.
AddScriptToEvaluateOnNewDocumentParams
Evaluates given script in every frame upon creation (before loading frame’s scripts).
AddScriptToEvaluateOnNewDocumentReturns
Evaluates given script in every frame upon creation (before loading frame’s scripts).
AppManifestError
Error while paring app manifest.
AppManifestParsedProperties
Parsed app manifest properties.
BackForwardCacheBlockingDetails
BackForwardCacheNotRestoredExplanation
BackForwardCacheNotRestoredExplanationTree
CaptureScreenshotParams
Capture page screenshot.
CaptureScreenshotReturns
Capture page screenshot.
CaptureSnapshotParams
Returns a snapshot of the page as a string. For MHTML format, the serialization includes iframes, shadow DOM, external resources, and element-inline styles.
CaptureSnapshotReturns
Returns a snapshot of the page as a string. For MHTML format, the serialization includes iframes, shadow DOM, external resources, and element-inline styles.
CompilationCacheParams
Per-script compilation cache parameters for ‘Page.produceCompilationCache’
CreateIsolatedWorldParams
Creates an isolated world for the given frame.
CreateIsolatedWorldReturns
Creates an isolated world for the given frame.
DeleteCookieParams
Deletes browser cookie with given name, domain and path.
EnableParams
Enables page domain notifications.
FileFilter
FileHandler
FontFamilies
Generic font families collection.
FontSizes
Default font sizes.
Frame
Information about the Frame on the page.
FrameResource
Information about the Resource on the page.
FrameResourceTree
Information about the Frame hierarchy along with their cached resources.
FrameTree
Information about the Frame hierarchy.
GenerateTestReportParams
Generates a report for testing.
GetAdScriptAncestryParams
GetAdScriptAncestryReturns
GetAnnotatedPageContentParams
Get the annotated page content for the main frame. This is an experimental command that is subject to change.
GetAnnotatedPageContentReturns
Get the annotated page content for the main frame. This is an experimental command that is subject to change.
GetAppIdReturns
Returns the unique (PWA) app id. Only returns values if the feature flag ‘WebAppEnableManifestId’ is enabled
GetAppManifestParams
Gets the processed manifest for this current document. This API always waits for the manifest to be loaded. If manifestId is provided, and it does not match the manifest of the current document, this API errors out. If there is not a loaded page, this API errors out immediately.
GetAppManifestReturns
Gets the processed manifest for this current document. This API always waits for the manifest to be loaded. If manifestId is provided, and it does not match the manifest of the current document, this API errors out. If there is not a loaded page, this API errors out immediately.
GetFrameTreeReturns
Returns present frame tree structure.
GetInstallabilityErrorsReturns
GetLayoutMetricsReturns
Returns metrics relating to the layouting of the page, such as viewport bounds/scale.
GetManifestIconsReturns
Deprecated because it’s not guaranteed that the returned icon is in fact the one used for PWA installation.
GetNavigationHistoryReturns
Returns navigation history for the current page.
GetOriginTrialsParams
Get Origin Trials on given frame.
GetOriginTrialsReturns
Get Origin Trials on given frame.
GetPermissionsPolicyStateParams
Get Permissions Policy state on given frame.
GetPermissionsPolicyStateReturns
Get Permissions Policy state on given frame.
GetResourceContentParams
Returns content of the given resource.
GetResourceContentReturns
Returns content of the given resource.
GetResourceTreeReturns
Returns present frame / resource tree structure.
HandleJavaScriptDialogParams
Accepts or dismisses a JavaScript initiated dialog (alert, confirm, prompt, or onbeforeunload).
ImageResource
The image definition used in both icon and screenshot.
InstallabilityError
The installability error
InstallabilityErrorArgument
LaunchHandler
LayoutViewport
Layout viewport position and dimensions.
NavigateParams
Navigates current page to the given URL.
NavigateReturns
Navigates current page to the given URL.
NavigateToHistoryEntryParams
Navigates current page to the given history entry.
NavigationEntry
Navigation history entry.
OriginTrial
OriginTrialToken
OriginTrialTokenWithStatus
PermissionsPolicyBlockLocator
PermissionsPolicyFeatureState
PrintToPDFParams
Print page as PDF.
PrintToPDFReturns
Print page as PDF.
ProduceCompilationCacheParams
Requests backend to produce compilation cache for the specified scripts. ‘scripts’ are appended to the list of scripts for which the cache would be produced. The list may be reset during page navigation. When script with a matching URL is encountered, the cache is optionally produced upon backend discretion, based on internal heuristics. See also: ‘Page.compilationCacheProduced’.
ProtocolHandler
RelatedApplication
ReloadParams
Reloads given page optionally ignoring the cache.
RemoveScriptToEvaluateOnLoadParams
Deprecated, please use removeScriptToEvaluateOnNewDocument instead.
RemoveScriptToEvaluateOnNewDocumentParams
Removes given script from the list.
ScopeExtension
ScreencastFrameAckParams
Acknowledges that a screencast frame has been received by the frontend.
ScreencastFrameMetadata
Screencast frame metadata.
Screenshot
ScriptFontFamilies
Font families collection for a script.
SearchInResourceParams
Searches for given string in resource content.
SearchInResourceReturns
Searches for given string in resource content.
SecurityOriginDetails
Additional information about the frame document’s security origin.
SetAdBlockingEnabledParams
Enable Chrome’s experimental ad filter on all sites.
SetBypassCSPParams
Enable page Content Security Policy by-passing.
SetDeviceMetricsOverrideParams
Overrides the values of device screen dimensions (window.screen.width, window.screen.height, window.innerWidth, window.innerHeight, and “device-width”/“device-height”-related CSS media query results).
SetDeviceOrientationOverrideParams
Overrides the Device Orientation.
SetDocumentContentParams
Sets given markup as the document’s HTML.
SetDownloadBehaviorParams
Set the behavior when downloading a file.
SetFontFamiliesParams
Set generic font families.
SetFontSizesParams
Set default font sizes.
SetGeolocationOverrideParams
Overrides the Geolocation Position or Error. Omitting any of the parameters emulates position unavailable.
SetInterceptFileChooserDialogParams
Intercept file chooser requests and transfer control to protocol clients. When file chooser interception is enabled, native file chooser dialog is not shown. Instead, a protocol event ‘Page.fileChooserOpened’ is emitted.
SetLifecycleEventsEnabledParams
Controls whether page will emit lifecycle events.
SetPrerenderingAllowedParams
Enable/disable prerendering manually.
SetRPHRegistrationModeParams
Extensions for Custom Handlers API: https://html.spec.whatwg.org/multipage/system-state.html#rph-automation
SetSPCTransactionModeParams
Sets the Secure Payment Confirmation transaction mode. https://w3c.github.io/secure-payment-confirmation/#sctn-automation-set-spc-transaction-mode
SetTouchEmulationEnabledParams
Toggles mouse event-based touch event emulation.
SetWebLifecycleStateParams
Tries to update the web lifecycle state of the page. It will transition the page to the given state according to: https://github.com/WICG/web-lifecycle/
ShareTarget
Shortcut
StartScreencastParams
Starts sending each frame using the ‘screencastFrame’ event.
Viewport
Viewport for capturing screenshot.
VisualViewport
Visual viewport position, dimensions, and scale.
WebAppManifest

Enums

AdFrameExplanation
AdFrameType
Indicates whether a frame has been identified as an ad.
BackForwardCacheNotRestoredReason
List of not restored reasons for back-forward cache.
BackForwardCacheNotRestoredReasonType
Types of not restored reasons for back-forward cache.
ClientNavigationDisposition
ClientNavigationReason
CrossOriginIsolatedContextType
Indicates whether the frame is cross-origin isolated and why it is the case.
DialogType
Javascript dialog type.
GatedAPIFeatures
NavigationType
The type of a frameNavigated event.
OriginTrialStatus
Status for an Origin Trial.
OriginTrialTokenStatus
Origin Trial(https://www.chromium.org/blink/origin-trials) support. Status for an Origin Trial token.
OriginTrialUsageRestriction
PermissionsPolicyBlockReason
Reason for a permissions policy feature to be disabled.
PermissionsPolicyFeature
All Permissions Policy features. This enum should match the one defined in services/network/public/cpp/permissions_policy/permissions_policy_features.json5. LINT.IfChange(PermissionsPolicyFeature)
ReferrerPolicy
The referring-policy used for the navigation.
SecureContextType
Indicates whether the frame is a secure context and why it is the case.
TransitionType
Transition type.

Type Aliases

FrameId
Unique frame identifier.
ScriptIdentifier
Unique script identifier.