pub struct CaptureScreenshotParamsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> CaptureScreenshotParamsBuilder<'a>
impl<'a> CaptureScreenshotParamsBuilder<'a>
Sourcepub fn format(self, format: impl Into<Cow<'a, str>>) -> Self
pub fn format(self, format: impl Into<Cow<'a, str>>) -> Self
Image compression format (defaults to png).
Sourcepub fn quality(self, quality: i64) -> Self
pub fn quality(self, quality: i64) -> Self
Compression quality from range [0..100] (jpeg only).
Sourcepub fn fromSurface(self, fromSurface: bool) -> Self
pub fn fromSurface(self, fromSurface: bool) -> Self
Capture the screenshot from the surface, rather than the view. Defaults to true.
Sourcepub fn captureBeyondViewport(self, captureBeyondViewport: bool) -> Self
pub fn captureBeyondViewport(self, captureBeyondViewport: bool) -> Self
Capture the screenshot beyond the viewport. Defaults to false.
Sourcepub fn optimizeForSpeed(self, optimizeForSpeed: bool) -> Self
pub fn optimizeForSpeed(self, optimizeForSpeed: bool) -> Self
Optimize image encoding for speed, not for resulting size (defaults to false)
pub fn build(self) -> CaptureScreenshotParams<'a>