pub struct Frame {Show 15 fields
pub id: FrameId,
pub parentId: Option<FrameId>,
pub loaderId: LoaderId,
pub name: Option<String>,
pub url: String,
pub urlFragment: Option<String>,
pub domainAndRegistry: String,
pub securityOrigin: String,
pub securityOriginDetails: Option<SecurityOriginDetails>,
pub mimeType: String,
pub unreachableUrl: Option<String>,
pub adFrameStatus: Option<AdFrameStatus>,
pub secureContextType: SecureContextType,
pub crossOriginIsolatedContextType: CrossOriginIsolatedContextType,
pub gatedAPIFeatures: Vec<GatedAPIFeatures>,
}Expand description
Information about the Frame on the page.
Fields
id: FrameIdFrame unique identifier.
parentId: Option<FrameId>Parent frame identifier.
loaderId: LoaderIdIdentifier of the loader associated with this frame.
name: Option<String>Frame’s name as specified in the tag.
url: StringFrame document’s URL without fragment.
urlFragment: Option<String>Frame document’s URL fragment including the ‘#’.
domainAndRegistry: StringFrame document’s registered domain, taking the public suffixes list into account. Extracted from the Frame’s url. Example URLs: http://www.google.com/file.html -> “google.com” http://a.b.co.uk/file.html -> “b.co.uk”
securityOrigin: StringFrame document’s security origin.
securityOriginDetails: Option<SecurityOriginDetails>Additional details about the frame document’s security origin.
mimeType: StringFrame document’s mimeType as determined by the browser.
unreachableUrl: Option<String>If the frame failed to load, this contains the URL that could not be loaded. Note that unlike url above, this URL may contain a fragment.
adFrameStatus: Option<AdFrameStatus>Indicates whether this frame was tagged as an ad and why.
secureContextType: SecureContextTypeIndicates whether the main document is a secure context and explains why that is the case.
crossOriginIsolatedContextType: CrossOriginIsolatedContextTypeIndicates whether this is a cross origin isolated context.
gatedAPIFeatures: Vec<GatedAPIFeatures>Indicated which gated APIs / features are available.