FrameBuilder

Struct FrameBuilder 

pub struct FrameBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> FrameBuilder<'a>

pub fn parentId(self, parentId: FrameId<'a>) -> Self

Parent frame identifier.

pub fn name(self, name: impl Into<Cow<'a, str>>) -> Self

Frame’s name as specified in the tag.

pub fn urlFragment(self, urlFragment: impl Into<Cow<'a, str>>) -> Self

Frame document’s URL fragment including the ‘#’.

pub fn securityOriginDetails( self, securityOriginDetails: SecurityOriginDetails, ) -> Self

Additional details about the frame document’s security origin.

pub fn unreachableUrl(self, unreachableUrl: impl Into<Cow<'a, str>>) -> Self

If the frame failed to load, this contains the URL that could not be loaded. Note that unlike url above, this URL may contain a fragment.

pub fn adFrameStatus(self, adFrameStatus: AdFrameStatus) -> Self

Indicates whether this frame was tagged as an ad and why.

pub fn build(self) -> Frame<'a>