pub struct FrameBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> FrameBuilder<'a>
impl<'a> FrameBuilder<'a>
Sourcepub fn urlFragment(self, urlFragment: impl Into<Cow<'a, str>>) -> Self
pub fn urlFragment(self, urlFragment: impl Into<Cow<'a, str>>) -> Self
Frame document’s URL fragment including the ‘#’.
Sourcepub fn securityOriginDetails(
self,
securityOriginDetails: SecurityOriginDetails,
) -> Self
pub fn securityOriginDetails( self, securityOriginDetails: SecurityOriginDetails, ) -> Self
Additional details about the frame document’s security origin.
Sourcepub fn unreachableUrl(self, unreachableUrl: impl Into<Cow<'a, str>>) -> Self
pub fn unreachableUrl(self, unreachableUrl: impl Into<Cow<'a, str>>) -> Self
If the frame failed to load, this contains the URL that could not be loaded. Note that unlike url above, this URL may contain a fragment.
Sourcepub fn adFrameStatus(self, adFrameStatus: AdFrameStatus) -> Self
pub fn adFrameStatus(self, adFrameStatus: AdFrameStatus) -> Self
Indicates whether this frame was tagged as an ad and why.
pub fn build(self) -> Frame<'a>