pub struct GetAdScriptAncestryReturns {
pub adScriptAncestry: Option<AdAncestry>,
}Fields
adScriptAncestry: Option<AdAncestry>The ancestry chain of ad script identifiers leading to this frame’s creation, along with the root script’s filterlist rule. The ancestry chain is ordered from the most immediate script (in the frame creation stack) to more distant ancestors (that created the immediately preceding script). Only sent if frame is labelled as an ad and ids are available.