pub struct GetAdScriptAncestryReturnsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> GetAdScriptAncestryReturnsBuilder<'a>
impl<'a> GetAdScriptAncestryReturnsBuilder<'a>
Sourcepub fn adScriptAncestry(self, adScriptAncestry: AdAncestry<'a>) -> Self
pub fn adScriptAncestry(self, adScriptAncestry: AdAncestry<'a>) -> Self
The ancestry chain of ad script identifiers leading to this frame’s creation, along with the root script’s filterlist rule. The ancestry chain is ordered from the most immediate script (in the frame creation stack) to more distant ancestors (that created the immediately preceding script). Only sent if frame is labelled as an ad and ids are available.
pub fn build(self) -> GetAdScriptAncestryReturns<'a>