pub struct GetAnnotatedPageContentParams {
pub includeActionableInformation: Option<bool>,
}Expand description
Get the annotated page content for the main frame. This is an experimental command that is subject to change.
Fields
includeActionableInformation: Option<bool>Whether to include actionable information. Defaults to true.