pub struct GetAnnotatedPageContentReturns<'a> { /* private fields */ }Expand description
Get the annotated page content for the main frame. This is an experimental command that is subject to change.
Implementations