GetAppManifestParams

Struct GetAppManifestParams 

pub struct GetAppManifestParams<'a> { /* private fields */ }
Gets the processed manifest for this current document. This API always waits for the manifest to be loaded. If manifestId is provided, and it does not match the manifest of the current document, this API errors out. If there is not a loaded page, this API errors out immediately.

Implementations

Source

impl<'a> GetAppManifestParams<'a>

pub fn builder() -> GetAppManifestParamsBuilder<'a>

Creates a builder for this type.

pub fn manifest_id(&self) -> Option<&str>

Source

impl<'a> GetAppManifestParams<'a>

pub const METHOD: &'static str = "Page.getAppManifest"