pub struct GetAppManifestParams<'a> { /* private fields */ }Expand description
Gets the processed manifest for this current document. This API always waits for the manifest to be loaded. If manifestId is provided, and it does not match the manifest of the current document, this API errors out. If there is not a loaded page, this API errors out immediately.
Implementations
Sourceimpl<'a> GetAppManifestParams<'a>
impl<'a> GetAppManifestParams<'a>
Sourcepub fn builder() -> GetAppManifestParamsBuilder<'a>
pub fn builder() -> GetAppManifestParamsBuilder<'a>
Creates a builder for this type.
pub fn manifest_id(&self) -> Option<&str>