pub struct GetAppManifestReturns {
pub url: String,
pub errors: Vec<AppManifestError>,
pub data: Option<String>,
pub parsed: Option<AppManifestParsedProperties>,
pub manifest: WebAppManifest,
}Expand description
Gets the processed manifest for this current document. This API always waits for the manifest to be loaded. If manifestId is provided, and it does not match the manifest of the current document, this API errors out. If there is not a loaded page, this API errors out immediately.
Fields
url: StringManifest location.
errors: Vec<AppManifestError>data: Option<String>Manifest content.
parsed: Option<AppManifestParsedProperties>Parsed manifest properties. Deprecated, use manifest instead.
manifest: WebAppManifestTrait Implementations
Sourceimpl Clone for GetAppManifestReturns
impl Clone for GetAppManifestReturns
Sourcefn clone(&self) -> GetAppManifestReturns
fn clone(&self) -> GetAppManifestReturns
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetAppManifestReturns
impl Debug for GetAppManifestReturns
Sourceimpl Default for GetAppManifestReturns
impl Default for GetAppManifestReturns
Sourcefn default() -> GetAppManifestReturns
fn default() -> GetAppManifestReturns
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for GetAppManifestReturns
impl<'de> Deserialize<'de> for GetAppManifestReturns
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more