pub struct PrintToPDFParams<'a> { /* private fields */ }Expand description
Print page as PDF.
Implementations
Sourceimpl<'a> PrintToPDFParams<'a>
impl<'a> PrintToPDFParams<'a>
Sourcepub fn builder() -> PrintToPDFParamsBuilder<'a>
pub fn builder() -> PrintToPDFParamsBuilder<'a>
Creates a builder for this type.
Display header and footer. Defaults to false.
Sourcepub fn print_background(&self) -> Option<bool>
pub fn print_background(&self) -> Option<bool>
Print background graphics. Defaults to false.
Sourcepub fn paper_width(&self) -> Option<f64>
pub fn paper_width(&self) -> Option<f64>
Paper width in inches. Defaults to 8.5 inches.
Sourcepub fn paper_height(&self) -> Option<f64>
pub fn paper_height(&self) -> Option<f64>
Paper height in inches. Defaults to 11 inches.
Sourcepub fn margin_top(&self) -> Option<f64>
pub fn margin_top(&self) -> Option<f64>
Top margin in inches. Defaults to 1cm (~0.4 inches).
Sourcepub fn margin_bottom(&self) -> Option<f64>
pub fn margin_bottom(&self) -> Option<f64>
Bottom margin in inches. Defaults to 1cm (~0.4 inches).
Sourcepub fn margin_left(&self) -> Option<f64>
pub fn margin_left(&self) -> Option<f64>
Left margin in inches. Defaults to 1cm (~0.4 inches).
Sourcepub fn margin_right(&self) -> Option<f64>
pub fn margin_right(&self) -> Option<f64>
Right margin in inches. Defaults to 1cm (~0.4 inches).
Sourcepub fn page_ranges(&self) -> Option<&str>
pub fn page_ranges(&self) -> Option<&str>
Paper ranges to print, one based, e.g., ‘1-5, 8, 11-13’. Pages are printed in the document order, not in the order specified, and no more than once. Defaults to empty string, which implies the entire document is printed. The page numbers are quietly capped to actual page count of the document, and ranges beyond the end of the document are ignored. If this results in no pages to print, an error is reported. It is an error to specify a range with start greater than end.
Sourcepub fn header_template(&self) -> Option<&str>
pub fn header_template(&self) -> Option<&str>
HTML template for the print header. Should be valid HTML markup with following classes used to inject printing values into them:
- ‘date’: formatted print date
- ‘title’: document title
- ‘url’: document location
- ‘pageNumber’: current page number
- ‘totalPages’: total pages in the document
For example, ‘<span class=title></span>’ would generate span containing the title.
HTML template for the print footer. Should use the same format as the ‘headerTemplate’.
Sourcepub fn prefer_css_page_size(&self) -> Option<bool>
pub fn prefer_css_page_size(&self) -> Option<bool>
Whether or not to prefer page size as defined by css. Defaults to false, in which case the content will be scaled to fit the paper size.
Sourcepub fn transfer_mode(&self) -> Option<&str>
pub fn transfer_mode(&self) -> Option<&str>
return as stream
Sourcepub fn generate_tagged_pdf(&self) -> Option<bool>
pub fn generate_tagged_pdf(&self) -> Option<bool>
Whether or not to generate tagged (accessible) PDF. Defaults to embedder choice.
Sourcepub fn generate_document_outline(&self) -> Option<bool>
pub fn generate_document_outline(&self) -> Option<bool>
Whether or not to embed the document outline into the PDF.