pub struct PrintToPDFParamsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> PrintToPDFParamsBuilder<'a>
impl<'a> PrintToPDFParamsBuilder<'a>
Display header and footer. Defaults to false.
Sourcepub fn printBackground(self, printBackground: bool) -> Self
pub fn printBackground(self, printBackground: bool) -> Self
Print background graphics. Defaults to false.
Sourcepub fn paperWidth(self, paperWidth: f64) -> Self
pub fn paperWidth(self, paperWidth: f64) -> Self
Paper width in inches. Defaults to 8.5 inches.
Sourcepub fn paperHeight(self, paperHeight: f64) -> Self
pub fn paperHeight(self, paperHeight: f64) -> Self
Paper height in inches. Defaults to 11 inches.
Sourcepub fn marginTop(self, marginTop: f64) -> Self
pub fn marginTop(self, marginTop: f64) -> Self
Top margin in inches. Defaults to 1cm (~0.4 inches).
Sourcepub fn marginBottom(self, marginBottom: f64) -> Self
pub fn marginBottom(self, marginBottom: f64) -> Self
Bottom margin in inches. Defaults to 1cm (~0.4 inches).
Sourcepub fn marginLeft(self, marginLeft: f64) -> Self
pub fn marginLeft(self, marginLeft: f64) -> Self
Left margin in inches. Defaults to 1cm (~0.4 inches).
Sourcepub fn marginRight(self, marginRight: f64) -> Self
pub fn marginRight(self, marginRight: f64) -> Self
Right margin in inches. Defaults to 1cm (~0.4 inches).
Sourcepub fn pageRanges(self, pageRanges: impl Into<Cow<'a, str>>) -> Self
pub fn pageRanges(self, pageRanges: impl Into<Cow<'a, str>>) -> Self
Paper ranges to print, one based, e.g., ‘1-5, 8, 11-13’. Pages are printed in the document order, not in the order specified, and no more than once. Defaults to empty string, which implies the entire document is printed. The page numbers are quietly capped to actual page count of the document, and ranges beyond the end of the document are ignored. If this results in no pages to print, an error is reported. It is an error to specify a range with start greater than end.
Sourcepub fn headerTemplate(self, headerTemplate: impl Into<Cow<'a, str>>) -> Self
pub fn headerTemplate(self, headerTemplate: impl Into<Cow<'a, str>>) -> Self
HTML template for the print header. Should be valid HTML markup with following classes used to inject printing values into them:
- ‘date’: formatted print date
- ‘title’: document title
- ‘url’: document location
- ‘pageNumber’: current page number
- ‘totalPages’: total pages in the document
For example, ‘’ would generate span containing the title.
HTML template for the print footer. Should use the same format as the ‘headerTemplate’.
Sourcepub fn preferCSSPageSize(self, preferCSSPageSize: bool) -> Self
pub fn preferCSSPageSize(self, preferCSSPageSize: bool) -> Self
Whether or not to prefer page size as defined by css. Defaults to false, in which case the content will be scaled to fit the paper size.
Sourcepub fn transferMode(self, transferMode: impl Into<Cow<'a, str>>) -> Self
pub fn transferMode(self, transferMode: impl Into<Cow<'a, str>>) -> Self
return as stream
Sourcepub fn generateTaggedPDF(self, generateTaggedPDF: bool) -> Self
pub fn generateTaggedPDF(self, generateTaggedPDF: bool) -> Self
Whether or not to generate tagged (accessible) PDF. Defaults to embedder choice.
Sourcepub fn generateDocumentOutline(self, generateDocumentOutline: bool) -> Self
pub fn generateDocumentOutline(self, generateDocumentOutline: bool) -> Self
Whether or not to embed the document outline into the PDF.