pub struct ProduceCompilationCacheParams<'a> { /* private fields */ }Expand description
Requests backend to produce compilation cache for the specified scripts. ‘scripts’ are appended to the list of scripts for which the cache would be produced. The list may be reset during page navigation. When script with a matching URL is encountered, the cache is optionally produced upon backend discretion, based on internal heuristics. See also: ‘Page.compilationCacheProduced’.
Implementations
Sourceimpl<'a> ProduceCompilationCacheParams<'a>
impl<'a> ProduceCompilationCacheParams<'a>
pub fn builder( scripts: Vec<CompilationCacheParams<'a>>, ) -> ProduceCompilationCacheParamsBuilder<'a>
pub fn scripts(&self) -> &[CompilationCacheParams<'a>]