ReloadParamsBuilder

Struct ReloadParamsBuilder 

pub struct ReloadParamsBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> ReloadParamsBuilder<'a>

pub fn ignoreCache(self, ignoreCache: bool) -> Self

If true, browser cache is ignored (as if the user pressed Shift+refresh).

pub fn scriptToEvaluateOnLoad( self, scriptToEvaluateOnLoad: impl Into<Cow<'a, str>>, ) -> Self

If set, the script will be injected into all frames of the inspected page after reload. Argument will be ignored if reloading dataURL origin.

pub fn loaderId(self, loaderId: LoaderId<'a>) -> Self

If set, an error will be thrown if the target page’s main frame’s loader id does not match the provided id. This prevents accidentally reloading an unintended target in case there’s a racing navigation.

pub fn build(self) -> ReloadParams<'a>