SetDeviceMetricsOverrideParamsBuilder

Struct SetDeviceMetricsOverrideParamsBuilder 

pub struct SetDeviceMetricsOverrideParamsBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> SetDeviceMetricsOverrideParamsBuilder<'a>

pub fn scale(self, scale: f64) -> Self

Scale to apply to resulting view image.

pub fn screenWidth(self, screenWidth: u64) -> Self

Overriding screen width value in pixels (minimum 0, maximum 10000000).

pub fn screenHeight(self, screenHeight: i64) -> Self

Overriding screen height value in pixels (minimum 0, maximum 10000000).

pub fn positionX(self, positionX: i64) -> Self

Overriding view X position on screen in pixels (minimum 0, maximum 10000000).

pub fn positionY(self, positionY: i64) -> Self

Overriding view Y position on screen in pixels (minimum 0, maximum 10000000).

pub fn dontSetVisibleSize(self, dontSetVisibleSize: bool) -> Self

Do not set visible view size, rely upon explicit setVisibleSize call.

pub fn screenOrientation(self, screenOrientation: ScreenOrientation<'a>) -> Self

Screen orientation override.

pub fn viewport(self, viewport: Viewport) -> Self

The viewport dimensions and scale. If not set, the override is cleared.

pub fn build(self) -> SetDeviceMetricsOverrideParams<'a>