Module performance

Module performance 

Structs

DisableParams
EnableParams
Enable collecting and reporting metrics.
GetMetricsParams
GetMetricsReturns
Retrieve current values of run-time metrics.
Metric
Run-time execution metric.
SetTimeDomainParams
Sets time domain to use for collecting and reporting duration metrics. Note that this must be called before enabling metrics collection. Calling this method while metrics collection is enabled returns an error.