Structs
- Disable
Params - Enable
Params - Enable collecting and reporting metrics.
- Enable
Params Builder - GetMetrics
Params - GetMetrics
Returns - Retrieve current values of run-time metrics.
- GetMetrics
Returns Builder - Metric
- Run-time execution metric.
- Metric
Builder - SetTime
Domain Params - Sets time domain to use for collecting and reporting duration metrics. Note that this must be called before enabling metrics collection. Calling this method while metrics collection is enabled returns an error.
- SetTime
Domain Params Builder