pub struct SetTimeDomainParams {
pub timeDomain: String,
}Expand description
Sets time domain to use for collecting and reporting duration metrics. Note that this must be called before enabling metrics collection. Calling this method while metrics collection is enabled returns an error.
Fields
timeDomain: StringTime domain
Implementations