SetTimeDomainParams

Struct SetTimeDomainParams 

pub struct SetTimeDomainParams<'a> { /* private fields */ }
Sets time domain to use for collecting and reporting duration metrics. Note that this must be called before enabling metrics collection. Calling this method while metrics collection is enabled returns an error.

Implementations

Source

impl<'a> SetTimeDomainParams<'a>

pub fn builder( timeDomain: impl Into<Cow<'a, str>>, ) -> SetTimeDomainParamsBuilder<'a>

pub fn timeDomain(&self) -> &str

Source

impl<'a> SetTimeDomainParams<'a>

pub const METHOD: &'static str = "Performance.setTimeDomain"