pub struct SetTimeDomainParams<'a> { /* private fields */ }Expand description
Sets time domain to use for collecting and reporting duration metrics. Note that this must be called before enabling metrics collection. Calling this method while metrics collection is enabled returns an error.
Implementations
Sourceimpl<'a> SetTimeDomainParams<'a>
impl<'a> SetTimeDomainParams<'a>
pub fn builder( timeDomain: impl Into<Cow<'a, str>>, ) -> SetTimeDomainParamsBuilder<'a>
pub fn timeDomain(&self) -> &str