pub struct PreloadingAttemptKey {
pub loaderId: LoaderId,
pub action: SpeculationAction,
pub url: String,
pub formSubmission: Option<bool>,
pub targetHint: Option<SpeculationTargetHint>,
}Expand description
A key that identifies a preloading attempt.
The url used is the url specified by the trigger (i.e. the initial URL), and not the final url that is navigated to. For example, prerendering allows same-origin main frame navigations during the attempt, but the attempt is still keyed with the initial URL.
Fields
loaderId: LoaderIdaction: SpeculationActionurl: StringformSubmission: Option<bool>targetHint: Option<SpeculationTargetHint>Trait Implementations
Sourceimpl Clone for PreloadingAttemptKey
impl Clone for PreloadingAttemptKey
Sourcefn clone(&self) -> PreloadingAttemptKey
fn clone(&self) -> PreloadingAttemptKey
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PreloadingAttemptKey
impl Debug for PreloadingAttemptKey
Sourceimpl Default for PreloadingAttemptKey
impl Default for PreloadingAttemptKey
Sourcefn default() -> PreloadingAttemptKey
fn default() -> PreloadingAttemptKey
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PreloadingAttemptKey
impl<'de> Deserialize<'de> for PreloadingAttemptKey
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more