pub struct RuleSet {
pub id: RuleSetId,
pub loaderId: LoaderId,
pub sourceText: String,
pub backendNodeId: Option<BackendNodeId>,
pub url: Option<String>,
pub requestId: Option<RequestId>,
pub errorType: Option<RuleSetErrorType>,
pub errorMessage: Option<String>,
pub tag: Option<String>,
}Expand description
Corresponds to SpeculationRuleSet
Fields
id: RuleSetIdloaderId: LoaderIdIdentifies a document which the rule set is associated with.
sourceText: StringSource text of JSON representing the rule set. If it comes from ‘<script>’ tag, it is the textContent of the node. Note that it is a JSON for valid case.
See also:
backendNodeId: Option<BackendNodeId>A speculation rule set is either added through an inline ‘<script>’ tag or through an external resource via the ‘Speculation-Rules’ HTTP header. For the first case, we include the BackendNodeId of the relevant ‘<script>’ tag. For the second case, we include the external URL where the rule set was loaded from, and also RequestId if Network domain is enabled.
See also:
url: Option<String>requestId: Option<RequestId>errorType: Option<RuleSetErrorType>Error information ‘errorMessage’ is null iff ‘errorType’ is null.
errorMessage: Option<String>TODO(https://crbug.com/1425354): Replace this property with structured error.
tag: Option<String>For more details, see: https://github.com/WICG/nav-speculation/blob/main/speculation-rules-tags.md