PreloadPipelineId

Type Alias PreloadPipelineId 

pub type PreloadPipelineId<'a> = Cow<'a, str>;
Chrome manages different types of preloads together using a concept of preloading pipeline. For example, if a site uses a SpeculationRules for prerender, Chrome first starts a prefetch and then upgrades it to prerender.

CDP events for them are emitted separately but they share ‘PreloadPipelineId’.

Aliased Type

pub enum PreloadPipelineId<'a> {
    Borrowed(&'a str),
    Owned(String),
}

Variants

1.0.0

Borrowed(&'a str)

Borrowed data.

1.0.0

Owned(String)

Owned data.