pub struct ChangeAppUserSettingsParams<'a> { /* private fields */ }Expand description
Changes user settings of the web app identified by its manifestId. If the app was not installed, this command returns an error. Unset parameters will be ignored; unrecognized values will cause an error.
Unlike the ones defined in the manifest files of the web apps, these settings are provided by the browser and controlled by the users, they impact the way the browser handling the web apps.
See the comment of each parameter.
Implementations
Sourceimpl<'a> ChangeAppUserSettingsParams<'a>
impl<'a> ChangeAppUserSettingsParams<'a>
Sourcepub fn builder(
manifest_id: impl Into<Cow<'a, str>>,
) -> ChangeAppUserSettingsParamsBuilder<'a>
pub fn builder( manifest_id: impl Into<Cow<'a, str>>, ) -> ChangeAppUserSettingsParamsBuilder<'a>
Creates a builder for this type with the required parameters:
manifest_id:
pub fn manifest_id(&self) -> &str
Sourcepub fn link_capturing(&self) -> Option<bool>
pub fn link_capturing(&self) -> Option<bool>
If user allows the links clicked on by the user in the app’s scope, or extended scope if the manifest has scope extensions and the flags ‘DesktopPWAsLinkCapturingWithScopeExtensions’ and ‘WebAppEnableScopeExtensions’ are enabled.
Note, the API does not support resetting the linkCapturing to the initial value, uninstalling and installing the web app again will reset it.
TODO(crbug.com/339453269): Setting this value on ChromeOS is not supported yet.
pub fn display_mode(&self) -> Option<&DisplayMode>