pub struct ChangeAppUserSettingsParams<'a> { /* private fields */ }Expand description
Changes user settings of the web app identified by its manifestId. If the app was not installed, this command returns an error. Unset parameters will be ignored; unrecognized values will cause an error.
Unlike the ones defined in the manifest files of the web apps, these settings are provided by the browser and controlled by the users, they impact the way the browser handling the web apps.
See the comment of each parameter.
Implementations
Sourceimpl<'a> ChangeAppUserSettingsParams<'a>
impl<'a> ChangeAppUserSettingsParams<'a>
pub fn builder( manifestId: impl Into<Cow<'a, str>>, ) -> ChangeAppUserSettingsParamsBuilder<'a>
pub fn manifestId(&self) -> &str
pub fn linkCapturing(&self) -> Option<bool>
pub fn displayMode(&self) -> Option<&DisplayMode>