ChangeAppUserSettingsParamsBuilder

Struct ChangeAppUserSettingsParamsBuilder 

pub struct ChangeAppUserSettingsParamsBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> ChangeAppUserSettingsParamsBuilder<'a>

pub fn linkCapturing(self, linkCapturing: bool) -> Self

If user allows the links clicked on by the user in the app’s scope, or extended scope if the manifest has scope extensions and the flags ‘DesktopPWAsLinkCapturingWithScopeExtensions’ and ‘WebAppEnableScopeExtensions’ are enabled.

Note, the API does not support resetting the linkCapturing to the initial value, uninstalling and installing the web app again will reset it.

TODO(crbug.com/339453269): Setting this value on ChromeOS is not supported yet.

pub fn displayMode(self, displayMode: DisplayMode) -> Self

pub fn build(self) -> ChangeAppUserSettingsParams<'a>