Structs
- Certificate
Security State - Details about the security state of the page certificate.
- Handle
Certificate Error Params - Handles a certificate error that fired a certificateError event.
- Insecure
Content Status - Information about insecure content on the page.
- Safety
TipInfo - Security
State Explanation - An explanation of an factor contributing to the security state.
- SetIgnore
Certificate Errors Params - Enable/disable whether all certificate errors should be ignored.
- SetOverride
Certificate Errors Params - Enable/disable overriding certificate errors. If enabled, all certificate error events need to be handled by the DevTools client and should be answered with ‘handleCertificateError’ commands.
- Visible
Security State - Security state information about the page.
Enums
- Certificate
Error Action - The action to take when a certificate error occurs. continue will continue processing the request and cancel will cancel the request.
- Mixed
Content Type - A description of mixed content (HTTP resources on HTTPS pages), as defined by https://www.w3.org/TR/mixed-content/#categories
- Safety
TipStatus - Security
State - The security level of a page or resource.
Type Aliases
- Certificate
Id - An internal certificate ID value.