CertificateSecurityState

Struct CertificateSecurityState 

pub struct CertificateSecurityState {
Show 18 fields pub protocol: String, pub keyExchange: String, pub keyExchangeGroup: Option<String>, pub cipher: String, pub mac: Option<String>, pub certificate: Vec<String>, pub subjectName: String, pub issuer: String, pub validFrom: TimeSinceEpoch, pub validTo: TimeSinceEpoch, pub certificateNetworkError: Option<String>, pub certificateHasWeakSignature: bool, pub certificateHasSha1Signature: bool, pub modernSSL: bool, pub obsoleteSslProtocol: bool, pub obsoleteSslKeyExchange: bool, pub obsoleteSslCipher: bool, pub obsoleteSslSignature: bool,
}
Details about the security state of the page certificate.

Fields

protocol: String

Protocol name (e.g. “TLS 1.2” or “QUIC”).

keyExchange: String

Key Exchange used by the connection, or the empty string if not applicable.

keyExchangeGroup: Option<String>

(EC)DH group used by the connection, if applicable.

cipher: String

Cipher name.

mac: Option<String>

TLS MAC. Note that AEAD ciphers do not have separate MACs.

certificate: Vec<String>

Page certificate.

subjectName: String

Certificate subject name.

issuer: String

Name of the issuing CA.

validFrom: TimeSinceEpoch

Certificate valid from date.

validTo: TimeSinceEpoch

Certificate valid to (expiration) date

certificateNetworkError: Option<String>

The highest priority network error code, if the certificate has an error.

certificateHasWeakSignature: bool

True if the certificate uses a weak signature algorithm.

certificateHasSha1Signature: bool

True if the certificate has a SHA1 signature in the chain.

modernSSL: bool

True if modern SSL

obsoleteSslProtocol: bool

True if the connection is using an obsolete SSL protocol.

obsoleteSslKeyExchange: bool

True if the connection is using an obsolete SSL key exchange.

obsoleteSslCipher: bool

True if the connection is using an obsolete SSL cipher.

obsoleteSslSignature: bool

True if the connection is using an obsolete SSL signature.