pub struct CertificateSecurityState {Show 18 fields
pub protocol: String,
pub keyExchange: String,
pub keyExchangeGroup: Option<String>,
pub cipher: String,
pub mac: Option<String>,
pub certificate: Vec<String>,
pub subjectName: String,
pub issuer: String,
pub validFrom: TimeSinceEpoch,
pub validTo: TimeSinceEpoch,
pub certificateNetworkError: Option<String>,
pub certificateHasWeakSignature: bool,
pub certificateHasSha1Signature: bool,
pub modernSSL: bool,
pub obsoleteSslProtocol: bool,
pub obsoleteSslKeyExchange: bool,
pub obsoleteSslCipher: bool,
pub obsoleteSslSignature: bool,
}Expand description
Details about the security state of the page certificate.
Fields
protocol: StringProtocol name (e.g. “TLS 1.2” or “QUIC”).
keyExchange: StringKey Exchange used by the connection, or the empty string if not applicable.
keyExchangeGroup: Option<String>(EC)DH group used by the connection, if applicable.
cipher: StringCipher name.
mac: Option<String>TLS MAC. Note that AEAD ciphers do not have separate MACs.
certificate: Vec<String>Page certificate.
subjectName: StringCertificate subject name.
issuer: StringName of the issuing CA.
validFrom: TimeSinceEpochCertificate valid from date.
validTo: TimeSinceEpochCertificate valid to (expiration) date
certificateNetworkError: Option<String>The highest priority network error code, if the certificate has an error.
certificateHasWeakSignature: boolTrue if the certificate uses a weak signature algorithm.
certificateHasSha1Signature: boolTrue if the certificate has a SHA1 signature in the chain.
modernSSL: boolTrue if modern SSL
obsoleteSslProtocol: boolTrue if the connection is using an obsolete SSL protocol.
obsoleteSslKeyExchange: boolTrue if the connection is using an obsolete SSL key exchange.
obsoleteSslCipher: boolTrue if the connection is using an obsolete SSL cipher.
obsoleteSslSignature: boolTrue if the connection is using an obsolete SSL signature.