pub struct SecurityStateExplanation<'a> { /* private fields */ }Expand description
An explanation of an factor contributing to the security state.
Implementations
Sourceimpl<'a> SecurityStateExplanation<'a>
impl<'a> SecurityStateExplanation<'a>
Sourcepub fn builder(
security_state: impl Into<SecurityState>,
title: impl Into<Cow<'a, str>>,
summary: impl Into<Cow<'a, str>>,
description: impl Into<Cow<'a, str>>,
mixed_content_type: impl Into<MixedContentType>,
certificate: Vec<Cow<'a, str>>,
) -> SecurityStateExplanationBuilder<'a>
pub fn builder( security_state: impl Into<SecurityState>, title: impl Into<Cow<'a, str>>, summary: impl Into<Cow<'a, str>>, description: impl Into<Cow<'a, str>>, mixed_content_type: impl Into<MixedContentType>, certificate: Vec<Cow<'a, str>>, ) -> SecurityStateExplanationBuilder<'a>
Creates a builder for this type with the required parameters:
security_state: Security state representing the severity of the factor being explained.title: Title describing the type of factor.summary: Short phrase describing the type of factor.description: Full text explanation of the factor.mixed_content_type: The type of mixed content described by the explanation.certificate: Page certificate.
Sourcepub fn security_state(&self) -> &SecurityState
pub fn security_state(&self) -> &SecurityState
Security state representing the severity of the factor being explained.
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Full text explanation of the factor.
Sourcepub fn mixed_content_type(&self) -> &MixedContentType
pub fn mixed_content_type(&self) -> &MixedContentType
The type of mixed content described by the explanation.
Sourcepub fn certificate(&self) -> &[Cow<'a, str>]
pub fn certificate(&self) -> &[Cow<'a, str>]
Page certificate.
Sourcepub fn recommendations(&self) -> Option<&[Cow<'a, str>]>
pub fn recommendations(&self) -> Option<&[Cow<'a, str>]>
Recommendations to fix any issues.