pub struct ServiceWorkerVersion<'a> { /* private fields */ }Expand description
ServiceWorker version.
Implementations
Sourceimpl<'a> ServiceWorkerVersion<'a>
impl<'a> ServiceWorkerVersion<'a>
Sourcepub fn builder(
version_id: impl Into<Cow<'a, str>>,
registration_id: impl Into<RegistrationID<'a>>,
script_url: impl Into<Cow<'a, str>>,
running_status: impl Into<ServiceWorkerVersionRunningStatus>,
status: impl Into<ServiceWorkerVersionStatus>,
) -> ServiceWorkerVersionBuilder<'a>
pub fn builder( version_id: impl Into<Cow<'a, str>>, registration_id: impl Into<RegistrationID<'a>>, script_url: impl Into<Cow<'a, str>>, running_status: impl Into<ServiceWorkerVersionRunningStatus>, status: impl Into<ServiceWorkerVersionStatus>, ) -> ServiceWorkerVersionBuilder<'a>
Creates a builder for this type with the required parameters:
version_id:registration_id:script_url:running_status:status:
pub fn version_id(&self) -> &str
pub fn registration_id(&self) -> &RegistrationID<'a>
pub fn script_url(&self) -> &str
pub fn running_status(&self) -> &ServiceWorkerVersionRunningStatus
pub fn status(&self) -> &ServiceWorkerVersionStatus
Sourcepub fn script_last_modified(&self) -> Option<f64>
pub fn script_last_modified(&self) -> Option<f64>
The Last-Modified header value of the main script.
Sourcepub fn script_response_time(&self) -> Option<f64>
pub fn script_response_time(&self) -> Option<f64>
The time at which the response headers of the main script were received from the server. For cached script it is the last time the cache entry was validated.
pub fn controlled_clients(&self) -> Option<&[TargetID<'a>]>
pub fn target_id(&self) -> Option<&TargetID<'a>>
pub fn router_rules(&self) -> Option<&str>