ServiceWorkerVersionBuilder

Struct ServiceWorkerVersionBuilder 

pub struct ServiceWorkerVersionBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> ServiceWorkerVersionBuilder<'a>

pub fn scriptLastModified(self, scriptLastModified: f64) -> Self

The Last-Modified header value of the main script.

pub fn scriptResponseTime(self, scriptResponseTime: f64) -> Self

The time at which the response headers of the main script were received from the server. For cached script it is the last time the cache entry was validated.

pub fn controlledClients(self, controlledClients: Vec<TargetID<'a>>) -> Self

pub fn targetId(self, targetId: TargetID<'a>) -> Self

pub fn routerRules(self, routerRules: impl Into<Cow<'a, str>>) -> Self

pub fn build(self) -> ServiceWorkerVersion<'a>