Structs
- Disable
Params - Enable
Params - Protocol
Set - Maps to the |SCARD_PROTOCOL_*| flags.
- Reader
State Flags - Maps to the |SCARD_STATE_*| flags.
- Reader
State In - Reader
State Out - Report
Begin Transaction Result Params - Reports the result of a |SCardBeginTransaction| call. On success, this creates a new transaction object.
- Report
Connect Result Params - Reports the successful result of a |SCardConnect| call.
- Report
Data Result Params - Reports the successful result of a call that sends back data on success. Used for |SCardTransmit|, |SCardControl|, and |SCardGetAttrib|.
- Report
Error Params - Reports an error result for the given request.
- Report
Establish Context Result Params - Reports the successful result of a |SCardEstablishContext| call.
- Report
GetStatus Change Result Params - Reports the successful result of a |SCardGetStatusChange| call.
- Report
List Readers Result Params - Reports the successful result of a |SCardListReaders| call.
- Report
Plain Result Params - Reports the successful result of a call that returns only a result code. Used for: |SCardCancel|, |SCardDisconnect|, |SCardSetAttrib|, |SCardEndTransaction|.
- Report
Release Context Result Params - Reports the successful result of a |SCardReleaseContext| call.
- Report
Status Result Params - Reports the successful result of a |SCardStatus| call.
Enums
- Connection
State - Maps to |SCARD_*| connection state values.
- Disposition
- Indicates what the reader should do with the card.
- Protocol
- Maps to the |SCARD_PROTOCOL_*| values.
- Result
Code - Indicates the PC/SC error code.
- Share
Mode - Maps to the |SCARD_SHARE_*| values.