Module smartcardemulation

Module smartcardemulation 

Structs

ProtocolSet
Maps to the |SCARD_PROTOCOL_*| flags.
ReaderStateFlags
Maps to the |SCARD_STATE_*| flags.
ReaderStateIn
ReaderStateOut
ReportBeginTransactionResultParams
Reports the result of a |SCardBeginTransaction| call. On success, this creates a new transaction object.
ReportConnectResultParams
Reports the successful result of a |SCardConnect| call.
ReportDataResultParams
Reports the successful result of a call that sends back data on success. Used for |SCardTransmit|, |SCardControl|, and |SCardGetAttrib|.
ReportErrorParams
Reports an error result for the given request.
ReportEstablishContextResultParams
Reports the successful result of a |SCardEstablishContext| call.
ReportGetStatusChangeResultParams
Reports the successful result of a |SCardGetStatusChange| call.
ReportListReadersResultParams
Reports the successful result of a |SCardListReaders| call.
ReportPlainResultParams
Reports the successful result of a call that returns only a result code. Used for: |SCardCancel|, |SCardDisconnect|, |SCardSetAttrib|, |SCardEndTransaction|.
ReportReleaseContextResultParams
Reports the successful result of a |SCardReleaseContext| call.
ReportStatusResultParams
Reports the successful result of a |SCardStatus| call.

Enums

ConnectionState
Maps to |SCARD_*| connection state values.
Disposition
Indicates what the reader should do with the card.
Protocol
Maps to the |SCARD_PROTOCOL_*| values.
ResultCode
Indicates the PC/SC error code.
ShareMode
Maps to the |SCARD_SHARE_*| values.