Module storage

Module storage 

Structs

ClearCookiesParams
Clears cookies.
ClearDataForOriginParams
Clears storage for origin.
ClearDataForStorageKeyParams
Clears storage for storage key.
ClearSharedStorageEntriesParams
Clears all entries for a given origin’s shared storage.
ClearTrustTokensParams
Removes all Trust Tokens issued by the provided issuerOrigin. Leaves other stored data, including the issuer’s Redemption Records, intact.
ClearTrustTokensReturns
Removes all Trust Tokens issued by the provided issuerOrigin. Leaves other stored data, including the issuer’s Redemption Records, intact.
DeleteSharedStorageEntryParams
Deletes entry for ‘key’ (if it exists) for a given origin’s shared storage.
DeleteStorageBucketParams
Deletes the Storage Bucket with the given storage key and bucket name.
GetCookiesParams
Returns all browser cookies.
GetCookiesReturns
Returns all browser cookies.
GetInterestGroupDetailsParams
Gets details for a named interest group.
GetInterestGroupDetailsReturns
Gets details for a named interest group.
GetRelatedWebsiteSetsParams
GetRelatedWebsiteSetsReturns
Returns the effective Related Website Sets in use by this profile for the browser session. The effective Related Website Sets will not change during a browser session.
GetSharedStorageEntriesParams
Gets the entries in an given origin’s shared storage.
GetSharedStorageEntriesReturns
Gets the entries in an given origin’s shared storage.
GetSharedStorageMetadataParams
Gets metadata for an origin’s shared storage.
GetSharedStorageMetadataReturns
Gets metadata for an origin’s shared storage.
GetStorageKeyForFrameParams
Returns a storage key given a frame id. Deprecated. Please use Storage.getStorageKey instead.
GetStorageKeyForFrameReturns
Returns a storage key given a frame id. Deprecated. Please use Storage.getStorageKey instead.
GetStorageKeyParams
Returns storage key for the given frame. If no frame ID is provided, the storage key of the target executing this command is returned.
GetStorageKeyReturns
Returns storage key for the given frame. If no frame ID is provided, the storage key of the target executing this command is returned.
GetTrustTokensParams
GetTrustTokensReturns
Returns the number of stored Trust Tokens per issuer for the current browsing context.
GetUsageAndQuotaParams
Returns usage and quota in bytes.
GetUsageAndQuotaReturns
Returns usage and quota in bytes.
OverrideQuotaForOriginParams
Override quota for the specified origin
RelatedWebsiteSet
A single Related Website Set object.
ResetSharedStorageBudgetParams
Resets the budget for ‘ownerOrigin’ by clearing all budget withdrawals.
RunBounceTrackingMitigationsParams
RunBounceTrackingMitigationsReturns
Deletes state for sites identified as potential bounce trackers, immediately.
SetCookiesParams
Sets given cookies.
SetInterestGroupAuctionTrackingParams
Enables/Disables issuing of interestGroupAuctionEventOccurred and interestGroupAuctionNetworkRequestCreated.
SetInterestGroupTrackingParams
Enables/Disables issuing of interestGroupAccessed events.
SetProtectedAudienceKAnonymityParams
SetSharedStorageEntryParams
Sets entry with ‘key’ and ‘value’ for a given origin’s shared storage.
SetSharedStorageTrackingParams
Enables/disables issuing of sharedStorageAccessed events.
SetStorageBucketTrackingParams
Set tracking for a storage key’s buckets.
SharedStorageAccessParams
Bundles the parameters for shared storage access events whose presence/absence can vary according to SharedStorageAccessType.
SharedStorageEntry
Struct for a single key-value pair in an origin’s shared storage.
SharedStorageMetadata
Details for an origin’s shared storage.
SharedStoragePrivateAggregationConfig
Represents a dictionary object passed in as privateAggregationConfig to run or selectURL.
SharedStorageReportingMetadata
Pair of reporting metadata details for a candidate URL for ‘selectURL()’.
SharedStorageUrlWithMetadata
Bundles a candidate URL with its reporting metadata.
StorageBucket
StorageBucketInfo
TrackCacheStorageForOriginParams
Registers origin to be notified when an update occurs to its cache storage list.
TrackCacheStorageForStorageKeyParams
Registers storage key to be notified when an update occurs to its cache storage list.
TrackIndexedDBForOriginParams
Registers origin to be notified when an update occurs to its IndexedDB.
TrackIndexedDBForStorageKeyParams
Registers storage key to be notified when an update occurs to its IndexedDB.
TrustTokens
Pair of issuer origin and number of available (signed, but not used) Trust Tokens from that issuer.
UntrackCacheStorageForOriginParams
Unregisters origin from receiving notifications for cache storage.
UntrackCacheStorageForStorageKeyParams
Unregisters storage key from receiving notifications for cache storage.
UntrackIndexedDBForOriginParams
Unregisters origin from receiving notifications for IndexedDB.
UntrackIndexedDBForStorageKeyParams
Unregisters storage key from receiving notifications for IndexedDB.
UsageForType
Usage for a storage type.

Enums

InterestGroupAccessType
Enum of interest group access types.
InterestGroupAuctionEventType
Enum of auction events.
InterestGroupAuctionFetchType
Enum of network fetches auctions can do.
SharedStorageAccessMethod
Enum of shared storage access methods.
SharedStorageAccessScope
Enum of shared storage access scopes.
StorageBucketsDurability
StorageType
Enum of possible storage types.

Type Aliases

InterestGroupAuctionId
Protected audience interest group auction identifier.
SerializedStorageKey