Structs
- Clear
Cookies Params - Clears cookies.
- Clear
Data ForOrigin Params - Clears storage for origin.
- Clear
Data ForStorage KeyParams - Clears storage for storage key.
- Clear
Shared Storage Entries Params - Clears all entries for a given origin’s shared storage.
- Clear
Trust Tokens Params - Removes all Trust Tokens issued by the provided issuerOrigin. Leaves other stored data, including the issuer’s Redemption Records, intact.
- Clear
Trust Tokens Returns - Removes all Trust Tokens issued by the provided issuerOrigin. Leaves other stored data, including the issuer’s Redemption Records, intact.
- Delete
Shared Storage Entry Params - Deletes entry for ‘key’ (if it exists) for a given origin’s shared storage.
- Delete
Storage Bucket Params - Deletes the Storage Bucket with the given storage key and bucket name.
- GetCookies
Params - Returns all browser cookies.
- GetCookies
Returns - Returns all browser cookies.
- GetInterest
Group Details Params - Gets details for a named interest group.
- GetInterest
Group Details Returns - Gets details for a named interest group.
- GetRelated
Website Sets Params - GetRelated
Website Sets Returns - Returns the effective Related Website Sets in use by this profile for the browser session. The effective Related Website Sets will not change during a browser session.
- GetShared
Storage Entries Params - Gets the entries in an given origin’s shared storage.
- GetShared
Storage Entries Returns - Gets the entries in an given origin’s shared storage.
- GetShared
Storage Metadata Params - Gets metadata for an origin’s shared storage.
- GetShared
Storage Metadata Returns - Gets metadata for an origin’s shared storage.
- GetStorage
KeyFor Frame Params - Returns a storage key given a frame id. Deprecated. Please use Storage.getStorageKey instead.
- GetStorage
KeyFor Frame Returns - Returns a storage key given a frame id. Deprecated. Please use Storage.getStorageKey instead.
- GetStorage
KeyParams - Returns storage key for the given frame. If no frame ID is provided, the storage key of the target executing this command is returned.
- GetStorage
KeyReturns - Returns storage key for the given frame. If no frame ID is provided, the storage key of the target executing this command is returned.
- GetTrust
Tokens Params - GetTrust
Tokens Returns - Returns the number of stored Trust Tokens per issuer for the current browsing context.
- GetUsage
AndQuota Params - Returns usage and quota in bytes.
- GetUsage
AndQuota Returns - Returns usage and quota in bytes.
- Override
Quota ForOrigin Params - Override quota for the specified origin
- Related
Website Set - A single Related Website Set object.
- Reset
Shared Storage Budget Params - Resets the budget for ‘ownerOrigin’ by clearing all budget withdrawals.
- RunBounce
Tracking Mitigations Params - RunBounce
Tracking Mitigations Returns - Deletes state for sites identified as potential bounce trackers, immediately.
- SetCookies
Params - Sets given cookies.
- SetInterest
Group Auction Tracking Params - Enables/Disables issuing of interestGroupAuctionEventOccurred and interestGroupAuctionNetworkRequestCreated.
- SetInterest
Group Tracking Params - Enables/Disables issuing of interestGroupAccessed events.
- SetProtected
AudienceK Anonymity Params - SetShared
Storage Entry Params - Sets entry with ‘key’ and ‘value’ for a given origin’s shared storage.
- SetShared
Storage Tracking Params - Enables/disables issuing of sharedStorageAccessed events.
- SetStorage
Bucket Tracking Params - Set tracking for a storage key’s buckets.
- Shared
Storage Access Params - Bundles the parameters for shared storage access events whose presence/absence can vary according to SharedStorageAccessType.
- Shared
Storage Entry - Struct for a single key-value pair in an origin’s shared storage.
- Shared
Storage Metadata - Details for an origin’s shared storage.
- Shared
Storage Private Aggregation Config - Represents a dictionary object passed in as privateAggregationConfig to run or selectURL.
- Shared
Storage Reporting Metadata - Pair of reporting metadata details for a candidate URL for ‘selectURL()’.
- Shared
Storage UrlWith Metadata - Bundles a candidate URL with its reporting metadata.
- Storage
Bucket - Storage
Bucket Info - Track
Cache Storage ForOrigin Params - Registers origin to be notified when an update occurs to its cache storage list.
- Track
Cache Storage ForStorage KeyParams - Registers storage key to be notified when an update occurs to its cache storage list.
- Track
IndexedDB ForOrigin Params - Registers origin to be notified when an update occurs to its IndexedDB.
- Track
IndexedDB ForStorage KeyParams - Registers storage key to be notified when an update occurs to its IndexedDB.
- Trust
Tokens - Pair of issuer origin and number of available (signed, but not used) Trust Tokens from that issuer.
- Untrack
Cache Storage ForOrigin Params - Unregisters origin from receiving notifications for cache storage.
- Untrack
Cache Storage ForStorage KeyParams - Unregisters storage key from receiving notifications for cache storage.
- Untrack
IndexedDB ForOrigin Params - Unregisters origin from receiving notifications for IndexedDB.
- Untrack
IndexedDB ForStorage KeyParams - Unregisters storage key from receiving notifications for IndexedDB.
- Usage
ForType - Usage for a storage type.
Enums
- Interest
Group Access Type - Enum of interest group access types.
- Interest
Group Auction Event Type - Enum of auction events.
- Interest
Group Auction Fetch Type - Enum of network fetches auctions can do.
- Shared
Storage Access Method - Enum of shared storage access methods.
- Shared
Storage Access Scope - Enum of shared storage access scopes.
- Storage
Buckets Durability - Storage
Type - Enum of possible storage types.
Type Aliases
- Interest
Group Auction Id - Protected audience interest group auction identifier.
- Serialized
Storage Key