pub struct OverrideQuotaForOriginParamsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> OverrideQuotaForOriginParamsBuilder<'a>
impl<'a> OverrideQuotaForOriginParamsBuilder<'a>
Sourcepub fn quotaSize(self, quotaSize: f64) -> Self
pub fn quotaSize(self, quotaSize: f64) -> Self
The quota size (in bytes) to override the original quota with. If this is called multiple times, the overridden quota will be equal to the quotaSize provided in the final call. If this is called without specifying a quotaSize, the quota will be reset to the default value for the specified origin. If this is called multiple times with different origins, the override will be maintained for each origin until it is disabled (called without a quotaSize).
pub fn build(self) -> OverrideQuotaForOriginParams<'a>