pub struct RelatedWebsiteSet {
pub primarySites: Vec<String>,
pub associatedSites: Vec<String>,
pub serviceSites: Vec<String>,
}Expand description
A single Related Website Set object.
Fields
primarySites: Vec<String>The primary site of this set, along with the ccTLDs if there is any.
associatedSites: Vec<String>The associated sites of this set, along with the ccTLDs if there is any.
serviceSites: Vec<String>The service sites of this set, along with the ccTLDs if there is any.