pub struct SharedStorageAccessParams<'a> { /* private fields */ }Expand description
Bundles the parameters for shared storage access events whose presence/absence can vary according to SharedStorageAccessType.
Implementations
Sourcepub fn builder() -> SharedStorageAccessParamsBuilder<'a>
pub fn builder() -> SharedStorageAccessParamsBuilder<'a>
Creates a builder for this type.
Sourcepub fn script_source_url(&self) -> Option<&str>
pub fn script_source_url(&self) -> Option<&str>
Spec of the module script URL. Present only for SharedStorageAccessMethods: addModule and createWorklet.
Sourcepub fn data_origin(&self) -> Option<&str>
pub fn data_origin(&self) -> Option<&str>
String denoting “context-origin”, “script-origin”, or a custom origin to be used as the worklet’s data origin. Present only for SharedStorageAccessMethod: createWorklet.
Sourcepub fn operation_name(&self) -> Option<&str>
pub fn operation_name(&self) -> Option<&str>
Name of the registered operation to be run. Present only for SharedStorageAccessMethods: run and selectURL.
Sourcepub fn operation_id(&self) -> Option<&str>
pub fn operation_id(&self) -> Option<&str>
ID of the operation call. Present only for SharedStorageAccessMethods: run and selectURL.
Sourcepub fn keep_alive(&self) -> Option<bool>
pub fn keep_alive(&self) -> Option<bool>
Whether or not to keep the worket alive for future run or selectURL calls. Present only for SharedStorageAccessMethods: run and selectURL.
Sourcepub fn private_aggregation_config(
&self,
) -> Option<&SharedStoragePrivateAggregationConfig<'a>>
pub fn private_aggregation_config( &self, ) -> Option<&SharedStoragePrivateAggregationConfig<'a>>
Configures the private aggregation options. Present only for SharedStorageAccessMethods: run and selectURL.
Sourcepub fn serialized_data(&self) -> Option<&str>
pub fn serialized_data(&self) -> Option<&str>
The operation’s serialized data in bytes (converted to a string). Present only for SharedStorageAccessMethods: run and selectURL. TODO(crbug.com/401011862): Consider updating this parameter to binary.
Sourcepub fn urls_with_metadata(&self) -> Option<&[SharedStorageUrlWithMetadata<'a>]>
pub fn urls_with_metadata(&self) -> Option<&[SharedStorageUrlWithMetadata<'a>]>
Array of candidate URLs’ specs, along with any associated metadata. Present only for SharedStorageAccessMethod: selectURL.
Sourcepub fn urn_uuid(&self) -> Option<&str>
pub fn urn_uuid(&self) -> Option<&str>
Spec of the URN:UUID generated for a selectURL call. Present only for SharedStorageAccessMethod: selectURL.
Sourcepub fn key(&self) -> Option<&str>
pub fn key(&self) -> Option<&str>
Key for a specific entry in an origin’s shared storage. Present only for SharedStorageAccessMethods: set, append, delete, and get.
Sourcepub fn value(&self) -> Option<&str>
pub fn value(&self) -> Option<&str>
Value for a specific entry in an origin’s shared storage. Present only for SharedStorageAccessMethods: set and append.
Sourcepub fn ignore_if_present(&self) -> Option<bool>
pub fn ignore_if_present(&self) -> Option<bool>
Whether or not to set an entry for a key if that key is already present. Present only for SharedStorageAccessMethod: set.
Sourcepub fn worklet_ordinal(&self) -> Option<i64>
pub fn worklet_ordinal(&self) -> Option<i64>
A number denoting the (0-based) order of the worklet’s creation relative to all other shared storage worklets created by documents using the current storage partition. Present only for SharedStorageAccessMethods: addModule, createWorklet.
Sourcepub fn worklet_target_id(&self) -> Option<&TargetID<'a>>
pub fn worklet_target_id(&self) -> Option<&TargetID<'a>>
Hex representation of the DevTools token used as the TargetID for the associated shared storage worklet. Present only for SharedStorageAccessMethods: addModule, createWorklet, run, selectURL, and any other SharedStorageAccessMethod when the SharedStorageAccessScope is sharedStorageWorklet.
Sourcepub fn with_lock(&self) -> Option<&str>
pub fn with_lock(&self) -> Option<&str>
Name of the lock to be acquired, if present. Optionally present only for SharedStorageAccessMethods: batchUpdate, set, append, delete, and clear.
Sourcepub fn batch_update_id(&self) -> Option<&str>
pub fn batch_update_id(&self) -> Option<&str>
If the method has been called as part of a batchUpdate, then this number identifies the batch to which it belongs. Optionally present only for SharedStorageAccessMethods: batchUpdate (required), set, append, delete, and clear.
Sourcepub fn batch_size(&self) -> Option<u64>
pub fn batch_size(&self) -> Option<u64>
Number of modifier methods sent in batch. Present only for SharedStorageAccessMethod: batchUpdate.