pub struct SharedStorageAccessParamsBuilder<'a> { /* private fields */ }Implementations
Sourcepub fn script_source_url(
self,
script_source_url: impl Into<Cow<'a, str>>,
) -> Self
pub fn script_source_url( self, script_source_url: impl Into<Cow<'a, str>>, ) -> Self
Spec of the module script URL. Present only for SharedStorageAccessMethods: addModule and createWorklet.
Sourcepub fn data_origin(self, data_origin: impl Into<Cow<'a, str>>) -> Self
pub fn data_origin(self, data_origin: impl Into<Cow<'a, str>>) -> Self
String denoting “context-origin”, “script-origin”, or a custom origin to be used as the worklet’s data origin. Present only for SharedStorageAccessMethod: createWorklet.
Sourcepub fn operation_name(self, operation_name: impl Into<Cow<'a, str>>) -> Self
pub fn operation_name(self, operation_name: impl Into<Cow<'a, str>>) -> Self
Name of the registered operation to be run. Present only for SharedStorageAccessMethods: run and selectURL.
Sourcepub fn operation_id(self, operation_id: impl Into<Cow<'a, str>>) -> Self
pub fn operation_id(self, operation_id: impl Into<Cow<'a, str>>) -> Self
ID of the operation call. Present only for SharedStorageAccessMethods: run and selectURL.
Sourcepub fn keep_alive(self, keep_alive: bool) -> Self
pub fn keep_alive(self, keep_alive: bool) -> Self
Whether or not to keep the worket alive for future run or selectURL calls. Present only for SharedStorageAccessMethods: run and selectURL.
Sourcepub fn private_aggregation_config(
self,
private_aggregation_config: SharedStoragePrivateAggregationConfig<'a>,
) -> Self
pub fn private_aggregation_config( self, private_aggregation_config: SharedStoragePrivateAggregationConfig<'a>, ) -> Self
Configures the private aggregation options. Present only for SharedStorageAccessMethods: run and selectURL.
Sourcepub fn serialized_data(self, serialized_data: impl Into<Cow<'a, str>>) -> Self
pub fn serialized_data(self, serialized_data: impl Into<Cow<'a, str>>) -> Self
The operation’s serialized data in bytes (converted to a string). Present only for SharedStorageAccessMethods: run and selectURL. TODO(crbug.com/401011862): Consider updating this parameter to binary.
Sourcepub fn urls_with_metadata(
self,
urls_with_metadata: Vec<SharedStorageUrlWithMetadata<'a>>,
) -> Self
pub fn urls_with_metadata( self, urls_with_metadata: Vec<SharedStorageUrlWithMetadata<'a>>, ) -> Self
Array of candidate URLs’ specs, along with any associated metadata. Present only for SharedStorageAccessMethod: selectURL.
Sourcepub fn urn_uuid(self, urn_uuid: impl Into<Cow<'a, str>>) -> Self
pub fn urn_uuid(self, urn_uuid: impl Into<Cow<'a, str>>) -> Self
Spec of the URN:UUID generated for a selectURL call. Present only for SharedStorageAccessMethod: selectURL.
Sourcepub fn key(self, key: impl Into<Cow<'a, str>>) -> Self
pub fn key(self, key: impl Into<Cow<'a, str>>) -> Self
Key for a specific entry in an origin’s shared storage. Present only for SharedStorageAccessMethods: set, append, delete, and get.
Sourcepub fn value(self, value: impl Into<Cow<'a, str>>) -> Self
pub fn value(self, value: impl Into<Cow<'a, str>>) -> Self
Value for a specific entry in an origin’s shared storage. Present only for SharedStorageAccessMethods: set and append.
Sourcepub fn ignore_if_present(self, ignore_if_present: bool) -> Self
pub fn ignore_if_present(self, ignore_if_present: bool) -> Self
Whether or not to set an entry for a key if that key is already present. Present only for SharedStorageAccessMethod: set.
Sourcepub fn worklet_ordinal(self, worklet_ordinal: i64) -> Self
pub fn worklet_ordinal(self, worklet_ordinal: i64) -> Self
A number denoting the (0-based) order of the worklet’s creation relative to all other shared storage worklets created by documents using the current storage partition. Present only for SharedStorageAccessMethods: addModule, createWorklet.
Sourcepub fn worklet_target_id(self, worklet_target_id: TargetID<'a>) -> Self
pub fn worklet_target_id(self, worklet_target_id: TargetID<'a>) -> Self
Hex representation of the DevTools token used as the TargetID for the associated shared storage worklet. Present only for SharedStorageAccessMethods: addModule, createWorklet, run, selectURL, and any other SharedStorageAccessMethod when the SharedStorageAccessScope is sharedStorageWorklet.
Sourcepub fn with_lock(self, with_lock: impl Into<Cow<'a, str>>) -> Self
pub fn with_lock(self, with_lock: impl Into<Cow<'a, str>>) -> Self
Name of the lock to be acquired, if present. Optionally present only for SharedStorageAccessMethods: batchUpdate, set, append, delete, and clear.
Sourcepub fn batch_update_id(self, batch_update_id: impl Into<Cow<'a, str>>) -> Self
pub fn batch_update_id(self, batch_update_id: impl Into<Cow<'a, str>>) -> Self
If the method has been called as part of a batchUpdate, then this number identifies the batch to which it belongs. Optionally present only for SharedStorageAccessMethods: batchUpdate (required), set, append, delete, and clear.
Sourcepub fn batch_size(self, batch_size: u64) -> Self
pub fn batch_size(self, batch_size: u64) -> Self
Number of modifier methods sent in batch. Present only for SharedStorageAccessMethod: batchUpdate.