SharedStorageAccessParamsBuilder

Struct SharedStorageAccessParamsBuilder 

pub struct SharedStorageAccessParamsBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> SharedStorageAccessParamsBuilder<'a>

pub fn scriptSourceUrl(self, scriptSourceUrl: impl Into<Cow<'a, str>>) -> Self

Spec of the module script URL. Present only for SharedStorageAccessMethods: addModule and createWorklet.

pub fn dataOrigin(self, dataOrigin: impl Into<Cow<'a, str>>) -> Self

String denoting “context-origin”, “script-origin”, or a custom origin to be used as the worklet’s data origin. Present only for SharedStorageAccessMethod: createWorklet.

pub fn operationName(self, operationName: impl Into<Cow<'a, str>>) -> Self

Name of the registered operation to be run. Present only for SharedStorageAccessMethods: run and selectURL.

pub fn operationId(self, operationId: impl Into<Cow<'a, str>>) -> Self

ID of the operation call. Present only for SharedStorageAccessMethods: run and selectURL.

pub fn keepAlive(self, keepAlive: bool) -> Self

Whether or not to keep the worket alive for future run or selectURL calls. Present only for SharedStorageAccessMethods: run and selectURL.

pub fn privateAggregationConfig( self, privateAggregationConfig: SharedStoragePrivateAggregationConfig<'a>, ) -> Self

Configures the private aggregation options. Present only for SharedStorageAccessMethods: run and selectURL.

pub fn serializedData(self, serializedData: impl Into<Cow<'a, str>>) -> Self

The operation’s serialized data in bytes (converted to a string). Present only for SharedStorageAccessMethods: run and selectURL. TODO(crbug.com/401011862): Consider updating this parameter to binary.

pub fn urlsWithMetadata( self, urlsWithMetadata: Vec<SharedStorageUrlWithMetadata<'a>>, ) -> Self

Array of candidate URLs’ specs, along with any associated metadata. Present only for SharedStorageAccessMethod: selectURL.

pub fn urnUuid(self, urnUuid: impl Into<Cow<'a, str>>) -> Self

Spec of the URN:UUID generated for a selectURL call. Present only for SharedStorageAccessMethod: selectURL.

pub fn key(self, key: impl Into<Cow<'a, str>>) -> Self

Key for a specific entry in an origin’s shared storage. Present only for SharedStorageAccessMethods: set, append, delete, and get.

pub fn value(self, value: impl Into<Cow<'a, str>>) -> Self

Value for a specific entry in an origin’s shared storage. Present only for SharedStorageAccessMethods: set and append.

pub fn ignoreIfPresent(self, ignoreIfPresent: bool) -> Self

Whether or not to set an entry for a key if that key is already present. Present only for SharedStorageAccessMethod: set.

pub fn workletOrdinal(self, workletOrdinal: i64) -> Self

A number denoting the (0-based) order of the worklet’s creation relative to all other shared storage worklets created by documents using the current storage partition. Present only for SharedStorageAccessMethods: addModule, createWorklet.

pub fn workletTargetId(self, workletTargetId: TargetID<'a>) -> Self

Hex representation of the DevTools token used as the TargetID for the associated shared storage worklet. Present only for SharedStorageAccessMethods: addModule, createWorklet, run, selectURL, and any other SharedStorageAccessMethod when the SharedStorageAccessScope is sharedStorageWorklet.

pub fn withLock(self, withLock: impl Into<Cow<'a, str>>) -> Self

Name of the lock to be acquired, if present. Optionally present only for SharedStorageAccessMethods: batchUpdate, set, append, delete, and clear.

pub fn batchUpdateId(self, batchUpdateId: impl Into<Cow<'a, str>>) -> Self

If the method has been called as part of a batchUpdate, then this number identifies the batch to which it belongs. Optionally present only for SharedStorageAccessMethods: batchUpdate (required), set, append, delete, and clear.

pub fn batchSize(self, batchSize: u64) -> Self

Number of modifier methods sent in batch. Present only for SharedStorageAccessMethod: batchUpdate.

pub fn build(self) -> SharedStorageAccessParams<'a>