pub struct SharedStorageAccessParamsBuilder<'a> { /* private fields */ }Implementations
Sourcepub fn scriptSourceUrl(self, scriptSourceUrl: impl Into<Cow<'a, str>>) -> Self
pub fn scriptSourceUrl(self, scriptSourceUrl: impl Into<Cow<'a, str>>) -> Self
Spec of the module script URL. Present only for SharedStorageAccessMethods: addModule and createWorklet.
Sourcepub fn dataOrigin(self, dataOrigin: impl Into<Cow<'a, str>>) -> Self
pub fn dataOrigin(self, dataOrigin: impl Into<Cow<'a, str>>) -> Self
String denoting “context-origin”, “script-origin”, or a custom origin to be used as the worklet’s data origin. Present only for SharedStorageAccessMethod: createWorklet.
Sourcepub fn operationName(self, operationName: impl Into<Cow<'a, str>>) -> Self
pub fn operationName(self, operationName: impl Into<Cow<'a, str>>) -> Self
Name of the registered operation to be run. Present only for SharedStorageAccessMethods: run and selectURL.
Sourcepub fn operationId(self, operationId: impl Into<Cow<'a, str>>) -> Self
pub fn operationId(self, operationId: impl Into<Cow<'a, str>>) -> Self
ID of the operation call. Present only for SharedStorageAccessMethods: run and selectURL.
Sourcepub fn keepAlive(self, keepAlive: bool) -> Self
pub fn keepAlive(self, keepAlive: bool) -> Self
Whether or not to keep the worket alive for future run or selectURL calls. Present only for SharedStorageAccessMethods: run and selectURL.
Sourcepub fn privateAggregationConfig(
self,
privateAggregationConfig: SharedStoragePrivateAggregationConfig<'a>,
) -> Self
pub fn privateAggregationConfig( self, privateAggregationConfig: SharedStoragePrivateAggregationConfig<'a>, ) -> Self
Configures the private aggregation options. Present only for SharedStorageAccessMethods: run and selectURL.
Sourcepub fn serializedData(self, serializedData: impl Into<Cow<'a, str>>) -> Self
pub fn serializedData(self, serializedData: impl Into<Cow<'a, str>>) -> Self
The operation’s serialized data in bytes (converted to a string). Present only for SharedStorageAccessMethods: run and selectURL. TODO(crbug.com/401011862): Consider updating this parameter to binary.
Sourcepub fn urlsWithMetadata(
self,
urlsWithMetadata: Vec<SharedStorageUrlWithMetadata<'a>>,
) -> Self
pub fn urlsWithMetadata( self, urlsWithMetadata: Vec<SharedStorageUrlWithMetadata<'a>>, ) -> Self
Array of candidate URLs’ specs, along with any associated metadata. Present only for SharedStorageAccessMethod: selectURL.
Sourcepub fn urnUuid(self, urnUuid: impl Into<Cow<'a, str>>) -> Self
pub fn urnUuid(self, urnUuid: impl Into<Cow<'a, str>>) -> Self
Spec of the URN:UUID generated for a selectURL call. Present only for SharedStorageAccessMethod: selectURL.
Sourcepub fn key(self, key: impl Into<Cow<'a, str>>) -> Self
pub fn key(self, key: impl Into<Cow<'a, str>>) -> Self
Key for a specific entry in an origin’s shared storage. Present only for SharedStorageAccessMethods: set, append, delete, and get.
Sourcepub fn value(self, value: impl Into<Cow<'a, str>>) -> Self
pub fn value(self, value: impl Into<Cow<'a, str>>) -> Self
Value for a specific entry in an origin’s shared storage. Present only for SharedStorageAccessMethods: set and append.
Sourcepub fn ignoreIfPresent(self, ignoreIfPresent: bool) -> Self
pub fn ignoreIfPresent(self, ignoreIfPresent: bool) -> Self
Whether or not to set an entry for a key if that key is already present. Present only for SharedStorageAccessMethod: set.
Sourcepub fn workletOrdinal(self, workletOrdinal: i64) -> Self
pub fn workletOrdinal(self, workletOrdinal: i64) -> Self
A number denoting the (0-based) order of the worklet’s creation relative to all other shared storage worklets created by documents using the current storage partition. Present only for SharedStorageAccessMethods: addModule, createWorklet.
Sourcepub fn workletTargetId(self, workletTargetId: TargetID<'a>) -> Self
pub fn workletTargetId(self, workletTargetId: TargetID<'a>) -> Self
Hex representation of the DevTools token used as the TargetID for the associated shared storage worklet. Present only for SharedStorageAccessMethods: addModule, createWorklet, run, selectURL, and any other SharedStorageAccessMethod when the SharedStorageAccessScope is sharedStorageWorklet.
Sourcepub fn withLock(self, withLock: impl Into<Cow<'a, str>>) -> Self
pub fn withLock(self, withLock: impl Into<Cow<'a, str>>) -> Self
Name of the lock to be acquired, if present. Optionally present only for SharedStorageAccessMethods: batchUpdate, set, append, delete, and clear.
Sourcepub fn batchUpdateId(self, batchUpdateId: impl Into<Cow<'a, str>>) -> Self
pub fn batchUpdateId(self, batchUpdateId: impl Into<Cow<'a, str>>) -> Self
If the method has been called as part of a batchUpdate, then this number identifies the batch to which it belongs. Optionally present only for SharedStorageAccessMethods: batchUpdate (required), set, append, delete, and clear.
Sourcepub fn batchSize(self, batchSize: u64) -> Self
pub fn batchSize(self, batchSize: u64) -> Self
Number of modifier methods sent in batch. Present only for SharedStorageAccessMethod: batchUpdate.