The SystemInfo domain defines methods and events for querying low-level system information.
Structs
- GPUDevice
- Describes a single graphics processor (GPU).
- GPUInfo
- Provides information about the GPU(s) on the system.
- GetFeature
State Params - Returns information about the feature state.
- GetFeature
State Returns - Returns information about the feature state.
- GetInfo
Params - GetInfo
Returns - Returns information about the system.
- GetProcess
Info Params - GetProcess
Info Returns - Returns information about all running processes.
- Process
Info - Represents process info.
- Size
- Describes the width and height dimensions of an entity.
- Video
Decode Accelerator Capability - Describes a supported video decoding profile with its associated minimum and maximum resolutions.
- Video
Encode Accelerator Capability - Describes a supported video encoding profile with its associated maximum resolution and maximum framerate.
Enums
- Image
Type - Image format of a given image.
- Subsampling
Format - YUV subsampling type of the pixels of a given image.