Module systeminfo

Module systeminfo 

The SystemInfo domain defines methods and events for querying low-level system information.

Structs

GPUDevice
Describes a single graphics processor (GPU).
GPUDeviceBuilder
GPUInfo
Provides information about the GPU(s) on the system.
GPUInfoBuilder
GetFeatureStateParams
Returns information about the feature state.
GetFeatureStateParamsBuilder
GetFeatureStateReturns
Returns information about the feature state.
GetFeatureStateReturnsBuilder
GetInfoParams
GetInfoReturns
Returns information about the system.
GetInfoReturnsBuilder
GetProcessInfoParams
GetProcessInfoReturns
Returns information about all running processes.
GetProcessInfoReturnsBuilder
ProcessInfo
Represents process info.
ProcessInfoBuilder
Size
Describes the width and height dimensions of an entity.
SizeBuilder
VideoDecodeAcceleratorCapability
Describes a supported video decoding profile with its associated minimum and maximum resolutions.
VideoDecodeAcceleratorCapabilityBuilder
VideoEncodeAcceleratorCapability
Describes a supported video encoding profile with its associated maximum resolution and maximum framerate.
VideoEncodeAcceleratorCapabilityBuilder

Enums

ImageType
Image format of a given image.
SubsamplingFormat
YUV subsampling type of the pixels of a given image.