pub struct VideoDecodeAcceleratorCapability {
pub profile: String,
pub maxResolution: Size,
pub minResolution: Size,
}Expand description
Describes a supported video decoding profile with its associated minimum and maximum resolutions.
Fields
profile: StringVideo codec profile that is supported, e.g. VP9 Profile 2.
maxResolution: SizeMaximum video dimensions in pixels supported for this |profile|.
minResolution: SizeMinimum video dimensions in pixels supported for this |profile|.