Supports additional targets discovery and allows to attach to them.
Structs
- Activate
Target Params - Activates (focuses) the target.
- Activate
Target Params Builder - Attach
ToBrowser Target Params - Attach
ToBrowser Target Returns - Attaches to the browser target, only uses flat sessionId mode.
- Attach
ToBrowser Target Returns Builder - Attach
ToTarget Params - Attaches to the target with given id.
- Attach
ToTarget Params Builder - Attach
ToTarget Returns - Attaches to the target with given id.
- Attach
ToTarget Returns Builder - Auto
Attach Related Params - Adds the specified target to the list of targets that will be monitored for any related target creation (such as child frames, child workers and new versions of service worker) and reported through ‘attachedToTarget’. The specified target is also auto-attached. This cancels the effect of any previous ‘setAutoAttach’ and is also cancelled by subsequent ‘setAutoAttach’. Only available at the Browser target.
- Auto
Attach Related Params Builder - Close
Target Params - Closes the target. If the target is a page that gets closed too.
- Close
Target Params Builder - Close
Target Returns - Closes the target. If the target is a page that gets closed too.
- Close
Target Returns Builder - Create
Browser Context Params - Creates a new empty BrowserContext. Similar to an incognito profile but you can have more than one.
- Create
Browser Context Params Builder - Create
Browser Context Returns - Creates a new empty BrowserContext. Similar to an incognito profile but you can have more than one.
- Create
Browser Context Returns Builder - Create
Target Params - Creates a new page.
- Create
Target Params Builder - Create
Target Returns - Creates a new page.
- Create
Target Returns Builder - Detach
From Target Params - Detaches session with given id.
- Detach
From Target Params Builder - Dispose
Browser Context Params - Deletes a BrowserContext. All the belonging pages will be closed without calling their beforeunload hooks.
- Dispose
Browser Context Params Builder - Expose
DevTools Protocol Params - Inject object to the target’s main frame that provides a communication channel with browser target.
- Expose
DevTools Protocol Params Builder - Filter
Entry - A filter used by target query/discovery/auto-attach operations.
- Filter
Entry Builder - GetBrowser
Contexts Params - GetBrowser
Contexts Returns - Returns all browser contexts created with ‘Target.createBrowserContext’ method.
- GetBrowser
Contexts Returns Builder - GetDev
Tools Target Params - Gets the targetId of the DevTools page target opened for the given target (if any).
- GetDev
Tools Target Params Builder - GetDev
Tools Target Returns - Gets the targetId of the DevTools page target opened for the given target (if any).
- GetDev
Tools Target Returns Builder - GetTarget
Info Params - Returns information about a target.
- GetTarget
Info Params Builder - GetTarget
Info Returns - Returns information about a target.
- GetTarget
Info Returns Builder - GetTargets
Params - Retrieves a list of available targets.
- GetTargets
Params Builder - GetTargets
Returns - Retrieves a list of available targets.
- GetTargets
Returns Builder - Open
DevTools Params - Opens a DevTools window for the target.
- Open
DevTools Params Builder - Open
DevTools Returns - Opens a DevTools window for the target.
- Open
DevTools Returns Builder - Remote
Location - Remote
Location Builder - Send
Message ToTarget Params - Sends protocol message over session with given id. Consider using flat mode instead; see commands attachToTarget, setAutoAttach, and crbug.com/991325.
- Send
Message ToTarget Params Builder - SetAuto
Attach Params - Controls whether to automatically attach to new targets which are considered to be directly related to this one (for example, iframes or workers). When turned on, attaches to all existing related targets as well. When turned off, automatically detaches from all currently attached targets. This also clears all targets added by ‘autoAttachRelated’ from the list of targets to watch for creation of related targets. You might want to call this recursively for auto-attached targets to attach to all available targets.
- SetAuto
Attach Params Builder - SetDiscover
Targets Params - Controls whether to discover available targets and notify via ‘targetCreated/targetInfoChanged/targetDestroyed’ events.
- SetDiscover
Targets Params Builder - SetRemote
Locations Params - Enables target discovery for the specified locations, when ‘setDiscoverTargets’ was set to ‘true’.
- SetRemote
Locations Params Builder - Target
Info - Target
Info Builder
Enums
- Window
State - The state of the target window.
Type Aliases
- SessionID
- Unique identifier of attached debugging session.
- Target
Filter - The entries in TargetFilter are matched sequentially against targets and the first entry that matches determines if the target is included or not, depending on the value of ‘exclude’ field in the entry. If filter is not specified, the one assumed is [{type: “browser”, exclude: true}, {type: “tab”, exclude: true}, {}] (i.e. include everything but ‘browser’ and ‘tab’).
- TargetID