AutoAttachRelatedParams

Struct AutoAttachRelatedParams 

pub struct AutoAttachRelatedParams<'a> { /* private fields */ }
Adds the specified target to the list of targets that will be monitored for any related target creation (such as child frames, child workers and new versions of service worker) and reported through ‘attachedToTarget’. The specified target is also auto-attached. This cancels the effect of any previous ‘setAutoAttach’ and is also cancelled by subsequent ‘setAutoAttach’. Only available at the Browser target.

Implementations

Source

impl<'a> AutoAttachRelatedParams<'a>

pub fn builder( targetId: TargetID<'a>, waitForDebuggerOnStart: bool, ) -> AutoAttachRelatedParamsBuilder<'a>

pub fn targetId(&self) -> &TargetID<'a>

pub fn waitForDebuggerOnStart(&self) -> bool

pub fn filter(&self) -> Option<&TargetFilter<'a>>

Source

impl<'a> AutoAttachRelatedParams<'a>

pub const METHOD: &'static str = "Target.autoAttachRelated"