pub struct CreateBrowserContextParamsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> CreateBrowserContextParamsBuilder<'a>
impl<'a> CreateBrowserContextParamsBuilder<'a>
Sourcepub fn disposeOnDetach(self, disposeOnDetach: bool) -> Self
pub fn disposeOnDetach(self, disposeOnDetach: bool) -> Self
If specified, disposes this context when debugging session disconnects.
Sourcepub fn proxyServer(self, proxyServer: impl Into<Cow<'a, str>>) -> Self
pub fn proxyServer(self, proxyServer: impl Into<Cow<'a, str>>) -> Self
Proxy server, similar to the one passed to –proxy-server
Sourcepub fn proxyBypassList(self, proxyBypassList: impl Into<Cow<'a, str>>) -> Self
pub fn proxyBypassList(self, proxyBypassList: impl Into<Cow<'a, str>>) -> Self
Proxy bypass list, similar to the one passed to –proxy-bypass-list
Sourcepub fn originsWithUniversalNetworkAccess(
self,
originsWithUniversalNetworkAccess: Vec<Cow<'a, str>>,
) -> Self
pub fn originsWithUniversalNetworkAccess( self, originsWithUniversalNetworkAccess: Vec<Cow<'a, str>>, ) -> Self
An optional list of origins to grant unlimited cross-origin access to. Parts of the URL other than those constituting origin are ignored.
pub fn build(self) -> CreateBrowserContextParams<'a>