pub struct ExposeDevToolsProtocolParams<'a> { /* private fields */ }Expand description
Inject object to the target’s main frame that provides a communication channel with browser target.
Injected object will be available as ‘window[bindingName]’.
The object has the following API:
- ‘binding.send(json)’ - a method to send messages over the remote debugging protocol
- ‘binding.onmessage = json => handleMessage(json)’ - a callback that will be called for the protocol notifications and command responses.
Implementations
Sourceimpl<'a> ExposeDevToolsProtocolParams<'a>
impl<'a> ExposeDevToolsProtocolParams<'a>
pub fn builder( targetId: TargetID<'a>, ) -> ExposeDevToolsProtocolParamsBuilder<'a>
pub fn targetId(&self) -> &TargetID<'a>
pub fn bindingName(&self) -> Option<&str>
pub fn inheritPermissions(&self) -> Option<bool>