pub struct ExposeDevToolsProtocolParams {
pub targetId: TargetID,
pub bindingName: Option<String>,
pub inheritPermissions: Option<bool>,
}Expand description
Inject object to the target’s main frame that provides a communication channel with browser target.
Injected object will be available as ‘window[bindingName]’.
The object has the following API:
- ‘binding.send(json)’ - a method to send messages over the remote debugging protocol
- ‘binding.onmessage = json => handleMessage(json)’ - a callback that will be called for the protocol notifications and command responses.
Fields
targetId: TargetIDbindingName: Option<String>Binding name, ‘cdp’ if not specified.
inheritPermissions: Option<bool>If true, inherits the current root session’s permissions (default: false).