pub struct SetAutoAttachParams<'a> { /* private fields */ }Expand description
Controls whether to automatically attach to new targets which are considered to be directly related to this one (for example, iframes or workers). When turned on, attaches to all existing related targets as well. When turned off, automatically detaches from all currently attached targets. This also clears all targets added by ‘autoAttachRelated’ from the list of targets to watch for creation of related targets. You might want to call this recursively for auto-attached targets to attach to all available targets.
Implementations
Sourceimpl<'a> SetAutoAttachParams<'a>
impl<'a> SetAutoAttachParams<'a>
pub fn builder( autoAttach: bool, waitForDebuggerOnStart: bool, ) -> SetAutoAttachParamsBuilder<'a>
pub fn autoAttach(&self) -> bool
pub fn waitForDebuggerOnStart(&self) -> bool
pub fn flatten(&self) -> Option<bool>
pub fn filter(&self) -> Option<&TargetFilter<'a>>