SetAutoAttachParams

Struct SetAutoAttachParams 

pub struct SetAutoAttachParams {
    pub autoAttach: bool,
    pub waitForDebuggerOnStart: bool,
    pub flatten: Option<bool>,
    pub filter: Option<TargetFilter>,
}
Controls whether to automatically attach to new targets which are considered to be directly related to this one (for example, iframes or workers). When turned on, attaches to all existing related targets as well. When turned off, automatically detaches from all currently attached targets. This also clears all targets added by ‘autoAttachRelated’ from the list of targets to watch for creation of related targets. You might want to call this recursively for auto-attached targets to attach to all available targets.

Fields

autoAttach: bool

Whether to auto-attach to related targets.

waitForDebuggerOnStart: bool

Whether to pause new targets when attaching to them. Use ‘Runtime.runIfWaitingForDebugger’ to run paused targets.

flatten: Option<bool>

Enables “flat” access to the session via specifying sessionId attribute in the commands. We plan to make this the default, deprecate non-flattened mode, and eventually retire it. See crbug.com/991325.

filter: Option<TargetFilter>

Only targets matching filter will be attached.

Implementations

Source

impl SetAutoAttachParams

pub const METHOD: &'static str = "Target.setAutoAttach"