pub struct TargetInfo {
pub targetId: TargetID,
pub type_: String,
pub title: String,
pub url: String,
pub attached: bool,
pub openerId: Option<TargetID>,
pub canAccessOpener: bool,
pub openerFrameId: Option<FrameId>,
pub parentFrameId: Option<FrameId>,
pub browserContextId: Option<BrowserContextID>,
pub subtype: Option<String>,
}Fields
targetId: TargetIDtype_: Stringtitle: Stringurl: Stringattached: boolWhether the target has an attached client.
openerId: Option<TargetID>Opener target Id
canAccessOpener: boolWhether the target has access to the originating window.
openerFrameId: Option<FrameId>Frame id of originating window (is only set if target has an opener).
parentFrameId: Option<FrameId>Id of the parent frame, present for “iframe” and “worker” targets. For nested workers, this is the “ancestor” frame that created the first worker in the nested chain.
browserContextId: Option<BrowserContextID>subtype: Option<String>Provides additional details for specific target types. For example, for the type of “page”, this may be set to “prerender”.