Module tracing

Module tracing 

Structs

GetCategoriesReturns
Gets supported tracing categories.
GetTrackEventDescriptorReturns
Return a descriptor for all available tracing categories.
RecordClockSyncMarkerParams
Record a clock sync marker in the trace.
RequestMemoryDumpParams
Request a global memory dump.
RequestMemoryDumpReturns
Request a global memory dump.
StartParams
Start trace events collection.
TraceConfig

Enums

MemoryDumpLevelOfDetail
Details exposed when memory request explicitly declared. Keep consistent with memory_dump_request_args.h and memory_instrumentation.mojom
StreamCompression
Compression type to use for traces returned via streams.
StreamFormat
Data format of a trace. Can be either the legacy JSON format or the protocol buffer format. Note that the JSON format will be deprecated soon.
TracingBackend
Backend type to use for tracing. ‘chrome’ uses the Chrome-integrated tracing service and is supported on all platforms. ‘system’ is only supported on Chrome OS and uses the Perfetto system tracing service. ‘auto’ chooses ‘system’ when the perfettoConfig provided to Tracing.start specifies at least one non-Chrome data source; otherwise uses ‘chrome’.

Type Aliases

MemoryDumpConfig
Configuration for memory dump. Used only when “memory-infra” category is enabled.