pub struct StartParams {
pub categories: Option<String>,
pub options: Option<String>,
pub bufferUsageReportingInterval: Option<f64>,
pub transferMode: Option<String>,
pub streamFormat: Option<StreamFormat>,
pub streamCompression: Option<StreamCompression>,
pub traceConfig: Option<TraceConfig>,
pub perfettoConfig: Option<String>,
pub tracingBackend: Option<TracingBackend>,
}Expand description
Start trace events collection.
Fields
categories: Option<String>Category/tag filter
options: Option<String>Tracing options
bufferUsageReportingInterval: Option<f64>If set, the agent will issue bufferUsage events at this interval, specified in milliseconds
transferMode: Option<String>Whether to report trace events as series of dataCollected events or to save trace to a stream (defaults to ‘ReportEvents’).
streamFormat: Option<StreamFormat>Trace data format to use. This only applies when using ‘ReturnAsStream’ transfer mode (defaults to ‘json’).
streamCompression: Option<StreamCompression>Compression format to use. This only applies when using ‘ReturnAsStream’ transfer mode (defaults to ‘none’)
traceConfig: Option<TraceConfig>perfettoConfig: Option<String>Base64-encoded serialized perfetto.protos.TraceConfig protobuf message When specified, the parameters ‘categories’, ‘options’, ‘traceConfig’ are ignored. (Encoded as a base64 string when passed over JSON)
tracingBackend: Option<TracingBackend>Backend type (defaults to ‘auto’)
Implementations