pub struct StartParamsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> StartParamsBuilder<'a>
impl<'a> StartParamsBuilder<'a>
Sourcepub fn categories(self, categories: impl Into<Cow<'a, str>>) -> Self
pub fn categories(self, categories: impl Into<Cow<'a, str>>) -> Self
Category/tag filter
Sourcepub fn bufferUsageReportingInterval(
self,
bufferUsageReportingInterval: f64,
) -> Self
pub fn bufferUsageReportingInterval( self, bufferUsageReportingInterval: f64, ) -> Self
If set, the agent will issue bufferUsage events at this interval, specified in milliseconds
Sourcepub fn transferMode(self, transferMode: impl Into<Cow<'a, str>>) -> Self
pub fn transferMode(self, transferMode: impl Into<Cow<'a, str>>) -> Self
Whether to report trace events as series of dataCollected events or to save trace to a stream (defaults to ‘ReportEvents’).
Sourcepub fn streamFormat(self, streamFormat: StreamFormat) -> Self
pub fn streamFormat(self, streamFormat: StreamFormat) -> Self
Trace data format to use. This only applies when using ‘ReturnAsStream’ transfer mode (defaults to ‘json’).
Sourcepub fn streamCompression(self, streamCompression: StreamCompression) -> Self
pub fn streamCompression(self, streamCompression: StreamCompression) -> Self
Compression format to use. This only applies when using ‘ReturnAsStream’ transfer mode (defaults to ‘none’)
pub fn traceConfig(self, traceConfig: TraceConfig<'a>) -> Self
Sourcepub fn perfettoConfig(self, perfettoConfig: impl Into<Cow<'a, str>>) -> Self
pub fn perfettoConfig(self, perfettoConfig: impl Into<Cow<'a, str>>) -> Self
Base64-encoded serialized perfetto.protos.TraceConfig protobuf message When specified, the parameters ‘categories’, ‘options’, ‘traceConfig’ are ignored. (Encoded as a base64 string when passed over JSON)
Sourcepub fn tracingBackend(self, tracingBackend: TracingBackend) -> Self
pub fn tracingBackend(self, tracingBackend: TracingBackend) -> Self
Backend type (defaults to ‘auto’)
pub fn build(self) -> StartParams<'a>