Module webauthn

Module webauthn 

This domain allows configuring virtual authenticators to test the WebAuthn API.

Structs

AddCredentialParams
Adds the credential to the specified authenticator.
AddCredentialParamsBuilder
AddVirtualAuthenticatorParams
Creates and adds a virtual authenticator.
AddVirtualAuthenticatorParamsBuilder
AddVirtualAuthenticatorReturns
Creates and adds a virtual authenticator.
AddVirtualAuthenticatorReturnsBuilder
ClearCredentialsParams
Clears all the credentials from the specified device.
ClearCredentialsParamsBuilder
Credential
CredentialBuilder
DisableParams
EnableParams
Enable the WebAuthn domain and start intercepting credential storage and retrieval with a virtual authenticator.
EnableParamsBuilder
GetCredentialParams
Returns a single credential stored in the given virtual authenticator that matches the credential ID.
GetCredentialParamsBuilder
GetCredentialReturns
Returns a single credential stored in the given virtual authenticator that matches the credential ID.
GetCredentialReturnsBuilder
GetCredentialsParams
Returns all the credentials stored in the given virtual authenticator.
GetCredentialsParamsBuilder
GetCredentialsReturns
Returns all the credentials stored in the given virtual authenticator.
GetCredentialsReturnsBuilder
RemoveCredentialParams
Removes a credential from the authenticator.
RemoveCredentialParamsBuilder
RemoveVirtualAuthenticatorParams
Removes the given authenticator.
RemoveVirtualAuthenticatorParamsBuilder
SetAutomaticPresenceSimulationParams
Sets whether tests of user presence will succeed immediately (if true) or fail to resolve (if false) for an authenticator. The default is true.
SetAutomaticPresenceSimulationParamsBuilder
SetCredentialPropertiesParams
Allows setting credential properties. https://w3c.github.io/webauthn/#sctn-automation-set-credential-properties
SetCredentialPropertiesParamsBuilder
SetResponseOverrideBitsParams
Resets parameters isBogusSignature, isBadUV, isBadUP to false if they are not present.
SetResponseOverrideBitsParamsBuilder
SetUserVerifiedParams
Sets whether User Verification succeeds or fails for an authenticator. The default is true.
SetUserVerifiedParamsBuilder
VirtualAuthenticatorOptions
VirtualAuthenticatorOptionsBuilder

Enums

AuthenticatorProtocol
AuthenticatorTransport
Ctap2Version

Type Aliases

AuthenticatorId