Module webauthn

Module webauthn 

This domain allows configuring virtual authenticators to test the WebAuthn API.

Structs

AddCredentialParams
Adds the credential to the specified authenticator.
AddVirtualAuthenticatorParams
Creates and adds a virtual authenticator.
AddVirtualAuthenticatorReturns
Creates and adds a virtual authenticator.
ClearCredentialsParams
Clears all the credentials from the specified device.
Credential
DisableParams
EnableParams
Enable the WebAuthn domain and start intercepting credential storage and retrieval with a virtual authenticator.
GetCredentialParams
Returns a single credential stored in the given virtual authenticator that matches the credential ID.
GetCredentialReturns
Returns a single credential stored in the given virtual authenticator that matches the credential ID.
GetCredentialsParams
Returns all the credentials stored in the given virtual authenticator.
GetCredentialsReturns
Returns all the credentials stored in the given virtual authenticator.
RemoveCredentialParams
Removes a credential from the authenticator.
RemoveVirtualAuthenticatorParams
Removes the given authenticator.
SetAutomaticPresenceSimulationParams
Sets whether tests of user presence will succeed immediately (if true) or fail to resolve (if false) for an authenticator. The default is true.
SetCredentialPropertiesParams
Allows setting credential properties. https://w3c.github.io/webauthn/#sctn-automation-set-credential-properties
SetResponseOverrideBitsParams
Resets parameters isBogusSignature, isBadUV, isBadUP to false if they are not present.
SetUserVerifiedParams
Sets whether User Verification succeeds or fails for an authenticator. The default is true.
VirtualAuthenticatorOptions

Enums

AuthenticatorProtocol
AuthenticatorTransport
Ctap2Version

Type Aliases

AuthenticatorId