This domain allows configuring virtual authenticators to test the WebAuthn API.
Structs
- AddCredential
Params - Adds the credential to the specified authenticator.
- AddVirtual
Authenticator Params - Creates and adds a virtual authenticator.
- AddVirtual
Authenticator Returns - Creates and adds a virtual authenticator.
- Clear
Credentials Params - Clears all the credentials from the specified device.
- Credential
- Disable
Params - Enable
Params - Enable the WebAuthn domain and start intercepting credential storage and retrieval with a virtual authenticator.
- GetCredential
Params - Returns a single credential stored in the given virtual authenticator that matches the credential ID.
- GetCredential
Returns - Returns a single credential stored in the given virtual authenticator that matches the credential ID.
- GetCredentials
Params - Returns all the credentials stored in the given virtual authenticator.
- GetCredentials
Returns - Returns all the credentials stored in the given virtual authenticator.
- Remove
Credential Params - Removes a credential from the authenticator.
- Remove
Virtual Authenticator Params - Removes the given authenticator.
- SetAutomatic
Presence Simulation Params - Sets whether tests of user presence will succeed immediately (if true) or fail to resolve (if false) for an authenticator. The default is true.
- SetCredential
Properties Params - Allows setting credential properties. https://w3c.github.io/webauthn/#sctn-automation-set-credential-properties
- SetResponse
Override Bits Params - Resets parameters isBogusSignature, isBadUV, isBadUP to false if they are not present.
- SetUser
Verified Params - Sets whether User Verification succeeds or fails for an authenticator. The default is true.
- Virtual
Authenticator Options