pub struct Credential {
pub credentialId: String,
pub isResidentCredential: bool,
pub rpId: Option<String>,
pub privateKey: String,
pub userHandle: Option<String>,
pub signCount: u64,
pub largeBlob: Option<String>,
pub backupEligibility: Option<bool>,
pub backupState: Option<bool>,
pub userName: Option<String>,
pub userDisplayName: Option<String>,
}Fields
credentialId: StringisResidentCredential: boolrpId: Option<String>Relying Party ID the credential is scoped to. Must be set when adding a credential.
privateKey: StringThe ECDSA P-256 private key in PKCS#8 format. (Encoded as a base64 string when passed over JSON)
userHandle: Option<String>An opaque byte sequence with a maximum size of 64 bytes mapping the credential to a specific user. (Encoded as a base64 string when passed over JSON)
signCount: u64Signature counter. This is incremented by one for each successful assertion. See https://w3c.github.io/webauthn/#signature-counter
largeBlob: Option<String>The large blob associated with the credential. See https://w3c.github.io/webauthn/#sctn-large-blob-extension (Encoded as a base64 string when passed over JSON)
backupEligibility: Option<bool>Assertions returned by this credential will have the backup eligibility (BE) flag set to this value. Defaults to the authenticator’s defaultBackupEligibility value.
backupState: Option<bool>Assertions returned by this credential will have the backup state (BS) flag set to this value. Defaults to the authenticator’s defaultBackupState value.
userName: Option<String>The credential’s user.name property. Equivalent to empty if not set. https://w3c.github.io/webauthn/#dom-publickeycredentialentity-name
userDisplayName: Option<String>The credential’s user.displayName property. Equivalent to empty if not set. https://w3c.github.io/webauthn/#dom-publickeycredentialuserentity-displayname