pub struct CredentialBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> CredentialBuilder<'a>
impl<'a> CredentialBuilder<'a>
Sourcepub fn rp_id(self, rp_id: impl Into<Cow<'a, str>>) -> Self
pub fn rp_id(self, rp_id: impl Into<Cow<'a, str>>) -> Self
Relying Party ID the credential is scoped to. Must be set when adding a credential.
Sourcepub fn user_handle(self, user_handle: impl Into<Cow<'a, str>>) -> Self
pub fn user_handle(self, user_handle: impl Into<Cow<'a, str>>) -> Self
An opaque byte sequence with a maximum size of 64 bytes mapping the credential to a specific user. (Encoded as a base64 string when passed over JSON)
Sourcepub fn large_blob(self, large_blob: impl Into<Cow<'a, str>>) -> Self
pub fn large_blob(self, large_blob: impl Into<Cow<'a, str>>) -> Self
The large blob associated with the credential. See https://w3c.github.io/webauthn/#sctn-large-blob-extension (Encoded as a base64 string when passed over JSON)
Sourcepub fn backup_eligibility(self, backup_eligibility: bool) -> Self
pub fn backup_eligibility(self, backup_eligibility: bool) -> Self
Assertions returned by this credential will have the backup eligibility (BE) flag set to this value. Defaults to the authenticator’s defaultBackupEligibility value.
Sourcepub fn backup_state(self, backup_state: bool) -> Self
pub fn backup_state(self, backup_state: bool) -> Self
Assertions returned by this credential will have the backup state (BS) flag set to this value. Defaults to the authenticator’s defaultBackupState value.
Sourcepub fn user_name(self, user_name: impl Into<Cow<'a, str>>) -> Self
pub fn user_name(self, user_name: impl Into<Cow<'a, str>>) -> Self
The credential’s user.name property. Equivalent to empty if not set. https://w3c.github.io/webauthn/#dom-publickeycredentialentity-name
Sourcepub fn user_display_name(
self,
user_display_name: impl Into<Cow<'a, str>>,
) -> Self
pub fn user_display_name( self, user_display_name: impl Into<Cow<'a, str>>, ) -> Self
The credential’s user.displayName property. Equivalent to empty if not set. https://w3c.github.io/webauthn/#dom-publickeycredentialuserentity-displayname