pub struct CredentialBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> CredentialBuilder<'a>
impl<'a> CredentialBuilder<'a>
Sourcepub fn rpId(self, rpId: impl Into<Cow<'a, str>>) -> Self
pub fn rpId(self, rpId: impl Into<Cow<'a, str>>) -> Self
Relying Party ID the credential is scoped to. Must be set when adding a credential.
Sourcepub fn userHandle(self, userHandle: impl Into<Cow<'a, str>>) -> Self
pub fn userHandle(self, userHandle: impl Into<Cow<'a, str>>) -> Self
An opaque byte sequence with a maximum size of 64 bytes mapping the credential to a specific user. (Encoded as a base64 string when passed over JSON)
Sourcepub fn largeBlob(self, largeBlob: impl Into<Cow<'a, str>>) -> Self
pub fn largeBlob(self, largeBlob: impl Into<Cow<'a, str>>) -> Self
The large blob associated with the credential. See https://w3c.github.io/webauthn/#sctn-large-blob-extension (Encoded as a base64 string when passed over JSON)
Sourcepub fn backupEligibility(self, backupEligibility: bool) -> Self
pub fn backupEligibility(self, backupEligibility: bool) -> Self
Assertions returned by this credential will have the backup eligibility (BE) flag set to this value. Defaults to the authenticator’s defaultBackupEligibility value.
Sourcepub fn backupState(self, backupState: bool) -> Self
pub fn backupState(self, backupState: bool) -> Self
Assertions returned by this credential will have the backup state (BS) flag set to this value. Defaults to the authenticator’s defaultBackupState value.
Sourcepub fn userName(self, userName: impl Into<Cow<'a, str>>) -> Self
pub fn userName(self, userName: impl Into<Cow<'a, str>>) -> Self
The credential’s user.name property. Equivalent to empty if not set. https://w3c.github.io/webauthn/#dom-publickeycredentialentity-name
Sourcepub fn userDisplayName(self, userDisplayName: impl Into<Cow<'a, str>>) -> Self
pub fn userDisplayName(self, userDisplayName: impl Into<Cow<'a, str>>) -> Self
The credential’s user.displayName property. Equivalent to empty if not set. https://w3c.github.io/webauthn/#dom-publickeycredentialuserentity-displayname