pub struct SetResponseOverrideBitsParams {
pub authenticatorId: AuthenticatorId,
pub isBogusSignature: Option<bool>,
pub isBadUV: Option<bool>,
pub isBadUP: Option<bool>,
}Expand description
Resets parameters isBogusSignature, isBadUV, isBadUP to false if they are not present.
Fields
authenticatorId: AuthenticatorIdisBogusSignature: Option<bool>If isBogusSignature is set, overrides the signature in the authenticator response to be zero. Defaults to false.
isBadUV: Option<bool>If isBadUV is set, overrides the UV bit in the flags in the authenticator response to be zero. Defaults to false.
isBadUP: Option<bool>If isBadUP is set, overrides the UP bit in the flags in the authenticator response to be zero. Defaults to false.
Implementations