pub struct SetResponseOverrideBitsParamsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> SetResponseOverrideBitsParamsBuilder<'a>
impl<'a> SetResponseOverrideBitsParamsBuilder<'a>
Sourcepub fn isBogusSignature(self, isBogusSignature: bool) -> Self
pub fn isBogusSignature(self, isBogusSignature: bool) -> Self
If isBogusSignature is set, overrides the signature in the authenticator response to be zero. Defaults to false.
Sourcepub fn isBadUV(self, isBadUV: bool) -> Self
pub fn isBadUV(self, isBadUV: bool) -> Self
If isBadUV is set, overrides the UV bit in the flags in the authenticator response to be zero. Defaults to false.
Sourcepub fn isBadUP(self, isBadUP: bool) -> Self
pub fn isBadUP(self, isBadUP: bool) -> Self
If isBadUP is set, overrides the UP bit in the flags in the authenticator response to be zero. Defaults to false.
pub fn build(self) -> SetResponseOverrideBitsParams<'a>