pub struct VirtualAuthenticatorOptions {Show 15 fields
pub protocol: AuthenticatorProtocol,
pub ctap2Version: Option<Ctap2Version>,
pub transport: AuthenticatorTransport,
pub hasResidentKey: Option<bool>,
pub hasUserVerification: Option<bool>,
pub hasLargeBlob: Option<bool>,
pub hasCredBlob: Option<bool>,
pub hasMinPinLength: Option<bool>,
pub hasPrf: Option<bool>,
pub hasHmacSecret: Option<bool>,
pub hasHmacSecretMc: Option<bool>,
pub automaticPresenceSimulation: Option<bool>,
pub isUserVerified: Option<bool>,
pub defaultBackupEligibility: Option<bool>,
pub defaultBackupState: Option<bool>,
}Fields
protocol: AuthenticatorProtocolctap2Version: Option<Ctap2Version>Defaults to ctap2_0. Ignored if |protocol| == u2f.
transport: AuthenticatorTransporthasResidentKey: Option<bool>Defaults to false.
hasUserVerification: Option<bool>Defaults to false.
hasLargeBlob: Option<bool>If set to true, the authenticator will support the largeBlob extension. https://w3c.github.io/webauthn#largeBlob Defaults to false.
hasCredBlob: Option<bool>If set to true, the authenticator will support the credBlob extension. https://fidoalliance.org/specs/fido-v2.1-rd-20201208/fido-client-to-authenticator-protocol-v2.1-rd-20201208.html#sctn-credBlob-extension Defaults to false.
hasMinPinLength: Option<bool>If set to true, the authenticator will support the minPinLength extension. https://fidoalliance.org/specs/fido-v2.1-ps-20210615/fido-client-to-authenticator-protocol-v2.1-ps-20210615.html#sctn-minpinlength-extension Defaults to false.
hasPrf: Option<bool>If set to true, the authenticator will support the prf extension. https://w3c.github.io/webauthn/#prf-extension Defaults to false.
hasHmacSecret: Option<bool>If set to true, the authenticator will support the hmac-secret extension. https://fidoalliance.org/specs/fido-v2.1-ps-20210615/fido-client-to-authenticator-protocol-v2.1-ps-20210615.html#sctn-hmac-secret-extension Defaults to false.
hasHmacSecretMc: Option<bool>If set to true, the authenticator will support the hmac-secret-mc extension. https://fidoalliance.org/specs/fido-v2.2-rd-20241003/fido-client-to-authenticator-protocol-v2.2-rd-20241003.html#sctn-hmac-secret-make-cred-extension Defaults to false.
automaticPresenceSimulation: Option<bool>If set to true, tests of user presence will succeed immediately. Otherwise, they will not be resolved. Defaults to true.
isUserVerified: Option<bool>Sets whether User Verification succeeds or fails for an authenticator. Defaults to false.
defaultBackupEligibility: Option<bool>Credentials created by this authenticator will have the backup eligibility (BE) flag set to this value. Defaults to false. https://w3c.github.io/webauthn/#sctn-credential-backup
defaultBackupState: Option<bool>Credentials created by this authenticator will have the backup state (BS) flag set to this value. Defaults to false. https://w3c.github.io/webauthn/#sctn-credential-backup