pub struct VirtualAuthenticatorOptionsBuilder { /* private fields */ }Implementations
Sourceimpl VirtualAuthenticatorOptionsBuilder
impl VirtualAuthenticatorOptionsBuilder
Sourcepub fn ctap2Version(self, ctap2Version: Ctap2Version) -> Self
pub fn ctap2Version(self, ctap2Version: Ctap2Version) -> Self
Defaults to ctap2_0. Ignored if |protocol| == u2f.
Sourcepub fn hasResidentKey(self, hasResidentKey: bool) -> Self
pub fn hasResidentKey(self, hasResidentKey: bool) -> Self
Defaults to false.
Sourcepub fn hasUserVerification(self, hasUserVerification: bool) -> Self
pub fn hasUserVerification(self, hasUserVerification: bool) -> Self
Defaults to false.
Sourcepub fn hasLargeBlob(self, hasLargeBlob: bool) -> Self
pub fn hasLargeBlob(self, hasLargeBlob: bool) -> Self
If set to true, the authenticator will support the largeBlob extension. https://w3c.github.io/webauthn#largeBlob Defaults to false.
Sourcepub fn hasCredBlob(self, hasCredBlob: bool) -> Self
pub fn hasCredBlob(self, hasCredBlob: bool) -> Self
If set to true, the authenticator will support the credBlob extension. https://fidoalliance.org/specs/fido-v2.1-rd-20201208/fido-client-to-authenticator-protocol-v2.1-rd-20201208.html#sctn-credBlob-extension Defaults to false.
Sourcepub fn hasMinPinLength(self, hasMinPinLength: bool) -> Self
pub fn hasMinPinLength(self, hasMinPinLength: bool) -> Self
If set to true, the authenticator will support the minPinLength extension. https://fidoalliance.org/specs/fido-v2.1-ps-20210615/fido-client-to-authenticator-protocol-v2.1-ps-20210615.html#sctn-minpinlength-extension Defaults to false.
Sourcepub fn hasPrf(self, hasPrf: bool) -> Self
pub fn hasPrf(self, hasPrf: bool) -> Self
If set to true, the authenticator will support the prf extension. https://w3c.github.io/webauthn/#prf-extension Defaults to false.
Sourcepub fn hasHmacSecret(self, hasHmacSecret: bool) -> Self
pub fn hasHmacSecret(self, hasHmacSecret: bool) -> Self
If set to true, the authenticator will support the hmac-secret extension. https://fidoalliance.org/specs/fido-v2.1-ps-20210615/fido-client-to-authenticator-protocol-v2.1-ps-20210615.html#sctn-hmac-secret-extension Defaults to false.
Sourcepub fn hasHmacSecretMc(self, hasHmacSecretMc: bool) -> Self
pub fn hasHmacSecretMc(self, hasHmacSecretMc: bool) -> Self
If set to true, the authenticator will support the hmac-secret-mc extension. https://fidoalliance.org/specs/fido-v2.2-rd-20241003/fido-client-to-authenticator-protocol-v2.2-rd-20241003.html#sctn-hmac-secret-make-cred-extension Defaults to false.
Sourcepub fn automaticPresenceSimulation(
self,
automaticPresenceSimulation: bool,
) -> Self
pub fn automaticPresenceSimulation( self, automaticPresenceSimulation: bool, ) -> Self
If set to true, tests of user presence will succeed immediately. Otherwise, they will not be resolved. Defaults to true.
Sourcepub fn isUserVerified(self, isUserVerified: bool) -> Self
pub fn isUserVerified(self, isUserVerified: bool) -> Self
Sets whether User Verification succeeds or fails for an authenticator. Defaults to false.
Sourcepub fn defaultBackupEligibility(self, defaultBackupEligibility: bool) -> Self
pub fn defaultBackupEligibility(self, defaultBackupEligibility: bool) -> Self
Credentials created by this authenticator will have the backup eligibility (BE) flag set to this value. Defaults to false. https://w3c.github.io/webauthn/#sctn-credential-backup
Sourcepub fn defaultBackupState(self, defaultBackupState: bool) -> Self
pub fn defaultBackupState(self, defaultBackupState: bool) -> Self
Credentials created by this authenticator will have the backup state (BS) flag set to this value. Defaults to false. https://w3c.github.io/webauthn/#sctn-credential-backup